@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5913 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-03-14 19:23:42 +0100 (Wed, 14 Mar 2012) $
+$Revision: 6469 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-23 00:54:30 +0200 (Sun, 23 Sep 2012) $
 
 ********************************************************************/
 
@@ -34,6 +34,7 @@ $Date: 2012-03-14 19:23:42 +0100 (Wed, 14 Mar 2012) $
 #include "../connectors/connectoritem.h"
 #include "../items/moduleidnames.h"
 #include "../processeventblocker.h"
+#include "../referencemodel/referencemodel.h"
 
 #include <qmath.h>
 #include <QApplication>
@@ -63,6 +64,11 @@ void Autorouter::updateRoutingStatus() {
 
 TraceWire * Autorouter::drawOneTrace(QPointF fromPos, QPointF toPos, double width, ViewLayer::ViewLayerSpec viewLayerSpec)
 {
+    if (qAbs(fromPos.x() - toPos.x()) < 0.01 && qAbs(fromPos.y() - toPos.y()) < 0.01) {
+        DebugDialog::debug("zero length trace", fromPos);
+    }
+    
+
 	long newID = ItemBase::getNextID();
 	ViewGeometry viewGeometry;
 	viewGeometry.setWireFlags(m_sketchWidget->getTraceFlag());
@@ -71,8 +77,8 @@ TraceWire * Autorouter::drawOneTrace(QPointF fromPos, QPointF toPos, double widt
 	QLineF line(0, 0, toPos.x() - fromPos.x(), toPos.y() - fromPos.y());
 	viewGeometry.setLine(line);
 
-	ItemBase * trace = m_sketchWidget->addItem(m_sketchWidget->paletteModel()->retrieveModelPart(ModuleIDNames::WireModuleIDName), 
-		  viewLayerSpec, BaseCommand::SingleView, viewGeometry, newID, -1, NULL, NULL);
+	ItemBase * trace = m_sketchWidget->addItem(m_sketchWidget->referenceModel()->retrieveModelPart(ModuleIDNames::WireModuleIDName), 
+		                                 viewLayerSpec, BaseCommand::SingleView, viewGeometry, newID, -1, NULL);
 	if (trace == NULL) {
 		// we're in trouble
 		DebugDialog::debug("autorouter unable to draw one trace");
