@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5913 $:
+$Revision: 6218 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-03-14 19:23:42 +0100 (Wed, 14 Mar 2012) $
+$Date: 2012-07-26 10:32:57 +0200 (Thu, 26 Jul 2012) $
 
 ********************************************************************/
 
@@ -49,7 +49,7 @@ $Date: 2012-03-14 19:23:42 +0100 (Wed, 14 Mar 2012) $
 #include <QComboBox>
 
 #include "../items/tracewire.h"
-#include "../items/hole.h"
+#include "../items/via.h"
 #include "../fsvgrenderer.h"
 #include "../sketch/pcbsketchwidget.h"
 #include "../utils/textutils.h"
@@ -64,14 +64,12 @@ AutorouterSettingsDialog::AutorouterSettingsDialog(QWidget *parent) : QDialog(pa
 		QSettings settings;
 		m_traceWidth = settings.value(AutorouteTraceWidth, "0").toInt();
 		if (m_traceWidth == 0) {
-			m_traceWidth = GraphicsUtils::pixels2mils(Wire::STANDARD_TRACE_WIDTH, FSvgRenderer::printerScale());
+			m_traceWidth = GraphicsUtils::pixels2mils(Wire::STANDARD_TRACE_WIDTH, GraphicsUtils::SVGDPI);
 			settings.setValue(AutorouteTraceWidth, m_traceWidth);
 		}
 	}
 
-	Hole::initHoleSettings(m_holeSettings);
-	m_holeSettings.ringThicknessRange = Via::ringThicknessRange;
-	m_holeSettings.holeDiameterRange = Via::holeDiameterRange;
+	Via::initHoleSettings(m_holeSettings);
 
 	PCBSketchWidget::getDefaultViaSize(m_holeSettings.ringThickness, m_holeSettings.holeDiameter);
 
@@ -107,7 +105,7 @@ AutorouterSettingsDialog::AutorouterSettingsDialog(QWidget *parent) : QDialog(pa
 	QVBoxLayout * viaLayout = new QVBoxLayout();
 	viaGroupBox->setLayout(viaLayout);
 
-	QWidget * viaWidget = Hole::createHoleSettings(viaGroupBox, m_holeSettings, true, "");
+	QWidget * viaWidget = Hole::createHoleSettings(viaGroupBox, m_holeSettings, true, "", true);
 
 	connect(m_holeSettings.sizesComboBox, SIGNAL(currentIndexChanged(const QString &)), this, SLOT(changeHoleSize(const QString &)));
 	connect(m_holeSettings.mmRadioButton, SIGNAL(toggled(bool)), this, SLOT(changeUnits(bool)));
@@ -176,10 +174,10 @@ void AutorouterSettingsDialog::production(bool checked) {
 
 void AutorouterSettingsDialog::acceptAnd() {
 	QSettings settings;
-	settings.setValue(Hole::AutorouteViaHoleSize, m_holeSettings.holeDiameter);
-	Hole::DefaultAutorouteViaHoleSize = m_holeSettings.holeDiameter;
-	settings.setValue(Hole::AutorouteViaRingThickness, m_holeSettings.ringThickness);
-	Hole::DefaultAutorouteViaRingThickness = m_holeSettings.ringThickness;
+	settings.setValue(Via::AutorouteViaHoleSize, m_holeSettings.holeDiameter);
+	Via::DefaultAutorouteViaHoleSize = m_holeSettings.holeDiameter;
+	settings.setValue(Via::AutorouteViaRingThickness, m_holeSettings.ringThickness);
+	Via::DefaultAutorouteViaRingThickness = m_holeSettings.ringThickness;
 	settings.setValue(AutorouteTraceWidth, m_traceWidth);
 	
 	accept();
@@ -203,14 +201,14 @@ void AutorouterSettingsDialog::enableCustom(bool enable)
 bool AutorouterSettingsDialog::initRadios() 
 {
 	bool custom = true;
-	foreach (QString name, Hole::HoleSizes.keys()) {
-		QStringList values = Hole::HoleSizes.value(name).split(",");
+	foreach (QString name, m_holeSettings.holeThing->holeSizeKeys) {
+		QStringList values = m_holeSettings.holeThing->holeSizes.value(name).split(",");
 		QString ringThickness = values[1];
 		QString holeSize = values[0];
 		if (!name.isEmpty() && !ringThickness.isEmpty() && !holeSize.isEmpty()) {
 			QRadioButton * button = NULL;
-			if (name.contains("homebrew", Qt::CaseInsensitive)) button = m_homebrewButton;
-			else if (name.contains("professional", Qt::CaseInsensitive)) button = m_professionalButton;
+			if (name.contains("home", Qt::CaseInsensitive)) button = m_homebrewButton;
+			else if (name.contains("standard", Qt::CaseInsensitive)) button = m_professionalButton;
 			if (button) {
 				button->setProperty("ringthickness", ringThickness);
 				button->setProperty("holesize", holeSize);
@@ -236,17 +234,17 @@ void AutorouterSettingsDialog::widthEntry(const QString & text) {
 
 void AutorouterSettingsDialog::changeHoleSize(const QString & newSize) {
 	QString s = newSize;
-	Hole::setHoleSize(s, false, m_holeSettings);
+	PaletteItem::setHoleSize(s, false, m_holeSettings);
 }
 
 void AutorouterSettingsDialog::changeUnits(bool) 
 {
-	QString newVal = Hole::changeUnits(m_holeSettings.currentUnits(), m_holeSettings);
+	QString newVal = PaletteItem::changeUnits(m_holeSettings);
 }
 
 void AutorouterSettingsDialog::changeDiameter() 
 {
-	if (Hole::changeDiameter(m_holeSettings, sender())) {
+	if (PaletteItem::changeDiameter(m_holeSettings, sender())) {
 		QLineEdit * edit = qobject_cast<QLineEdit *>(sender());
 		changeHoleSize(edit->text() + m_holeSettings.currentUnits() + "," + m_holeSettings.ringThickness);
 	}
@@ -254,7 +252,7 @@ void AutorouterSettingsDialog::changeDiameter()
 
 void AutorouterSettingsDialog::changeThickness() 
 {
-	if (Hole::changeThickness(m_holeSettings, sender())) {
+	if (PaletteItem::changeThickness(m_holeSettings, sender())) {
 		QLineEdit * edit = qobject_cast<QLineEdit *>(sender());
 		changeHoleSize(m_holeSettings.holeDiameter + "," + edit->text() + m_holeSettings.currentUnits());
 	}	
