@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5721 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-03 16:53:58 +0100 (Tue, 03 Jan 2012) $
+$Revision: 6557 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-12 15:09:05 +0200 (Fri, 12 Oct 2012) $
 
 ********************************************************************/
 
@@ -173,11 +173,10 @@ class CMRouter : public Autorouter
 	Q_OBJECT
 
 public:
-	CMRouter(class PCBSketchWidget *);
+	CMRouter(class PCBSketchWidget *, ItemBase * board, bool adjustIf);
 	~CMRouter(void);
 
 	void start();
-	bool drc(QString & message); 
 	void drcClean(); 
 
 public:
@@ -212,6 +211,7 @@ protected:
 	//bool findShortcut(TileRect & tileRect, bool useX, bool targetGreater, JSubedge * subedge, QList<QPointF> & allPoints, int ix);
 	//void shortenUs(QList<QPointF> & allPoints, JSubedge *);
 	void removeCorners(QList<QPointF> & allPoints, Plane *);
+	void removeColinear(QList<QPointF> & allPoints);
 	bool checkProposed(const QPointF & proposed, const QPointF & p1, const QPointF & p3, Plane *, bool atStartOrEnd); 
 	bool runEdges(QList<Edge *> &, QVector<int> & netCounters, struct RoutingStatus &, 
 					bool makeJumper, Ordering * bestOrdering);
@@ -257,7 +257,7 @@ protected:
 	bool overlapsOnly(QGraphicsItem * item, QList<Tile *> & alreadyTiled);
 	void eliminateThinTiles(QList<TileRect> & tileRects, Plane * thePlane);
 	void eliminateThinTiles2(QList<TileRect> & tileRects, Plane * thePlane);
-	void clearPlane(Plane * thePlane, bool rotate90);
+	void clearPlane(Plane * thePlane);
 	bool allowEquipotentialOverlaps(QGraphicsItem * item, QList<Tile *> & alreadyTiled);
 	PathUnit * findNearestSpace(PriorityQueue<PathUnit *> & priorityQueue, QMultiHash<Tile *, PathUnit *> & tilePathUnits, int tWidthNeeded, int tHeightNeeded, TileRect & nearestSpace);
 	bool findNearestSpaceOne(PathUnit * pathUnit, int tWidthNeeded, int tHeightNeeded, PathUnit * & nearest, int & bestCost, TileRect & nearestSpace);
@@ -297,7 +297,6 @@ protected:
 	QRectF m_maxRect;
 	TileRect m_tileMaxRect;
 	QRectF m_maxRect90;
-	TileRect m_tileMaxRect90;
 	TileRect m_overlappingTileRect;
 	QList<PathUnit *> m_pathUnits;
 	LayerList m_viewLayerIDs;
