@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5895 $:
+$Revision: 6335 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-03-06 01:43:16 +0100 (Tue, 06 Mar 2012) $
+$Date: 2012-08-27 16:13:14 +0200 (Mon, 27 Aug 2012) $
 
 ********************************************************************/
 
@@ -43,7 +43,7 @@ int BaseCommand::nextIndex = 0;
 BaseCommand::BaseCommand(BaseCommand::CrossViewType crossViewType, SketchWidget* sketchWidget, QUndoCommand *parent)
 	: QUndoCommand(parent)
 {
-	m_undoOnly = m_redoOnly = false;
+	m_skipFirstRedo = m_undoOnly = m_redoOnly = false;
 	m_crossViewType = crossViewType;
 	m_sketchWidget = sketchWidget;
 	m_parentCommand = parent;
@@ -82,6 +82,10 @@ void BaseCommand::setRedoOnly()
 	m_redoOnly = true;
 }
 
+void BaseCommand::setSkipFirstRedo() {
+    m_skipFirstRedo = true;
+}
+
 QString BaseCommand::getParamString() const {
 	return QString("%1 %2")
 		.arg(m_sketchWidget->viewName())
@@ -180,7 +184,6 @@ SketchWidget * AddDeleteItemCommand::dropOrigin() {
 AddItemCommand::AddItemCommand(SketchWidget* sketchWidget, BaseCommand::CrossViewType crossViewType, QString moduleID, ViewLayer::ViewLayerSpec viewLayerSpec, ViewGeometry & viewGeometry, qint64 id, bool updateInfoView, long modelIndex, QUndoCommand *parent)
     : AddDeleteItemCommand(sketchWidget, crossViewType, moduleID, viewLayerSpec, viewGeometry, id, modelIndex, parent)
 {
-	m_doFirstRedo = m_firstRedo = true;
 	m_module = false;
 	m_updateInfoView = updateInfoView;
 }
@@ -192,18 +195,19 @@ void AddItemCommand::undo()
 
 void AddItemCommand::redo()
 {
-	if (!m_firstRedo || m_doFirstRedo) {
+	if (!m_skipFirstRedo) {
 		m_sketchWidget->addItem(m_moduleID, m_viewLayerSpec, m_crossViewType, m_viewGeometry, m_itemID, m_modelIndex, this);
 	}
-	m_firstRedo = false;
-}
-
-void AddItemCommand::turnOffFirstRedo() {
-	m_doFirstRedo = false;
+	m_skipFirstRedo = false;
 }
 
 QString AddItemCommand::getParamString() const {
-	return "AddItemCommand " + AddDeleteItemCommand::getParamString();
+	return "AddItemCommand " + AddDeleteItemCommand::getParamString() +
+        QString(" loc:%1,%2 pt1:%3,%4 pt2:%5,%6")
+            .arg(m_viewGeometry.loc().x()).arg(m_viewGeometry.loc().y())
+            .arg(m_viewGeometry.line().p1().x()).arg(m_viewGeometry.line().p1().y())
+            .arg(m_viewGeometry.line().p2().x()).arg(m_viewGeometry.line().p2().y())
+        ;
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -499,7 +503,6 @@ ChangeWireCurveCommand::ChangeWireCurveCommand(SketchWidget* sketchWidget, long
 									 QUndoCommand *parent)
     : BaseCommand(BaseCommand::SingleView, sketchWidget, parent)
 {
-	m_firstTime = false;
     m_fromID = fromID;
 	m_oldBezier = m_newBezier = NULL;
 	if (oldBezier) {
@@ -522,8 +525,8 @@ void ChangeWireCurveCommand::undo()
 void ChangeWireCurveCommand::redo()
 {
 	if (!m_undoOnly) {
-		if (m_firstTime) {
-			m_firstTime = false;
+		if (m_skipFirstRedo) {
+			m_skipFirstRedo = false;
 		}
 		else {
 			m_sketchWidget->changeWireCurve(m_fromID, m_newBezier);
@@ -531,10 +534,6 @@ void ChangeWireCurveCommand::redo()
 	}
 }
 
-void ChangeWireCurveCommand::setFirstTime() {
-	m_firstTime = true;
-}
-
 QString ChangeWireCurveCommand::getParamString() const {
 	QString oldBezier;
 	QString newBezier;
@@ -666,7 +665,6 @@ ChangeLegCurveCommand::ChangeLegCurveCommand(SketchWidget* sketchWidget, long fr
 									 const Bezier * oldBezier, const Bezier * newBezier, QUndoCommand *parent)
     : BaseCommand(BaseCommand::SingleView, sketchWidget, parent)
 {
-	m_firstTime = false;
     m_fromID = fromID;
 	m_oldBezier = m_newBezier = NULL;
 	if (oldBezier) {
@@ -689,18 +687,14 @@ void ChangeLegCurveCommand::undo()
 
 void ChangeLegCurveCommand::redo()
 {
-	if (m_firstTime) {
-		m_firstTime = false;
+	if (m_skipFirstRedo) {
+		m_skipFirstRedo = false;
 	}
 	else if (!m_undoOnly) {
 		m_sketchWidget->changeLegCurve(m_fromID, m_fromConnectorID, m_index, m_newBezier);
 	}
 }
 
-void ChangeLegCurveCommand::setFirstTime() {
-	m_firstTime = true;
-}
-
 QString ChangeLegCurveCommand::getParamString() const {
 	QString oldBezier;
 	QString newBezier;
@@ -729,7 +723,6 @@ ChangeLegBendpointCommand::ChangeLegBendpointCommand(SketchWidget* sketchWidget,
 									const Bezier * bezier0, const Bezier * bezier1, const Bezier * bezier2, QUndoCommand *parent)
     : BaseCommand(BaseCommand::SingleView, sketchWidget, parent)
 {
-	m_firstTime = false;
     m_fromID = fromID;
 	m_bezier0 = m_bezier1 = m_bezier2 = NULL;
 	if (bezier0 != NULL) {
@@ -764,8 +757,8 @@ void ChangeLegBendpointCommand::undo()
 
 void ChangeLegBendpointCommand::redo()
 {
-	if (m_firstTime) {
-		m_firstTime = false;
+	if (m_skipFirstRedo) {
+		m_skipFirstRedo = false;
 	}
 	else {
 		if (m_newCount > m_oldCount) {
@@ -777,10 +770,6 @@ void ChangeLegBendpointCommand::redo()
 	}
 }
 
-void ChangeLegBendpointCommand::setFirstTime() {
-	m_firstTime = true;
-}
-
 QString ChangeLegBendpointCommand::getParamString() const {
 	QString bezier;
 	if (m_bezier0) {
@@ -1032,7 +1021,7 @@ CheckStickyCommand::CheckStickyCommand(SketchWidget* sketchWidget, BaseCommand::
 : BaseCommand(crossViewType, sketchWidget, parent)
 {
 	m_itemID = itemID;
-	m_firstTime = true;
+	m_skipFirstRedo = true;
 	m_checkType = checkType;
 	m_checkCurrent = checkCurrent;
 }
@@ -1063,9 +1052,9 @@ void CheckStickyCommand::redo()
 {
 	if (m_checkType == UndoOnly) return;
 
-	if (m_firstTime) {
+	if (m_skipFirstRedo) {
 		m_sketchWidget->checkSticky(m_itemID, m_crossViewType == BaseCommand::CrossView, m_checkCurrent, this);
-		m_firstTime = false;
+		m_skipFirstRedo = false;
 	}
 	else {
 		foreach (StickyThing * stickyThing, m_stickyList) {
@@ -1082,7 +1071,6 @@ QString CheckStickyCommand::getParamString() const {
 }
 
 void CheckStickyCommand::stick(SketchWidget * sketchWidget, long fromID, long toID, bool stickem) {
-	m_firstTime = false;
 	StickyThing * stickyThing = new StickyThing;
 	stickyThing->sketchWidget = sketchWidget;
 	stickyThing->fromID = fromID;
@@ -1408,11 +1396,11 @@ ChangeLabelTextCommand::ChangeLabelTextCommand(SketchWidget *sketchWidget, long
 }
 
 void ChangeLabelTextCommand::undo() {
-	m_sketchWidget->setInstanceTitle(m_itemID, m_oldText, false, true);
+	m_sketchWidget->setInstanceTitle(m_itemID, m_newText, m_oldText, false, true);
 }
 
 void ChangeLabelTextCommand::redo() {
-    m_sketchWidget->setInstanceTitle(m_itemID, m_newText, false, true);
+    m_sketchWidget->setInstanceTitle(m_itemID, m_oldText, m_newText, false, true);
 }
 
 QString ChangeLabelTextCommand::getParamString() const {
@@ -1429,7 +1417,6 @@ IncLabelTextCommand::IncLabelTextCommand(SketchWidget *sketchWidget, long id,  Q
 	: BaseCommand(BaseCommand::CrossView, sketchWidget, parent)
 {
     m_itemID = id;
-	m_firstTime = true;
 }
 
 void IncLabelTextCommand::undo() { 
@@ -1437,7 +1424,7 @@ void IncLabelTextCommand::undo() {
 }
 
 void IncLabelTextCommand::redo() {
-	if (m_firstTime) {
+	if (!m_skipFirstRedo) {
 		m_sketchWidget->incInstanceTitle(m_itemID);
 	}
 }
@@ -1460,7 +1447,6 @@ ChangeNoteTextCommand::ChangeNoteTextCommand(SketchWidget *sketchWidget, long id
     m_newText = newText;
 	m_oldSize = oldSize;
 	m_newSize = newSize;
-	m_firstTime = true;
 }
 
 void ChangeNoteTextCommand::undo() {
@@ -1471,8 +1457,8 @@ void ChangeNoteTextCommand::undo() {
 }
 
 void ChangeNoteTextCommand::redo() {
-	if (m_firstTime) {
-		m_firstTime = false;
+	if (m_skipFirstRedo) {
+		m_skipFirstRedo = false;
 		return;
 	}
 
@@ -1480,11 +1466,6 @@ void ChangeNoteTextCommand::redo() {
 	if (m_oldSize != m_newSize) {
 		m_sketchWidget->resizeNote(m_itemID, m_newSize);
 	}
-
-}
-
-void ChangeNoteTextCommand::setFirstTime(bool f) {
-	m_firstTime = f;
 }
 
 int ChangeNoteTextCommand::id() const {
@@ -1590,11 +1571,15 @@ ResizeBoardCommand::ResizeBoardCommand(SketchWidget * sketchWidget, long itemID,
 }
 
 void ResizeBoardCommand::undo() {
-	m_sketchWidget->resizeBoard(m_itemID, m_oldWidth, m_oldHeight);
+    if (!m_redoOnly) {
+	    m_sketchWidget->resizeBoard(m_itemID, m_oldWidth, m_oldHeight);
+    }
 }
 
 void ResizeBoardCommand::redo() {
-	m_sketchWidget->resizeBoard(m_itemID, m_newWidth, m_newHeight);
+    if (!m_undoOnly) {
+	    m_sketchWidget->resizeBoard(m_itemID, m_newWidth, m_newHeight);
+    }
 }
 
 QString ResizeBoardCommand::getParamString() const {
@@ -1786,13 +1771,15 @@ LoadLogoImageCommand::LoadLogoImageCommand(SketchWidget *sketchWidget, long id,
 }
 
 void LoadLogoImageCommand::undo() {
-	m_sketchWidget->loadLogoImage(m_itemID, m_oldSvg, m_oldAspectRatio, m_oldFilename);
+    if (!m_redoOnly) {
+	    m_sketchWidget->loadLogoImage(m_itemID, m_oldSvg, m_oldAspectRatio, m_oldFilename);
+    }
 }
 
 void LoadLogoImageCommand::redo() {
 	if (m_newFilename.isEmpty()) {
 	}
-	else {
+	else if (!m_undoOnly) {
 		m_sketchWidget->loadLogoImage(m_itemID, m_newFilename, m_addName);
 	}
 }
@@ -1964,3 +1951,23 @@ QString WireExtrasCommand::getParamString() const {
 		;
 }
 
+////////////////////////////////////
+
+
+TemporaryCommand::TemporaryCommand(const QString & text) : QUndoCommand(text) {
+    m_enabled = true;
+}
+
+TemporaryCommand::~TemporaryCommand() {
+}
+
+void TemporaryCommand::setEnabled(bool enabled) {
+    m_enabled = enabled;
+}
+
+ void TemporaryCommand::redo() {
+     if (m_enabled) {
+         QUndoCommand::redo();
+     }
+}
+
