@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5721 $:
+$Revision: 6309 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-01-03 16:53:58 +0100 (Tue, 03 Jan 2012) $
+$Date: 2012-08-17 11:16:43 +0200 (Fri, 17 Aug 2012) $
 
 ********************************************************************/
 
@@ -40,7 +40,7 @@ public:
 	BusShared(const QDomElement & busElement, const QHash<QString, QPointer<class ConnectorShared> > & connectorHash);
 	BusShared(const QString & id);
 
-	const QString & id();
+	const QString & id() const;
 	const QList<class ConnectorShared *> & connectors();
 	void addConnectorShared(class ConnectorShared *);
 
