@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5721 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-01-03 16:53:58 +0100 (Tue, 03 Jan 2012) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -34,8 +34,9 @@ $Date: 2012-01-03 16:53:58 +0100 (Tue, 03 Jan 2012) $
 #include "ercdata.h"
 
 QHash <Connector::ConnectorType, QString > Connector::Names;
+static const QList<SvgIdLayer *> EmptySvgIdLayerList;
 
-static inline int QuickHash(ViewIdentifierClass::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID) {
+static inline int QuickHash(ViewLayer::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID) {
 	return (1000 * viewIdentifier) + viewLayerID;
 }
 
@@ -79,7 +80,7 @@ const QString & Connector::connectorNameFromType(ConnectorType type) {
 	return Names[type];
 }
 
-Connector::ConnectorType Connector::connectorType() {
+Connector::ConnectorType Connector::connectorType() const {
 	if (m_connectorShared != NULL) {
 		return m_connectorShared->connectorType();
 	}
@@ -130,9 +131,9 @@ void Connector::saveAsPart(QXmlStreamWriter & writer) {
 	writer.writeAttribute("name", connectorShared()->sharedName());
 	writer.writeTextElement("description", connectorShared()->description());
 	writer.writeStartElement("views");
-	QMultiHash<ViewIdentifierClass::ViewIdentifier,SvgIdLayer *> pins = m_connectorShared->pins();
-	foreach (ViewIdentifierClass::ViewIdentifier currView, pins.uniqueKeys()) {
-		writer.writeStartElement(ViewIdentifierClass::viewIdentifierXmlName(currView));
+	QMultiHash<ViewLayer::ViewIdentifier,SvgIdLayer *> pins = m_connectorShared->pins();
+	foreach (ViewLayer::ViewIdentifier currView, pins.uniqueKeys()) {
+		writer.writeStartElement(ViewLayer::viewIdentifierXmlName(currView));
 		foreach (SvgIdLayer * svgIdLayer, pins.values(currView)) {
 			writer.writeStartElement("p");
 			writeLayerAttr(writer, svgIdLayer->m_svgViewLayerID);
@@ -150,13 +151,13 @@ void Connector::writeLayerAttr(QXmlStreamWriter &writer, ViewLayer::ViewLayerID
 	writer.writeAttribute("layer",ViewLayer::viewLayerXmlNameFromID(viewLayerID));
 }
 
-void Connector::writeSvgIdAttr(QXmlStreamWriter &writer, ViewIdentifierClass::ViewIdentifier view, QString connId) {
+void Connector::writeSvgIdAttr(QXmlStreamWriter &writer, ViewLayer::ViewIdentifier view, QString connId) {
 	Q_UNUSED(view);
 	writer.writeAttribute("svgId",connId);
 }
 
-void Connector::writeTerminalIdAttr(QXmlStreamWriter &writer, ViewIdentifierClass::ViewIdentifier view, QString terminalId) {
-        if((view == ViewIdentifierClass::BreadboardView || view == ViewIdentifierClass::SchematicView)
+void Connector::writeTerminalIdAttr(QXmlStreamWriter &writer, ViewLayer::ViewIdentifier view, QString terminalId) {
+        if((view == ViewLayer::BreadboardView || view == ViewLayer::SchematicView)
             &&
            (!terminalId.isNull() && !terminalId.isEmpty()) ) {
 		writer.writeAttribute("terminalId",terminalId);
@@ -169,7 +170,7 @@ const QList<Connector *> & Connector::toConnectors() {
 	return m_toConnectors;
 }
 
-ConnectorItem * Connector::connectorItemByViewLayerID(ViewIdentifierClass::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID) {
+ConnectorItem * Connector::connectorItemByViewLayerID(ViewLayer::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID) {
 	return m_connectorItems.value(QuickHash(viewIdentifier, viewLayerID), NULL);
 }
 
@@ -186,13 +187,13 @@ bool Connector::connectionIsAllowed(Connector* that)
 	return (thisConnectorType != thatConnectorType);		// otherwise heterosexual
 }
 
-const QString & Connector::connectorSharedID() {
+const QString & Connector::connectorSharedID() const {
 	if (m_connectorShared == NULL) return ___emptyString___;
 
 	return m_connectorShared->id();
 }
 
-const QString & Connector::connectorSharedName() {
+const QString & Connector::connectorSharedName() const {
 	if (m_connectorShared == NULL) return ___emptyString___;
 
 	if (!m_connectorLocalName.isEmpty()) {
@@ -202,7 +203,7 @@ const QString & Connector::connectorSharedName() {
 	return m_connectorShared->sharedName();
 }
 
-const QString & Connector::connectorSharedDescription() {
+const QString & Connector::connectorSharedDescription() const {
 	if (m_connectorShared == NULL) return ___emptyString___;
 
 	return m_connectorShared->description();
@@ -228,14 +229,14 @@ void Connector::setBus(Bus * bus) {
 	m_bus = bus;
 }
 
-void Connector::unprocess(ViewIdentifierClass::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID) {
+void Connector::unprocess(ViewLayer::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID) {
 	SvgIdLayer * svgIdLayer = m_connectorShared->fullPinInfo(viewIdentifier, viewLayerID);
 	if (svgIdLayer != NULL) {
 		svgIdLayer->m_processed = false;
 	}
 }
 
-SvgIdLayer * Connector::fullPinInfo(ViewIdentifierClass::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID) {
+SvgIdLayer * Connector::fullPinInfo(ViewLayer::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID) {
 	if (m_connectorShared == NULL) return NULL;
 
 	return m_connectorShared->fullPinInfo(viewIdentifier, viewLayerID);
@@ -261,7 +262,7 @@ QList< QPointer<ConnectorItem> > Connector::viewItems() {
 	return m_connectorItems.values();
 }
 
-const QString & Connector::legID(ViewIdentifierClass::ViewIdentifier viewID, ViewLayer::ViewLayerID viewLayerID) {
+const QString & Connector::legID(ViewLayer::ViewIdentifier viewID, ViewLayer::ViewLayerID viewLayerID) {
 	if (m_connectorShared) return m_connectorShared->legID(viewID, viewLayerID);
 
 	return ___emptyString___;
@@ -279,3 +280,14 @@ void Connector::setConnectorLocalName(const QString & name) {
 const QString & Connector::connectorLocalName() {
 	return m_connectorLocalName;
 }
+
+const QList<SvgIdLayer *> Connector::svgIdLayers() const {
+    if (m_connectorShared) return m_connectorShared->svgIdLayers();
+
+    return EmptySvgIdLayerList;
+}
+
+void Connector::addPin(ViewLayer::ViewIdentifier viewIdentifier, const QString & svgId, ViewLayer::ViewLayerID viewLayerId, const QString & terminalId, const QString & legId, bool hybrid)
+{
+    if (m_connectorShared) m_connectorShared->addPin(viewIdentifier, svgId, viewLayerId, terminalId, legId, hybrid);
+}
