@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5666 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2011-12-05 18:07:55 +0100 (Mon, 05 Dec 2011) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -35,7 +35,6 @@ $Date: 2011-12-05 18:07:55 +0100 (Mon, 05 Dec 2011) $
 #include <QSvgRenderer>
 #include <QPointer>
 
-#include "../viewidentifierclass.h"
 #include "../viewlayer.h"
 
 class Connector : public QObject
@@ -54,7 +53,7 @@ public:
 	Connector(class ConnectorShared *, class ModelPart * modelPart);
 	~Connector();
 
-	Connector::ConnectorType connectorType();
+	Connector::ConnectorType connectorType() const;
 	void addViewItem(class ConnectorItem *);
 	void removeViewItem(class ConnectorItem *);
 	class ConnectorShared * connectorShared();
@@ -62,11 +61,11 @@ public:
 	void disconnectFrom(Connector *);
 	void saveAsPart(QXmlStreamWriter & writer);
 	const QList<Connector *> & toConnectors();
-	ConnectorItem * connectorItemByViewLayerID(ViewIdentifierClass::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID);
+	ConnectorItem * connectorItemByViewLayerID(ViewLayer::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID);
 	bool connectionIsAllowed(Connector* that);
-	const QString & connectorSharedID();
-	const QString & connectorSharedName();	
-	const QString & connectorSharedDescription();
+	const QString & connectorSharedID() const;
+	const QString & connectorSharedName() const;	
+	const QString & connectorSharedDescription() const;
 	class ErcData * connectorSharedErcData();
 	const QString & busID();
 	class Bus * bus();
@@ -74,12 +73,14 @@ public:
 	long modelIndex();
 	ModelPart * modelPart();
 	int connectorItemCount();
-	void unprocess(ViewIdentifierClass::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID);
-	struct SvgIdLayer * fullPinInfo(ViewIdentifierClass::ViewIdentifier viewId, ViewLayer::ViewLayerID viewLayerID);
+	void unprocess(ViewLayer::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID);
+	struct SvgIdLayer * fullPinInfo(ViewLayer::ViewIdentifier viewId, ViewLayer::ViewLayerID viewLayerID);
+	const QList<SvgIdLayer *> svgIdLayers() const;
 	QList< QPointer<class ConnectorItem> > viewItems();
-	const QString & legID(ViewIdentifierClass::ViewIdentifier, ViewLayer::ViewLayerID);
+	const QString & legID(ViewLayer::ViewIdentifier, ViewLayer::ViewLayerID);
 	void setConnectorLocalName(const QString &);
 	const QString & connectorLocalName();
+	void addPin(ViewLayer::ViewIdentifier, const QString & svgId, ViewLayer::ViewLayerID, const QString & terminalId, const QString & legId, bool hybrid);
 
 public:
 	static void initNames();
@@ -88,8 +89,8 @@ public:
 
 protected:
 	void writeLayerAttr(QXmlStreamWriter &writer, ViewLayer::ViewLayerID);
-	void writeSvgIdAttr(QXmlStreamWriter &writer, ViewIdentifierClass::ViewIdentifier view, QString connId);
-	void writeTerminalIdAttr(QXmlStreamWriter &writer, ViewIdentifierClass::ViewIdentifier view, QString terminalId);
+	void writeSvgIdAttr(QXmlStreamWriter &writer, ViewLayer::ViewIdentifier view, QString connId);
+	void writeTerminalIdAttr(QXmlStreamWriter &writer, ViewLayer::ViewIdentifier view, QString terminalId);
 
 protected:
 	QPointer<class ConnectorShared> m_connectorShared;
