@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5939 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-03 09:44:37 +0200 (Tue, 03 Apr 2012) $
+$Revision: 6460 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-20 17:37:06 +0200 (Thu, 20 Sep 2012) $
 
 ********************************************************************/
 
@@ -844,7 +844,7 @@ void ConnectorItem::mousePressEvent(QGraphicsSceneMouseEvent *event) {
 		connectorItem->showEqualPotential(true);
 	}
 	
-	if (m_rubberBandLeg) {
+	if (m_rubberBandLeg && this->m_attachedTo != NULL && m_attachedTo->acceptsMousePressLegEvent(this, event)) {
 		if (legMousePressEvent(event)) return;
 	}
 
@@ -862,17 +862,31 @@ int ConnectorItem::connectionsCount() {
 
 void ConnectorItem::attachedMoved() {
 	//DebugDialog::debug("attached moved");
-	foreach (ConnectorItem * toConnector, m_connectedTo) {
-		ItemBase * itemBase = toConnector->attachedTo();
+    if (!this->isVisible()) return;
+
+    QSet<ConnectorItem *> allTo;
+    allTo.insert(this);
+	foreach (ConnectorItem * toConnectorItem, m_connectedTo) {
+        allTo.insert(toConnectorItem);
+        foreach (ConnectorItem * subTo, toConnectorItem->connectedToItems()) {
+            allTo.insert(subTo);
+        }
+	}
+    allTo.remove(this);
+    foreach (ConnectorItem * toConnectorItem, allTo) {
+        ItemBase * itemBase = toConnectorItem->attachedTo();
 		if (itemBase == NULL) continue;
 		if (!itemBase->isVisible()) {
 			//this->debugInfo("continue");
 			//itemBase->debugInfo("    ");
 			continue;
 		}
+        if (itemBase->getRatsnest()) {
+            continue;
+        }
 
-		itemBase->connectedMoved(this, toConnector);
-	}
+        toConnectorItem->attachedTo()->connectedMoved(this, toConnectorItem);
+    }
 }
 
 ConnectorItem * ConnectorItem::firstConnectedToIsh() {
@@ -1081,8 +1095,8 @@ ViewLayer::ViewLayerSpec ConnectorItem::attachedToViewLayerSpec() {
 	return m_attachedTo->viewLayerSpec();
 }
 
-ViewIdentifierClass::ViewIdentifier ConnectorItem::attachedToViewIdentifier() {
-	if (m_attachedTo == NULL) return ViewIdentifierClass::UnknownView;
+ViewLayer::ViewIdentifier ConnectorItem::attachedToViewIdentifier() {
+	if (m_attachedTo == NULL) return ViewLayer::UnknownView;
 
 	return m_attachedTo->viewIdentifier();
 }
@@ -1456,11 +1470,39 @@ void ConnectorItem::collectPart(ConnectorItem * connectorItem, QList<ConnectorIt
 }
 
 void ConnectorItem::updateTooltip() {
-	QList<ConnectorItem *> connectors;
-	if (!attachedToItemType() == ModelPart::Wire) {
-		connectors.append(this);
+	if (attachedToItemType() != ModelPart::Wire) {
+		QString name = connectorSharedName();
+		QString descr = connectorSharedDescription();
+        if (name == descr) {
+            descr = "";
+        }
+        else {
+            descr = ":" + descr;
+        }
+        QString id = connectorSharedID();
+        int ix = IntegerFinder.indexIn(id);
+        if (ix < 0) {
+            id = "";
+        }
+        else {
+            if (attachedTo()->modelPart()->hasZeroConnector()) {
+                id = QString::number(IntegerFinder.cap(0).toInt() + 1) + " ";
+            }
+            else {
+                id = IntegerFinder.cap(0) + " ";
+            }
+        }
+       
+        QString tt = QString("%1<b>%2</b>%3<br /><span style='font-size:small;'>%4</span>")
+                .arg(id)
+                .arg(name)
+                .arg(descr)
+                .arg(attachedToTitle());
+		setToolTip(tt);
+		return;
 	}
 
+	QList<ConnectorItem *> connectors;
 	foreach(ConnectorItem * toConnectorItem, m_connectedTo) {
 		if (!toConnectorItem->attachedToItemType() == ModelPart::Wire) {
 			connectors.append(toConnectorItem);
@@ -1472,19 +1514,6 @@ void ConnectorItem::updateTooltip() {
 		return;
 	}
 
-	if (connectors.count() == 1) {
-		QString name = connectors[0]->connectorSharedName();
-		QString descr = connectors[0]->connectorSharedDescription();
-		if (name.compare(descr) == 0) {
-			name = connectors[0]->connectorSharedID();
-		}
-        QString tt = QString("<b>%1</b>: %2<br /><span style='font-size:small;'>%3</span>")
-                .arg(name)
-                .arg(descr)
-                .arg(connectors[0]->attachedToTitle());
-		setToolTip(tt);
-		return;
-	}
 
 	QString connections = QString("<ul style='margin-left:0;padding-left:0;'>");
 	foreach(ConnectorItem * connectorItem, connectors) {
@@ -1568,7 +1597,7 @@ bool ConnectorItem::isGrounded() {
 ConnectorItem * ConnectorItem::getCrossLayerConnectorItem() {
 	if (m_connector == NULL) return NULL;
 	if (m_attachedTo == NULL) return NULL;
-	if (m_attachedTo->viewIdentifier() != ViewIdentifierClass::PCBView) return NULL;
+	if (m_attachedTo->viewIdentifier() != ViewLayer::PCBView) return NULL;
 
 	ViewLayer::ViewLayerID viewLayerID = attachedToViewLayerID();
 	if (viewLayerID == ViewLayer::Copper0) {
@@ -1618,7 +1647,7 @@ void ConnectorItem::paint(QPainter * painter, const QStyleOptionGraphicsItem * o
 
 	if (m_effectively == EffectivelyUnknown) {
 		if (!m_circular && m_shape.isEmpty()) {
-			if (this->attachedTo()->viewIdentifier() == ViewIdentifierClass::PCBView) {
+			if (this->attachedTo()->viewIdentifier() == ViewLayer::PCBView) {
 				QRectF r = rect();
 				if (qAbs(r.width() - r.height()) < 0.01) m_effectively = EffectivelyCircular;
 				else m_effectively = EffectivelyRectangular;
@@ -1815,7 +1844,7 @@ void ConnectorItem::displayRatsnest(QList<ConnectorItem *> & partConnectorItems,
 
 	foreach (ConnectorItem * key, result.uniqueKeys()) {
 		foreach (ConnectorItem * value, result.values(key)) {
-			VirtualWire * vw = infoGraphicsView->makeOneRatsnestWire(key, value, false, color);
+			VirtualWire * vw = infoGraphicsView->makeOneRatsnestWire(key, value, false, color, false);
 			if (vw) {
 				vw->setColorWasNamed(colorWasNamed);
 			}
@@ -1896,7 +1925,7 @@ void ConnectorItem::debugInfo(const QString & msg)
 {
 
 #ifndef QT_NO_DEBUG
-	QString s = QString("%1 cid:%2 %3 %4 id:%5 %6 vlid:%7 vid:%8 spec:%9 flg:%10 hy:%11 bus:%12")
+	QString s = QString("%1 cid:%2 %3 %4 id:%5 %6 vlid:%7 vid:%8 spec:%9 flg:%10 hy:%11 bus:%12 r:%13 sw:%14")
 	//QString s = QString("%1 %2 %3 %4 id:%5 %6 vlid:%7 vid:%8")
 			.arg(msg)
 			.arg(this->connectorSharedID())
@@ -1907,9 +1936,12 @@ void ConnectorItem::debugInfo(const QString & msg)
 			.arg(this->attachedToViewLayerID())
 			.arg(this->attachedToViewIdentifier())
 			.arg(this->attachedToViewLayerSpec())
-			.arg(this->attachedTo()->wireFlags())
+			.arg(this->attachedTo()->wireFlags()) 
 			.arg(this->m_hybrid)
-			.arg((long) this->bus(), 0, 16);
+			.arg((long) this->bus(), 0, 16)
+            .arg(this->m_radius)
+            .arg(this->m_strokeWidth)
+            ;
 	//s.replace(" ", "_");
 	DebugDialog::debug(s);
 #else
@@ -2317,7 +2349,7 @@ double ConnectorItem::findT(Bezier * bezier, double blen, double length)
 	return t;
 }
 
-const QString & ConnectorItem::legID(ViewIdentifierClass::ViewIdentifier viewID, ViewLayer::ViewLayerID viewLayerID) {
+const QString & ConnectorItem::legID(ViewLayer::ViewIdentifier viewID, ViewLayer::ViewLayerID viewLayerID) {
 	if (m_connector) return m_connector->legID(viewID, viewLayerID);
 
 	return ___emptyString___;
@@ -2744,7 +2776,7 @@ void ConnectorItem::updateWireCursor(Qt::KeyboardModifiers modifiers)
 	if (isBendpoint()) {
 		//DebugDialog::debug("uwc bend");
 		if (modifiers & altOrMetaModifier()) {
-			DebugDialog::debug("uwc alt");
+			//DebugDialog::debug("uwc alt");
 			Wire * wire = qobject_cast<Wire *>(attachedTo());
 			if (wire != NULL && wire->canChainMultiple()) {
 				//DebugDialog::debug("uwc make wire");
