@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5935 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-04-01 00:22:41 +0200 (Sun, 01 Apr 2012) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -81,7 +81,7 @@ public:
 	int attachedToItemType();
 	ViewLayer::ViewLayerID attachedToViewLayerID();
 	ViewLayer::ViewLayerSpec attachedToViewLayerSpec();
-	ViewIdentifierClass::ViewIdentifier attachedToViewIdentifier();
+	ViewLayer::ViewIdentifier attachedToViewIdentifier();
 	const QString & connectorSharedID();
 	const QString & connectorSharedName();
 	const QString & connectorSharedDescription();
@@ -141,7 +141,7 @@ public:
 	void moveDone(int & index0, QPointF & oldPos0, QPointF & newPos0, int & index1, QPointF & oldPos1, QPointF & newPos1);
 	void killRubberBandLeg();  // hack; see caller
 	QRectF boundingRect() const;
-	const QString & legID(ViewIdentifierClass::ViewIdentifier, ViewLayer::ViewLayerID);
+	const QString & legID(ViewLayer::ViewIdentifier, ViewLayer::ViewLayerID);
 	QPainterPath shape() const;
 	QPainterPath hoverShape() const;
 	void changeLegCurve(int index, const class Bezier *);
