@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5928 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-03-25 13:15:25 +0200 (Sun, 25 Mar 2012) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -104,6 +104,7 @@ void ConnectorShared::setDescription(QString description) {
 const QString & ConnectorShared::sharedName() {
 	return m_name;
 }
+
 void ConnectorShared::setSharedName(QString name) {
 	m_name = name;
 }
@@ -121,35 +122,42 @@ void ConnectorShared::setConnectorType(QString type) {
 	m_type = Connector::connectorTypeFromName(type);
 }
 
-const QMultiHash<ViewIdentifierClass::ViewIdentifier,SvgIdLayer*> & ConnectorShared::pins() {
+void ConnectorShared::setConnectorType(Connector::ConnectorType type) {
+	m_typeString = Connector::connectorNameFromType(type);
+	m_type = type;
+}
+
+const QMultiHash<ViewLayer::ViewIdentifier,SvgIdLayer*> & ConnectorShared::pins() {
 	return m_pins;
 }
 
-void ConnectorShared::insertPin(ViewIdentifierClass::ViewIdentifier layer, SvgIdLayer * svgIdLayer) {
+void ConnectorShared::insertPin(ViewLayer::ViewIdentifier layer, SvgIdLayer * svgIdLayer) {
 	m_pins.insert(layer, svgIdLayer);
 }
 
-void ConnectorShared::addPin(ViewIdentifierClass::ViewIdentifier layer, QString connectorId, ViewLayer::ViewLayerID viewLayerID, QString terminalId) {
-	SvgIdLayer * svgIdLayer = new SvgIdLayer;
+void ConnectorShared::addPin(ViewLayer::ViewIdentifier viewIdentifier, const QString & svgId, ViewLayer::ViewLayerID viewLayerID, const QString & terminalId, const QString & legId, bool hybrid) {
+	SvgIdLayer * svgIdLayer = new SvgIdLayer(viewIdentifier);
 	svgIdLayer->m_svgViewLayerID = viewLayerID;
-	svgIdLayer->m_svgId = connectorId;
+	svgIdLayer->m_svgId = svgId;
 	svgIdLayer->m_terminalId = terminalId;
-	m_pins.insert(layer, svgIdLayer);
+    svgIdLayer->m_hybrid = hybrid;
+    svgIdLayer->m_legId = legId;
+	m_pins.insert(viewIdentifier, svgIdLayer);
 	// DebugDialog::debug(QString("insert a %1 %2 %3").arg(layer).arg(connectorId).arg(viewLayerID));
 }
 
-void ConnectorShared::removePins(ViewIdentifierClass::ViewIdentifier layer) {
+void ConnectorShared::removePins(ViewLayer::ViewIdentifier layer) {
 	m_pins.remove(layer);
 	if (m_pins.values(layer).size() != 0) {
 		throw "ConnectorShared::removePins";
 	}
 }
 
-void ConnectorShared::removePin(ViewIdentifierClass::ViewIdentifier layer, SvgIdLayer * svgIdLayer) {
+void ConnectorShared::removePin(ViewLayer::ViewIdentifier layer, SvgIdLayer * svgIdLayer) {
 	m_pins.remove(layer, svgIdLayer);
 }
 
-SvgIdLayer * ConnectorShared::fullPinInfo(ViewIdentifierClass::ViewIdentifier viewId, ViewLayer::ViewLayerID viewLayerID) {
+SvgIdLayer * ConnectorShared::fullPinInfo(ViewLayer::ViewIdentifier viewId, ViewLayer::ViewLayerID viewLayerID) {
 	QList<SvgIdLayer *> svgLayers = m_pins.values(viewId);
 	foreach ( SvgIdLayer * svgIdLayer, svgLayers) {
 		if (svgIdLayer->m_svgViewLayerID == viewLayerID) {
@@ -160,7 +168,7 @@ SvgIdLayer * ConnectorShared::fullPinInfo(ViewIdentifierClass::ViewIdentifier vi
 	return NULL;
 }
 
-const QString & ConnectorShared::legID(ViewIdentifierClass::ViewIdentifier viewId, ViewLayer::ViewLayerID viewLayerID) {
+const QString & ConnectorShared::legID(ViewLayer::ViewIdentifier viewId, ViewLayer::ViewLayerID viewLayerID) {
 	QList<SvgIdLayer *> svgLayers = m_pins.values(viewId);
 	foreach ( SvgIdLayer * svgIdLayer, svgLayers) {
 		if (svgIdLayer->m_svgViewLayerID == viewLayerID) {
@@ -177,12 +185,12 @@ void ConnectorShared::loadPins(const QDomElement & domElement) {
 
 	// TODO: this is view-related stuff and it would be nice if the model didn't know about it
 	QDomElement viewsTag = domElement.firstChildElement("views");
-	loadPin(viewsTag.firstChildElement("breadboardView"),ViewIdentifierClass::BreadboardView);
-	loadPin(viewsTag.firstChildElement("schematicView"),ViewIdentifierClass::SchematicView);
-	loadPin(viewsTag.firstChildElement("pcbView"),ViewIdentifierClass::PCBView);
+	loadPin(viewsTag.firstChildElement("breadboardView"),ViewLayer::BreadboardView);
+	loadPin(viewsTag.firstChildElement("schematicView"),ViewLayer::SchematicView);
+	loadPin(viewsTag.firstChildElement("pcbView"),ViewLayer::PCBView);
 }
 
-void ConnectorShared::loadPin(QDomElement elem, ViewIdentifierClass::ViewIdentifier viewId) {
+void ConnectorShared::loadPin(QDomElement elem, ViewLayer::ViewIdentifier viewIdentifier) {
 	QDomElement pinElem = elem.firstChildElement("p");
 	while (!pinElem.isNull()) {
 		//QString temp;
@@ -192,7 +200,7 @@ void ConnectorShared::loadPin(QDomElement elem, ViewIdentifierClass::ViewIdentif
 		QString svgId = pinElem.attribute("svgId");
 		//svgId = svgId.left(svgId.lastIndexOf(QRegExp("\\d"))+1);
 		QString layer = pinElem.attribute("layer");
-		SvgIdLayer * svgIdLayer = new SvgIdLayer;
+		SvgIdLayer * svgIdLayer = new SvgIdLayer(viewIdentifier);
 		svgIdLayer->m_hybrid = (pinElem.attribute("hybrid").compare("yes") == 0);
 		svgIdLayer->m_legId = pinElem.attribute("legId");
 		svgIdLayer->m_svgId = svgId;
@@ -203,7 +211,7 @@ void ConnectorShared::loadPin(QDomElement elem, ViewIdentifierClass::ViewIdentif
 		//if (!svgIdLayer->m_terminalId.isEmpty()) {
 		//	DebugDialog::debug("terminalid " + svgIdLayer->m_terminalId);
 		//}
-		m_pins.insert(viewId, svgIdLayer);
+		m_pins.insert(viewIdentifier, svgIdLayer);
 		//DebugDialog::debug(QString("insert b %1 %2 %3").arg(viewId).arg(svgId).arg(layer));
 
 		pinElem = pinElem.nextSiblingElement("p");
@@ -226,3 +234,8 @@ const QString & ConnectorShared::busID() {
 ErcData * ConnectorShared::ercData() {
 	return m_ercData;
 }
+
+const QList<SvgIdLayer *> ConnectorShared::svgIdLayers() const
+{
+    return m_pins.values();
+}
