@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5721 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-01-03 16:53:58 +0100 (Tue, 03 Jan 2012) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -52,15 +52,17 @@ public:
 	void setSharedName(QString name);
 	const QString & connectorTypeString();
 	void setConnectorType(QString type);
+	void setConnectorType(Connector::ConnectorType);
 	Connector::ConnectorType connectorType();
 
-	const QString & legID(ViewIdentifierClass::ViewIdentifier viewId, ViewLayer::ViewLayerID viewLayerID);
-	const QMultiHash<ViewIdentifierClass::ViewIdentifier,SvgIdLayer *> &pins();
-	SvgIdLayer * fullPinInfo(ViewIdentifierClass::ViewIdentifier viewId, ViewLayer::ViewLayerID viewLayerID);
-	void addPin(ViewIdentifierClass::ViewIdentifier layer, QString connectorId, ViewLayer::ViewLayerID, QString terminalId);
-	void insertPin(ViewIdentifierClass::ViewIdentifier layer, SvgIdLayer * svgIdLayer);
-	void removePins(ViewIdentifierClass::ViewIdentifier layer);
-	void removePin(ViewIdentifierClass::ViewIdentifier layer, SvgIdLayer * svgIdLayer);
+	const QString & legID(ViewLayer::ViewIdentifier viewId, ViewLayer::ViewLayerID viewLayerID);
+	const QMultiHash<ViewLayer::ViewIdentifier,SvgIdLayer *> &pins();
+	SvgIdLayer * fullPinInfo(ViewLayer::ViewIdentifier viewId, ViewLayer::ViewLayerID viewLayerID);
+    const QList<SvgIdLayer *> svgIdLayers() const;
+	void addPin(ViewLayer::ViewIdentifier, const QString & svgId, ViewLayer::ViewLayerID, const QString & terminalId, const QString & legId, bool hybrid);
+	void insertPin(ViewLayer::ViewIdentifier layer, SvgIdLayer * svgIdLayer);
+	void removePins(ViewLayer::ViewIdentifier layer);
+	void removePin(ViewLayer::ViewIdentifier layer, SvgIdLayer * svgIdLayer);
 
 	class BusShared * bus();
 	void setBus(class BusShared *);
@@ -69,7 +71,7 @@ public:
 
 protected:
 	void loadPins(const QDomElement & domElement);
-	void loadPin(QDomElement elem, ViewIdentifierClass::ViewIdentifier viewId);
+	void loadPin(QDomElement elem, ViewLayer::ViewIdentifier viewId);
 
 	QString m_description;
 	QString m_id;
@@ -80,7 +82,7 @@ protected:
 	class ErcData * m_ercData;
 	class BusShared * m_bus;
 
-	QMultiHash<ViewIdentifierClass::ViewIdentifier, SvgIdLayer*> m_pins;
+	QMultiHash<ViewLayer::ViewIdentifier, SvgIdLayer*> m_pins;
 };
 
 static QList<ConnectorShared *> ___emptyConnectorSharedList___;
