@@ -18,21 +18,22 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5309 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2011-07-30 21:17:22 +0200 (Sat, 30 Jul 2011) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
 #include "svgidlayer.h"
 
-SvgIdLayer::SvgIdLayer() {
+SvgIdLayer::SvgIdLayer(ViewLayer::ViewIdentifier viewIdentifier) {
+    m_viewIdentifier = viewIdentifier;
 	m_processed = m_hybrid = false;
 	m_radius = m_strokeWidth = 0;
 }
 
 SvgIdLayer * SvgIdLayer::copyLayer() {
-	SvgIdLayer * toSvgIdLayer = new SvgIdLayer;
+	SvgIdLayer * toSvgIdLayer = new SvgIdLayer(m_viewIdentifier);
 	*toSvgIdLayer = *this;
 	return toSvgIdLayer;
 }
