@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5730 $:
+$Revision: 6373 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-01-05 20:17:05 +0100 (Thu, 05 Jan 2012) $
+$Date: 2012-09-06 08:39:51 +0200 (Thu, 06 Sep 2012) $
 
 ********************************************************************/
 
@@ -31,7 +31,7 @@ $Date: 2012-01-05 20:17:05 +0100 (Thu, 05 Jan 2012) $
 #include "../utils/clickablelabel.h"
 #include "setcolordialog.h"
 #include "../sketch/zoomablegraphicsview.h"
-#include "../mainwindow.h"
+#include "../mainwindow/mainwindow.h"
 
 #include <QFormLayout>
 #include <QLabel>
@@ -46,6 +46,8 @@ $Date: 2012-01-05 20:17:05 +0100 (Thu, 05 Jan 2012) $
 #include <QLineEdit>
 
 #define MARGIN 5
+#define FORMLABELWIDTH 195
+#define SPACING 15
 
 PrefsDialog::PrefsDialog(const QString & language, QWidget *parent)
 	: QDialog(parent)
@@ -61,14 +63,11 @@ PrefsDialog::~PrefsDialog()
 {
 }
 
-void PrefsDialog::initViewInfo(int index, const QString & viewName, const QString & shortName, double defaultSize, QColor current, QColor standard, bool curvy) 
+void PrefsDialog::initViewInfo(int index, const QString & viewName, const QString & shortName, bool curvy) 
 {
 	m_viewInfoThings[index].index = index;
-	m_viewInfoThings[index].defaultGridSize = defaultSize;
 	m_viewInfoThings[index].viewName = viewName;
 	m_viewInfoThings[index].shortName = shortName;
-	m_viewInfoThings[index].currentBColor = current;
-	m_viewInfoThings[index].standardBColor = standard;
 	m_viewInfoThings[index].curvy = curvy;
 }
 
@@ -77,22 +76,22 @@ void PrefsDialog::initLayout(QFileInfoList & list)
 	m_tabWidget = new QTabWidget();
 	m_general = new QWidget();
 	m_breadboard = new QWidget();
-	m_schematic = new QWidget();
-	m_pcb = new QWidget();
+	//m_schematic = new QWidget();
+	//m_pcb = new QWidget();
 
 	m_tabWidget->addTab(m_general, tr("General"));
 	m_tabWidget->addTab(m_breadboard, m_viewInfoThings[0].viewName);
-	m_tabWidget->addTab(m_schematic, m_viewInfoThings[1].viewName);
-	m_tabWidget->addTab(m_pcb, m_viewInfoThings[2].viewName);
+	//m_tabWidget->addTab(m_schematic, m_viewInfoThings[1].viewName);
+	//m_tabWidget->addTab(m_pcb, m_viewInfoThings[2].viewName);
 
-	QVBoxLayout * vLayout = new QVBoxLayout(this);
+	QVBoxLayout * vLayout = new QVBoxLayout();
 	vLayout->addWidget(m_tabWidget);
 
 	initGeneral(m_general, list);
 
 	initBreadboard(m_breadboard, &m_viewInfoThings[0]);
-	initSchematic(m_schematic, &m_viewInfoThings[1]);
-	initPCB(m_pcb, &m_viewInfoThings[2]);
+	//initSchematic(m_schematic, &m_viewInfoThings[1]);
+	//initPCB(m_pcb, &m_viewInfoThings[2]);
 
     QDialogButtonBox * buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
 	buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
@@ -103,11 +102,13 @@ void PrefsDialog::initLayout(QFileInfoList & list)
 
 	vLayout->addWidget(buttonBox);
 
+    this->setLayout(vLayout);
+
 }
 
 void PrefsDialog::initGeneral(QWidget * widget, QFileInfoList & list)
 {
-	QVBoxLayout * vLayout = new QVBoxLayout(widget);
+	QVBoxLayout * vLayout = new QVBoxLayout();
 
 	// TODO: if no translation files found, don't put up the translation part of this dialog
 
@@ -116,26 +117,16 @@ void PrefsDialog::initGeneral(QWidget * widget, QFileInfoList & list)
 	vLayout->addWidget(createZoomerForm());
 	vLayout->addWidget(createAutosaveForm());
 
-#ifndef QT_NO_DEBUG
 	vLayout->addWidget(createOtherForm());
-#endif
 
 	widget->setLayout(vLayout);
 }
 
 void PrefsDialog::initBreadboard(QWidget * widget, ViewInfoThing * viewInfoThing)
 {
-	QVBoxLayout * vLayout = new QVBoxLayout(widget);
-
-	QWidget * w1 = createGridSizeForm(viewInfoThing);
-	vLayout->addWidget(w1);
-	
-	QWidget * w2 = createBackgroundColorForm(viewInfoThing);
-	vLayout->addWidget(w2);
-
-	QWidget * w3 = createCurvyForm(viewInfoThing);
-	vLayout->addWidget(w3);
+	QVBoxLayout * vLayout = new QVBoxLayout();
 
+	vLayout->addWidget(createCurvyForm(viewInfoThing));
 	vLayout->addSpacerItem(new QSpacerItem(1, 1, QSizePolicy::Preferred, QSizePolicy::Expanding));
 
 	widget->setLayout(vLayout);
@@ -143,13 +134,8 @@ void PrefsDialog::initBreadboard(QWidget * widget, ViewInfoThing * viewInfoThing
 
 void PrefsDialog::initSchematic(QWidget * widget, ViewInfoThing * viewInfoThing)
 {
-	QVBoxLayout * vLayout = new QVBoxLayout(widget);
-
-	QWidget * w1 = createGridSizeForm(viewInfoThing);
-	vLayout->addWidget(w1);
-
-	QWidget * w2 = createBackgroundColorForm(viewInfoThing);
-	vLayout->addWidget(w2);
+    Q_UNUSED(viewInfoThing);
+	QVBoxLayout * vLayout = new QVBoxLayout();
 
 	vLayout->addSpacerItem(new QSpacerItem(1, 1, QSizePolicy::Preferred, QSizePolicy::Expanding));
 
@@ -158,13 +144,8 @@ void PrefsDialog::initSchematic(QWidget * widget, ViewInfoThing * viewInfoThing)
 
 void PrefsDialog::initPCB(QWidget * widget, ViewInfoThing * viewInfoThing)
 {
-	QVBoxLayout * vLayout = new QVBoxLayout(widget);
-
-	QWidget * w1 = createGridSizeForm(viewInfoThing);
-	vLayout->addWidget(w1);
-
-	QWidget * w2 = createBackgroundColorForm(viewInfoThing);
-	vLayout->addWidget(w2);
+    Q_UNUSED(viewInfoThing);
+	QVBoxLayout * vLayout = new QVBoxLayout();
 
 	vLayout->addSpacerItem(new QSpacerItem(1, 1, QSizePolicy::Preferred, QSizePolicy::Expanding));
 
@@ -175,18 +156,24 @@ QWidget * PrefsDialog::createZoomerForm() {
 	QGroupBox * zoomer = new QGroupBox(tr("Mouse Wheel Behavior"), this );
 
 	QHBoxLayout * zhlayout = new QHBoxLayout();
-	zhlayout->setSpacing(5);
+	zhlayout->setSpacing(SPACING);
 
-#ifdef Q_WS_MAC
-	QString cKey = tr("Command");
-#else
-	QString cKey = tr("Control");
-#endif
+    QFrame * frame = new QFrame();
+    frame->setFixedWidth(FORMLABELWIDTH);
+
+    QVBoxLayout * vLayout = new QVBoxLayout();
+    vLayout->setSpacing(0);
+    vLayout->setMargin(0);
+
+    for (int i = 0; i < 3; i++) {
+	    m_wheelLabel[i] = new QLabel();
+        vLayout->addWidget(m_wheelLabel[i]);
+    }
 
-	m_wheelLabel = new QLabel(this);
-	m_wheelLabel->setWordWrap(true);
 	updateWheelText();
-	zhlayout->addWidget(m_wheelLabel);
+
+    frame->setLayout(vLayout);
+	zhlayout->addWidget(frame);
 
 	QPushButton * pushButton = new QPushButton(tr("Change Wheel Behavior"), this);
 	connect(pushButton, SIGNAL(clicked()), this, SLOT(changeWheelBehavior()));
@@ -201,7 +188,7 @@ QWidget * PrefsDialog::createAutosaveForm() {
 	QGroupBox * autosave = new QGroupBox(tr("Autosave"), this );
 
 	QHBoxLayout * zhlayout = new QHBoxLayout();
-	zhlayout->setSpacing(5);
+	zhlayout->setSpacing(SPACING);
 
 	QCheckBox * box = new QCheckBox(tr("Autosave every:"));
 	box->setChecked(MainWindow::AutosaveEnabled);
@@ -228,15 +215,10 @@ QWidget * PrefsDialog::createAutosaveForm() {
 	return autosave;
 }
 
-
 QWidget * PrefsDialog::createLanguageForm(QFileInfoList & list) 
 {
 	QGroupBox * formGroupBox = new QGroupBox(tr("Language"));
-    QFormLayout *layout = new QFormLayout();
-
-	QLabel * languageLabel = new QLabel(this);
-	languageLabel->setWordWrap(true);
-	languageLabel->setText(QObject::tr("<b>Language</b>"));
+    QVBoxLayout *layout = new QVBoxLayout();
 	
 	QComboBox* comboBox = new QComboBox(this);
 	m_translatorListModel = new TranslatorListModel(list, this);
@@ -244,15 +226,14 @@ QWidget * PrefsDialog::createLanguageForm(QFileInfoList & list)
 	comboBox->setCurrentIndex(m_translatorListModel->findIndex(m_name));
 	connect(comboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(changeLanguage(int)));
 
-	layout->addRow(languageLabel, comboBox);	
+	layout->addWidget(comboBox);	
 
-	QLabel * ll = new QLabel(this);
-	ll->setFixedWidth(250);
+	QLabel * ll = new QLabel();
 	ll->setMinimumHeight(45);
 	ll->setWordWrap(true);
 	ll->setText(QObject::tr("Please note that a new language setting will not take effect "
-		"until the next time you run Fritzing."));
-	layout->addRow(ll);
+		                    "until the next time you run Fritzing."));
+	layout->addWidget(ll);
 
 	formGroupBox->setLayout(layout);
 	return formGroupBox;
@@ -261,11 +242,18 @@ QWidget * PrefsDialog::createLanguageForm(QFileInfoList & list)
 QWidget* PrefsDialog::createColorForm() 
 {
 	QGroupBox * formGroupBox = new QGroupBox(tr("Colors"));
-    QFormLayout *layout = new QFormLayout();
+    QVBoxLayout *layout = new QVBoxLayout();
+    layout->setSpacing(0);
+    layout->setMargin(0);
 
-	QLabel * c1 = new QLabel(this);
+    QFrame * f1 = new QFrame();
+    QHBoxLayout * h1 = new QHBoxLayout();
+    h1->setSpacing(SPACING);
+
+	QLabel * c1 = new QLabel(QObject::tr("Connected highlight color"));
 	c1->setWordWrap(true);
-	c1->setText(QObject::tr("<b>Connected highlight color</b>"));
+    c1->setFixedWidth(FORMLABELWIDTH);
+    h1->addWidget(c1);
 
 	QColor connectedColor = ItemBase::connectedColor();
 	ClickableLabel * cl1 = new ClickableLabel(tr("%1 (click to change...)").arg(connectedColor.name()), this);
@@ -273,11 +261,19 @@ QWidget* PrefsDialog::createColorForm()
 	cl1->setPalette(QPalette(connectedColor));
 	cl1->setAutoFillBackground(true);
 	cl1->setMargin(MARGIN);
-	layout->addRow(c1, cl1);
+	h1->addWidget(cl1);
 
-	QLabel * c2 = new QLabel(this);
+    f1->setLayout(h1);
+    layout->addWidget(f1);
+
+    QFrame * f2 = new QFrame();
+    QHBoxLayout * h2 = new QHBoxLayout();
+    h2->setSpacing(SPACING);
+
+	QLabel * c2 = new QLabel(QObject::tr("Unconnected highlight color"));
 	c2->setWordWrap(true);
-	c2->setText(QObject::tr("<b>Unconnected highlight color</b>"));
+    c2->setFixedWidth(FORMLABELWIDTH);
+    h2->addWidget(c2);
 
 	QColor unconnectedColor = ItemBase::unconnectedColor();
 	ClickableLabel * cl2 = new ClickableLabel(tr("%1 (click to change...)").arg(unconnectedColor.name()), this);
@@ -285,7 +281,10 @@ QWidget* PrefsDialog::createColorForm()
 	cl2->setPalette(QPalette(unconnectedColor));
 	cl2->setAutoFillBackground(true);
 	cl2->setMargin(MARGIN);
-	layout->addRow(c2, cl2);
+	h2->addWidget(cl2);
+
+    f2->setLayout(h2);
+    layout->addWidget(f2);
 
 	formGroupBox->setLayout(layout);
 	return formGroupBox;
@@ -293,19 +292,42 @@ QWidget* PrefsDialog::createColorForm()
 
 QWidget* PrefsDialog::createOtherForm() 
 {
-	QGroupBox * formGroupBox = new QGroupBox(tr("Debug"));
-    QFormLayout *layout = new QFormLayout();
+	QGroupBox * formGroupBox = new QGroupBox(tr("Clear Settings"));
+    QHBoxLayout *layout = new QHBoxLayout();
+    layout->setSpacing(SPACING);
 
-	QLabel * clearLabel = new QLabel(this);
-	clearLabel->setFixedWidth(195);
-	clearLabel->setWordWrap(true);
-	clearLabel->setText(QObject::tr("Clear all saved settings and close this dialog (debug mode only)."));	
+    QFrame * frame = new QFrame;
+    QVBoxLayout * vlayout = new QVBoxLayout();
+    vlayout->setMargin(0);
+    vlayout->setSpacing(0);
 
-	QPushButton * clear = new QPushButton(QObject::tr("Clear"), this);
+    QLabel * clearLabel = new QLabel(QObject::tr("Clear all saved settings and close this dialog immediately."));
+    clearLabel->setWordWrap(true);
+    clearLabel->setFixedWidth(FORMLABELWIDTH);
+    vlayout->addWidget(clearLabel);
+
+    vlayout->addSpacing(SPACING);
+
+    clearLabel = new QLabel(QObject::tr("This action does not delete any files; it restores settings to their default values."));
+    clearLabel->setWordWrap(true);
+    clearLabel->setFixedWidth(FORMLABELWIDTH);
+    vlayout->addWidget(clearLabel);
+
+    vlayout->addSpacing(SPACING);
+
+    clearLabel = new QLabel(QObject::tr("There is no undo for this action, and no further warning!!!!"));
+    clearLabel->setWordWrap(true);
+    clearLabel->setFixedWidth(FORMLABELWIDTH);
+    vlayout->addWidget(clearLabel);
+
+    frame->setLayout(vlayout);
+    layout->addWidget(frame);
+
+	QPushButton * clear = new QPushButton(QObject::tr("Clear Settings"), this);
 	clear->setMaximumWidth(220);
 	connect(clear, SIGNAL(clicked()), this, SLOT(clear()));
 
-	layout->addRow(clearLabel, clear);	
+	layout->addWidget(clear);	
 
 	formGroupBox->setLayout(layout);
 	return formGroupBox;
@@ -395,7 +417,11 @@ void PrefsDialog::updateWheelText() {
 			text = tr("no keys down = zoom\nAlt or %1 key = scroll\nshift key swaps scroll axis").arg(cKey);
 			break;
 	}
-	m_wheelLabel->setText(text);
+
+    QStringList strings = text.split('\n');
+    for (int i = 0; i < 3; i++) {
+        m_wheelLabel[i]->setText(strings.at(i));
+    }
 }
 
 void PrefsDialog::toggleAutosave(bool checked) {
@@ -406,179 +432,22 @@ void PrefsDialog::changeAutosavePeriod(int value) {
 	m_settings.insert("autosavePeriod", QString("%1").arg(value));
 }
 
-QWidget * PrefsDialog::createGridSizeForm(ViewInfoThing * viewInfoThing)
-{
-	QGroupBox * over = new QGroupBox(tr("Align-to-Grid size"), this);
-
-	QVBoxLayout * vLayout = new QVBoxLayout();
-
-	QLabel * explain = new QLabel(tr("Set the grid size for %1.").arg(viewInfoThing->viewName));
-	vLayout->addWidget(explain);
-
-	QGroupBox * groupBox = new QGroupBox(this);
-
-	QHBoxLayout * hLayout = new QHBoxLayout();
-
-	QLabel * label = new QLabel(tr("Grid Size:"));
-	hLayout->addWidget(label);
-
-	viewInfoThing->lineEdit = new QLineEdit();
-	
-	viewInfoThing->lineEdit->setFixedWidth(45);
-
-	viewInfoThing->validator = new QDoubleValidator(viewInfoThing->lineEdit);
-	viewInfoThing->validator->setRange(0.001, 1.0, 3);
-	viewInfoThing->validator->setNotation(QDoubleValidator::StandardNotation);
-	viewInfoThing->lineEdit->setValidator(viewInfoThing->validator);
-
-	hLayout->addWidget(viewInfoThing->lineEdit);
-
-	viewInfoThing->inButton = new QRadioButton(tr("in"), this); 
-	hLayout->addWidget(viewInfoThing->inButton);
-
-	viewInfoThing->mmButton = new QRadioButton(tr("mm"), this); 
-	hLayout->addWidget(viewInfoThing->mmButton);
-
-	groupBox->setLayout(hLayout);
-
-	vLayout->addWidget(groupBox);
-	vLayout->addSpacing(5);
-
-	QPushButton * pushButton = new QPushButton(this);
-	pushButton->setText(tr("Restore Default"));
-	pushButton->setMaximumWidth(115);
-	vLayout->addWidget(pushButton);
-	vLayout->addSpacing(10);
-
-	over->setLayout(vLayout);
-
-	QSettings settings;
-	QString szString = settings.value(QString("%1GridSize").arg(viewInfoThing->viewName), "").toString();
-	if (szString.isEmpty()) {
-		viewInfoThing->inButton->setChecked(true);
-		viewInfoThing->lineEdit->setText(QString::number(viewInfoThing->defaultGridSize));
-	}
-	else {
-		if (szString.endsWith("mm")) {
-			viewInfoThing->mmButton->setChecked(true);
-			viewInfoThing->validator->setTop(25.4);
-		}
-		else {
-			viewInfoThing->inButton->setChecked(true);
-		}
-		szString.chop(2);
-		viewInfoThing->lineEdit->setText(szString);
-	}
-
-	viewInfoThing->inButton->setProperty("index", viewInfoThing->index);
-	pushButton->setProperty("index", viewInfoThing->index);
-	viewInfoThing->mmButton->setProperty("index", viewInfoThing->index);
-	viewInfoThing->lineEdit->setProperty("index", viewInfoThing->index);
-
-	connect(viewInfoThing->lineEdit, SIGNAL(editingFinished()), this, SLOT(gridEditingFinished()));
-	connect(viewInfoThing->inButton, SIGNAL(clicked(bool)), this, SLOT(units(bool)));
-	connect(pushButton, SIGNAL(clicked()), this, SLOT(restoreDefault()));
-	connect(viewInfoThing->mmButton, SIGNAL(clicked(bool)), this, SLOT(units(bool)));
-
-	return over;
-}
-
-void PrefsDialog::gridEditingFinished() {
-	ViewInfoThing * viewInfoThing = &m_viewInfoThings[sender()->property("index").toInt()];
-	updateGridSize(viewInfoThing);
-}
-
-void PrefsDialog::units(bool checked) {
-	ViewInfoThing * viewInfoThing = &m_viewInfoThings[sender()->property("index").toInt()];
-
-	QString units;
-	if (sender() == viewInfoThing->inButton) {
-		units = (checked) ? "in" : "mm";
-	}
-	else {
-		units = (checked) ? "mm" : "in";
-	}
-	
-	if (units.startsWith("mm")) {
-		viewInfoThing->validator->setTop(25.4);
-		viewInfoThing->lineEdit->setText(QString::number(viewInfoThing->lineEdit->text().toDouble() * 25.4));
-	}
-	else {
-		viewInfoThing->validator->setTop(1.0);
-		viewInfoThing->lineEdit->setText(QString::number(viewInfoThing->lineEdit->text().toDouble() / 25.4));
-	}
-
-	updateGridSize(viewInfoThing);
-}
-
-void PrefsDialog::restoreDefault() {
-	ViewInfoThing * viewInfoThing = &m_viewInfoThings[sender()->property("index").toInt()];
-
-	viewInfoThing->inButton->setChecked(true);
-	viewInfoThing->mmButton->setChecked(false);
-	viewInfoThing->lineEdit->setText(QString::number(viewInfoThing->defaultGridSize));
-	updateGridSize(viewInfoThing);
-}
-
-QWidget* PrefsDialog::createBackgroundColorForm(ViewInfoThing * viewInfoThing) 
-{
-	QGroupBox * groupBox = new QGroupBox(tr("Background color"));
-    QVBoxLayout *layout = new QVBoxLayout;
-
-	ClickableLabel * cl1 = new ClickableLabel(tr("%1 (click to change...)").arg(viewInfoThing->currentBColor.name()), this);
-	cl1->setProperty("index", viewInfoThing->index);
-	connect(cl1, SIGNAL(clicked()), this, SLOT(setBackgroundColor()));
-	cl1->setPalette(QPalette(viewInfoThing->currentBColor));
-	cl1->setAutoFillBackground(true);
-	cl1->setMargin(MARGIN);
-
-	layout->addWidget(cl1);
-
-	groupBox->setLayout(layout);
-	return groupBox;
-}
-
-void PrefsDialog::setBackgroundColor() {
-	ViewInfoThing * viewInfoThing = &m_viewInfoThings[sender()->property("index").toInt()];
-
-	QColor cc = viewInfoThing->currentBColor;
-	QColor scc = viewInfoThing->standardBColor;
-
-	SetColorDialog setColorDialog(tr("%1 background Color").arg(viewInfoThing->viewName), cc, scc, true, this);
-	int result = setColorDialog.exec();
-	if (result == QDialog::Rejected) return;
-
-	viewInfoThing->currentBColor = setColorDialog.selectedColor();
-	ClickableLabel * cl = qobject_cast<ClickableLabel *>(sender());
-	if (cl) {
-		cl->setPalette(QPalette(viewInfoThing->currentBColor));
-	}
-
-	if (setColorDialog.isPrefsColor()) {
-		QSettings settings;
-		m_settings.insert(QString("%1BackgroundColor").arg(viewInfoThing->shortName), setColorDialog.selectedColor().name());
-	}
-
-	m_tempSettings.insert(QString("%1BackgroundColor").arg(viewInfoThing->shortName), setColorDialog.selectedColor().name());
-}
-
-void PrefsDialog::updateGridSize(ViewInfoThing * viewInfoThing) {
-	QString units = (viewInfoThing->inButton->isChecked() ? "in" : "mm");
-	m_settings.insert(QString("%1GridSize").arg(viewInfoThing->viewName), viewInfoThing->lineEdit->text() + units);
-}
-
-
 QWidget* PrefsDialog::createCurvyForm(ViewInfoThing * viewInfoThing) 
 {
 	QGroupBox * groupBox = new QGroupBox(tr("Curvy vs. straight wires"));
     QVBoxLayout *layout = new QVBoxLayout;
 
-	QLabel * label = new QLabel(tr("When you mouse-down and drag on a wire or the leg of a part (as opposed to a connector or a bendpoint) "
-									"do you want to change the curvature of the wire (or leg) or drag out a new bendpoint?\n\n" 
-									"This checkbox sets the default behavior. "
-									"You can switch back to the non-default behavior by holding down the Control key (Mac: Command key) when you drag.\n"));
-	label->setWordWrap(true);
-	layout->addWidget(label);
+    QLabel * label1 = new QLabel(tr("When you mouse-down and drag on a wire or the leg of a part (as opposed to a connector or a bendpoint) "
+									"do you want to change the curvature of the wire (or leg) or drag out a new bendpoint?"));
+	label1->setWordWrap(true);
+	layout->addWidget(label1);
+
+	QLabel * label2 = new QLabel(tr("This checkbox sets the default behavior. "
+									"You can switch back to the non-default behavior by holding down the Control key (Mac: Command key) when you drag."));
+    label2->setWordWrap(true);
+	layout->addWidget(label2);
+
+    layout->addSpacing(10);
 
 	QCheckBox * checkbox = new QCheckBox("Curvy wires and legs");
 	checkbox->setProperty("index", viewInfoThing->index);
