@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5933 $:
+$Revision: 6451 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-03-30 13:45:18 +0200 (Fri, 30 Mar 2012) $
+$Date: 2012-09-18 07:20:56 +0200 (Tue, 18 Sep 2012) $
 
 ********************************************************************/
 
@@ -98,6 +98,12 @@ TranslatorListModel::TranslatorListModel(QFileInfoList & fileInfoList, QObject*
 
 		m_languages.insert("indonesian", tr("Indonesian - %1").arg("Bahasa Indonesia"));
 
+		ushort t14[] = { 0x53, 0x6C, 0x6F, 0x76, 0x65, 0x6E, 0x010D, 0x69, 0x6E, 0x61, 0};
+		m_languages.insert("slovak", tr("Slovak - %1").arg(QString::fromUtf16(t14)));
+
+        ushort t15[] = { 0x09AC,  0x09BE,   0x0982,   0x09B2,   0x09BE, 0 };
+        m_languages.insert("bengali", tr("Bengali - %1").arg(QString::fromUtf16(t15)));
+
 
         // More languages written in their own language can be found
         // at http://www.mozilla.com/en-US/firefox/all.html 
