@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,38 +18,40 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5929 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-03-28 12:13:01 +0200 (Wed, 28 Mar 2012) $
+$Revision: 6503 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-02 17:20:22 +0200 (Tue, 02 Oct 2012) $
 
 ********************************************************************/
 
 #include "fapplication.h"
 #include "debugdialog.h"
 #include "utils/misc.h"
-#include "mainwindow.h"
+#include "mainwindow/mainwindow.h"
 #include "fsplashscreen.h"
 #include "version/version.h"
 #include "dialogs/prefsdialog.h"
 #include "help/helper.h"
-#include "partseditor/partseditormainwindow.h"
 #include "fsvgrenderer.h"
 #include "version/versionchecker.h"
 #include "version/updatedialog.h"
 #include "itemdrag.h"
-#include "viewswitcher/viewswitcher.h"
+#include "dock/viewswitcher.h"
 #include "items/wire.h"
 #include "partsbinpalette/binmanager/binmanager.h"
 #include "help/tipsandtricks.h"
 #include "utils/folderutils.h"
 #include "utils/lockmanager.h"
 #include "dialogs/translatorlistmodel.h"
+#include "partsbinpalette/partsbinview.h"
 #include "partsbinpalette/svgiconwidget.h"
+#include "partsbinpalette/partsbinpalettewidget.h"
 #include "items/moduleidnames.h"
 #include "partsbinpalette/searchlineedit.h"
 #include "utils/ratsnestcolors.h"
 #include "utils/cursormaster.h"
 #include "utils/textutils.h"
+#include "utils/graphicsutils.h"
 #include "infoview/htmlinfoview.h"
 #include "svg/gedaelement2svg.h"
 #include "svg/kicadmodule2svg.h"
@@ -58,10 +60,12 @@ $Date: 2012-03-28 12:13:01 +0200 (Wed, 28 Mar 2012) $
 #include "installedfonts.h"
 #include "items/pinheader.h"
 #include "items/partfactory.h"
+#include "items/propertydef.h"
 #include "dialogs/recoverydialog.h"
 #include "lib/qtsysteminfo/QtSystemInfo.h"
 #include "processeventblocker.h"
 #include "autoroute/cmrouter/panelizer.h"
+#include "sketch/sketchwidget.h"
 
 // dependency injection :P
 #include "referencemodel/sqlitereferencemodel.h"
@@ -107,23 +111,188 @@ static QNetworkAccessManager * NetworkAccessManager = NULL;
 #endif
 #endif
 
-int FApplication::RestartNeeded = 9999;
-
 QSet<QString> InstalledFonts::InstalledFontsList;
 QMultiHash<QString, QString> InstalledFonts::InstalledFontsNameMapper;   // family name to filename; SVG files seem to have to use filename
 
 static const double LoadProgressStart = 0.085;
 static const double LoadProgressEnd = 0.6;
 
-//////////////////////////
+////////////////////////////////////////////////////
+
+FServer::FServer(QObject *parent)
+    : QTcpServer(parent)
+{
+}
+
+void FServer::incomingConnection(int socketDescriptor)
+{
+    emit newConnection(socketDescriptor);
+}
+
+////////////////////////////////////////////////////
+
+QMutex FServerThread::m_busy;
+
+FServerThread::FServerThread(int socketDescriptor, QObject *parent) : QThread(parent), m_socketDescriptor(socketDescriptor)
+{
+}
+
+ void FServerThread::run()
+ {
+    QTcpSocket * socket = new QTcpSocket();
+    if (!socket->setSocketDescriptor(m_socketDescriptor)) {
+        emit error(socket->error());
+        DebugDialog::debug(QString("Socket error %1 %2").arg(socket->error()).arg(socket->errorString()));
+        socket->deleteLater();
+        return;
+    }
+
+    socket->waitForReadyRead();
+    QString header;
+    while (socket->canReadLine()) {
+        header += socket->readLine();
+    }
+
+    DebugDialog::debug("header " + header);
+
+    QStringList tokens = header.split(QRegExp("[ \r\n][ \r\n]*"), QString::SkipEmptyParts);
+    if (tokens.count() <= 0) {
+        writeResponse(socket, 400, "Bad Request", "", "");
+        return;
+    }
+
+    if (tokens[0] != "GET") {
+        writeResponse(socket, 405, "Method Not Allowed", "", "");
+        return;
+    }
+
+    if (tokens.count() < 2) {
+        writeResponse(socket, 400, "Bad Request", "", "");
+        return;
+    }
+
+    QStringList params = tokens.at(1).split("/", QString::SkipEmptyParts);
+    QString command = params.takeFirst();
+    if (params.count() == 0) {
+        writeResponse(socket, 400, "Bad Request", "", "");
+        return;
+    }
+
+    QString subFolder = params.join("/");
+	bool fixSubFolder = false;
+    QString mimeType;
+    if (command == "svg") {
+		 mimeType = "image/svg+xml";
+    }
+    else if (command == "gerber") {
+    }
+    else if (command == "svg-tcp") {
+		fixSubFolder = true;
+    }
+    else if (command == "gerber-tcp") {
+		fixSubFolder = true;
+    }
+    else {
+        writeResponse(socket, 400, "Bad Request", "", "");
+        return;
+    }
+
+	if (fixSubFolder) {
+		// replace "/" that was removed from "http:/blah" above
+		int ix = subFolder.indexOf(":/");
+		if (ix >= 0) {
+			subFolder.insert(ix + 1, "/");
+		}
+	}
+
+    int waitInterval = 100;     // 100ms to wait
+    int timeoutSeconds = 2 * 60;    // timeout after 2 minutes
+    int attempts = timeoutSeconds * 1000 / waitInterval;  // timeout a
+    bool gotLock = false;
+    for (int i = 0; i < attempts; i++) {
+        if (m_busy.tryLock()) {
+            gotLock = true;
+            break;
+        }
+    }
+
+    if (!gotLock) {
+        writeResponse(socket, 503, "Service Unavailable", "", "Server busy.");
+        return;
+    }
+
+    DebugDialog::debug(QString("emitting do command %1 %2").arg(command).arg(subFolder));
+    QString result;
+	int status;
+    emit doCommand(command, subFolder, result, status);
+
+    m_busy.unlock();
+
+	if (status != 200) {
+		writeResponse(socket, status, "failed", "", result);
+	}
+	else if (command.endsWith("tcp")) {
+		QString filename = result;
+		mimeType = "application/zip";
+		QFile file(filename);
+		if (file.open(QFile::ReadOnly)) {
+			QString response = QString("HTTP/1.0 %1 %2\r\n").arg(200).arg("ok");
+			response += QString("Content-Type: %1; charset=\"utf-8\"\r\n").arg(mimeType);
+			response += QString("Content-Length: %1\r\n").arg(file.size());
+			response += QString("\r\n");    
+			socket->write(response.toUtf8());
+			int buffersize = 8192;
+			long remaining = file.size();
+			while (remaining >= buffersize) {
+				QByteArray bytes = file.read(buffersize);
+				socket->write(bytes);
+				remaining -= buffersize;
+			}
+			if (remaining > 0) {
+				QByteArray bytes = file.read(remaining);
+				socket->write(bytes);
+			}
+			socket->disconnectFromHost();
+			socket->waitForDisconnected();
+			socket->deleteLater();
+			file.close();
+		}
+		else {
+			writeResponse(socket, 500, "failed", "", "local zip failure (2)");
+		}
+
+		QFileInfo info(filename);
+		QDir dir = info.dir();
+		FolderUtils::rmdir(dir);
+	}
+	else {
+		writeResponse(socket, 200, "Ok", mimeType, result);
+	}
+}
+
+void FServerThread::writeResponse(QTcpSocket * socket, int code, const QString & codeString, const QString & mimeType, const QString & message) 
+{
+    QString type = mimeType;
+    if (type.isEmpty()) type = "text/plain";
+    QString response = QString("HTTP/1.0 %1 %2\r\n").arg(code).arg(codeString);
+    response += QString("Content-Type: %1; charset=\"utf-8\"\r\n").arg(type);
+    response += QString("Content-Length: %1\r\n").arg(message.count());
+    response += QString("\r\n%1").arg(message);
+       
+    socket->write(response.toUtf8());
+    socket->disconnectFromHost();
+    socket->waitForDisconnected();
+    socket->deleteLater();
+}
+
+////////////////////////////////////////////////////
 
 FApplication::FApplication( int & argc, char ** argv) : QApplication(argc, argv)
 {
-	MainWindow::RestartNeeded = FApplication::RestartNeeded;
+    m_fServer = NULL;
 	m_spaceBarIsPressed = false;
 	m_mousePressed = false;
 	m_referenceModel = NULL;
-	m_paletteBinModel = NULL;
 	m_started = false;
 	m_updateDialog = NULL;
 	m_lastTopmostWindow = NULL;
@@ -153,6 +322,7 @@ bool FApplication::init() {
 		if ((m_arguments[i].compare("-e", Qt::CaseInsensitive) == 0) ||
 			(m_arguments[i].compare("-examples", Qt::CaseInsensitive) == 0)||
 			(m_arguments[i].compare("--examples", Qt::CaseInsensitive) == 0)) {
+            DebugDialog::setEnabled(true);
 			m_serviceType = ExampleService;
 			m_outputFolder = " ";					// otherwise program will bail out
 			toRemove << i;
@@ -183,6 +353,14 @@ bool FApplication::init() {
 			toRemove << i << i + 1;
 		}
 
+		if ((m_arguments[i].compare("-db", Qt::CaseInsensitive) == 0) ||
+            (m_arguments[i].compare("-database", Qt::CaseInsensitive) == 0) ||
+			(m_arguments[i].compare("--database", Qt::CaseInsensitive) == 0)) {
+			m_serviceType = DatabaseService;
+			m_outputFolder = m_arguments[i + 1];
+			toRemove << i << i + 1;
+		}
+
 		if ((m_arguments[i].compare("-kicad", Qt::CaseInsensitive) == 0) ||
 			(m_arguments[i].compare("--kicad", Qt::CaseInsensitive) == 0)) {
 			m_serviceType = KicadFootprintService;
@@ -197,10 +375,43 @@ bool FApplication::init() {
 			toRemove << i << i + 1;
 		}
 
+		if ((m_arguments[i].compare("-svg", Qt::CaseInsensitive) == 0) ||
+			(m_arguments[i].compare("--svg", Qt::CaseInsensitive) == 0)) {
+			m_serviceType = SvgService;
+            DebugDialog::setEnabled(true);
+			m_outputFolder = m_arguments[i + 1];
+			toRemove << i << i + 1;
+		}
+
+		if ((m_arguments[i].compare("-port", Qt::CaseInsensitive) == 0) ||
+			(m_arguments[i].compare("--port", Qt::CaseInsensitive) == 0)) {
+            DebugDialog::setEnabled(true);
+            bool ok;
+            int p = m_arguments[i + 1].toInt(&ok);
+            if (ok) {
+                m_portNumber = p;
+            }
+
+            toRemove << i << i + 1;
+
+            if (i + 2 < m_arguments.count()) {
+                if (ok) {
+                    m_portRootFolder = m_arguments[i + 2];
+                    m_serviceType = PortService;
+                }
+                toRemove << i + 2;
+            }
+
+			m_outputFolder = m_arguments[i + 1];
+		}
+
+
+
 		if ((m_arguments[i].compare("-g", Qt::CaseInsensitive) == 0) ||
 			(m_arguments[i].compare("-gerber", Qt::CaseInsensitive) == 0)||
 			(m_arguments[i].compare("--gerber", Qt::CaseInsensitive) == 0)) {
 			m_serviceType = GerberService;
+            DebugDialog::setEnabled(true);
 			m_outputFolder = m_arguments[i + 1];
 			toRemove << i << i + 1;
 		}
@@ -211,6 +422,15 @@ bool FApplication::init() {
 			m_serviceType = PanelizerService;
 			m_panelFilename = m_arguments[i + 1];
 			m_outputFolder = " ";					// otherwise program will bail out
+            m_panelizerCustom = false;
+			toRemove << i << i + 1;
+		}
+
+		if ((m_arguments[i].compare("-pc", Qt::CaseInsensitive) == 0)) {
+			m_serviceType = PanelizerService;
+			m_panelFilename = m_arguments[i + 1];
+			m_outputFolder = " ";					// otherwise program will bail out
+            m_panelizerCustom = true;
 			toRemove << i << i + 1;
 		}
 
@@ -279,15 +499,14 @@ bool FApplication::init() {
 	Q_INIT_RESOURCE(phoenixresources);
 
 	MainWindow::initNames();
-	FSvgRenderer::calcPrinterScale();
-	ViewIdentifierClass::initNames();
+	FSvgRenderer::initNames();
+	ViewLayer::initNames();
 	RatsnestColors::initNames();
 	Wire::initNames();
 	ItemBase::initNames();
 	ViewLayer::initNames();
 	Connector::initNames();
 	Helper::initText();
-	PartsEditorMainWindow::initText();
 	BinManager::initNames();
 	PaletteModel::initNames();
 	SvgIconWidget::initNames();
@@ -308,7 +527,7 @@ FApplication::~FApplication(void)
 	}
 
 	FSvgRenderer::cleanup();
-	ViewIdentifierClass::cleanup();
+	ViewLayer::cleanup();
 	ViewLayer::cleanup();
 	ItemBase::cleanup();
 	Wire::cleanup();
@@ -324,13 +543,14 @@ FApplication::~FApplication(void)
 	HtmlInfoView::cleanup();
 	SvgIconWidget::cleanup();
 	PartFactory::cleanup();
+    PartsBinView::cleanup();
+    PropertyDefMaster::cleanup();
+    CursorMaster::cleanup();
+    LockManager::cleanup();
+    PartsBinPaletteWidget::cleanup();
 }
 
 void FApplication::clearModels() {
-	if (m_paletteBinModel) {
-		m_paletteBinModel->clearPartHash();
-		delete m_paletteBinModel;
-	}
 	if (m_referenceModel) {
 		m_referenceModel->clearPartHash();
 		delete m_referenceModel;
@@ -350,17 +570,27 @@ bool FApplication::eventFilter(QObject *obj, QEvent *event)
 
 	switch (event->type()) {
 		case QEvent::MouseButtonPress:
+            //DebugDialog::debug("button press");
 			m_mousePressed = true;
 			break;
 		case QEvent::MouseButtonRelease:
+            //DebugDialog::debug("button release");
 			m_mousePressed = false;
 			break;
+        case QEvent::Drop:
+            // at least under Windows, the MouseButtonRelease event is not triggered if the Drop event is triggered
+            m_mousePressed = false;
+            break;
 		case QEvent::KeyPress:
 			{
-				if (!m_mousePressed) {
+                //DebugDialog::debug(QString("key pressed %1 %2").arg(m_mousePressed).arg(QApplication::mouseButtons()));
+				if (!m_mousePressed && !m_spaceBarIsPressed) {
 					QKeyEvent * kevent = static_cast<QKeyEvent *>(event);
 					if (!kevent->isAutoRepeat() && (kevent->key() == Qt::Key_Space)) {
 						m_spaceBarIsPressed = true;
+                        //DebugDialog::debug("spacebar pressed");
+                        CursorMaster::instance()->block();
+                        setOverrideCursor(Qt::OpenHandCursor);
 						emit spaceBarIsPressedSignal(true);
 					}
 				}
@@ -368,10 +598,14 @@ bool FApplication::eventFilter(QObject *obj, QEvent *event)
 			break;
 		case QEvent::KeyRelease:
 			{
+                //DebugDialog::debug(QString("key released %1 %2").arg(m_mousePressed).arg(QApplication::mouseButtons()));
 				if (m_spaceBarIsPressed) {
 					QKeyEvent * kevent = static_cast<QKeyEvent *>(event);
 					if (!kevent->isAutoRepeat() && (kevent->key() == Qt::Key_Space)) {
 						m_spaceBarIsPressed = false;
+                        //DebugDialog::debug("spacebar pressed");
+                        restoreOverrideCursor();
+                        CursorMaster::instance()->unblock();
 						emit spaceBarIsPressedSignal(false);
 					}
 				}
@@ -440,41 +674,33 @@ void FApplication::registerFonts() {
 	*/	
 }
 
-ReferenceModel * FApplication::loadReferenceModel() {
+ReferenceModel * FApplication::loadReferenceModel(const QString & databaseName, bool fullLoad) {
 	m_referenceModel = new CurrentReferenceModel();	
 	ItemBase::setReferenceModel(m_referenceModel);
 	connect(m_referenceModel, SIGNAL(loadedPart(int, int)), this, SLOT(loadedPart(int, int)));
-	m_referenceModel->loadAll(true);								// this is very slow
-	m_paletteBinModel = new PaletteModel(true, false, false);
-	//DebugDialog::debug("after new palette model");
+
+	bool ok = m_referenceModel->loadAll(databaseName, fullLoad);		// loads local parts, resource parts, and any other parts in files not in the db--these part override db parts with the same moduleID
+    if (ok && databaseName.isEmpty()) {
+        QDir * dir = FolderUtils::getApplicationSubFolder("parts");
+        if (dir == NULL) {
+        }
+        else {
+            QFile file(dir->absoluteFilePath("parts.db"));
+            if (file.exists()) {
+                m_referenceModel->loadFromDB(dir->absoluteFilePath("parts.db"));
+            }
+            delete dir;
+        }
+    }
+
 	return m_referenceModel;
 }
 
-bool FApplication::loadBin(QString binToOpen) {
-	binToOpen = binToOpen.isNull() || binToOpen.isEmpty()? BinManager::CorePartsBinLocation: binToOpen;
-
-	if (!m_paletteBinModel->load(binToOpen, m_referenceModel)) {
-		if(binToOpen == BinManager::CorePartsBinLocation
-		   || !m_paletteBinModel->load(BinManager::CorePartsBinLocation, m_referenceModel)) {
-			return false;
-		}
-	}
-
-	return true;
-}
-
-MainWindow * FApplication::loadWindows(int & loaded, bool lockFiles) {
+MainWindow * FApplication::openWindowForService(bool lockFiles) {
 	// our MainWindows use WA_DeleteOnClose so this has to be added to the heap (via new) rather than the stack (for local vars)
-	MainWindow * mainWindow = MainWindow::newMainWindow(m_paletteBinModel, m_referenceModel, "", false, lockFiles);   // this is also slow
+	MainWindow * mainWindow = MainWindow::newMainWindow(m_referenceModel, "", false, lockFiles);   // this is also slow
 	mainWindow->setReportMissingModules(false);
-
-	loaded = 0;
-	initFilesToLoad();
-	foreach (QString file, m_filesToLoad) {
-		loadOne(mainWindow, file, loaded++);
-	}
-
-	//DebugDialog::debug("after argc");
+    mainWindow->noBackup();
 
 	return mainWindow;
 }
@@ -490,6 +716,10 @@ int FApplication::serviceStartup() {
 			runGedaService();
 			return 0;
 	
+		case DatabaseService:
+			runDatabaseService();
+			return 0;
+	
 		case KicadFootprintService:
 			runKicadFootprintService();
 			return 0;
@@ -502,6 +732,10 @@ int FApplication::serviceStartup() {
 			runGerberService();
 			return 0;
 
+		case SvgService:
+			runSvgService();
+			return 0;
+
 		case PanelizerService:
 			runPanelizerService();
 			return 0;
@@ -520,17 +754,14 @@ int FApplication::serviceStartup() {
 	}
 }
 
-
 void FApplication::runGerberService()
 {
-	createUserDataStoreFolderStructure();
-
-	registerFonts();
-	loadReferenceModel();
-	if (!loadBin("")) {
-		return;
-	}
+	initService();
+    runGerberServiceAux();
+}
 
+void FApplication::runGerberServiceAux()
+{
 	QDir dir(m_outputFolder);
 	QString s = dir.absolutePath();
 	QStringList filters;
@@ -538,14 +769,13 @@ void FApplication::runGerberService()
 	QStringList filenames = dir.entryList(filters, QDir::Files);
 	foreach (QString filename, filenames) {
 		QString filepath = dir.absoluteFilePath(filename);
-		int loaded = 0;
-		MainWindow * mainWindow = loadWindows(loaded, false);
-		mainWindow->noBackup();
+		MainWindow * mainWindow = openWindowForService(false);
 		m_started = true;
-
+        
 		FolderUtils::setOpenSaveFolderAux(m_outputFolder);
 		if (mainWindow->loadWhich(filepath, false, false, "")) {
-			mainWindow->exportToGerber(m_outputFolder);
+            QFileInfo info(filepath);
+            GerberGenerator::exportToGerber(info.completeBaseName(), m_outputFolder, NULL, mainWindow->pcbView(), false);
 		}
 
 		mainWindow->setCloseSilently(true);
@@ -553,6 +783,76 @@ void FApplication::runGerberService()
 	}
 }
 
+void FApplication::initService() 
+{
+	createUserDataStoreFolderStructure();
+	registerFonts();
+	loadReferenceModel("", false);
+}
+
+void FApplication::runSvgService()
+{
+    initService();
+    runSvgServiceAux();
+}
+
+void FApplication::runSvgServiceAux()
+{
+	QDir dir(m_outputFolder);
+	QString s = dir.absolutePath();
+	QStringList filters;
+	filters << "*" + FritzingBundleExtension;
+	QStringList filenames = dir.entryList(filters, QDir::Files);
+	foreach (QString filename, filenames) {
+		QString filepath = dir.absoluteFilePath(filename);
+		MainWindow * mainWindow = openWindowForService(false);
+		m_started = true;
+        
+		FolderUtils::setOpenSaveFolderAux(m_outputFolder);
+		if (mainWindow->loadWhich(filepath, false, false, "")) {
+            QFileInfo info(filepath);
+            QList<ViewLayer::ViewIdentifier> ids;
+            ids << ViewLayer::BreadboardView << ViewLayer::SchematicView << ViewLayer::PCBView;
+            foreach (ViewLayer::ViewIdentifier id, ids) {
+                QString fn = QString("%1_%2.svg").arg(info.completeBaseName()).arg(ViewLayer::viewIdentifierNaturalName(id));
+                QString svgPath = dir.absoluteFilePath(fn);
+                mainWindow->setCurrentView(id);
+                mainWindow->exportSvg(GraphicsUtils::StandardFritzingDPI, false, false, svgPath);
+            }
+		}
+
+		mainWindow->setCloseSilently(true);
+		mainWindow->close();
+	}
+}
+
+void FApplication::runDatabaseService()
+{
+    DebugDialog::setEnabled(true);
+    QDir * parent = FolderUtils::getApplicationSubFolder("pdb");
+    QFileInfoList dirs = parent->entryInfoList(QDir::AllDirs | QDir::NoDotAndDotDot | QDir::NoSymLinks);
+    delete parent;
+
+    QStringList nameFilters;
+    nameFilters << ("*" + FritzingPartExtension);
+    foreach (QFileInfo dirInfo, dirs) {
+        if (!dirInfo.isDir()) continue;
+
+        QDir dir(dirInfo.absoluteFilePath());
+        QFileInfoList files = dir.entryInfoList(nameFilters, QDir::Files | QDir::NoSymLinks);
+        foreach (QFileInfo fileInfo, files) {
+            QString path = fileInfo.absoluteFilePath();
+            QString newPath = path;
+            newPath.replace("/pdb/", "/parts/");
+            QFile::rename(path, newPath);
+        }
+    }
+
+
+    QFile::remove(m_outputFolder);
+	loadReferenceModel(m_outputFolder, true);  // m_outputFolder is actually a full path ending in ".db"
+}
+
 void FApplication::runGedaService() {
 	try {
 		QDir dir(m_outputFolder);
@@ -565,13 +865,7 @@ void FApplication::runGedaService() {
 			newfilepath.replace(".fp", ".svg");
 			GedaElement2Svg geda;
 			QString svg = geda.convert(filepath, false);
-			QFile file(newfilepath);
-			if (file.open(QFile::WriteOnly)) {
-				QTextStream stream(&file);
-				stream.setCodec("UTF-8");
-				stream << svg;
-				file.close();
-			}
+            TextUtils::writeUtf8(newfilepath, svg);
 		}
 	}
 	catch (const QString & msg) {
@@ -604,14 +898,8 @@ void FApplication::runKicadFootprintService() {
 
 				QString newFilePath = dir.absoluteFilePath(moduleName + "_" + filename);
 				newFilePath.replace(".mod", ".svg");
-				QFile file(newFilePath);
-				if (file.open(QFile::WriteOnly)) {
-					QTextStream stream(&file);
-					stream.setCodec("UTF-8");
-					stream << svg;
-					file.close();
-				}
-				else {
+
+				if (!TextUtils::writeUtf8(newFilePath, svg)) {
 					DebugDialog::debug("unable to open file " + newFilePath);
 				}
 			}
@@ -649,14 +937,9 @@ void FApplication::runKicadSchematicService() {
 
 				QString newFilePath = dir.absoluteFilePath(defName + "_" + filename);
 				newFilePath.replace(".lib", ".svg");
+                
 				QFile file(newFilePath);
-				if (file.open(QFile::WriteOnly)) {
-					QTextStream stream(&file);
-					stream.setCodec("UTF-8");
-					stream << svg;
-					file.close();
-				}
-				else {
+				if (!TextUtils::writeUtf8(newFilePath, svg)) {
 					DebugDialog::debug("unable to open file " + newFilePath);
 				}
 			}
@@ -670,7 +953,7 @@ void FApplication::runKicadSchematicService() {
 	}
 }
 
-int FApplication::startup(bool firstRun)
+int FApplication::startup()
 {
 	//DebugDialog::setEnabled(true);
 
@@ -694,38 +977,30 @@ int FApplication::startup(bool firstRun)
 
 	// DebugDialog::debug("Data Location: "+QDesktopServices::storageLocation(QDesktopServices::DataLocation));
 
-	if(firstRun) {		
-		registerFonts();
+	registerFonts();
 
-		if (m_progressIndex >= 0) splash.showProgress(m_progressIndex, LoadProgressStart);
-		ProcessEventBlocker::processEvents();
+	if (m_progressIndex >= 0) splash.showProgress(m_progressIndex, LoadProgressStart);
+	ProcessEventBlocker::processEvents();
 
-		#ifdef Q_WS_WIN
-			// associate .fz file with fritzing app on windows (xp only--vista is different)
-			// TODO: don't change settings if they're already set?
-			// TODO: only do this at install time?
-			QSettings settings1("HKEY_CLASSES_ROOT\\Fritzing", QSettings::NativeFormat);
-			settings1.setValue(".", "Fritzing Application");
-			foreach (QString extension, fritzingExtensions()) {
-				QSettings settings2("HKEY_CLASSES_ROOT\\" + extension, QSettings::NativeFormat);
-				settings2.setValue(".", "Fritzing");
-			}
-			QSettings settings3("HKEY_CLASSES_ROOT\\Fritzing\\shell\\open\\command", QSettings::NativeFormat);
-			settings3.setValue(".", QString("\"%1\" \"%2\"")
-							   .arg(QDir::toNativeSeparators(QApplication::applicationFilePath()))
-							   .arg("%1") );
-		#endif
+	#ifdef Q_WS_WIN
+		// associate .fz file with fritzing app on windows (xp only--vista is different)
+		// TODO: don't change settings if they're already set?
+		// TODO: only do this at install time?
+		QSettings settings1("HKEY_CLASSES_ROOT\\Fritzing", QSettings::NativeFormat);
+		settings1.setValue(".", "Fritzing Application");
+		foreach (QString extension, fritzingExtensions()) {
+			QSettings settings2("HKEY_CLASSES_ROOT\\" + extension, QSettings::NativeFormat);
+			settings2.setValue(".", "Fritzing");
+		}
+		QSettings settings3("HKEY_CLASSES_ROOT\\Fritzing\\shell\\open\\command", QSettings::NativeFormat);
+		settings3.setValue(".", QString("\"%1\" \"%2\"")
+							.arg(QDir::toNativeSeparators(QApplication::applicationFilePath()))
+							.arg("%1") );
+	#endif
 
+	cleanFzzs();
 
-		cleanFzzs();
-	} 
-	else 
-	{
-		clearModels();
-		FSvgRenderer::cleanup();
-	}
-
-	loadReferenceModel();
+	loadReferenceModel("", false);
 
 	QString prevVersion;
 	{
@@ -759,13 +1034,6 @@ int FApplication::startup(bool firstRun)
 	if (m_progressIndex >= 0) splash.showProgress(m_progressIndex, 0.65);
 	ProcessEventBlocker::processEvents();
 
-	QSettings settings;
-	if (!loadBin(settings.value("lastBin").toString())) {
-			// TODO: we're really screwed, what now?
-		QMessageBox::warning(NULL, QObject::tr("Fritzing"), QObject::tr("Friting cannot load the parts bin"));
-		return -1;
-	}
-
 	if (m_progressIndex >= 0) splash.showProgress(m_progressIndex, 0.825);
 	ProcessEventBlocker::processEvents();
 
@@ -776,7 +1044,7 @@ int FApplication::startup(bool firstRun)
 	if (m_progressIndex >= 0) splash.showProgress(m_progressIndex, 0.875);
 
 	DebugDialog::debug("load something");
-	loadSomething(firstRun, prevVersion);
+	loadSomething(prevVersion);
 	m_started = true;
 
 	if (m_progressIndex >= 0) splash.showProgress(m_progressIndex, 0.99);
@@ -807,7 +1075,7 @@ void FApplication::finish()
 }
 
 void FApplication::loadNew(QString path) {
-	MainWindow * mw = MainWindow::newMainWindow(m_paletteBinModel, m_referenceModel, path, true, true);
+	MainWindow * mw = MainWindow::newMainWindow(m_referenceModel, path, true, true);
 	if (!mw->loadWhich(path, false, true, "")) {
 		mw->close();
 	}
@@ -825,6 +1093,13 @@ void FApplication::loadOne(MainWindow * mw, QString path, int loaded) {
 }
 
 void FApplication::preferences() {
+    // delay keeps OS 7 from crashing?
+
+    QTimer::singleShot(30, this, SLOT(preferencesAfter()));
+}
+
+void FApplication::preferencesAfter() 
+{
 	QDir dir(m_translationPath);
 	QStringList nameFilters;
 	nameFilters << "*.qm";
@@ -847,8 +1122,6 @@ void FApplication::preferences() {
 	int ix = 0;
 	foreach (SketchWidget * sketchWidget, mainWindow->sketchWidgets()) {
 		prefsDialog.initViewInfo(ix++,  sketchWidget->viewName(), sketchWidget->getShortName(), 
-									sketchWidget->defaultGridSizeInches(), 
-									sketchWidget->background(), sketchWidget->standardBackground(),
 									sketchWidget->curvyWires());
 	}
 
@@ -894,15 +1167,6 @@ void FApplication::updatePrefs(PrefsDialog & prefsDialog)
 		else if (key.compare("autosaveEnabled") == 0) {
 			MainWindow::setAutosaveEnabled(hash.value(key).toInt());
 		}
-		else if (key.contains("gridsize", Qt::CaseInsensitive)) {
-			foreach (MainWindow * mainWindow, mainWindows) {
-				foreach (SketchWidget * sketchWidget, mainWindow->sketchWidgets()) {
-					if (key.contains(sketchWidget->viewName())) {
-						sketchWidget->initGrid();
-					}
-				}
-			}
-		}
 		else if (key.contains("curvy", Qt::CaseInsensitive)) {
 			foreach (MainWindow * mainWindow, mainWindows) {
 				foreach (SketchWidget * sketchWidget, mainWindow->sketchWidgets()) {
@@ -914,18 +1178,6 @@ void FApplication::updatePrefs(PrefsDialog & prefsDialog)
 		}
 	}
 
-	hash = prefsDialog.tempSettings();
-	foreach (QString key, hash.keys()) {
-		if (key.contains("background", Qt::CaseInsensitive)) {
-			foreach (MainWindow * mainWindow, mainWindows) {
-				foreach (SketchWidget * sketchWidget, mainWindow->sketchWidgets()) {
-					if (key.contains(sketchWidget->getShortName())) {
-						sketchWidget->setBackground(hash.value(key));
-					}
-				}
-			}
-		}
-	}
 }
 
 void FApplication::initSplash(FSplashScreen & splash) {
@@ -967,7 +1219,7 @@ void FApplication::initSplash(FSplashScreen & splash) {
 
 struct Thing {
         QString moduleID;
-        ViewIdentifierClass::ViewIdentifier viewIdentifier;
+        ViewLayer::ViewIdentifier viewIdentifier;
         ViewLayer::ViewLayerID viewLayerID;
 };
 
@@ -1036,42 +1288,12 @@ void FApplication::createUserDataStoreFolderStructure() {
 		}
 	}
 
-    copyBin(BinManager::MyPartsBinLocation, BinManager::MyPartsBinTemplateLocation);
-    copyBin(BinManager::SearchBinLocation, BinManager::SearchBinTemplateLocation);
+    FolderUtils::copyBin(BinManager::MyPartsBinLocation, BinManager::MyPartsBinTemplateLocation);
+    FolderUtils::copyBin(BinManager::SearchBinLocation, BinManager::SearchBinTemplateLocation);
 	PartFactory::initFolder();
 
 }
 
-void FApplication::copyBin(const QString & dest, const QString & source) {
-    if(QFileInfo(dest).exists()) return;
-
-    // this copy action, is not working on windows, because is a resources file
-    if(!QFile(source).copy(dest)) {
-#ifdef Q_WS_WIN // may not be needed from qt 4.5.2 on
-        DebugDialog::debug("Failed to copy a file from the resources");
-        ProcessEventBlocker::processEvents();
-        QDir binsFolder = QFileInfo(dest).dir().absolutePath();
-        QStringList binFiles = binsFolder.entryList(QDir::AllEntries | QDir::NoDotAndDotDot);
-        foreach(QString binName, binFiles) {
-            if(binName.startsWith("qt_temp.")) {
-                QString filePath = binsFolder.absoluteFilePath(binName);
-                bool success = QFile(filePath).rename(dest);
-                Q_UNUSED(success);
-                break;
-            }
-        }
-#endif
-    }
-    QFlags<QFile::Permission> ps = QFile::permissions(dest);
-    QFile::setPermissions(
-        dest,
-        QFile::WriteOwner | QFile::WriteUser | ps
-#ifdef Q_WS_WIN
-        | QFile::WriteOther | QFile::WriteGroup
-#endif
-
-    );
-}
 
 void FApplication::changeActivation(bool activate, QWidget * originator) {
 	if (!activate) return;
@@ -1186,7 +1408,12 @@ which is really not intended for hundreds of widgets.
 }
 
 bool FApplication::runAsService() {
-	return ((FApplication *) qApp)->m_serviceType != NoService;
+    if (m_serviceType == PortService) {
+        initServer();
+        return false;
+    }
+
+	return m_serviceType != NoService;
 }
 
 void FApplication::loadedPart(int loaded, int total) {
@@ -1222,12 +1449,11 @@ bool FApplication::notify(QObject *receiver, QEvent *e)
     return false;
 }
 
-void FApplication::loadSomething(bool firstRun, const QString & prevVersion) {
+void FApplication::loadSomething(const QString & prevVersion) {
     // At this point we're trying to determine what sketches to load which are from one of the following sources:
     // Only one of these sources will actually provide sketches to load and they're listed in order of priority:
 
     //		We found sketch backups to recover
-	//		it's a restart (!firstRun)
 	//		there's a previous version (open an empty sketch)
 	//		files were double-clicked
     //		The last opened sketch
@@ -1247,20 +1473,13 @@ void FApplication::loadSomething(bool firstRun, const QString & prevVersion) {
 
 	DebugDialog::debug(QString("load previous %1").arg(loadPrevious));
 
-	if (!loadPrevious && sketchesToLoad.isEmpty()) {
-		if (!firstRun) {
-			DebugDialog::debug(QString("not first run"));
-			sketchesToLoad = loadLastOpenSketch();
-		}
-	}
-
 	if (!loadPrevious && sketchesToLoad.isEmpty()) {
 		// Check for double-clicked files to load
 		DebugDialog::debug(QString("check files to load %1").arg(m_filesToLoad.count()));
 
         foreach (QString filename, m_filesToLoad) {
             DebugDialog::debug(QString("Loading non-service file %1").arg(filename));
-            MainWindow *mainWindow = MainWindow::newMainWindow(m_paletteBinModel, m_referenceModel, filename, true, true);
+            MainWindow *mainWindow = MainWindow::newMainWindow(m_referenceModel, filename, true, true);
             mainWindow->loadWhich(filename, true, true, "");
             sketchesToLoad << mainWindow;
         }
@@ -1275,7 +1494,7 @@ void FApplication::loadSomething(bool firstRun, const QString & prevVersion) {
 	MainWindow * newBlankSketch = NULL;
 	if (sketchesToLoad.isEmpty()) {
 		DebugDialog::debug(QString("create empty sketch"));
-		newBlankSketch = MainWindow::newMainWindow(m_paletteBinModel, m_referenceModel, "", true, true);
+		newBlankSketch = MainWindow::newMainWindow(m_referenceModel, "", true, true);
 		if (newBlankSketch) {
 			// make sure to start an empty sketch with a board
 			newBlankSketch->addDefaultParts();   // do this before call to show()
@@ -1295,7 +1514,7 @@ void FApplication::loadSomething(bool firstRun, const QString & prevVersion) {
 		doLoadPrevious(newBlankSketch);
 	}
 	else if (newBlankSketch) {
-		newBlankSketch->hideTempBin();
+		newBlankSketch->hideTempPartsBin();
 	}
 }
 
@@ -1312,7 +1531,7 @@ QList<MainWindow *> FApplication::loadLastOpenSketch() {
 
     DebugDialog::debug(QString("Loading last open sketch %1").arg(lastSketchPath));
     settings.remove("lastOpenSketch");				// clear the preference, in case the load crashes
-    MainWindow *mainWindow = MainWindow::newMainWindow(m_paletteBinModel, m_referenceModel, lastSketchPath, true, true);
+    MainWindow *mainWindow = MainWindow::newMainWindow(m_referenceModel, lastSketchPath, true, true);
     mainWindow->loadWhich(lastSketchPath, true, true, "");
     sketches << mainWindow;
     settings.setValue("lastOpenSketch", lastSketchPath);	// the load works, so restore the preference
@@ -1370,7 +1589,7 @@ QList<MainWindow *> FApplication::recoverBackups()
 			QString fileExt;
 			QString bundledFileName = FolderUtils::getSaveFileName(NULL, tr("Please specify an .fzz file name to save to (cancel will delete the backup)"), originalPath, tr("Fritzing (*%1)").arg(FritzingBundleExtension), &fileExt);
 			if (!bundledFileName.isEmpty()) {
-				MainWindow *currentRecoveredSketch = MainWindow::newMainWindow(m_paletteBinModel, m_referenceModel, originalBaseName, true, true);
+				MainWindow *currentRecoveredSketch = MainWindow::newMainWindow(m_referenceModel, originalBaseName, true, true);
     			currentRecoveredSketch->mainLoad(backupName, bundledFileName);
 				currentRecoveredSketch->saveAsShareable(bundledFileName, true);
 				currentRecoveredSketch->setCurrentFile(bundledFileName, true, true);
@@ -1453,7 +1672,7 @@ QString FApplication::makeRequestParamsString() {
 void FApplication::runPanelizerService()
 {	
 	m_started = true;
-	Panelizer::panelize(this, m_panelFilename);
+	Panelizer::panelize(this, m_panelFilename, m_panelizerCustom);
 }
 
 void FApplication::runInscriptionService()
@@ -1475,14 +1694,7 @@ void FApplication::runExampleService()
 {	
 	m_started = true;
 
-	createUserDataStoreFolderStructure();
-	registerFonts();
-	loadReferenceModel();
-
-	if (!loadBin("")) {
-		DebugDialog::debug(QString("load bin failed"));
-		return;
-	}
+	initService();
 
 	QDir sketchesDir(FolderUtils::getApplicationSubFolderPath("sketches"));
 	runExampleService(sketchesDir);
@@ -1496,12 +1708,9 @@ void FApplication::runExampleService(QDir & dir) {
 		QString path = fileInfo.absoluteFilePath();
 		DebugDialog::debug("sketch file " + path);
 
-		int loaded = 0;
-		MainWindow * mainWindow = loadWindows(loaded, false);
+		MainWindow * mainWindow = openWindowForService(false);
 		if (mainWindow == NULL) continue;
 
-		mainWindow->noBackup();
-
 		FolderUtils::setOpenSaveFolderAux(dir.absolutePath());
 
 		if (!mainWindow->loadWhich(path, false, false, "")) {
@@ -1531,3 +1740,130 @@ void FApplication::cleanFzzs() {
 	LockManager::checkLockedFiles("fzz", backupList, lockedFiles, true, LockManager::SlowTime);
 	LockManager::releaseLockedFiles(folder, lockedFiles);
 }
+
+void FApplication::initServer() {
+    m_fServer = new FServer(this);
+    connect(m_fServer, SIGNAL(newConnection(int)), this, SLOT(newConnection(int)));
+    m_fServer->listen(QHostAddress::Any, m_portNumber);
+}
+
+void FApplication::newConnection(int socketDescription) {
+     FServerThread *thread = new FServerThread(socketDescription, this);
+     connect(thread, SIGNAL(finished()), thread, SLOT(deleteLater()));
+     connect(thread, SIGNAL(doCommand(const QString &, const QString &, QString &, int &)), 
+			this, SLOT(doCommand(const QString &, const QString &, QString &, int &)), Qt::BlockingQueuedConnection);
+     thread->start();
+}
+
+
+void FApplication::doCommand(const QString & command, const QString & params, QString & result, int & status) {
+	status = 200;
+	result = "";
+
+    QDir dir(m_portRootFolder);
+
+	QString subfolder = params;
+	if (command.endsWith("tcp")) {
+		subfolder = FolderUtils::getRandText();
+		dir.mkdir(subfolder);
+	}
+
+    dir.cd(subfolder);
+    m_outputFolder = dir.absolutePath();
+
+	if (command.endsWith("tcp")) {
+		QEventLoop loop;
+		QNetworkAccessManager networkManager;
+		QObject::connect(&networkManager, SIGNAL(finished(QNetworkReply*)), &loop, SLOT(quit()));
+
+		QUrl url = params;
+		QNetworkReply* reply = networkManager.get(QNetworkRequest(url));
+
+		loop.exec();
+
+		status = 404;
+
+		if (reply->error() == QNetworkReply::NoError) {
+			if (reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toUInt() == 200) {
+				if (reply->isReadable()) {
+					int buffersize = 8192;
+					QStringList components = params.split("/");
+					QString filename = components.last();
+					QFile file(dir.absoluteFilePath(filename));
+					if (file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
+						status = 200;
+						while (reply->bytesAvailable() >= buffersize) {
+							QByteArray bytes = reply->read(buffersize);
+							file.write(bytes);
+						}
+						if (reply->bytesAvailable() > 0) {
+							file.write(reply->readAll());
+						}
+						file.close();
+					}
+					else {
+						result = "unable to save to local file";
+					}
+				}
+				else {
+					result = "response unreadable";
+				}
+			}
+			else {
+				result = QString("bad response from url server %1").arg(reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toUInt());
+			}
+		}
+		else {
+			result = QString("url get failed %1").arg(reply->error());
+		}
+
+		reply->deleteLater();
+	}
+
+	if (!result.isEmpty()) {
+		// network problem
+		return;
+	}
+
+	if (command.startsWith("svg")) {
+        runSvgServiceAux();
+	    QStringList nameFilters;
+	    nameFilters << ("*.svg");
+	    QFileInfoList fileList = dir.entryInfoList(nameFilters, QDir::Files | QDir::NoSymLinks);
+        if (fileList.count() > 0) {
+            QFile file(fileList.at(0).absoluteFilePath());
+            if (file.open(QFile::ReadOnly)) {
+                result = file.readAll();
+            }
+        }
+    }
+    else if (command.startsWith("gerber")) {
+        runGerberServiceAux();
+	    QStringList nameFilters;
+	    nameFilters << ("*.txt");
+	    QFileInfoList fileList = dir.entryInfoList(nameFilters, QDir::Files | QDir::NoSymLinks);
+        if (fileList.count() > 0) {
+            QFile file(fileList.at(0).absoluteFilePath());
+            if (file.open(QFile::ReadOnly)) {
+                result = file.readAll();
+            }
+        }
+    }
+
+
+	if (command.endsWith("tcp")) {
+		QStringList skipSuffixes(".zip");
+		skipSuffixes << ".fzz";
+		QString filename = dir.absoluteFilePath(subfolder + ".zip");
+		if (FolderUtils::createZipAndSaveTo(dir, filename, skipSuffixes)) {
+			status = 200;
+			result = filename;
+		}
+		else {
+			status = 500;
+			result = "local zip failure";
+		}
+	}
+}
+
+
