@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5590 $:
-$Author: cohen@irascible.com $:
-$Date: 2011-11-05 14:17:28 +0100 (Sat, 05 Nov 2011) $
+$Revision$:
+$Author$:
+$Date$
 
 ********************************************************************/
 
@@ -85,6 +85,9 @@ FSplashScreen::~FSplashScreen() {
 	foreach (MessageThing * messageThing, m_messages) {
 		delete messageThing;
 	}
+	foreach (MessageThing * messageThing, m_items) {
+		delete messageThing;
+	}
 	foreach (PixmapThing * pixmapThing, m_pixmaps) {
 		delete pixmapThing;
 	}
