@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5948 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-07 11:02:13 +0200 (Sat, 07 Apr 2012) $
+$Revision: 6561 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-12 22:39:11 +0200 (Fri, 12 Oct 2012) $
 
 ********************************************************************/
 
@@ -28,6 +28,7 @@ $Date: 2012-04-07 11:02:13 +0200 (Sat, 07 Apr 2012) $
 #include "debugdialog.h"
 #include "svg/svgfilesplitter.h"
 #include "utils/textutils.h"
+#include "utils/graphicsutils.h"
 #include "connectors/svgidlayer.h"
 
 #include <QRegExp>
@@ -39,12 +40,6 @@ $Date: 2012-04-07 11:02:13 +0200 (Sat, 07 Apr 2012) $
 
 QString FSvgRenderer::NonConnectorName("nonconn");
 
-QHash<QString, RendererHash *> FSvgRenderer::m_moduleIDRendererHash;
-QHash<QString, RendererHash * > FSvgRenderer::m_filenameRendererHash;
-QSet<RendererHash * > FSvgRenderer::m_deleted;
-
-double FSvgRenderer::m_printerScale = 90.0;
-
 static ConnectorInfo VanillaConnectorInfo;
 
 FSvgRenderer::FSvgRenderer(QObject * parent) : QSvgRenderer(parent)
@@ -58,6 +53,10 @@ FSvgRenderer::~FSvgRenderer()
 	clearConnectorInfoHash(m_nonConnectorInfoHash);
 }
 
+void FSvgRenderer::initNames() {
+    VanillaConnectorInfo.gotCircle = false;	
+}
+
 void FSvgRenderer::clearConnectorInfoHash(QHash<QString, ConnectorInfo *> & hash) {
 	foreach (ConnectorInfo * connectorInfo, hash.values()) {
 		delete connectorInfo;
@@ -66,22 +65,7 @@ void FSvgRenderer::clearConnectorInfoHash(QHash<QString, ConnectorInfo *> & hash
 }
 
 void FSvgRenderer::cleanup() {
-	foreach (RendererHash * rendererHash, m_filenameRendererHash.values()) {
-		foreach (FSvgRenderer * renderer, rendererHash->values()) {
-			delete renderer;
-		}
-		delete rendererHash;
-	}
-	m_filenameRendererHash.clear();
-	foreach (RendererHash * rendererHash, m_moduleIDRendererHash.values()) {
-		delete rendererHash;
-	}
-	m_moduleIDRendererHash.clear();
 
-	foreach (RendererHash * rendererHash, m_deleted) {
-		delete rendererHash;
-	}
-	m_deleted.clear();
 }
 
 QByteArray FSvgRenderer::loadSvg(const QString & filename) {
@@ -111,61 +95,42 @@ QByteArray FSvgRenderer::loadSvg(const QString & filename, const QStringList & c
 
 bool FSvgRenderer::loadSvgString(const QString & svg) {
 	QByteArray byteArray(svg.toUtf8());
-	QByteArray result = loadSvg(byteArray, "");
-	return !result.isEmpty();
+	QByteArray result = loadSvg(byteArray, "", true);
+    return (!result.isEmpty());
 }
 
-QByteArray FSvgRenderer::loadSvg(const QByteArray & contents, const QString & filename) {
+bool FSvgRenderer::loadSvgString(const QString & svg, QString & newSvg) {
+	QByteArray byteArray(svg.toUtf8());
+	QByteArray result = loadSvg(byteArray, "", true);
+    newSvg = QString(result);
+    return (!result.isEmpty());
+}
+
+QByteArray FSvgRenderer::loadSvg(const QByteArray & contents, const QString & filename, bool findNonConnectors) {
 	QStringList strings;
 	QString string;
-	return loadSvg(contents, filename, strings, strings, strings, string, string, false);
+	return loadSvg(contents, filename, strings, strings, strings, string, string, findNonConnectors);
 }
 
 QByteArray FSvgRenderer::loadSvg(const QByteArray & contents, const QString & filename, const QStringList & connectorIDs, const QStringList & terminalIDs, const QStringList & legIDs, const QString & setColor, const QString & colorElementID, bool findNonConnectors) {
 	return loadAux(contents, filename, connectorIDs, terminalIDs, legIDs, setColor, colorElementID, findNonConnectors);
 }
 
-QByteArray FSvgRenderer::loadAux(const QByteArray & contents, const QString & filename, const QStringList & connectorIDs, const QStringList & terminalIDs, const QStringList & legIDs, const QString & setColor, const QString & colorElementID, bool findNonConnectors) {
-
-	QByteArray cleanContents;
+QByteArray FSvgRenderer::loadAux(const QByteArray & theContents, const QString & filename, const QStringList & connectorIDs, const QStringList & terminalIDs, const QStringList & legIDs, const QString & setColor, const QString & colorElementID, bool findNonConnectors) 
+{
+	QByteArray cleanContents(theContents);
 	bool cleaned = false;
-	if (TextUtils::isIllustratorFile(contents)) {
-		QString string(contents);
 
-		if (contents.contains("sodipodi") || contents.contains("inkscape")) {
-			// if svg has both Illustrator and Inkscape crap then converting back and forth between strings and QDomDocument
-			// in FixPixelDimensionsIn() can result in invalid xml
-			TextUtils::cleanSodipodi(string);
-#ifndef QT_NO_DEBUG
-			if (!filename.contains("icon", Qt::CaseInsensitive)) {
-				DebugDialog::debug("Illustrator and inkscape:" + filename);
-			}
-#endif
-		}
-
-		//DebugDialog::debug("Illustrator " + filename);
-		if (TextUtils::fixPixelDimensionsIn(string)) {
-			cleaned = true;
-			cleanContents = string.toUtf8();
-		}
-	}
-	
-	if (contents.contains("sodipodi") || contents.contains("inkscape")) {
-		//DebugDialog::debug("inkscape " + filename);
-	}
-
-	if (contents.contains("<tspan")) {
-		QString string(contents);
-		TextUtils::tspanRemove(string);
-		cleanContents = string.toUtf8();
+    QString string(cleanContents);
+    if (TextUtils::fixMuch(string, false)) {
 		cleaned = true;
 	}
-
-	if (!cleaned) {
-		cleanContents = contents; 
-	}
-
-	// no it isn't
+	if (TextUtils::fixPixelDimensionsIn(string)) {
+        cleaned = true;
+    }
+    if (cleaned) {
+        cleanContents = string.toUtf8();
+    }
 
 	if (connectorIDs.count() > 0 || !setColor.isEmpty() || findNonConnectors) {
 		QString errorStr;
@@ -189,11 +154,11 @@ QByteArray FSvgRenderer::loadAux(const QByteArray & contents, const QString & fi
 			}
 		}
 		if (connectorIDs.count() > 0) {
-			bool init =  initConnectorInfo(doc, connectorIDs, terminalIDs, legIDs);
+			bool init =  initConnectorInfo(doc, connectorIDs, terminalIDs, legIDs, filename);
 			resetContents = resetContents || init;
 		}
 		if (findNonConnectors) {
-			initNonConnectorInfo(doc);
+			initNonConnectorInfo(doc, filename);
 		}
 
 		if (resetContents) {
@@ -239,104 +204,43 @@ const QString & FSvgRenderer::filename() {
 	return m_filename;
 }
 
-FSvgRenderer * FSvgRenderer::getByFilename(const QString & filename, ViewLayer::ViewLayerID viewLayerID) {
-	RendererHash * rendererHash = m_filenameRendererHash.value(filename);
-	if (rendererHash == NULL) return NULL;
-
-	return rendererHash->value(viewLayerID, NULL);
-}
-
-FSvgRenderer * FSvgRenderer::getByModuleID(const QString & moduleID, ViewLayer::ViewLayerID viewLayerID) {
-	RendererHash * rendererHash = m_moduleIDRendererHash.value(moduleID);
-	if (rendererHash == NULL) return NULL;
-
-	return rendererHash->value(viewLayerID, NULL);
-}
-
-QPixmap * FSvgRenderer::getPixmap(const QString & moduleID, ViewLayer::ViewLayerID viewLayerId, QSize size) {
-	// TODO: cache pixmap by size?
-
-	QPixmap *pixmap = NULL;
-	FSvgRenderer * renderer = getByModuleID(moduleID, viewLayerId);
-	if (renderer) {
-		pixmap = new QPixmap(size);
-		pixmap->fill(Qt::transparent);
-		QPainter painter(pixmap);
-		// preserve aspect ratio
-		QSizeF def = renderer->defaultSizeF();
-		double newW = size.width();
-		double newH = newW * def.height() / def.width();
-		if (newH > size.height()) {
-			newH = size.height();
-			newW = newH * def.width() / def.height();
-		}
-		QRectF bounds((size.width() - newW) / 2.0, (size.height() - newH) / 2.0, newW, newH);
-		renderer->render(&painter, bounds);
-		painter.end();
+QPixmap * FSvgRenderer::getPixmap(QSvgRenderer * renderer, QSize size) 
+{
+	QPixmap *pixmap = new QPixmap(size);
+	pixmap->fill(Qt::transparent);
+	QPainter painter(pixmap);
+	// preserve aspect ratio
+	QSizeF def = renderer->defaultSize();
+    FSvgRenderer * frenderer = qobject_cast<FSvgRenderer *>(renderer);
+    if (frenderer) {
+        def = frenderer->defaultSizeF();
+    }
+	double newW = size.width();
+	double newH = newW * def.height() / def.width();
+	if (newH > size.height()) {
+		newH = size.height();
+		newW = newH * def.width() / def.height();
 	}
-	return pixmap;
-}
+	QRectF bounds((size.width() - newW) / 2.0, (size.height() - newH) / 2.0, newW, newH);
+	renderer->render(&painter, bounds);
+	painter.end();
 
-void FSvgRenderer::set(const QString & moduleID, ViewLayer::ViewLayerID viewLayerID, FSvgRenderer * renderer) {
-	RendererHash * rendererHash = m_filenameRendererHash.value(renderer->filename());
-	if (rendererHash == NULL) {
-		rendererHash = new RendererHash();
-		m_filenameRendererHash.insert(renderer->filename(), rendererHash);
-	}
-	rendererHash->insert(viewLayerID, renderer);
-	rendererHash = m_moduleIDRendererHash.value(moduleID);
-	if (rendererHash == NULL) {
-		rendererHash = new RendererHash();
-		m_moduleIDRendererHash.insert(moduleID, rendererHash);
-	}
-	rendererHash->insert(viewLayerID, renderer);
+    return pixmap;
 }
 
 bool FSvgRenderer::determineDefaultSize(QXmlStreamReader & xml)
 {
 	QSizeF size = parseForWidthAndHeight(xml);
 
-	m_defaultSizeF = QSizeF(size.width() * m_printerScale, size.height() * m_printerScale);
+	m_defaultSizeF = QSizeF(size.width() * GraphicsUtils::SVGDPI, size.height() * GraphicsUtils::SVGDPI);
 	return (size.width() != 0 && size.height() != 0);
 }
 
 QSizeF FSvgRenderer::parseForWidthAndHeight(QXmlStreamReader & xml)
 {
-    xml.setNamespaceProcessing(false);
-
-	QSizeF size(0,0);
-
-	bool isIllustrator = false;
-	bool bad = false;
-
-	while (!xml.atEnd() && !bad) {
-        switch (xml.readNext()) {
-		case QXmlStreamReader::Comment:
-			if (!isIllustrator) {
-				isIllustrator = TextUtils::isIllustratorFile(xml.text().toString());
-			}
-			break;
-        case QXmlStreamReader::StartElement:
-			if (xml.name().toString().compare("svg") == 0) {
-				QString ws = xml.attributes().value("width").toString();
-				QString hs = xml.attributes().value("height").toString();
-				bool okw, okh;
-				double w = TextUtils::convertToInches(ws, &okw, isIllustrator);
-				double h = TextUtils::convertToInches(hs, &okh, isIllustrator);
-				if (!okw || qIsNaN(w) || qIsInf(w) || !okh || qIsNaN(h) || qIsInf(h)) {
-					bad = true;
-					break;
-				}
-
-				size.setWidth(w);
-				size.setHeight(h);
-				return size;
-			}
-			break;		
-		default:
-			break;		
-		}
-	}
+	QRectF viewBox;
+    QSizeF size = TextUtils::parseForWidthAndHeight(xml, viewBox);
+    if (size.width() != 0 && size.height() != 0) return size;
 
 	QIODevice * device = xml.device();
 	DebugDialog::debug("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!");
@@ -359,49 +263,34 @@ QSizeF FSvgRenderer::defaultSizeF() {
 	return m_defaultSizeF;
 }
 
-void FSvgRenderer::calcPrinterScale() {
 
-	// note: I think that printerScale is probably just 90 dpi, since the calculation
-	// result is 89.8407 for the breadboard svg across all three platforms 
-	// note: calculation result depends on the svg used; if the svg size is a float, the scale will vary a little
-	// using an svg file with exactly a 1-inch width (like 'wire.svg') gives exactly a 90.0 printerscale value.
-
-	VanillaConnectorInfo.gotCircle = false;				
-	m_printerScale = 90.0;
-
-}
-
-double FSvgRenderer::printerScale() {
-	return m_printerScale;
-}
-
-void FSvgRenderer::initNonConnectorInfo(QDomDocument & domDocument)
+void FSvgRenderer::initNonConnectorInfo(QDomDocument & domDocument, const QString & filename)
 {
 	clearConnectorInfoHash(m_nonConnectorInfoHash);
 	QDomElement root = domDocument.documentElement();
-	initNonConnectorInfoAux(root);
+	initNonConnectorInfoAux(root, filename);
 }
 
-void FSvgRenderer::initNonConnectorInfoAux(QDomElement & element)
+void FSvgRenderer::initNonConnectorInfoAux(QDomElement & element, const QString & filename)
 {
 	QString id = element.attribute("id");
 	if (id.startsWith(NonConnectorName, Qt::CaseInsensitive)) {
-		ConnectorInfo * connectorInfo = initConnectorInfoStruct(element);
+		ConnectorInfo * connectorInfo = initConnectorInfoStruct(element, filename);
 		m_nonConnectorInfoHash.insert(id, connectorInfo);
 	}
 	QDomElement child = element.firstChildElement();
 	while (!child.isNull()) {
-		initNonConnectorInfoAux(child);
+		initNonConnectorInfoAux(child, filename);
 		child = child.nextSiblingElement();
 	}
 }
 
-bool FSvgRenderer::initConnectorInfo(QDomDocument & domDocument, const QStringList & connectorIDs, const QStringList & terminalIDs, const QStringList & legIDs)
+bool FSvgRenderer::initConnectorInfo(QDomDocument & domDocument, const QStringList & connectorIDs, const QStringList & terminalIDs, const QStringList & legIDs, const QString & filename)
 {
 	bool result = false;
 	clearConnectorInfoHash(m_connectorInfoHash);
 	QDomElement root = domDocument.documentElement();
-	initConnectorInfoAux(root, connectorIDs);
+	initConnectorInfoAux(root, connectorIDs, filename);
 	if (terminalIDs.count() > 0) {
 		initTerminalInfoAux(root, connectorIDs, terminalIDs);
 	}
@@ -492,12 +381,12 @@ void FSvgRenderer::initTerminalInfoAux(QDomElement & element, const QStringList
 	}
 }
 
-void FSvgRenderer::initConnectorInfoAux(QDomElement & element, const QStringList & connectorIDs)
+void FSvgRenderer::initConnectorInfoAux(QDomElement & element, const QStringList & connectorIDs, const QString & filename)
 {
 	QString id = element.attribute("id");
 	if (!id.isEmpty()) {
 		if (connectorIDs.contains(id)) {
-			ConnectorInfo * connectorInfo = initConnectorInfoStruct(element);
+			ConnectorInfo * connectorInfo = initConnectorInfoStruct(element, filename);
 			m_connectorInfoHash.insert(id, connectorInfo);
 		}
 		// don't return here, might miss other connectors
@@ -505,12 +394,12 @@ void FSvgRenderer::initConnectorInfoAux(QDomElement & element, const QStringList
 
 	QDomElement child = element.firstChildElement();
 	while (!child.isNull()) {
-		initConnectorInfoAux(child, connectorIDs);
+		initConnectorInfoAux(child, connectorIDs, filename);
 		child = child.nextSiblingElement();
 	}
 }
 
-ConnectorInfo * FSvgRenderer::initConnectorInfoStruct(QDomElement & connectorElement) {
+ConnectorInfo * FSvgRenderer::initConnectorInfoStruct(QDomElement & connectorElement, const QString & filename) {
 	ConnectorInfo * connectorInfo = new ConnectorInfo();
 	connectorInfo->radius = connectorInfo->strokeWidth = 0;
 	connectorInfo->gotCircle = false;
@@ -518,17 +407,17 @@ ConnectorInfo * FSvgRenderer::initConnectorInfoStruct(QDomElement & connectorEle
 	if (connectorElement.isNull()) return connectorInfo;
 
 	connectorInfo->matrix = TextUtils::elementToMatrix(connectorElement);
-	initConnectorInfoStructAux(connectorElement, connectorInfo);
+	initConnectorInfoStructAux(connectorElement, connectorInfo, filename);
 	return connectorInfo;
 }
 
-bool FSvgRenderer::initConnectorInfoStructAux(QDomElement & element, ConnectorInfo * connectorInfo) 
+bool FSvgRenderer::initConnectorInfoStructAux(QDomElement & element, ConnectorInfo * connectorInfo, const QString & filename) 
 {
 	// right now we only handle circles
 	if (element.nodeName().compare("circle") != 0) {
 		QDomElement child = element.firstChildElement();
 		while (!child.isNull()) {
-			if (initConnectorInfoStructAux(child, connectorInfo)) return true;
+			if (initConnectorInfoStructAux(child, connectorInfo, filename)) return true;
 
 			child = child.nextSiblingElement();
 		}
@@ -547,13 +436,32 @@ bool FSvgRenderer::initConnectorInfoStructAux(QDomElement & element, ConnectorIn
 
 	double sw = element.attribute("stroke-width").toDouble(&ok);	
 	if (!ok) {
-		//QString strokewidth("stroke-width");
-		//QString s = element.attribute("style");
-		//SvgFileSplitter::fixStyleAttribute(connectorElement, s, strokewidth);
-		//sw = connectorElement.attribute("stroke-width").toDouble(&ok);
-		//if (!ok) {
-			return false;
-		//}
+        QDomElement parent = element.parentNode().toElement();
+        while (!parent.isNull()) {
+            sw = element.attribute("stroke-width").toDouble(&ok);
+            if (ok) {
+                break;
+            }
+
+            parent = parent.parentNode().toElement();
+        }
+
+        if (!ok) {
+            QString text;
+            QTextStream stream(&text);
+            element.save(stream, 0);
+            //DebugDialog::debug(QString("no circle stroke width set in %1: %2").arg(filename).arg(text));
+            element.setAttribute("stroke-width", 1);
+            sw = 1;
+
+		    //QString strokewidth("stroke-width");
+		    //QString s = element.attribute("style");
+		    //SvgFileSplitter::fixStyleAttribute(connectorElement, s, strokewidth);
+		    //sw = connectorElement.attribute("stroke-width").toDouble(&ok);
+		    //if (!ok) {
+			    //return false;
+		    //}
+        }
 	}
 
 	QMatrix matrix = TextUtils::elementToMatrix(element);
@@ -574,19 +482,6 @@ bool FSvgRenderer::initConnectorInfoStructAux(QDomElement & element, ConnectorIn
 	return true;
 }
 
-void FSvgRenderer::removeFromHash(const QString &moduleId, const QString filename) {
-	//DebugDialog::debug(QString("length before %1").arg(m_moduleIDRendererHash.size()));
-	RendererHash * r = m_moduleIDRendererHash.take(moduleId);
-	if (r != NULL) {
-		m_deleted.insert(r);
-	}
-	//DebugDialog::debug(QString("length after %1").arg(m_moduleIDRendererHash.size()));
-	r = m_filenameRendererHash.take(filename);
-	if (r != NULL) {
-		m_deleted.insert(r);
-	}
-}
-
 ConnectorInfo * FSvgRenderer::getConnectorInfo(const QString & connectorID) {
 	return m_connectorInfoHash.value(connectorID, &VanillaConnectorInfo);
 }
@@ -631,12 +526,6 @@ bool FSvgRenderer::setUpConnector(SvgIdLayer * svgIdLayer, bool ignoreTerminalPo
 				bounds);
 	*/
 
-	if (connectorInfo && connectorInfo->gotCircle) {
-		svgIdLayer->m_radius = connectorInfo->radius * defaultSizeF.width() / viewBox.width();
-		svgIdLayer->m_strokeWidth = connectorInfo->strokeWidth * defaultSizeF.width() / viewBox.width();
-		//bounds = connectorInfo->cbounds;
-	}
-
 	
 	/*DebugDialog::debug(QString("identity matrix %11 %1 %2, viewbox: %3 %4 %5 %6, bounds: %7 %8 %9 %10, size: %12 %13").arg(m_modelPart->title()).arg(connectorSharedID())
 					   .arg(viewBox.x()).arg(viewBox.y()).arg(viewBox.width()).arg(viewBox.height())
@@ -650,7 +539,21 @@ bool FSvgRenderer::setUpConnector(SvgIdLayer * svgIdLayer, bool ignoreTerminalPo
 	// might be a qt problem.
 	//QMatrix matrix0 = connectorInfo->matrix * this->matrixForElement(connectorID);  
 	//QRectF r1 = matrix0.mapRect(bounds);
-	QRectF r1 = this->matrixForElement(connectorID).mapRect(bounds);
+
+    QMatrix elementMatrix = this->matrixForElement(connectorID);
+	QRectF r1 = elementMatrix.mapRect(bounds);
+
+	if (connectorInfo && connectorInfo->gotCircle) {
+        QLineF l(0,0,connectorInfo->radius, 0);
+        QLineF lm = elementMatrix.map(l);
+		svgIdLayer->m_radius = lm.length() * defaultSizeF.width() / viewBox.width();
+
+        QLineF k(0,0,connectorInfo->strokeWidth, 0);
+        QLineF km = elementMatrix.map(l);
+		svgIdLayer->m_strokeWidth = km.length() * defaultSizeF.width() / viewBox.width();
+		//bounds = connectorInfo->cbounds;
+	}
+
 
 	/*
 	svgIdLayer->m_rect.setRect(r1.x() * defaultSize.width() / viewBox.width(), 
@@ -760,7 +663,7 @@ QList<SvgIdLayer *> FSvgRenderer::setUpNonConnectors() {
 	if (m_nonConnectorInfoHash.count() == 0) return list;
 
 	foreach (QString nonConnectorID, m_nonConnectorInfoHash.keys()) {
-		SvgIdLayer * svgIdLayer = new SvgIdLayer();
+		SvgIdLayer * svgIdLayer = new SvgIdLayer(ViewLayer::PCBView);
 		svgIdLayer->m_processed = true;
 		svgIdLayer->m_svgId = nonConnectorID;
 		QRectF bounds = this->boundsOnElement(nonConnectorID);
