@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5948 $:
+$Revision: 6245 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-04-07 11:02:13 +0200 (Sat, 07 Apr 2012) $
+$Date: 2012-08-04 08:42:55 +0200 (Sat, 04 Aug 2012) $
 
 ********************************************************************/
 
@@ -53,6 +53,7 @@ typedef QHash<ViewLayer::ViewLayerID, class FSvgRenderer *> RendererHash;
 
 class FSvgRenderer : public QSvgRenderer
 {
+Q_OBJECT
 public:
 	FSvgRenderer(QObject * parent = 0);
 	~FSvgRenderer();
@@ -60,8 +61,9 @@ public:
 	QByteArray loadSvg(const QString & filename, const QStringList & connectorIDs, const QStringList & terminalIDs, const QStringList & legIDs, const QString & setColor, const QString & colorElementID, bool findNonConnectors);
 	QByteArray loadSvg(const QString & filename);
 	QByteArray loadSvg( const QByteArray & contents, const QString & filename, const QStringList & connectorIDs, const QStringList & terminalIDs, const QStringList & legIDs, const QString & setColor, const QString & colorElementID, bool findNonConnectors);     // for SvgSplitter loads
-	QByteArray loadSvg( const QByteArray & contents, const QString & filename);						// for SvgSplitter loads
+	QByteArray loadSvg( const QByteArray & contents, const QString & filename, bool findNonConnectors);						// for SvgSplitter loads
 	bool loadSvgString(const QString & svg);
+	bool loadSvgString(const QString & svg, QString & newSvg);
 	bool fastLoad(const QByteArray & contents);								
 	const QString & filename();
 	QSizeF defaultSizeF();
@@ -69,27 +71,22 @@ public:
 	QList<SvgIdLayer *> setUpNonConnectors();
 
 public:
-	static void set(const QString & moduleID, ViewLayer::ViewLayerID, FSvgRenderer *);
-	static FSvgRenderer * getByModuleID(const QString & moduleID, ViewLayer::ViewLayerID);
-	static FSvgRenderer * getByFilename(const QString & filename, ViewLayer::ViewLayerID);
-	static QPixmap * getPixmap(const QString & moduleID, ViewLayer::ViewLayerID viewLayerID, QSize size);
-	static void calcPrinterScale();
-	static double printerScale();
 	static void cleanup();
 	static QSizeF parseForWidthAndHeight(QXmlStreamReader &);
-	static void removeFromHash(const QString &moduleId, const QString filename);
+	static QPixmap * getPixmap(QSvgRenderer * renderer, QSize size);
+    static void initNames();
 
 protected:
 	bool determineDefaultSize(QXmlStreamReader &);
 	QByteArray loadAux (const QByteArray & contents, const QString & filename, const QStringList & connectorIDs, const QStringList & terminalIDs, const QStringList & legIDs, const QString & setColor, const QString & colorElementID, bool findNonConnectors);
-	bool initConnectorInfo(QDomDocument &, const QStringList & connectorIDs, const QStringList & terminalIDs, const QStringList & legIDs);
-	ConnectorInfo * initConnectorInfoStruct(QDomElement & connectorElement);
-	bool initConnectorInfoStructAux(QDomElement &, ConnectorInfo * connectorInfo);
-	void initNonConnectorInfo(QDomDocument & domDocument);
-	void initNonConnectorInfoAux(QDomElement & element);
+	bool initConnectorInfo(QDomDocument &, const QStringList & connectorIDs, const QStringList & terminalIDs, const QStringList & legIDs, const QString & filename);
+	ConnectorInfo * initConnectorInfoStruct(QDomElement & connectorElement, const QString & filename);
+	bool initConnectorInfoStructAux(QDomElement &, ConnectorInfo * connectorInfo, const QString & filename);
+	void initNonConnectorInfo(QDomDocument & domDocument, const QString & filename);
+	void initNonConnectorInfoAux(QDomElement & element, const QString & filename);
 	void initTerminalInfoAux(QDomElement & element, const QStringList & connectorIDs, const QStringList & terminalIDs);
 	void initLegInfoAux(QDomElement & element, const QStringList & connectorIDs, const QStringList & legIDs, bool & gotOne);
-	void initConnectorInfoAux(QDomElement & element, const QStringList & connectorIDs);
+	void initConnectorInfoAux(QDomElement & element, const QStringList & connectorIDs, const QString & filename);
 	QPointF calcTerminalPoint(const QString & terminalId, const QRectF & connectorRect, bool ignoreTerminalPoint, const QRectF & viewBox, QMatrix & terminalMatrix);
 	bool initLegInfoAux(QDomElement & element, ConnectorInfo * connectorInfo);
 	void calcLeg(SvgIdLayer *, const QRectF & viewBox, ConnectorInfo * connectorInfo);
@@ -102,12 +99,6 @@ protected:
 	QHash<QString, ConnectorInfo *> m_connectorInfoHash;
 	QHash<QString, ConnectorInfo *> m_nonConnectorInfoHash;
 
-protected:
-	static double m_printerScale;
-	static QHash<QString, RendererHash * > m_filenameRendererHash;
-	static QHash<QString, RendererHash * > m_moduleIDRendererHash;
-	static QSet<RendererHash *> m_deleted;
-
 public:
 	static QString NonConnectorName;
 
