@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2010 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5765 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-21 12:26:11 +0100 (Sat, 21 Jan 2012) $
+$Revision: 6565 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-15 12:10:48 +0200 (Mon, 15 Oct 2012) $
 
 ********************************************************************/
 
@@ -121,11 +121,11 @@ Helper::~Helper() {
 }
 
 void Helper::connectToView(SketchWidget* view) {
-	connect(view, SIGNAL(dropSignal(const QPoint &, ModelPart *)), this, SLOT(somethingDroppedIntoView(const QPoint &, ModelPart *)));
+	connect(view, SIGNAL(dropSignal(const QPoint &)), this, SLOT(somethingDroppedIntoView(const QPoint &)));
 }
 
 
-void Helper::somethingDroppedIntoView(const QPoint & pos, ModelPart *) {
+void Helper::somethingDroppedIntoView(const QPoint & pos) {
 	Q_UNUSED(pos);
 
 	if(m_stillWaitingFirstDrop) {
@@ -137,7 +137,7 @@ void Helper::somethingDroppedIntoView(const QPoint & pos, ModelPart *) {
 		m_breadMainHelp->setTransparent();
 		m_schemMainHelp->setTransparent();
 		m_pcbMainHelp->setTransparent();
-		disconnect(m_owner->m_currentGraphicsView, SIGNAL(dropSignal(const QPoint &, ModelPart *)), this, SLOT(somethingDroppedIntoView(const QPoint &, ModelPart *)));
+		disconnect(m_owner->m_currentGraphicsView, SIGNAL(dropSignal(const QPoint &)), this, SLOT(somethingDroppedIntoView(const QPoint &)));
 	}
 	m_owner->update();   // fixes update problem, thanks to bryant.mairs
 }
