@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5765 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-21 12:26:11 +0100 (Sat, 21 Jan 2012) $
+$Revision: 6565 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-15 12:10:48 +0200 (Mon, 15 Oct 2012) $
 
 ********************************************************************/
 
@@ -34,7 +34,7 @@ $Date: 2012-01-21 12:26:11 +0100 (Sat, 21 Jan 2012) $
 #include <QObject>
 
 #include "sketchmainhelp.h"
-#include "../mainwindow.h"
+#include "../mainwindow/mainwindow.h"
 
 class Helper : public QObject {
 	Q_OBJECT
@@ -51,7 +51,7 @@ class Helper : public QObject {
 		static void initText();
 
 	protected slots:
-		void somethingDroppedIntoView(const QPoint &, ModelPart *);
+		void somethingDroppedIntoView(const QPoint &);
 		void viewSwitched();
 
 	protected:
