@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5782 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-26 06:04:40 +0100 (Thu, 26 Jan 2012) $
+$Revision: 6506 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-03 13:11:12 +0200 (Wed, 03 Oct 2012) $
 
 ********************************************************************/
 
@@ -28,7 +28,6 @@ $Date: 2012-01-26 06:04:40 +0100 (Thu, 26 Jan 2012) $
 #include <QHBoxLayout>
 #include <QSettings>
 #include <QPalette>
-#include <QFormLayout>
 #include <QFontMetricsF>
 #include <qmath.h>
 
@@ -38,9 +37,9 @@ $Date: 2012-01-26 06:04:40 +0100 (Thu, 26 Jan 2012) $
 #include "../connectors/connectorshared.h"
 #include "../connectors/connector.h"
 #include "../fsvgrenderer.h"
-#include "../dockmanager.h"
 #include "../utils/flineedit.h"
 #include "../items/moduleidnames.h"
+#include "../items/paletteitem.h"
 
 
 #define HTML_EOF "</body>\n</html>"
@@ -51,8 +50,6 @@ const int HtmlInfoView::STANDARD_ICON_IMG_WIDTH = 32;
 const int HtmlInfoView::STANDARD_ICON_IMG_HEIGHT = 32;
 const int IconSpace = 0;
 
-QHash<QString, QPixmap *> HtmlInfoView::m_pixmaps;
-
 /////////////////////////////////////
 
 QLabel * addLabel(QHBoxLayout * hboxLayout, QPixmap * pixmap) {
@@ -109,7 +106,7 @@ HtmlInfoView::HtmlInfoView(QWidget * parent) : QScrollArea(parent)
 	m_lastTitleItemBase = NULL;
 	m_lastTagsModelPart = NULL;
 	m_lastConnectorItem = NULL;
-	m_lastIconModelPart = NULL;
+	m_lastIconItemBase = NULL;
 	m_lastPropsModelPart = NULL;
 	m_lastPropsItemBase = NULL;
 
@@ -117,6 +114,7 @@ HtmlInfoView::HtmlInfoView(QWidget * parent) : QScrollArea(parent)
 	m_partUrl = NULL;
 	m_partVersion = NULL;
 	m_lockCheckbox = NULL;
+	m_stickyCheckbox = NULL;
 	m_connDescr = NULL;
 	m_tagsTextLabel = NULL;
 	m_lastSwappingEnabled = false;
@@ -137,7 +135,7 @@ HtmlInfoView::HtmlInfoView(QWidget * parent) : QScrollArea(parent)
 	m_titleEdit->setToolTip(tr("Change the part label here"));
 	m_titleEdit->setAlignment(Qt::AlignLeft);
 
-	connect(m_titleEdit, SIGNAL(editingFinished()), this, SLOT(setInstanceTitle()));
+	connect(m_titleEdit, SIGNAL(editingFinished()), this, SLOT(setInstanceTitle()), Qt::QueuedConnection);
 	connect(m_titleEdit, SIGNAL(mouseEnter()), this, SLOT(instanceTitleEnter()));
 	connect(m_titleEdit, SIGNAL(mouseLeave()), this, SLOT(instanceTitleLeave()));
 	connect(m_titleEdit, SIGNAL(editable(bool)), this, SLOT(instanceTitleEditable(bool)));
@@ -171,15 +169,28 @@ HtmlInfoView::HtmlInfoView(QWidget * parent) : QScrollArea(parent)
 	m_partVersion = new QLabel();
 	m_partVersion->setObjectName("infoViewPartVersion");
 	m_partVersion->setToolTip(tr("Part version number"));
+    m_partVersion->setOpenExternalLinks(false);
+    m_partVersion->setAlignment(Qt::AlignLeft | Qt::AlignTop);
+    connect(m_partVersion, SIGNAL(linkActivated(const QString &)), this, SLOT(clickObsolete(const QString &)));
 	subVersionLayout->addWidget(m_partVersion, 0, Qt::AlignLeft);
 	subVersionLayout->addStretch(1);
 	versionLayout->addLayout(subVersionLayout);
+
+    QHBoxLayout * cbLayout = new QHBoxLayout();
 	
 	m_lockCheckbox = new QCheckBox(tr("Locked"));
 	m_lockCheckbox->setObjectName("infoViewLockCheckbox");
-	m_lockCheckbox->setToolTip(tr("Change the locked state of the part in this view.  A locked part can't be moved"));
+	m_lockCheckbox->setToolTip(tr("Change the locked state of the part in this view. A locked part can't be moved."));
 	connect(m_lockCheckbox, SIGNAL(clicked(bool)), this, SLOT(changeLock(bool)));
-	versionLayout->addWidget(m_lockCheckbox);
+	cbLayout->addWidget(m_lockCheckbox);
+
+	m_stickyCheckbox = new QCheckBox(tr("Sticky"));
+	m_stickyCheckbox->setObjectName("infoViewLockCheckbox");
+	m_stickyCheckbox->setToolTip(tr("Change the \"sticky\" state of the part in this view. When a sticky part is moved, objects on top of it also move."));
+	connect(m_stickyCheckbox, SIGNAL(clicked(bool)), this, SLOT(changeSticky(bool)));
+	cbLayout->addWidget(m_stickyCheckbox);
+
+    versionLayout->addLayout(cbLayout);
 
 	hboxLayout->addLayout(versionLayout);
 	
@@ -271,11 +282,6 @@ HtmlInfoView::~HtmlInfoView() {
 		delete propThing;
 	}
 	m_propThings.clear();
-
-	foreach (QPixmap * pixmap, m_pixmaps.values()) {
-		delete pixmap;
-	}
-	m_pixmaps.clear();
 }
 
 void HtmlInfoView::cleanup() {
@@ -380,11 +386,12 @@ void HtmlInfoView::appendWireStuff(Wire* wire, bool swappingEnabled) {
 	else {
 		 nameString = modelPart->description();
 	}
-	partTitle(nameString, modelPart->version(), modelPart->url());
+	partTitle(nameString, modelPart->version(), modelPart->url(), modelPart->isObsolete());
 	m_lockCheckbox->setVisible(false);
+	m_stickyCheckbox->setVisible(false);
 
 	setUpTitle(wire);
-	setUpIcons(wire->modelPart());
+	setUpIcons(wire, swappingEnabled);
 
 	displayProps(modelPart, wire, swappingEnabled);
 	addTags(modelPart);
@@ -403,7 +410,7 @@ void HtmlInfoView::appendItemStuff(ItemBase * itemBase, ModelPart * modelPart, b
 	if (modelPart->modelPartShared() == NULL) return;
 
 	setUpTitle(itemBase);
-	setUpIcons(modelPart);
+	setUpIcons(itemBase, swappingEnabled);
 
 	QString nameString;
 	if (swappingEnabled) {
@@ -412,9 +419,16 @@ void HtmlInfoView::appendItemStuff(ItemBase * itemBase, ModelPart * modelPart, b
 	else {
 		nameString = modelPart->description();
 	}
-	partTitle(nameString, modelPart->version(), modelPart->url());
+	partTitle(nameString, modelPart->version(), modelPart->url(), modelPart->isObsolete());
 	m_lockCheckbox->setVisible(true);
 	m_lockCheckbox->setChecked(itemBase->moveLock());
+    if (itemBase->isBaseSticky()) {
+	    m_stickyCheckbox->setVisible(true);
+        m_stickyCheckbox->setChecked(itemBase->isSticky());
+    }
+    else {
+	    m_stickyCheckbox->setVisible(false);
+    }
 
 	displayProps(modelPart, itemBase, swappingEnabled);
 	addTags(modelPart);
@@ -449,7 +463,7 @@ void HtmlInfoView::setContent()
 }
 
 QSize HtmlInfoView::sizeHint() const {
-	return QSize(DockManager::DockDefaultWidth, DockManager::InfoViewDefaultHeight);
+	return QSize(DockWidthDefault, InfoViewHeightDefault);
 }
 
 void HtmlInfoView::setCurrentItem(ItemBase * item) {
@@ -485,9 +499,10 @@ void HtmlInfoView::reloadContent(InfoGraphicsView * infoGraphicsView) {
 void HtmlInfoView::setNullContent()
 {
 	setUpTitle(NULL);
-	partTitle("", "", "");
+	partTitle("", "", "", false);
 	m_lockCheckbox->setVisible(false);
-	setUpIcons(NULL);
+	m_stickyCheckbox->setVisible(false);
+	setUpIcons(NULL, false);
 	displayProps(NULL, NULL, false);
 	addTags(NULL);
 	viewConnectorItemInfo(NULL, NULL);
@@ -506,7 +521,7 @@ void HtmlInfoView::setInstanceTitle() {
 	if (m_currentItem == NULL) return;
 
 	DebugDialog::debug(QString("set instance title to %1").arg(edit->text()));
-	m_infoGraphicsView->setInstanceTitle(m_currentItem->id(), edit->text(), true, false);
+	m_infoGraphicsView->setInstanceTitle(m_currentItem->id(), m_partTitle->text(), edit->text(), true, false);
 }
 
 void HtmlInfoView::instanceTitleEnter() {
@@ -541,7 +556,10 @@ void HtmlInfoView::setInstanceTitleColors(FLineEdit * edit, const QColor & base,
 
 void HtmlInfoView::setUpTitle(ItemBase * itemBase) 
 {
-	if (itemBase == m_lastTitleItemBase) return;
+	if (itemBase == m_lastTitleItemBase) {
+        if (itemBase == NULL) return;
+        if (itemBase->instanceTitle().compare(m_titleEdit->text()) == 0) return;
+    }
 
 	m_lastTitleItemBase = itemBase;
 	if (itemBase) {
@@ -565,49 +583,25 @@ void HtmlInfoView::setUpTitle(ItemBase * itemBase)
 
 }
 
-void HtmlInfoView::setUpIcons(ModelPart * modelPart) {
-	if (m_lastIconModelPart == modelPart) return;
+void HtmlInfoView::setUpIcons(ItemBase * itemBase, bool swappingEnabled) {
+	if (m_lastIconItemBase == itemBase) return;
 	
-	m_lastIconModelPart = modelPart;
+	m_lastIconItemBase = itemBase;
 
-	QPixmap *pixmap0 = NULL;
 	QPixmap *pixmap1 = NULL;
 	QPixmap *pixmap2 = NULL;
 	QPixmap *pixmap3 = NULL;
 
-	QSize size = NoIcon->size();
+    QSize size = NoIcon->size();
 
-	if (modelPart != NULL) {
-		pixmap0 = getPixmap(modelPart, ViewIdentifierClass::IconView);
-		pixmap1 = getPixmap(modelPart, ViewIdentifierClass::BreadboardView);
-		pixmap2 = getPixmap(modelPart, ViewIdentifierClass::SchematicView);
-		pixmap3 = getPixmap(modelPart, ViewIdentifierClass::PCBView);
-	}
+    if (itemBase) {
+        itemBase->getPixmaps(pixmap1, pixmap2, pixmap3, swappingEnabled, size);
+    }
 
 	QPixmap* use1 = pixmap1;
 	QPixmap* use2 = pixmap2;
 	QPixmap* use3 = pixmap3;
 
-	// use the icon image instead of the breadboard image, unless the item doesn't have a breadboard view
-	if (pixmap1 && pixmap2 && pixmap3) {
-		use1 = pixmap0;
-		if (pixmap2 == pixmap1) {
-			use2 = pixmap0;
-		}
-		if (pixmap3 == pixmap1) {
-			use3 = pixmap0;
-		}
-	}
-	else if (pixmap3) {
-		use3 = pixmap0;
-	}
-	else if (pixmap1) {
-		use1 = pixmap0;
-	}
-	else if (pixmap2) {
-		use2 = pixmap0;
-	}
-
 	if (use1 == NULL) use1 = NoIcon;
 	if (use2 == NULL) use2 = NoIcon;
 	if (use3 == NULL) use3 = NoIcon;
@@ -615,6 +609,10 @@ void HtmlInfoView::setUpIcons(ModelPart * modelPart) {
 	m_icon1->setPixmap(*use1);
 	m_icon2->setPixmap(*use2);
 	m_icon3->setPixmap(*use3);
+
+    if (pixmap1 != NULL) delete pixmap1;
+    if (pixmap2 != NULL) delete pixmap2;
+    if (pixmap3 != NULL) delete pixmap3;
 }
 
 void HtmlInfoView::addTags(ModelPart * modelPart) {
@@ -632,7 +630,7 @@ void HtmlInfoView::addTags(ModelPart * modelPart) {
 	m_tagsTextLabel->setText(modelPart->tags().join(", "));
 }
 
-void HtmlInfoView::partTitle(const QString & title, const QString & version, const QString & url) {
+void HtmlInfoView::partTitle(const QString & title, const QString & version, const QString & url, bool isObsolete) {
 	if (m_partTitle == NULL) return;
 
 	if (m_lastPartTitle == title && m_lastPartVersion == version) return;
@@ -651,7 +649,7 @@ void HtmlInfoView::partTitle(const QString & title, const QString & version, con
 
 	m_partTitle->setText(title);
 	if (!version.isEmpty()) {
-		m_partVersion->setText(tr("v. %1").arg(version));
+		m_partVersion->setText(tr("v. %1 %2").arg(version).arg(isObsolete ? QString("<a href='x'>%1</a>").arg(tr("obsolete")) : ""));
 	}
 	else m_partVersion->setText("");
 }
@@ -800,56 +798,19 @@ void HtmlInfoView::clearPropThingPlugin(PropThing * propThing, QWidget * plugin)
     //DebugDialog::debug(QString("clearing %1").arg((long) plugin, 0, 16));
 
 	propThing->m_layout->removeWidget(plugin);
-	plugin->setVisible(false);
+    plugin->blockSignals(true);     
+	plugin->setVisible(false);          // seems to trigger an unwanted focus out signal
 	plugin->deleteLater();
 }
 
 
-QPixmap * HtmlInfoView::getPixmap(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier) {
-	if (!modelPart->hasViewFor(viewIdentifier)) return NULL;
-
-	QString baseName = modelPart->hasBaseNameFor(viewIdentifier);
-	if (baseName.isEmpty()) return NULL;
-
-	QString filename = ItemBase::getSvgFilename(modelPart, baseName);
-	if (filename.isEmpty()) {
-		return NULL;
-	}
-
-	QPixmap * cached = m_pixmaps.value(filename, NULL);
-	if (cached) {
-		return cached;
-	}
-
-	QSvgRenderer renderer(filename);
-
-	QSize size = NoIcon->size();
-	QPixmap * pixmap = new QPixmap(size);
-	pixmap->fill(Qt::transparent);
-	QPainter painter(pixmap);
-	// preserve aspect ratio
-	QSize def = renderer.defaultSize();
-	double newW = size.width();
-	double newH = newW * def.height() / def.width();
-	if (newH > size.height()) {
-		newH = size.height();
-		newW = newH * def.width() / def.height();
-	}
-	QRectF bounds((size.width() - newW) / 2.0, (size.height() - newH) / 2.0, newW, newH);
-	renderer.render(&painter, bounds);
-	painter.end();
-
-	m_pixmaps.insert(filename, pixmap);
-
-	return pixmap;
-}
-
 QHash<QString, QString> HtmlInfoView::getPartProperties(ModelPart * modelPart, ItemBase * itemBase, bool wantDebug, QStringList & keys) 
 {
 	QHash<QString, QString> properties;
 	QString family;
 	QString partNumber;
 	if (modelPart) {
+        // TODO: someday get local props
 		properties = modelPart->properties();
 		family = properties.value("family", "").toLower();
 		if (itemBase) {
@@ -885,11 +846,12 @@ QHash<QString, QString> HtmlInfoView::getPartProperties(ModelPart * modelPart, I
 				keys.insert(insertAt++, "class");
 			}
 			else {
-				FSvgRenderer * renderer = FSvgRenderer::getByModuleID(modelPart->moduleID(), ViewLayer::Icon);
-				if (renderer != NULL) {
-					properties.insert("svg", renderer->filename());
-					keys.insert(insertAt++, "svg");
-				}
+                DebugDialog::debug("htmlinfoview has modelpart without itembase?");
+				//FSvgRenderer * renderer = FSvgRenderer::getByModuleID(modelPart->moduleID(), ViewLayer::Icon);
+				//if (renderer != NULL) {
+				//	properties.insert("svg", renderer->filename());
+				//	keys.insert(insertAt++, "svg");
+				//}
 			}
 			if (modelPart->modelPartShared()) {
 				properties.insert("fzp",  modelPart->path());
@@ -913,3 +875,16 @@ void HtmlInfoView::changeLock(bool lockState)
 
 	m_currentItem->setMoveLock(lockState);
 }
+
+
+void HtmlInfoView::changeSticky(bool lockState)
+{
+	if (m_currentItem == NULL) return;
+	if (m_currentItem->itemType() == ModelPart::Wire) return;
+
+	m_currentItem->setLocalSticky(lockState);
+}
+
+void HtmlInfoView::clickObsolete(const QString &) {
+    emit clickObsoleteSignal();
+}
