@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2010 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5783 $:
+$Revision: 6264 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-01-26 07:31:21 +0100 (Thu, 26 Jan 2012) $
+$Date: 2012-08-07 17:59:08 +0200 (Tue, 07 Aug 2012) $
 
 ********************************************************************/
 
@@ -33,6 +33,8 @@ ItemDrag * ItemDrag::Singleton = new ItemDrag();
 ItemDrag::ItemDrag(QObject * parent) :
 	QObject(parent)
 {
+    m_originator = NULL;
+    m_originatorIsTempBin = false;
 }
 
 void ItemDrag::__dragIsDone() {
@@ -66,3 +68,11 @@ void ItemDrag::setOriginator(QWidget * originator) {
 QWidget* ItemDrag::originator() {
 	return Singleton->m_originator;
 }
+
+void ItemDrag::setOriginatorIsTempBin(bool itb) {
+	Singleton->m_originatorIsTempBin = itb;
+}
+
+bool ItemDrag::originatorIsTempBin() {
+	return Singleton->m_originatorIsTempBin;
+}
