@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2010 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5783 $:
+$Revision: 6264 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-01-26 07:31:21 +0100 (Thu, 26 Jan 2012) $
+$Date: 2012-08-07 17:59:08 +0200 (Tue, 07 Aug 2012) $
 
 ********************************************************************/
 
@@ -32,6 +32,7 @@ $Date: 2012-01-26 07:31:21 +0100 (Thu, 26 Jan 2012) $
 #include <QDrag>
 #include <QHash>
 #include <QPixmap>
+#include <QPointer>
 
 
 class ItemDrag : public QObject {
@@ -47,16 +48,19 @@ public:
 	static ItemDrag * singleton();
 	static QHash<QObject *, QObject *> & cache();
 	static void dragIsDone();
-	static QWidget * originator();
 	static void cleanup();
 	static void setOriginator(QWidget *);
+	static QWidget * originator();
+    static bool originatorIsTempBin();
+    static void setOriginatorIsTempBin(bool);
 
 signals:
 	void dragIsDoneSignal(ItemDrag *);
 
 protected:
 	QHash<QObject *, QObject *> m_cache;
-	QWidget * m_originator;
+	QPointer<QWidget> m_originator;
+    bool m_originatorIsTempBin;
 	
 protected:
 	static ItemDrag * Singleton;
