@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5430 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2011-08-26 01:07:33 +0200 (Fri, 26 Aug 2011) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -139,7 +139,7 @@ register int	line_flag ;
 
 /////////////////////////////////////////////////////////
 
-ClipableWire::ClipableWire( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool initLabel ) 
+ClipableWire::ClipableWire( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool initLabel ) 
 	: Wire(modelPart, viewIdentifier,  viewGeometry,  id, itemMenu, initLabel)
 {
 	m_canHaveCurve = false;
@@ -207,6 +207,8 @@ void ClipableWire::setClipEnds(bool clipEnds ) {
 void ClipableWire::calcClip(QPointF & p1, QPointF & p2, ConnectorItem * c1, ConnectorItem * c2) {
 
 	if (c1 != NULL && c2 != NULL && c1->isEffectivelyCircular() && c2->isEffectivelyCircular()) {
+        //c1->debugInfo("c1");
+        //c2->debugInfo("c2");
 		GraphicsUtils::shortenLine(p1, p2, c1->calcClipRadius() + (m_pen.width() / 2.0), c2->calcClipRadius() + (m_pen.width() / 2.0));
 		return;
 	}
@@ -251,7 +253,7 @@ bool ClipableWire::filterMousePressConnectorEvent(ConnectorItem * connectorItem,
 	m_justFilteredEvent = NULL;
 
 	if (!m_clipEnds) return false;
-	if (m_viewIdentifier != ViewIdentifierClass::PCBView) return false;
+	if (m_viewIdentifier != ViewLayer::PCBView) return false;
 
 	ConnectorItem * to = NULL;
 	foreach (ConnectorItem * toConnectorItem, connectorItem->connectedToItems()) {
