@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,17 +18,19 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5859 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-02-13 13:29:26 +0100 (Mon, 13 Feb 2012) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
 #include "dip.h"
 #include "../utils/textutils.h"
 #include "../utils/graphicsutils.h"
+#include "../utils/familypropertycombobox.h"
 #include "../connectors/connectoritem.h"
 #include "../fsvgrenderer.h"
+#include "pinheader.h"
 
 #include <QFontMetricsF>
 
@@ -41,7 +43,7 @@ static int MaxDipPins = 64;
 
 //////////////////////////////////////////////////
 
-Dip::Dip( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+Dip::Dip( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
 	: MysteryPart(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
 {
 }
@@ -63,7 +65,7 @@ bool Dip::isDIP() {
 	QString package = modelPart()->properties().value("package", "");
 	if (package.indexOf("dip", 0, Qt::CaseInsensitive) >= 0) return true;
 	if (package.indexOf("sip", 0, Qt::CaseInsensitive) >= 0) return false;
-	return m_modelPart->family().contains("generic ic", Qt::CaseInsensitive);
+	return family().contains("generic ic", Qt::CaseInsensitive);
 }
 
 bool Dip::otherPropsChange(const QMap<QString, QString> & propsMap) {
@@ -81,12 +83,12 @@ const QStringList & Dip::spacings() {
 
 QString Dip::genSipFZP(const QString & moduleid)
 {
-	return PaletteItem::genFZP(moduleid, "generic_sip_fzpTemplate", MinSipPins, MaxSipPins, 1, false);
+	return genxFZP(moduleid, "generic_sip_fzpTemplate", MinSipPins, MaxSipPins, 1);
 }
 
 QString Dip::genDipFZP(const QString & moduleid)
 {
-	return PaletteItem::genFZP(moduleid, "generic_dip_fzpTemplate", MinDipPins, MaxDipPins, 2, false);
+	return genxFZP(moduleid, "generic_dip_fzpTemplate", MinDipPins, MaxDipPins, 2);
 }
 
 QStringList Dip::collectValues(const QString & family, const QString & prop, QString & value) {
@@ -113,70 +115,22 @@ QStringList Dip::collectValues(const QString & family, const QString & prop, QSt
 
 QString Dip::genModuleID(QMap<QString, QString> & currPropsMap)
 {
+    QString spacing = currPropsMap.value("pin spacing", "300mil");
 	QString value = currPropsMap.value("package");
 	QString pins = currPropsMap.value("pins");
 	if (pins.isEmpty()) pins = "16";		// pick something safe
 	QString moduleID;
 	if (value.contains("sip", Qt::CaseInsensitive)) {
-		return QString("generic_sip_%1_300mil").arg(pins);
+		return QString("generic_sip_%1_%2").arg(pins).arg(spacing);
 	}
 	else {
 		int p = pins.toInt();
 		if (p < 4) p = 4;
 		if (p % 2 == 1) p--;
-		return QString("generic_ic_dip_%1_300mil").arg(p);
+		return QString("generic_ic_dip_%1_%2").arg(p).arg(spacing);
 	}
 }
 
-QString Dip::makePcbSvg(const QString & expectedFileName) 
-{
-	QStringList pieces = expectedFileName.split("_");
-	if (pieces.count() != 4) return "";
-
-	int pins = pieces.at(1).toInt();
-	QString spacingString = pieces.at(2);
-
-	QString header("<?xml version='1.0' encoding='UTF-8'?>\n"
-				    "<svg baseProfile='tiny' version='1.2' width='%1in' height='%2in' viewBox='0 0 %3 %4' xmlns='http://www.w3.org/2000/svg'>\n"
-				    "<desc>Fritzing footprint SVG</desc>\n"
-					"<g id='silkscreen'>\n"
-					"<line stroke='white' stroke-width='10' x1='10' x2='10' y1='10' y2='%5'/>\n"
-					"<line stroke='white' stroke-width='10' x1='10' x2='%6' y1='%5' y2='%5'/>\n"
-					"<line stroke='white' stroke-width='10' x1='%6' x2='%6' y1='%5' y2='10'/>\n"
-					"<line stroke='white' stroke-width='10' x1='10' x2='%7' y1='10' y2='10'/>\n"
-					"<line stroke='white' stroke-width='10' x1='%8' x2='%6' y1='10' y2='10'/>\n"
-					"</g>\n"
-					"<g id='copper1'><g id='copper0'>\n"
-					"<rect fill='none' height='55' stroke='rgb(255, 191, 0)' stroke-width='20' width='55' x='32.5' y='32.5'/>\n");
-
-	double outerBorder = 10;
-	double silkSplitTop = 100;
-	double offsetX = 60;
-	double offsetY = 60;
-	double spacing = TextUtils::convertToInches(spacingString) * GraphicsUtils::StandardFritzingDPI; 
-	double totalWidth = 120 + spacing;
-	double totalHeight = (100 * pins / 2) + (outerBorder * 2);
-	double center = totalWidth / 2;
-
-	QString svg = header.arg(totalWidth / GraphicsUtils::StandardFritzingDPI).arg(totalHeight / GraphicsUtils::StandardFritzingDPI).arg(totalWidth).arg(totalHeight)
-							.arg(totalHeight - outerBorder).arg(totalWidth - outerBorder)
-							.arg(center - (silkSplitTop / 2)).arg(center + (silkSplitTop / 2));
-
-	QString circle("<circle cx='%1' cy='%2' fill='none' id='connector%3pin' r='27.5' stroke='rgb(255, 191, 0)' stroke-width='20'/>\n");
-
-	int y = offsetY;
-	for (int i = 0; i < pins / 2; i++) {
-		svg += circle.arg(offsetX).arg(y).arg(i);
-		svg += circle.arg(totalWidth - offsetX).arg(y).arg(pins - 1 - i);
-		y += 100;
-	}
-
-	svg += "</g></g>\n";
-	svg += "</svg>\n";
-
-	return svg;
-}
-
 QString Dip::retrieveSchematicSvg(QString & svg) {
 	bool hasLocal = false;
 	QStringList labels = getPinLabels(hasLocal);
@@ -198,11 +152,16 @@ QString Dip::makeSchematicSvg(const QString & expectedFileName)
 	QStringList pieces = expectedFileName.split("_");
 	if (pieces.count() != 5) return "";
 
-	int pins = pieces.at(3).toInt();
+    QString spacing;
+    int pins = TextUtils::getPinsAndSpacing(expectedFileName, spacing);
 	QStringList labels;
 	for (int i = 0; i < pins; i++) {
 		labels << QString::number(i + 1);
 	}
+    
+    if (expectedFileName.contains("sip", Qt::CaseInsensitive)) {
+        return MysteryPart::makeSchematicSvg(labels, true);
+    }
 
 	return makeSchematicSvg(labels);
 }
@@ -402,7 +361,7 @@ QString Dip::makeBreadboardDipSvg(const QString & expectedFileName)
 }
 
 bool Dip::changePinLabels(bool singleRow, bool sip) {
-	if (m_viewIdentifier != ViewIdentifierClass::SchematicView) return true;
+	if (m_viewIdentifier != ViewLayer::SchematicView) return true;
 
 	bool hasLocal = false;
 	QStringList labels = getPinLabels(hasLocal);
@@ -417,7 +376,7 @@ bool Dip::changePinLabels(bool singleRow, bool sip) {
 		svg = Dip::makeSchematicSvg(labels);
 	}
 
-	loadExtraRenderer(svg, false);
+	resetRenderer(svg);
 
 	return true;
 }
@@ -433,3 +392,31 @@ void Dip::addedToScene(bool temporary)
 		}
 	}
 }
+
+void Dip::swapEntry(const QString & text) {
+
+    FamilyPropertyComboBox * comboBox = qobject_cast<FamilyPropertyComboBox *>(sender());
+    if (comboBox == NULL) return;
+
+    bool sip = moduleID().contains("sip");
+    bool dip = moduleID().contains("dip");
+
+    if (comboBox->prop().contains("package", Qt::CaseInsensitive)) {
+        sip = text.contains("sip", Qt::CaseInsensitive);
+        dip = text.contains("dip", Qt::CaseInsensitive);
+        if (!dip && !sip) {
+            // one of the generic smds
+            PaletteItem::swapEntry(text);
+            return;
+        }
+    }
+
+    if (sip) {
+        generateSwap(text, genModuleID, genSipFZP, makeBreadboardSvg, makeSchematicSvg, PinHeader::makePcbSvg);
+    }
+    else if (dip) {
+        generateSwap(text, genModuleID, genDipFZP, makeBreadboardSvg, makeSchematicSvg, makePcbDipSvg);
+    }
+    PaletteItem::swapEntry(text);
+}
+
