@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5857 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-02-12 18:16:07 +0100 (Sun, 12 Feb 2012) $
+$Revision: 6505 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-03 10:14:52 +0200 (Wed, 03 Oct 2012) $
 
 ********************************************************************/
 
@@ -65,13 +65,13 @@ void loadIconSvg()
 
 /////////////////////////////////////////////////////////
 
-GroundPlane::GroundPlane( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel) 
+GroundPlane::GroundPlane( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel) 
 	: PaletteItem(modelPart, viewIdentifier,  viewGeometry,  id, itemMenu, doLabel)
 {
 	m_connector0 = NULL;
 }
 
-bool GroundPlane::setUpImage(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec viewLayerSpec, bool doConnectors, LayerAttributes & layerAttributes, QString & error)
+bool GroundPlane::setUpImage(ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec viewLayerSpec, bool doConnectors, LayerAttributes & layerAttributes, QString & error)
 {
 	bool result = PaletteItem::setUpImage(modelPart, viewIdentifier, viewLayers, viewLayerID, viewLayerSpec, doConnectors, layerAttributes, error);
 
@@ -99,17 +99,7 @@ QString GroundPlane::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QStri
 		xml = prop("svg");
 
 		if (!xml.isEmpty()) {
-			QString xmlName = ViewLayer::viewLayerXmlNameFromID(viewLayerID);
-			SvgFileSplitter splitter;
-			bool result = splitter.splitString(xml, xmlName);
-			if (!result) {
-				return ___emptyString___;
-			}
-			result = splitter.normalize(dpi, xmlName, blackOnly);
-			if (!result) {
-				return ___emptyString___;
-			}
-			return splitter.elementString(xmlName);
+            return PaletteItemBase::normalizeSvg(xml, viewLayerID, blackOnly, dpi);
 		}
 	}
 
@@ -122,7 +112,7 @@ ConnectorItem * GroundPlane::connector0() {
 
 bool GroundPlane::hasCustomSVG() {
 	switch (m_viewIdentifier) {
-		case ViewIdentifierClass::PCBView:
+		case ViewLayer::PCBView:
 			return true;
 		default:
 			return ItemBase::hasCustomSVG();
@@ -161,26 +151,26 @@ void GroundPlane::addedToScene(bool temporary)
 
 
 void GroundPlane::setSvg(const QString & svg) {
-	modelPart()->setProp("svg", svg);
+	modelPart()->setLocalProp("svg", svg);
 	setSvgAux(svg);
 }
 
 void GroundPlane::setSvgAux(const QString & svg) {
 	if (svg.isEmpty()) return;
-	if (m_viewIdentifier == ViewIdentifierClass::BreadboardView || m_viewIdentifier == ViewIdentifierClass::SchematicView) return;
+	if (m_viewIdentifier == ViewLayer::BreadboardView || m_viewIdentifier == ViewLayer::SchematicView) return;
 
 	QString xmlName = ViewLayer::viewLayerXmlNameFromID(m_viewLayerID);
 	SvgFileSplitter	splitter;
 	QString cpy = svg;
 	bool result = splitter.splitString(cpy, xmlName);
 	if (result) {
-		loadExtraRenderer(svg.toUtf8(), false);
+		resetRenderer(svg);
 		if (m_connector0) {
-			QPainterPath painterPath = splitter.painterPath(FSvgRenderer::printerScale(), GroundPlaneGenerator::ConnectorName);
+			QPainterPath painterPath = splitter.painterPath(GraphicsUtils::SVGDPI, GroundPlaneGenerator::ConnectorName);
 			m_connector0->setRect(painterPath.boundingRect());
 			m_connector0->setShape(painterPath);
 		}
-		//QPainterPath painterPath = splitter.painterPath(FSvgRenderer::printerScale(), xmlName);
+		//QPainterPath painterPath = splitter.painterPath(GraphicsUtils::SVGDPI, xmlName);
 		//this->setShape(painterPath);  
 	}
 }
@@ -232,14 +222,21 @@ QString GroundPlane::generateSvg() {
 
 void GroundPlane::setDropOffset(QPointF offset) 
 {
-	m_dropOffset = offset;
-	modelPart()->setProp("fillType", fillTypeIndividual);
+	InfoGraphicsView * infoGraphicsView = InfoGraphicsView::getInfoGraphicsView(this);
+	if (infoGraphicsView == NULL) return;
+    
+    m_dropOffset = offset;
+	modelPart()->setLocalProp("fillType", fillTypeIndividual);
 	QString svg = generateSvg();
+    bool resolve = true;
 	if (svg.isEmpty()) {
 		loadIconSvg();
 		svg = IconSvg;
+        resolve = false;
 	}
 	setSvg(svg);
+
+	infoGraphicsView->resolveTemporary(resolve, this);   
 }
 
 void GroundPlane::setShape(QPainterPath & pp) {
@@ -256,3 +253,11 @@ QPainterPath GroundPlane::shape() const
     return PaletteItemBase::shape();
 }
 
+ViewLayer::ViewIdentifier GroundPlane::useViewIdentifierForPixmap(ViewLayer::ViewIdentifier vid, bool) 
+{
+    if (vid == ViewLayer::PCBView) {
+        return ViewLayer::IconView;
+    }
+
+    return ViewLayer::UnknownView;
+}
