@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5944 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-04-06 16:06:09 +0200 (Fri, 06 Apr 2012) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -32,30 +32,9 @@ $Date: 2012-04-06 16:06:09 +0200 (Fri, 06 Apr 2012) $
 #include <QPainterPath>
 #include <QPixmap>
 #include <QVariant>
-#include <QComboBox>
-#include <QRadioButton>
-#include <QDoubleValidator>
 
 #include "paletteitem.h"
 
-typedef QPointF (*RangeCalc)(const QString &);
-
-struct HoleSettings
-{
-	QString holeDiameter;
-	QString ringThickness;
-	QPointer<QDoubleValidator> diameterValidator;
-	QPointer<QDoubleValidator> thicknessValidator;
-	QPointer<QLineEdit> diameterEdit;
-	QPointer<QLineEdit> thicknessEdit;
-	QPointer<QRadioButton> inRadioButton;
-	QPointer<QRadioButton> mmRadioButton;
-	QPointer<QComboBox> sizesComboBox;
-	RangeCalc ringThicknessRange;
-	RangeCalc holeDiameterRange;
-
-	QString currentUnits();
-};
 
 class Hole : public PaletteItem 
 {
@@ -63,7 +42,7 @@ class Hole : public PaletteItem
 
 public:
 	// after calling this constructor if you want to render the loaded svg (either from model or from file), MUST call <renderImage>
-	Hole(ModelPart *, ViewIdentifierClass::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
+	Hole(ModelPart *, ViewLayer::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
 	~Hole();
 
 	QString getProperty(const QString & key);
@@ -81,50 +60,22 @@ public:
 	bool rotationAllowed();
 	bool rotation45Allowed();
 	bool canFindConnectorsUnder();
-
-public:
-	static QWidget * createHoleSettings(QWidget * parent, HoleSettings &, bool swappingEnabled, const QString & currentHoleSize);
-	static void updateValidators(HoleSettings &);
-	static void updateEditTexts(HoleSettings &);
-	static void updateSizes(HoleSettings &);
-	static QString changeUnits(const QString &, HoleSettings &);
-	static QPointF ringThicknessRange(const QString & holeDiameter);
-	static QPointF holeDiameterRange(const QString & ringThickness);
-	static bool changeDiameter(HoleSettings & holeSettings, QObject * sender);
-	static bool changeThickness(HoleSettings & holeSettings, QObject * sender);
-	static bool setHoleSize(QString & holeSize, bool force, HoleSettings & holeSettings);
-	static QString holeSize(HoleSettings &);
-	static void initHoleSettings(HoleSettings & holeSettings);
+    QRectF trueSceneBoundingRect();
 
 protected slots:
-	void changeDiameter();
-	void changeThickness();
-	void changeUnits(bool);
 	void changeHoleSize(const QString &);
+	void changeUnits(bool);
 
 protected:
 	QString makeSvg(const QString & holeDiameter, const QString & ringThickness, ViewLayer::ViewLayerID);
 	virtual QString makeID();
 	ItemBase * setBothSvg(const QString & holeDiameter, const QString & ringThickness); 
 	void setBothNonConnectors(ItemBase * itemBase, SvgIdLayer * svgIdLayer);
-	void setUpHoleSizes();
 	virtual void setBoth(const QString & holeDiameter, const QString &  thickness);
-	QString currentUnits();
-	static QStringList getSizes(QString & holeSize);
 	QRectF getRect(const QString & newSize);
-
-protected:
-	QPointer<class FSvgRenderer> m_otherLayerRenderer;
-	HoleSettings m_holeSettings;
+    ViewLayer::ViewIdentifier useViewIdentifierForPixmap(ViewLayer::ViewIdentifier, bool swappingEnabled);
 
 public:
-	static QHash<QString, QString> HoleSizes;
-
-public:
-	static const QString AutorouteViaHoleSize;
-	static const QString AutorouteViaRingThickness;
-	static QString DefaultAutorouteViaHoleSize;
-	static QString DefaultAutorouteViaRingThickness;
 	static const double OffsetPixels;
 };
 
