@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5952 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-08 00:47:10 +0200 (Sun, 08 Apr 2012) $
+$Revision: 6569 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-16 05:51:14 +0200 (Tue, 16 Oct 2012) $
 
 ********************************************************************/
 
@@ -68,6 +68,7 @@ bool numberValueLessThan(QString v1, QString v2)
 }
 
 static QSvgRenderer MoveLockRenderer;
+static QSvgRenderer StickyRenderer;
 
 /////////////////////////////////
 
@@ -105,7 +106,7 @@ const QString ItemBase::ITEMBASE_FONT_SUFFIX = "</font>";
 
 QHash<QString, QString> ItemBase::TranslatedPropertyNames;
 
-QPointer<ReferenceModel> ItemBase::referenceModel = NULL;
+QPointer<ReferenceModel> ItemBase::TheReferenceModel = NULL;
 
 QString ItemBase::partInstanceDefaultTitle;
 QList<ItemBase *> ItemBase::emptyList;
@@ -139,13 +140,18 @@ static QHash<QString, QStringList> CachedValues;
 
 ///////////////////////////////////////////////////
 
-ItemBase::ItemBase( ModelPart* modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu )
+ItemBase::ItemBase( ModelPart* modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu )
 	: QGraphicsSvgItem()
 {
-	//DebugDialog::debug(QString("itembase %1 %2").arg(id).arg((long) static_cast<QGraphicsItem *>(this), 0, 16));
+    m_fsvgRenderer = NULL;
+
+	m_acceptsMousePressLegEvent = true;
+
+    //DebugDialog::debug(QString("itembase %1 %2").arg(id).arg((long) static_cast<QGraphicsItem *>(this), 0, 16));
 	m_hasRubberBandLeg = m_moveLock = m_hoverEnterSpaceBarWasPressed = m_spaceBarWasPressed = false;
 
 	m_moveLockItem = NULL;
+    m_stickyItem = NULL;
 
 	m_everVisible = true;
 
@@ -191,6 +197,11 @@ ItemBase::~ItemBase() {
 	if (m_modelPart != NULL) {
 		m_modelPart->removeViewItem(this);
 	}
+
+    if (m_fsvgRenderer) {
+        delete m_fsvgRenderer;
+    }
+
 }
 
 void ItemBase::setTooltip() {
@@ -285,6 +296,7 @@ void ItemBase::initNames() {
 		TranslatedPropertyNames.insert("maximum resistance", tr("maximum resistance"));
 		TranslatedPropertyNames.insert("pins", tr("pins"));
 		TranslatedPropertyNames.insert("spacing", tr("spacing"));
+		TranslatedPropertyNames.insert("pin spacing", tr("pin spacing"));
 		TranslatedPropertyNames.insert("frequency", tr("frequency"));
 		TranslatedPropertyNames.insert("processor", tr("processor"));
 		TranslatedPropertyNames.insert("variant", tr("variant"));
@@ -321,7 +333,7 @@ void ItemBase::initNames() {
 }
 
 void ItemBase::saveInstance(QXmlStreamWriter & streamWriter) {
-	streamWriter.writeStartElement(ViewIdentifierClass::viewIdentifierXmlName(m_viewIdentifier));
+	streamWriter.writeStartElement(ViewLayer::viewIdentifierXmlName(m_viewIdentifier));
 	streamWriter.writeAttribute("layer", ViewLayer::viewLayerXmlNameFromID(m_viewLayerID));
 	if (m_moveLock) {
 		streamWriter.writeAttribute("locked", "true");
@@ -364,12 +376,12 @@ ViewGeometry & ItemBase::getViewGeometry() {
 	return m_viewGeometry;
 }
 
-ViewIdentifierClass::ViewIdentifier ItemBase::viewIdentifier() {
+ViewLayer::ViewIdentifier ItemBase::viewIdentifier() {
 	return m_viewIdentifier;
 }
 
 QString & ItemBase::viewIdentifierName() {
-	return ViewIdentifierClass::viewIdentifierName(m_viewIdentifier);
+	return ViewLayer::viewIdentifierName(m_viewIdentifier);
 }
 
 ViewLayer::ViewLayerID ItemBase::viewLayerID() const {
@@ -466,6 +478,14 @@ bool ItemBase::acceptsMousePressConnectorEvent(ConnectorItem *, QGraphicsSceneMo
 	return true;
 }
 
+bool ItemBase::acceptsMousePressLegEvent(ConnectorItem *, QGraphicsSceneMouseEvent *) {
+	return m_acceptsMousePressLegEvent;
+}
+
+void ItemBase::setAcceptsMousePressLegEvent(bool b) {
+	m_acceptsMousePressLegEvent = b;
+}
+
 bool ItemBase::acceptsMouseReleaseConnectorEvent(ConnectorItem *, QGraphicsSceneMouseEvent *) {
 	return false;
 }
@@ -622,10 +642,15 @@ bool ItemBase::getRatsnest() {
 	return m_viewGeometry.getRatsnest();
 }
 
-const QHash<QString, QPointer<Bus> > & ItemBase::buses() {
-	if (m_modelPart != NULL) return m_modelPart->buses();
+QList<Bus *> ItemBase::buses() {
+	QList<Bus *> busList;
+	if (m_modelPart == NULL) return busList;
 
-	return Bus::___emptyBusList___;
+	foreach (Bus * bus, m_modelPart->buses().values()) {
+		busList.append(bus);
+	}
+
+	return busList;
 }
 
 void ItemBase::busConnectorItems(class Bus * bus, QList<class ConnectorItem *> & items) {
@@ -690,7 +715,7 @@ void ItemBase::paintBody(QPainter *painter, const QStyleOptionGraphicsItem *opti
 	Q_UNUSED(widget);
 
 	// Qt's SVG renderer's defaultSize is not correct when the svg has a fractional pixel size
-	renderer()->render(painter, boundingRectWithoutLegs());
+	fsvgRenderer()->render(painter, boundingRectWithoutLegs());
 }
 
 void ItemBase::paintHover(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
@@ -758,8 +783,13 @@ bool ItemBase::stickyEnabled() {
 	return true;
 }
 
-bool ItemBase::sticky() {
-	return m_sticky;
+bool ItemBase::isSticky() {
+	return isBaseSticky() && isLocalSticky();                      
+}
+
+
+bool ItemBase::isBaseSticky() {
+	return m_sticky;   // to cancel sticky return false; 
 }
 
 void ItemBase::setSticky(bool s)
@@ -767,29 +797,77 @@ void ItemBase::setSticky(bool s)
 	m_sticky = s;
 }
 
-void ItemBase::addSticky(ItemBase * sticky, bool stickem) {
-	sticky = sticky->layerKinChief();
+bool ItemBase::isLocalSticky() {
+    if (layerKinChief() != this) {
+        return layerKinChief()->isLocalSticky();
+    }
+    QString stickyVal = modelPart()->localProp("sticky").toString();
+	return (stickyVal.compare("false") != 0);                      
+}
+
+void ItemBase::setLocalSticky(bool s)
+{
+    // dirty the window?
+    // undo command?
+    if (layerKinChief() != this) {
+        layerKinChief()->setLocalSticky(s);
+        return;
+    }
+
+    modelPart()->setLocalProp("sticky", s ? "true" : "false");
+
+	if (s) {
+        if (m_stickyItem == NULL) {
+		    if (!StickyRenderer.isValid()) {
+			    QString fn(":resources/images/part_sticky.svg");
+			    bool success = StickyRenderer.load(fn);
+                Q_UNUSED(success);
+			    //DebugDialog::debug(QString("sticky load success %1").arg(success));
+		    }
+
+		    m_stickyItem = new QGraphicsSvgItem();
+		    m_stickyItem->setAcceptHoverEvents(false);
+		    m_stickyItem->setAcceptedMouseButtons(Qt::NoButton);
+		    m_stickyItem->setSharedRenderer(&StickyRenderer);
+		    m_stickyItem->setPos(m_moveLockItem == NULL ? 0 : m_moveLockItem->boundingRect().width() + 1, 0);
+		    m_stickyItem->setZValue(-99999);
+		    m_stickyItem->setParentItem(this);
+		    m_stickyItem->setVisible(true);
+        }
+	}
+	else {
+		if (m_stickyItem) {
+			delete m_stickyItem;
+			m_stickyItem = NULL;
+		}
+	}
+
+	update();
+}
+
+void ItemBase::addSticky(ItemBase * stickyBase, bool stickem) {
+	stickyBase = stickyBase->layerKinChief();
 	//this->debugInfo(QString("add sticky %1:").arg(stickem));
 	//sticky->debugInfo(QString("  to"));
 	if (stickem) {
-		if (!m_sticky) {
+		if (!isBaseSticky()) {
 			foreach (ItemBase * oldstickingTo, m_stickyList.values()) {
-				if (oldstickingTo == sticky) continue;
+				if (oldstickingTo == stickyBase) continue;
 
 				oldstickingTo->addSticky(this, false);
 			}
 			m_stickyList.clear();
 		}
-		m_stickyList.insert(sticky->id(), sticky);
+		m_stickyList.insert(stickyBase->id(), stickyBase);
 	}
 	else {
-		m_stickyList.remove(sticky->id());
+		m_stickyList.remove(stickyBase->id());
 	}
 }
 
 
 ItemBase * ItemBase::stickingTo() {
-	if (m_sticky) return NULL;
+	if (isBaseSticky()) return NULL;
 
 	if (m_stickyList.count() < 1) return NULL;
 
@@ -877,7 +955,7 @@ void ItemBase::setInstanceTitleTooltip(const QString &text) {
 
 void ItemBase::setDefaultTooltip() {
 	if (m_modelPart) {
-		if (m_viewIdentifier == ViewIdentifierClass::IconView) {
+		if (m_viewIdentifier == ViewLayer::IconView) {
 			QString base = ITEMBASE_FONT_PREFIX + "%1" + ITEMBASE_FONT_SUFFIX;
 			if(m_modelPart->itemType() != ModelPart::Wire) {
 				this->setToolTip(base.arg(m_modelPart->title()));
@@ -1169,7 +1247,7 @@ void ItemBase::saveLocAndTransform(QXmlStreamWriter & streamWriter)
 	GraphicsUtils::saveTransform(streamWriter, m_viewGeometry.transform());
 }
 
-FSvgRenderer * ItemBase::setUpImage(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec viewLayerSpec, LayerAttributes & layerAttributes, QString & error)
+FSvgRenderer * ItemBase::setUpImage(ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec viewLayerSpec, LayerAttributes & layerAttributes, QString & error)
 {
 #ifndef QT_NO_DEBUG
 	QTime t;
@@ -1182,16 +1260,6 @@ FSvgRenderer * ItemBase::setUpImage(ModelPart * modelPart, ViewIdentifierClass::
 		error = tr("model part problem");
 		return NULL;
 	}
-	if (modelPartShared->domDocument() == NULL) {
-		error = tr("part xml missing");
-		return NULL;
-	}
-
-	bool result = layerAttributes.getSvgElementID(modelPartShared->domDocument(), viewIdentifier, viewLayerID);
-	if (!result) {
-		error = tr("missing xml for view %1 layer %2").arg(viewIdentifier).arg(viewLayerID);
-		return NULL;
-	}
 
 	//DebugDialog::debug(QString("setting z %1 %2")
 		//.arg(this->z())
@@ -1199,133 +1267,137 @@ FSvgRenderer * ItemBase::setUpImage(ModelPart * modelPart, ViewIdentifierClass::
 
 
 	//DebugDialog::debug(QString("set up image elapsed (1) %1").arg(t.elapsed()) );
-	FSvgRenderer * renderer = FSvgRenderer::getByModuleID(modelPartShared->moduleID(), viewLayerID);
-	if (renderer == NULL) {
-		QString filename = getSvgFilename(modelPart, layerAttributes.filename());
-		if (filename.isEmpty()) {
-			filename = PartFactory::getSvgFilename(modelPart, layerAttributes.filename());
-		}
+	QString filename = getSvgFilename(modelPart, modelPartShared->imageFileName(viewIdentifier, viewLayerID));
 
 //#ifndef QT_NO_DEBUG
-		//DebugDialog::debug(QString("set up image elapsed (2) %1").arg(t.elapsed()) );
+	//DebugDialog::debug(QString("set up image elapsed (2) %1").arg(t.elapsed()) );
 //#endif
 
-		if (filename.isEmpty()) {
-			//QString deleteme = modelPartShared->domDocument()->toString();
-			error = tr("file %1 not found").arg(layerAttributes.filename());
+	if (filename.isEmpty()) {
+		//QString deleteme = modelPartShared->domDocument()->toString();
+		error = tr("file for %1 %2 not found").arg(modelPartShared->title()).arg(modelPartShared->moduleID());
+        return NULL;
+	}
+
+	QStringList connectorIDs, terminalIDs, legIDs;
+	QString setColor;
+	QString colorElementID;
+	switch (viewIdentifier) {
+		case ViewLayer::PCBView:
+			colorElementID = ViewLayer::viewLayerXmlNameFromID(viewLayerID);
+			switch (viewLayerID) {
+				case ViewLayer::Copper0:
+					modelPartShared->connectorIDs(viewIdentifier, viewLayerID, connectorIDs, terminalIDs, legIDs);
+					setColor = ViewLayer::Copper0Color;
+					break;
+				case ViewLayer::Copper1:
+					modelPartShared->connectorIDs(viewIdentifier, viewLayerID, connectorIDs, terminalIDs, legIDs);
+					setColor = ViewLayer::Copper1Color;
+					break;
+				case ViewLayer::Silkscreen1:
+					setColor = ViewLayer::Silkscreen1Color;
+					break;
+				case ViewLayer::Silkscreen0:
+					setColor = ViewLayer::Silkscreen0Color;
+					break;
+				default:
+					break;
+			}
+			break;
+		case ViewLayer::BreadboardView:
+			modelPartShared->connectorIDs(viewIdentifier, viewLayerID, connectorIDs, terminalIDs, legIDs);
+			break;
+        default:
+            break;
+	}
+
+	FSvgRenderer * newRenderer = new FSvgRenderer();
+	QDomDocument flipDoc;
+	if (!getFlipDoc(modelPart, filename, viewLayerID, viewLayerSpec, flipDoc)) {
+		fixCopper1(modelPart, filename, viewLayerID, viewLayerSpec, flipDoc);
+	}
+    QByteArray bytesToLoad;
+	if ((viewIdentifier != ViewLayer::IconView) && modelPartShared->hasMultipleLayers(viewIdentifier)) {
+        QString layerName = ViewLayer::viewLayerXmlNameFromID(viewLayerID);
+		// need to treat create "virtual" svg file for each layer
+		SvgFileSplitter svgFileSplitter;
+		bool result;
+		if (flipDoc.isNull()) {
+			result = svgFileSplitter.split(filename, layerName);
 		}
 		else {
-			renderer = FSvgRenderer::getByFilename(filename, viewLayerID);
-			if (renderer == NULL) {
-				QStringList connectorIDs, terminalIDs, legIDs;
-				QString setColor;
-				QString colorElementID;
-				switch (viewIdentifier) {
-					case ViewIdentifierClass::PCBView:
-						colorElementID = ViewLayer::viewLayerXmlNameFromID(viewLayerID);
-						switch (viewLayerID) {
-							case ViewLayer::Copper0:
-								modelPartShared->connectorIDs(viewIdentifier, viewLayerID, connectorIDs, terminalIDs, legIDs);
-								setColor = ViewLayer::Copper0Color;
-								break;
-							case ViewLayer::Copper1:
-								modelPartShared->connectorIDs(viewIdentifier, viewLayerID, connectorIDs, terminalIDs, legIDs);
-								setColor = ViewLayer::Copper1Color;
-								break;
-							case ViewLayer::Silkscreen1:
-								setColor = ViewLayer::Silkscreen1Color;
-								break;
-							case ViewLayer::Silkscreen0:
-								setColor = ViewLayer::Silkscreen0Color;
-								break;
-							default:
-								break;
-						}
-						break;
-					case ViewIdentifierClass::BreadboardView:
-						modelPartShared->connectorIDs(viewIdentifier, viewLayerID, connectorIDs, terminalIDs, legIDs);
-						break;
-                    default:
-                        break;
-				}
+			QString f = flipDoc.toString(); 
+			result = svgFileSplitter.splitString(f, layerName);
+		}
+		if (result) {
+            bytesToLoad = svgFileSplitter.byteArray();
+		}
+	}
+	else {
+		// only one layer, just load it directly
+		if (flipDoc.isNull()) {
+            QFile file(filename);
+            file.open(QFile::ReadOnly);
+            bytesToLoad = file.readAll();
+		}
+		else {
+            bytesToLoad = flipDoc.toByteArray();
+		}
+    }
 
-				bool gotOne = false;
-				renderer = new FSvgRenderer();
-				QDomDocument flipDoc;
-				if (!getFlipDoc(modelPart, filename, viewLayerID, viewLayerSpec, flipDoc)) {
-					fixCopper1(modelPart, filename, viewLayerID, viewLayerSpec, flipDoc);
-				}
-				if (layerAttributes.multiLayer()) {
-					// need to treat create "virtual" svg file for each layer
-					SvgFileSplitter svgFileSplitter;
-					bool result;
-					if (flipDoc.isNull()) {
-						result = svgFileSplitter.split(filename, layerAttributes.layerName());
-					}
-					else {
-						QString f = flipDoc.toString(); 
-						result = svgFileSplitter.splitString(f, layerAttributes.layerName());
-					}
-					if (result) {
-						QByteArray bytes = renderer->loadSvg(svgFileSplitter.byteArray(), filename, connectorIDs, terminalIDs, legIDs, setColor, colorElementID, viewIdentifier == ViewIdentifierClass::PCBView);
-						if (!bytes.isEmpty()) {
-							gotOne = true;
-						}
-					}
-				}
-				else {
-//#ifndef QT_NO_DEBUG
-//					DebugDialog::debug(QString("set up image elapsed (2.3) %1").arg(t.elapsed()) );
-//#endif
-					// only one layer, just load it directly
-					if (flipDoc.isNull()) {
-						layerAttributes.setLoaded(renderer->loadSvg(filename, connectorIDs, terminalIDs, legIDs, setColor, colorElementID, viewIdentifier == ViewIdentifierClass::PCBView));
-					}
-					else {
-						layerAttributes.setLoaded(renderer->loadSvg(flipDoc.toByteArray(), filename, connectorIDs, terminalIDs, legIDs, setColor, colorElementID, viewIdentifier == ViewIdentifierClass::PCBView));
-					}
-					if (!layerAttributes.loaded().isEmpty()) {
-						gotOne = true;
-					}
-//#ifndef QT_NO_DEBUG
-//					DebugDialog::debug(QString("set up image elapsed (2.4) %1").arg(t.elapsed()) );
-//#endif
-				}
-				if (!gotOne) {
-					delete renderer;
-					error = tr("unable to create renderer for svg %1").arg(filename);
-					renderer = NULL;
-				}
-			}
-			//DebugDialog::debug(QString("set up image elapsed (3) %1").arg(t.elapsed()) );
+    QByteArray resultBytes; 
+    if (!bytesToLoad.isEmpty()) {
+        makeLocalModifications(bytesToLoad, filename);
+        resultBytes = newRenderer->loadSvg(bytesToLoad, filename, connectorIDs, terminalIDs, legIDs, setColor, colorElementID, viewIdentifier == ViewLayer::PCBView);
+    }
 
-			if (renderer) {
-				FSvgRenderer::set(modelPartShared->moduleID(), viewLayerID, renderer);
-			}
-    	}
+    layerAttributes.setLoaded(resultBytes);
+
+#ifndef QT_NO_DEBUG
+//	DebugDialog::debug(QString("set up image elapsed (2.3) %1").arg(t.elapsed()) );
+#endif
+
+	if (resultBytes.isEmpty()) {
+		delete newRenderer;
+		error = tr("unable to create renderer for svg %1").arg(filename);
+		newRenderer = NULL;
+	}
+	//DebugDialog::debug(QString("set up image elapsed (3) %1").arg(t.elapsed()) );
+
+	if (newRenderer) {
+		layerAttributes.setFilename(newRenderer->filename());
 	}
 
-	if (renderer) {
-		layerAttributes.setFilename(renderer->filename());
-	}
-
-	return renderer;
+	return newRenderer;
 }
 
 QString ItemBase::getSvgFilename(ModelPart * modelPart, const QString & baseName) 
 {
 	QStringList tempPaths;
-	QString postfix = +"/"+ ItemBase::SvgFilesDir +"/%1/"+ baseName;
-	if(modelPart->path() != ___emptyString___) {
+	QString postfix = "/"+ ItemBase::SvgFilesDir +"/%1/"+ baseName;
+    QString userStore = FolderUtils::getUserDataStorePath("parts")+postfix;
+    QString pfPath = PartFactory::folderPath() + postfix;
+	if(!modelPart->path().isEmpty()) {
 		QDir dir(modelPart->path());			// is a path to a filename
 		dir.cdUp();									// lop off the filename
 		dir.cdUp();									// parts root
-		tempPaths << dir.absolutePath() + "/" + ItemBase::SvgFilesDir +"/%1/" + baseName;
+		tempPaths << dir.absolutePath() + postfix;
 		tempPaths << FolderUtils::getApplicationSubFolderPath("parts")+postfix;    // some svgs may still be in the fritzing parts folder, though the other svgs are in the user folder
-	} 
-	else { // for fake models
+        if (tempPaths.at(0).compare(userStore) != 0) {
+            tempPaths << userStore;
+        }
+        if (tempPaths.at(0).compare(pfPath) != 0) {
+            tempPaths << pfPath;
+        }
+        //DebugDialog::debug("temp path");
+        //foreach (QString tempPath, tempPaths) {
+        //    DebugDialog::debug(tempPath);
+        //}
+    } 
+	else {
+        DebugDialog::debug("modelPart with no path--this shouldn't happen");
 		tempPaths << FolderUtils::getApplicationSubFolderPath("parts")+postfix;
-		tempPaths << FolderUtils::getUserDataStorePath("parts")+postfix;
+		tempPaths << userStore;
 	}
 	tempPaths << ":resources/parts/svg/%1/" + baseName;
 
@@ -1368,7 +1440,7 @@ QString ItemBase::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString,
 	Q_UNUSED(svgHash);
 	Q_UNUSED(blackOnly);
 	Q_UNUSED(dpi);
-	return ___emptyString___;
+	return "";
 }
 
 bool ItemBase::hasConnections()
@@ -1449,7 +1521,7 @@ bool ItemBase::connectionIsAllowed(ConnectorItem * other) {
 QString ItemBase::getProperty(const QString & key) {
 	if (m_modelPart == NULL) return "";
 
-	QString result = m_modelPart->prop(key).toString();
+	QString result = m_modelPart->localProp(key).toString();
 	if (!result.isEmpty()) return result;
 
 	return m_modelPart->properties().value(key, "");
@@ -1500,14 +1572,15 @@ bool ItemBase::hasCustomSVG() {
 void ItemBase::setProp(const QString & prop, const QString & value) {
 	if (!m_modelPart) return;
 
-	m_modelPart->setProp(prop, value);
+    //DebugDialog::debug(QString("setting prop %1 %2").arg(prop).arg(value));
+	m_modelPart->setLocalProp(prop, value);
 }
 
 QString ItemBase::prop(const QString & p)
 {
 	if (m_modelPart == NULL) return "";
 
-	return m_modelPart->prop(p).toString();
+	return m_modelPart->localProp(p).toString();
 }
 
 bool ItemBase::isObsolete() {
@@ -1561,18 +1634,18 @@ void ItemBase::swapEntry(const QString & text) {
 }
 
 void ItemBase::setReferenceModel(ReferenceModel * rm) {
-	referenceModel = rm;
+	TheReferenceModel = rm;
 }
 
 QStringList ItemBase::collectValues(const QString & family, const QString & prop, QString & value) {
 	Q_UNUSED(value);
 
-	if (referenceModel == NULL) return ___emptyStringList___;
+	if (TheReferenceModel == NULL) return ___emptyStringList___;
 
 	QStringList values = CachedValues.value(family + prop, QStringList());
 	if (values.count() > 0) return values;
 
-	values = referenceModel->values(family, prop);
+	values = TheReferenceModel->propValues(family, prop, true);
 
 	// sort values numerically
 	NumberMatcherValues.clear();
@@ -1656,11 +1729,11 @@ bool ItemBase::getFlipDoc(ModelPart * modelPart, const QString & filename, ViewL
 {
 	if (viewLayerSpec == ViewLayer::ThroughHoleThroughTop_OneLayer) {
 		if ((viewLayerID == ViewLayer::Copper0) && modelPart->flippedSMD()) {
-			SvgFlattener::flipSMDSvg(filename, "", flipDoc, ViewLayer::viewLayerXmlNameFromID(ViewLayer::Copper1), ViewLayer::viewLayerXmlNameFromID(ViewLayer::Copper0), FSvgRenderer::printerScale());
+			SvgFlattener::flipSMDSvg(filename, "", flipDoc, ViewLayer::viewLayerXmlNameFromID(ViewLayer::Copper1), ViewLayer::viewLayerXmlNameFromID(ViewLayer::Copper0), GraphicsUtils::SVGDPI);
 			return true;
 		}
 		else if ((viewLayerID == ViewLayer::Silkscreen0) && modelPart->flippedSMD()) {
-			SvgFlattener::flipSMDSvg(filename, "", flipDoc, ViewLayer::viewLayerXmlNameFromID(ViewLayer::Silkscreen1), ViewLayer::viewLayerXmlNameFromID(ViewLayer::Silkscreen0), FSvgRenderer::printerScale());
+			SvgFlattener::flipSMDSvg(filename, "", flipDoc, ViewLayer::viewLayerXmlNameFromID(ViewLayer::Silkscreen1), ViewLayer::viewLayerXmlNameFromID(ViewLayer::Silkscreen0), GraphicsUtils::SVGDPI);
 			return true;
 		}
 	}
@@ -1709,24 +1782,24 @@ bool ItemBase::moveLock() {
 
 void ItemBase::setMoveLock(bool moveLock) 
 {
-	if (moveLock == m_moveLock) return;
-
 	m_moveLock = moveLock;
 	if (moveLock) {
-		if (!MoveLockRenderer.isValid()) {
-			QString fn(":resources/images/part_lock.svg");
-			bool success = MoveLockRenderer.load(fn);
-			DebugDialog::debug(QString("movelock load success %1").arg(success));
-		}
+        if (m_moveLockItem == NULL) {
+		    if (!MoveLockRenderer.isValid()) {
+			    QString fn(":resources/images/part_lock.svg");
+			    bool success = MoveLockRenderer.load(fn);
+			    DebugDialog::debug(QString("movelock load success %1").arg(success));
+		    }
 
-		m_moveLockItem = new QGraphicsSvgItem();
-		m_moveLockItem->setAcceptHoverEvents(false);
-		m_moveLockItem->setAcceptedMouseButtons(Qt::NoButton);
-		m_moveLockItem->setSharedRenderer(&MoveLockRenderer);
-		m_moveLockItem->setPos(0,0);
-		m_moveLockItem->setZValue(-99999);
-		m_moveLockItem->setParentItem(this);
-		m_moveLockItem->setVisible(true);
+		    m_moveLockItem = new QGraphicsSvgItem();
+		    m_moveLockItem->setAcceptHoverEvents(false);
+		    m_moveLockItem->setAcceptedMouseButtons(Qt::NoButton);
+		    m_moveLockItem->setSharedRenderer(&MoveLockRenderer);
+		    m_moveLockItem->setPos(0,0);
+		    m_moveLockItem->setZValue(-99999);
+		    m_moveLockItem->setParentItem(this);
+		    m_moveLockItem->setVisible(true);
+        }
 
 	}
 	else {
@@ -1736,14 +1809,19 @@ void ItemBase::setMoveLock(bool moveLock)
 		}
 	}
 
+    if (m_stickyItem) {
+		m_stickyItem->setPos(m_moveLockItem == NULL ? 0 : m_moveLockItem->boundingRect().width() + 1, 0);
+    }
+
 	update();
 }
 
-
 void ItemBase::debugInfo(const QString & msg) const
 {
 
 #ifndef QT_NO_DEBUG
+
+    debugInfo2(msg);
 	DebugDialog::debug(QString("%1 '%2' id:%3 '%4' vid:%9 vlid:%5 spec:%6 flg:%7 gi:%8")
 		.arg(msg)
 		.arg(this->title())
@@ -1766,9 +1844,34 @@ void ItemBase::debugInfo(const QString & msg) const
 #endif
 }
 
+void ItemBase::debugInfo2(const QString & msg) const
+{
+	DebugDialog::debug(QString("%1 '%2' id:%3 '%4' vid:%9 vlid:%5 spec:%6 flg:%7 gi:%8")
+		.arg(msg)
+		.arg(this->title())
+		.arg(this->id())
+		.arg(this->instanceTitle())
+		.arg(this->viewLayerID())
+		.arg(this->viewLayerSpec())
+		.arg(this->wireFlags())
+		.arg((long) dynamic_cast<const QGraphicsItem *const>(this), 0, 16)
+		.arg(m_viewIdentifier)
+	);
+
+	/*
+	foreach (ConnectorItem * connectorItem, cachedConnectorItems()) {
+		if (connectorItem) connectorItem->debugInfo("\t");
+	}
+	*/
+}
+
 void ItemBase::addedToScene(bool temporary) {
 	if (this->scene() && instanceTitle().isEmpty() && !temporary) {
 		setTooltip();
+        if (isBaseSticky()) {
+            // ensure icon is visible
+            setLocalSticky(true);
+        }
 	}
 }
 
@@ -1850,7 +1953,7 @@ QRectF ItemBase::boundingRectWithoutLegs() const
 
 QRectF ItemBase::boundingRect() const
 {    
-	FSvgRenderer * frenderer = dynamic_cast<FSvgRenderer *>(this->renderer());
+	FSvgRenderer * frenderer = fsvgRenderer();
 	if (frenderer == NULL) {
 		return QGraphicsSvgItem::boundingRect();
 	}
@@ -1875,4 +1978,157 @@ PartLabel * ItemBase::partLabel() {
 }
 
 void ItemBase::doneLoading() {
-}
\ No newline at end of file
+}
+
+QString ItemBase::family() {
+	return modelPart()->family();
+}
+
+QPixmap * ItemBase::getPixmap(QSize size) {
+    return FSvgRenderer::getPixmap(renderer(), size);
+}
+
+FSvgRenderer * ItemBase::fsvgRenderer() const {
+    if (m_fsvgRenderer) return m_fsvgRenderer;
+
+    FSvgRenderer * f = qobject_cast<FSvgRenderer *>(renderer());
+    if (f == NULL) {
+        DebugDialog::debug("shouldn't happen: missing fsvgRenderer");
+    }
+    return f;
+}
+
+void ItemBase::setSharedRendererEx(FSvgRenderer * newRenderer) {
+	if (newRenderer != m_fsvgRenderer) {
+		setSharedRenderer(newRenderer);  // original renderer is deleted if it is not shared
+        if (m_fsvgRenderer) delete m_fsvgRenderer;
+        m_fsvgRenderer = newRenderer;
+	}
+	else {
+		update();
+	}
+	m_size = newRenderer->defaultSizeF();
+}
+
+bool ItemBase::reloadRenderer(const QString & svg, bool fastLoad) {
+	if (!svg.isEmpty()) {
+		//DebugDialog::debug(svg);
+		prepareGeometryChange();
+		bool result = fastLoad ? fsvgRenderer()->fastLoad(svg.toUtf8()) : fsvgRenderer()->loadSvgString(svg.toUtf8());
+		if (result) {
+            update();
+		}
+
+		return result;
+	}
+
+	return false;
+}
+
+bool ItemBase::resetRenderer(const QString & svg) {
+    // use resetRenderer instead of reloadRender because if the svg size changes, with reloadRenderer the new image seems to be scaled to the old bounds
+    // what I don't understand is why the old renderer causes a crash if it is deleted here
+    
+    QString nothing;
+    return resetRenderer(svg, nothing);
+}
+
+bool ItemBase::resetRenderer(const QString & svg, QString & newSvg) {
+    // use resetRenderer instead of reloadRender because if the svg size changes, with reloadRenderer the new image seems to be scaled to the old bounds
+    // what I don't understand is why the old renderer causes a crash if it is deleted here
+    
+    FSvgRenderer * newRenderer = new FSvgRenderer();
+    bool result = newRenderer->loadSvgString(svg, newSvg);
+    if (result) {
+        setSharedRendererEx(newRenderer);
+    }
+    else {
+        delete newRenderer;
+    }
+    return result;
+}
+
+void ItemBase::getPixmaps(QPixmap * & pixmap1, QPixmap * & pixmap2, QPixmap * & pixmap3, bool swappingEnabled, QSize size) 
+{
+    pixmap1 = getPixmap(ViewLayer::BreadboardView, swappingEnabled, size);
+    pixmap2 = getPixmap(ViewLayer::SchematicView, swappingEnabled, size);
+    pixmap3 = getPixmap(ViewLayer::PCBView, swappingEnabled, size);
+}
+
+QPixmap * ItemBase::getPixmap(ViewLayer::ViewIdentifier vid, bool swappingEnabled, QSize size)
+{
+    ItemBase * vItemBase = NULL;
+
+    if (viewIdentifier() == vid) {
+        if (!isEverVisible()) return NULL;
+    }
+    else {
+        vItemBase = modelPart()->viewItem(vid);
+        if (vItemBase && !vItemBase->isEverVisible()) return NULL;
+    }
+
+    vid = useViewIdentifierForPixmap(vid, swappingEnabled);
+    if (vid == ViewLayer::UnknownView) return NULL;
+
+    if (viewIdentifier() == vid) {
+        return getPixmap(size);
+    }
+
+    if (vItemBase) {
+        return vItemBase->getPixmap(size);
+    }
+
+
+	if (!modelPart()->hasViewFor(vid)) return NULL;
+
+	QString baseName = modelPart()->hasBaseNameFor(vid);
+	if (baseName.isEmpty()) return NULL;
+
+	QString filename = ItemBase::getSvgFilename(modelPart(), baseName);
+	if (filename.isEmpty()) {
+		return NULL;
+	}
+
+	QSvgRenderer renderer(filename);
+
+	QPixmap * pixmap = new QPixmap(size);
+	pixmap->fill(Qt::transparent);
+	QPainter painter(pixmap);
+	// preserve aspect ratio
+	QSize def = renderer.defaultSize();
+	double newW = size.width();
+	double newH = newW * def.height() / def.width();
+	if (newH > size.height()) {
+		newH = size.height();
+		newW = newH * def.width() / def.height();
+	}
+	QRectF bounds((size.width() - newW) / 2.0, (size.height() - newH) / 2.0, newW, newH);
+	renderer.render(&painter, bounds);
+	painter.end();
+
+	return pixmap;
+}
+
+ViewLayer::ViewIdentifier ItemBase::useViewIdentifierForPixmap(ViewLayer::ViewIdentifier vid, bool) 
+{
+    if (vid == ViewLayer::BreadboardView) {
+        return ViewLayer::IconView;
+    }
+
+    return vid;
+}
+
+void ItemBase::makeLocalModifications(QByteArray &, const QString &) {
+}
+
+void ItemBase::showConnectors(const QStringList & connectorIDs) {
+	foreach (ConnectorItem * connectorItem, cachedConnectorItems()) {
+		if (connectorIDs.contains(connectorItem->connectorSharedID())) {
+			connectorItem->setVisible(true);
+		}
+	}
+}
+
+void ItemBase::setItemIsSelectable(bool selectable) {
+	setFlag(QGraphicsItem::ItemIsSelectable, selectable);
+}
