@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5952 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-08 00:47:10 +0200 (Sun, 08 Apr 2012) $
+$Revision: 6483 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-26 15:45:37 +0200 (Wed, 26 Sep 2012) $
 
 ********************************************************************/
 
@@ -41,7 +41,6 @@ $Date: 2012-04-08 00:47:10 +0200 (Sun, 08 Apr 2012) $
 
 #include "../viewgeometry.h"
 #include "../viewlayer.h"
-#include "../viewidentifierclass.h"
 #include "../utils/misc.h"
 
 class ConnectorItem;
@@ -62,7 +61,7 @@ public:
 	};
 
 public:
-	ItemBase(class ModelPart*, ViewIdentifierClass::ViewIdentifier, const ViewGeometry &, long id, QMenu * itemMenu);
+	ItemBase(class ModelPart*, ViewLayer::ViewIdentifier, const ViewGeometry &, long id, QMenu * itemMenu);
 	virtual ~ItemBase();
 
 	qint64 id() const;
@@ -87,7 +86,7 @@ public:
 	void transformItem(const QTransform &);
 	virtual void transformItem2(const QMatrix &);
 	virtual void removeLayerKin();
-	ViewIdentifierClass::ViewIdentifier viewIdentifier();
+	ViewLayer::ViewIdentifier viewIdentifier();
 	QString & viewIdentifierName();
 	ViewLayer::ViewLayerID viewLayerID() const;
 	void setViewLayerID(ViewLayer::ViewLayerID, const LayerHash & viewLayers);
@@ -106,10 +105,13 @@ public:
 	virtual void updateConnections();
 	virtual const QString & title() const;
 	bool getRatsnest();
-	const QHash<QString, QPointer<class Bus> > & buses();
+	QList<class Bus *> buses();
 	int itemType() const;					// wanted this to return ModelPart::ItemType but couldn't figure out how to get it to compile
-	virtual bool sticky();
+	virtual bool isSticky();
+	virtual bool isBaseSticky();
 	virtual void setSticky(bool);
+	void setLocalSticky(bool);
+    bool isLocalSticky();
 	virtual void addSticky(ItemBase *, bool stickem);
 	virtual ItemBase * stickingTo();
 	virtual QList< QPointer<ItemBase> > stickyList();
@@ -181,6 +183,7 @@ public:
 	bool moveLock();
 	virtual void setMoveLock(bool);
 	void debugInfo(const QString & msg) const;
+	void debugInfo2(const QString & msg) const;
 	virtual void addedToScene(bool temporary);
 	virtual bool hasPartNumberProperty();
 	void collectPropsMap(QString & family, QMap<QString, QString> &);
@@ -201,6 +204,17 @@ public:
 	virtual const QCursor * getCursor(Qt::KeyboardModifiers);
 	class PartLabel * partLabel();
 	virtual void doneLoading();
+	QString family();
+	QPixmap * getPixmap(QSize size);
+    class FSvgRenderer * fsvgRenderer() const;
+	void setSharedRendererEx(class FSvgRenderer *);
+	bool reloadRenderer(const QString & svg, bool fastload);
+	bool resetRenderer(const QString & svg);
+	bool resetRenderer(const QString & svg, QString & newSvg);
+    void getPixmaps(QPixmap * &, QPixmap * &, QPixmap * &, bool swappingEnabled, QSize);
+    class FSvgRenderer * setUpImage(class ModelPart * modelPart, ViewLayer::ViewIdentifier, ViewLayer::ViewLayerID, ViewLayer::ViewLayerSpec, class LayerAttributes &, QString & error);
+	void showConnectors(const QStringList &);
+	void setItemIsSelectable(bool selectable);
 
 public:
 	virtual void getConnectedColor(ConnectorItem *, QBrush * &, QPen * &, double & opacity, double & negativePenWidth, bool & negativeOffsetRect);
@@ -248,6 +262,8 @@ public:
 	virtual void mouseMoveConnectorEvent(ConnectorItem *, QGraphicsSceneMouseEvent *);
 	virtual void mouseReleaseConnectorEvent(ConnectorItem *, QGraphicsSceneMouseEvent *);
 	virtual bool acceptsMousePressConnectorEvent(ConnectorItem *, QGraphicsSceneMouseEvent *);
+	virtual bool acceptsMousePressLegEvent(ConnectorItem *, QGraphicsSceneMouseEvent *);
+	virtual void setAcceptsMousePressLegEvent(bool);
 	virtual bool acceptsMouseDoubleClickConnectorEvent(ConnectorItem *, QGraphicsSceneMouseEvent *);
 	virtual bool acceptsMouseMoveConnectorEvent(ConnectorItem *, QGraphicsSceneMouseEvent *);
 	virtual bool acceptsMouseReleaseConnectorEvent(ConnectorItem *, QGraphicsSceneMouseEvent *);
@@ -266,13 +282,12 @@ public slots:
 	void showPartLabel(bool show, ViewLayer *);
 	void hidePartLabel();
 	void partLabelChanged(const QString &newText);
-	void swapEntry(const QString & text);
+	virtual void swapEntry(const QString & text);
 
 public:
 	static bool zLessThan(ItemBase * & p1, ItemBase * & p2);
 	static qint64 getNextID();
 	static qint64 getNextID(qint64 fromIndex);
-	static class FSvgRenderer * setUpImage(class ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier, ViewLayer::ViewLayerID, ViewLayer::ViewLayerSpec, class LayerAttributes &, QString & error);
 	static QString getSvgFilename(ModelPart *, const QString & baseName); 
 
 protected:
@@ -291,6 +306,9 @@ protected:
 	virtual void setDefaultTooltip();
 	void setInstanceTitleAux(const QString & title);
 	void saveLocAndTransform(QXmlStreamWriter & streamWriter);
+    QPixmap * getPixmap(ViewLayer::ViewIdentifier, bool swappingEnabled, QSize size);
+    virtual ViewLayer::ViewIdentifier useViewIdentifierForPixmap(ViewLayer::ViewIdentifier, bool swappingEnabled);
+    virtual void makeLocalModifications(QByteArray & svg, const QString & filename);
 
 protected:
 	static bool getFlipDoc(ModelPart * modelPart, const QString & filename, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec, QDomDocument &);
@@ -301,7 +319,7 @@ protected:
 	qint64 m_id;
 	ViewGeometry m_viewGeometry;
 	QPointer<ModelPart> m_modelPart;
-	ViewIdentifierClass::ViewIdentifier m_viewIdentifier;
+	ViewLayer::ViewIdentifier m_viewIdentifier;
 	ViewLayer::ViewLayerID m_viewLayerID;
 	int m_connectorHoverCount;
 	int m_connectorHoverCount2;
@@ -326,10 +344,13 @@ protected:
 	bool m_hasRubberBandLeg;
 	QList<ConnectorItem *> m_cachedConnectorItems;
 	QGraphicsSvgItem * m_moveLockItem;
-
-protected:
+	QGraphicsSvgItem * m_stickyItem;
+    FSvgRenderer * m_fsvgRenderer;
+	bool m_acceptsMousePressLegEvent;
+       
+ protected:
 	static long nextID;
-	static QPointer<class ReferenceModel> referenceModel;
+	static QPointer<class ReferenceModel> TheReferenceModel;
 
 public:
 	static const QString ITEMBASE_FONT_PREFIX;
