@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5940 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-03 15:22:23 +0200 (Tue, 03 Apr 2012) $
+$Revision: 6505 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-03 10:14:52 +0200 (Wed, 03 Oct 2012) $
 
 ********************************************************************/
 
@@ -31,6 +31,7 @@ $Date: 2012-04-03 15:22:23 +0200 (Tue, 03 Apr 2012) $
 #include "../utils/graphicsutils.h"
 #include "../svg/svgfilesplitter.h"
 #include "../sketch/infographicsview.h"
+#include "../debugdialog.h"
 
 static QString Copper0LayerTemplate = "";
 static QString JumperWireLayerTemplate = "";
@@ -54,10 +55,10 @@ void shorten(QRectF r0, QPointF r0c, QPointF r1c, double & r0x, double & r0y, do
 {
 	double radius = r0.width() / 2.0;
 	GraphicsUtils::shortenLine(r0c, r1c, radius, radius);
-	r0x = GraphicsUtils::pixels2mils(r0c.x(), FSvgRenderer::printerScale());
-	r0y = GraphicsUtils::pixels2mils(r0c.y(), FSvgRenderer::printerScale());
-	r1x = GraphicsUtils::pixels2mils(r1c.x(), FSvgRenderer::printerScale());
-	r1y = GraphicsUtils::pixels2mils(r1c.y(), FSvgRenderer::printerScale());
+	r0x = GraphicsUtils::pixels2mils(r0c.x(), GraphicsUtils::SVGDPI);
+	r0y = GraphicsUtils::pixels2mils(r0c.y(), GraphicsUtils::SVGDPI);
+	r1x = GraphicsUtils::pixels2mils(r1c.x(), GraphicsUtils::SVGDPI);
+	r1y = GraphicsUtils::pixels2mils(r1c.y(), GraphicsUtils::SVGDPI);
 }
 
 
@@ -68,7 +69,7 @@ void shorten(QRectF r0, QPointF r0c, QPointF r1c, double & r0x, double & r0y, do
 
 /////////////////////////////////////////////////////////
 
-JumperItem::JumperItem( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel) 
+JumperItem::JumperItem( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel) 
 	: PaletteItem(modelPart, viewIdentifier,  viewGeometry,  id, itemMenu, doLabel)
 {
 	if (Colors.isEmpty()) {
@@ -96,12 +97,11 @@ JumperItem::JumperItem( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifi
 }
 
 JumperItem::~JumperItem() {
-	m_renderers.clear();
 }
 
 QRectF JumperItem::boundingRect() const
 {
-    if (m_viewIdentifier != ViewIdentifierClass::PCBView) {
+    if (m_viewIdentifier != ViewLayer::PCBView) {
         return PaletteItem::boundingRect();
     }
 
@@ -110,7 +110,7 @@ QRectF JumperItem::boundingRect() const
 
 void JumperItem::paintHover(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
-    if (m_viewIdentifier != ViewIdentifierClass::PCBView) {
+    if (m_viewIdentifier != ViewLayer::PCBView) {
        PaletteItem::paintHover(painter, option, widget);
 	   return;
     }
@@ -120,7 +120,7 @@ void JumperItem::paintHover(QPainter *painter, const QStyleOptionGraphicsItem *o
 
 void JumperItem::paintSelected(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
-    if (m_viewIdentifier != ViewIdentifierClass::PCBView) {
+    if (m_viewIdentifier != ViewLayer::PCBView) {
        PaletteItem::paintSelected(painter, option, widget);
 	   return;
     }
@@ -130,7 +130,7 @@ void JumperItem::paintSelected(QPainter *painter, const QStyleOptionGraphicsItem
 
 QPainterPath JumperItem::hoverShape() const
 {
-    if (m_viewIdentifier != ViewIdentifierClass::PCBView) {
+    if (m_viewIdentifier != ViewLayer::PCBView) {
         return PaletteItem::hoverShape();
      }
 
@@ -155,7 +155,7 @@ QPainterPath JumperItem::shape() const
 	return hoverShape();
 }
 
-bool JumperItem::setUpImage(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec viewLayerSpec, bool doConnectors, LayerAttributes & layerAttributes, QString & error)
+bool JumperItem::setUpImage(ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec viewLayerSpec, bool doConnectors, LayerAttributes & layerAttributes, QString & error)
 {
 	bool result = PaletteItem::setUpImage(modelPart, viewIdentifier, viewLayers, viewLayerID, viewLayerSpec, doConnectors, layerAttributes, error);
 
@@ -178,26 +178,26 @@ bool JumperItem::setUpImage(ModelPart * modelPart, ViewIdentifierClass::ViewIden
 	return result;
 }
 
-void JumperItem::initialResize(ViewIdentifierClass::ViewIdentifier viewIdentifier) {
-	if (viewIdentifier != ViewIdentifierClass::PCBView) return;
+void JumperItem::initialResize(ViewLayer::ViewIdentifier viewIdentifier) {
+	if (viewIdentifier != ViewLayer::PCBView) return;
 
 	bool ok;
-	double r0x = m_modelPart->prop("r0x").toDouble(&ok);
+	double r0x = m_modelPart->localProp("r0x").toDouble(&ok);
 	if (!ok) return;
 
-	double r0y = m_modelPart->prop("r0y").toDouble(&ok);
+	double r0y = m_modelPart->localProp("r0y").toDouble(&ok);
 	if (!ok) return;
 					
-	double r1x = m_modelPart->prop("r1x").toDouble(&ok);
+	double r1x = m_modelPart->localProp("r1x").toDouble(&ok);
 	if (!ok) return;
 						
-	double r1y = m_modelPart->prop("r1y").toDouble(&ok);
+	double r1y = m_modelPart->localProp("r1y").toDouble(&ok);
 	if (!ok) return;
 							
-	resizeAux(GraphicsUtils::mils2pixels(r0x, FSvgRenderer::printerScale()), 
-				GraphicsUtils::mils2pixels(r0y, FSvgRenderer::printerScale()),
-				GraphicsUtils::mils2pixels(r1x, FSvgRenderer::printerScale()), 
-				GraphicsUtils::mils2pixels(r1y, FSvgRenderer::printerScale()));
+	resizeAux(GraphicsUtils::mils2pixels(r0x, GraphicsUtils::SVGDPI), 
+				GraphicsUtils::mils2pixels(r0y, GraphicsUtils::SVGDPI),
+				GraphicsUtils::mils2pixels(r1x, GraphicsUtils::SVGDPI), 
+				GraphicsUtils::mils2pixels(r1y, GraphicsUtils::SVGDPI));
 
 }
 
@@ -280,20 +280,20 @@ QString JumperItem::makeSvg(ViewLayer::ViewLayerID viewLayerID)
 	QRectF r0 = m_connector0->rect();
 	QRectF r1 = m_connector1->rect();
 	QRectF r = r0.united(r1);
-	double w = GraphicsUtils::pixels2ins(r.width() + m_connectorTL.x() + m_connectorBR.x(), FSvgRenderer::printerScale());
-	double h = GraphicsUtils::pixels2ins(r.height() + m_connectorTL.y() + m_connectorBR.y(), FSvgRenderer::printerScale());
+	double w = GraphicsUtils::pixels2ins(r.width() + m_connectorTL.x() + m_connectorBR.x(), GraphicsUtils::SVGDPI);
+	double h = GraphicsUtils::pixels2ins(r.height() + m_connectorTL.y() + m_connectorBR.y(), GraphicsUtils::SVGDPI);
 
 	QPointF r0c = r0.center();
 	QPointF r1c = r1.center();
-	double r0x = GraphicsUtils::pixels2mils(r0c.x(), FSvgRenderer::printerScale());
-	double r0y = GraphicsUtils::pixels2mils(r0c.y(), FSvgRenderer::printerScale());
-	double r1x = GraphicsUtils::pixels2mils(r1c.x(), FSvgRenderer::printerScale());
-	double r1y = GraphicsUtils::pixels2mils(r1c.y(), FSvgRenderer::printerScale());
+	double r0x = GraphicsUtils::pixels2mils(r0c.x(), GraphicsUtils::SVGDPI);
+	double r0y = GraphicsUtils::pixels2mils(r0c.y(), GraphicsUtils::SVGDPI);
+	double r1x = GraphicsUtils::pixels2mils(r1c.x(), GraphicsUtils::SVGDPI);
+	double r1y = GraphicsUtils::pixels2mils(r1c.y(), GraphicsUtils::SVGDPI);
 
-	modelPart()->setProp("r0x", r0x);
-	modelPart()->setProp("r0y", r0y);
-	modelPart()->setProp("r1x", r1x);
-	modelPart()->setProp("r1y", r1y);
+	modelPart()->setLocalProp("r0x", r0x);
+	modelPart()->setLocalProp("r0y", r0y);
+	modelPart()->setLocalProp("r1x", r1x);
+	modelPart()->setLocalProp("r1y", r1y);
 
 	switch (viewLayerID) {
 		case ViewLayer::Copper0:
@@ -336,7 +336,7 @@ void JumperItem::resize(QPointF p0, QPointF p1) {
 }
 
 void JumperItem::resize() {
-	if (m_viewIdentifier != ViewIdentifierClass::PCBView) return;
+	if (m_viewIdentifier != ViewLayer::PCBView) return;
 
 	if (m_connector0 == NULL) return;
 	if (m_connector1 == NULL) return;
@@ -345,7 +345,7 @@ void JumperItem::resize() {
 
 	QString s = makeSvg(ViewLayer::Copper0);
 	//DebugDialog::debug(s);
-	loadExtraRenderer(s, false);
+	resetRenderer(s);
 
 	foreach (ItemBase * itemBase, m_layerKin) {
 		switch(itemBase->viewLayerID()) {
@@ -354,18 +354,8 @@ void JumperItem::resize() {
 			case ViewLayer::Silkscreen1:
 			//case ViewLayer::Silkscreen0:
                 {
-					FSvgRenderer * renderer = m_renderers.value(itemBase->viewLayerID(), NULL);
-					if (renderer == NULL) {
-						renderer = new FSvgRenderer(itemBase);
-						m_renderers.insert(itemBase->viewLayerID(), renderer);
-					}
-
 					s = makeSvg(itemBase->viewLayerID());
-					bool result = renderer->loadSvgString(s);
-					if (result) {
-						itemBase->prepareGeometryChange();
-						qobject_cast<PaletteItemBase *>(itemBase)->setSharedRendererEx(renderer);
-					}
+					itemBase->resetRenderer(s);
                 }
 				break;
             default:
@@ -437,20 +427,9 @@ QString JumperItem::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QStrin
 	}
 
 	if (!xml.isEmpty()) {
-		QString xmlName = ViewLayer::viewLayerXmlNameFromID(viewLayerID);
-		SvgFileSplitter splitter;
-		bool result = splitter.splitString(xml, xmlName);
-		if (!result) {
-			return ___emptyString___;
-		}
-		result = splitter.normalize(dpi, xmlName, blackOnly);
-		if (!result) {
-			return ___emptyString___;
-		}
-		return splitter.elementString(xmlName);
+        return PaletteItemBase::normalizeSvg(xml, viewLayerID, blackOnly, dpi);
 	}
 
-
 	return PaletteItemBase::retrieveSvg(viewLayerID, svgHash, blackOnly, dpi);
 }
 
@@ -472,7 +451,7 @@ ConnectorItem * JumperItem::connector1() {
 
 bool JumperItem::hasCustomSVG() {
 	switch (m_viewIdentifier) {
-		case ViewIdentifierClass::PCBView:
+		case ViewLayer::PCBView:
 			return true;
 		default:
 			return ItemBase::hasCustomSVG();
@@ -565,3 +544,12 @@ bool JumperItem::hasPartNumberProperty()
 {
 	return false;
 }
+
+ViewLayer::ViewIdentifier JumperItem::useViewIdentifierForPixmap(ViewLayer::ViewIdentifier vid, bool) 
+{
+    if (vid == ViewLayer::PCBView) {
+        return ViewLayer::IconView;
+    }
+
+    return ViewLayer::UnknownView;
+}
