@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5721 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-03 16:53:58 +0100 (Tue, 03 Jan 2012) $
+$Revision: 6526 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-07 15:31:22 +0200 (Sun, 07 Oct 2012) $
 
 ********************************************************************/
 
@@ -29,7 +29,7 @@ $Date: 2012-01-03 16:53:58 +0100 (Tue, 03 Jan 2012) $
 #include "../debugdialog.h"
 #include "../layerattributes.h"
 
-LayerKinPaletteItem::LayerKinPaletteItem(PaletteItemBase * chief, ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu* itemMenu)
+LayerKinPaletteItem::LayerKinPaletteItem(PaletteItemBase * chief, ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu* itemMenu)
 	: PaletteItemBase(modelPart, viewIdentifier, viewGeometry, id, itemMenu)
 
 {
@@ -85,7 +85,12 @@ bool LayerKinPaletteItem::ok() {
 }
 
 void LayerKinPaletteItem::updateConnections() {
-	m_layerKinChief->updateConnections();
+    if (m_layerKinChief) {
+	    m_layerKinChief->updateConnections();
+    }
+    else {
+        DebugDialog::debug("chief deleted before layerkin");
+    }
 }
 
 void LayerKinPaletteItem::mousePressEvent(QGraphicsSceneMouseEvent *event) {
@@ -140,8 +145,12 @@ bool LayerKinPaletteItem::stickyEnabled() {
 	return m_layerKinChief->stickyEnabled();
 }
 
-bool LayerKinPaletteItem::sticky() {
-	return m_layerKinChief->sticky();
+bool LayerKinPaletteItem::isSticky() {
+	return m_layerKinChief->isSticky();
+}
+
+bool LayerKinPaletteItem::isBaseSticky() {
+	return m_layerKinChief->isBaseSticky();
 }
 
 void LayerKinPaletteItem::setSticky(bool s) 
