@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5948 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-07 11:02:13 +0200 (Sat, 07 Apr 2012) $
+$Revision: 6505 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-03 10:14:52 +0200 (Wed, 03 Oct 2012) $
 
 ********************************************************************/
 
@@ -39,7 +39,7 @@ $Date: 2012-04-07 11:02:13 +0200 (Sat, 07 Apr 2012) $
 static QHash<QString, QString> BreadboardSvg;
 static QHash<QString, QString> IconSvg;
 
-LED::LED( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+LED::LED( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
 	: Capacitor(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
 {
 }
@@ -60,17 +60,7 @@ QString LED::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QStr
 	QString svg = getColorSVG(prop("color"), viewLayerID);
 	if (svg.isEmpty()) return "";
 
-	QString xmlName = ViewLayer::viewLayerXmlNameFromID(viewLayerID);
-	SvgFileSplitter splitter;
-	bool result = splitter.splitString(svg, xmlName);
-	if (!result) {
-		return "";
-	}
-	result = splitter.normalize(dpi, xmlName, blackOnly);
-	if (!result) {
-		return "";
-	}
-	return splitter.elementString(xmlName);
+    return PaletteItemBase::normalizeSvg(svg, viewLayerID, blackOnly, dpi);
 }
 
 void LED::addedToScene(bool temporary)
@@ -84,8 +74,8 @@ void LED::addedToScene(bool temporary)
 
 bool LED::hasCustomSVG() {
 	switch (m_viewIdentifier) {
-		case ViewIdentifierClass::BreadboardView:
-		case ViewIdentifierClass::IconView:
+		case ViewLayer::BreadboardView:
+		case ViewLayer::IconView:
 			return true;
 		default:
 			return ItemBase::hasCustomSVG();
@@ -133,7 +123,7 @@ void LED::setColor(const QString & color)
 			return;
 	}
 
-	loadExtraRenderer(getColorSVG(color, m_viewLayerID).toUtf8(),true);
+	reloadRenderer(getColorSVG(color, m_viewLayerID),true);
 
 	QString title = modelPart()->modelPartShared()->title();  // bypass any local title by going to modelPartShared
 	if (title.startsWith("red", Qt::CaseInsensitive)) {
@@ -173,7 +163,7 @@ QString LED::getColorSVG(const QString & color, ViewLayer::ViewLayerID viewLayer
 	return domDocument.toString();
 }
 
-bool LED::setUpImage(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec viewLayerSpec, bool doConnectors, LayerAttributes & layerAttributes, QString & error)
+bool LED::setUpImage(ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec viewLayerSpec, bool doConnectors, LayerAttributes & layerAttributes, QString & error)
 {
 	bool result = Capacitor::setUpImage(modelPart, viewIdentifier, viewLayers, viewLayerID, viewLayerSpec, doConnectors, layerAttributes, error);
 	if (viewLayerID == ViewLayer::Breadboard && BreadboardSvg.value(m_filename).isEmpty() && result) {
@@ -189,3 +179,12 @@ const QString & LED::title() {
 	m_title = prop("color") + " LED";
 	return m_title;
 }
+
+ViewLayer::ViewIdentifier LED::useViewIdentifierForPixmap(ViewLayer::ViewIdentifier vid, bool swappingEnabled) {
+    if (swappingEnabled && vid == ViewLayer::BreadboardView) {
+        return vid;
+    }
+
+    return ItemBase::useViewIdentifierForPixmap(vid, swappingEnabled);
+}
+
