@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5950 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-07 19:26:22 +0200 (Sat, 07 Apr 2012) $
+$Revision: 6561 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-12 22:39:11 +0200 (Fri, 12 Oct 2012) $
 
 ********************************************************************/
 
@@ -31,9 +31,11 @@ $Date: 2012-04-07 19:26:22 +0200 (Sat, 07 Apr 2012) $
 #include "../fsvgrenderer.h"
 #include "../sketch/infographicsview.h"
 #include "../svg/svgfilesplitter.h"
+#include "../svg/gerbergenerator.h"
 #include "moduleidnames.h"
 #include "../svg/groundplanegenerator.h"
 #include "../utils/cursormaster.h"
+#include "../debugdialog.h"
 
 #include <QHBoxLayout>
 #include <QVBoxLayout>
@@ -47,35 +49,37 @@ $Date: 2012-04-07 19:26:22 +0200 (Sat, 07 Apr 2012) $
 #include <QLineEdit>
 #include <QApplication>
 
-static QStringList ImageNames;
-static QStringList NewImageNames;
+static QStringList LogoImageNames;
+static QStringList NewLogoImageNames;
 static QStringList Copper0ImageNames;
-static QStringList NewCopper0ImageNames;
 static QStringList Copper1ImageNames;
-static QStringList NewCopper1ImageNames;
 
-LogoItem::LogoItem( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+LogoItem::LogoItem( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
 	: ResizableBoard(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
 {
-	if (ImageNames.count() == 0) {
-		ImageNames << "Made with Fritzing" << "Fritzing icon" << "OHANDA logo" << "OSHW logo";
+	if (LogoImageNames.count() == 0) {
+		LogoImageNames << "Made with Fritzing" << "Fritzing icon" << "OHANDA logo" << "OSHW logo";
 	}
 
+    m_svgOnly = false;
+    m_standardizeColors = true;
 	m_inLogoEntry = QTime::currentTime().addSecs(-10);
-	m_fileNameComboBox = NULL;
 	m_aspectRatioCheck = NULL;
 	m_keepAspectRatio = true;
-	m_hasLogo = (modelPart->moduleID() == ModuleIDNames::LogoTextModuleIDName);
-	m_logo = modelPart->prop("logo").toString();
+	m_hasLogo = (modelPart->moduleID().endsWith(ModuleIDNames::LogoTextModuleIDName));
+	m_logo = modelPart->localProp("logo").toString();
 	if (m_hasLogo && m_logo.isEmpty()) {
 		m_logo = modelPart->properties().value("logo", "logo");
-		modelPart->setProp("logo", m_logo);
+		modelPart->setLocalProp("logo", m_logo);
 	}
 }
 
 LogoItem::~LogoItem() {
 }
 
+QString LogoItem::getShapeForRenderer(const QString & svg) {
+    return svg;
+}
 
 void LogoItem::addedToScene(bool temporary)
 {
@@ -84,13 +88,13 @@ void LogoItem::addedToScene(bool temporary)
 		m_aspectRatio.setWidth(this->boundingRect().width());
 		m_aspectRatio.setHeight(this->boundingRect().height());
 		m_originalFilename = filename();
-		QString shape = prop("shape");
-		if (!shape.isEmpty()) {					
-			m_aspectRatio = modelPart()->prop("aspectratio").toSizeF();
-			if (loadExtraRenderer(shape.toUtf8(), false)) {
+		QString svg = prop("shape");
+		if (!svg.isEmpty()) {					
+			m_aspectRatio = modelPart()->localProp("aspectratio").toSizeF();
+			if (resetRenderer(getShapeForRenderer(svg))) {
 			}
 			else {
-				DebugDialog::debug("bad shape in " + m_originalFilename + " " + shape);
+				DebugDialog::debug("bad shape in " + m_originalFilename + " " + svg);
 			}
 		}
 		else {
@@ -98,8 +102,8 @@ void LogoItem::addedToScene(bool temporary)
 			if (f.open(QFile::ReadOnly)) {
 				QString svg = f.readAll();
 				f.close();
-				modelPart()->setProp("shape", svg);
-				modelPart()->setProp("lastfilename", m_originalFilename);
+				modelPart()->setLocalProp("shape", svg);
+				modelPart()->setLocalProp("lastfilename", m_originalFilename);
 				initImage();
 			}
 		}
@@ -108,10 +112,21 @@ void LogoItem::addedToScene(bool temporary)
     return ResizableBoard::addedToScene(temporary);
 }
 
+bool LogoItem::canRetrieveLayer(ViewLayer::ViewLayerID viewLayerID) {
+    return viewLayerID == layer();
+}
+
+QStringList & LogoItem::getImageNames() {
+	return LogoImageNames;
+}
+
+QStringList & LogoItem::getNewImageNames() {
+	return NewLogoImageNames;
+}
 
 QString LogoItem::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi)
 {
-	if (viewLayerID == layer() ) {
+	if (canRetrieveLayer(viewLayerID)) {
 		QString svg = prop("shape");
 		if (!svg.isEmpty()) {
 			QString xmlName = ViewLayer::viewLayerXmlNameFromID(viewLayerID);
@@ -184,120 +199,84 @@ bool LogoItem::collectExtraInfo(QWidget * parent, const QString & family, const
 	}
 	else {
 		if (prop.compare("filename", Qt::CaseInsensitive) == 0) {
-			returnProp = tr("image file");
-
-			QFrame * frame = new QFrame();
-			frame->setObjectName("infoViewPartFrame");
-			QVBoxLayout * vboxLayout = new QVBoxLayout();
-			vboxLayout->setContentsMargins(0, 0, 0, 0);
-			vboxLayout->setSpacing(0);
-			vboxLayout->setMargin(0);
-
-			QComboBox * comboBox = new QComboBox();
-			comboBox->setObjectName("infoViewComboBox");
-			comboBox->setEditable(false);
-			comboBox->setEnabled(swappingEnabled);
-			m_fileNameComboBox = comboBox;
-
-			setFileNameItems();
-
-			connect(comboBox, SIGNAL(currentIndexChanged(const QString &)), this, SLOT(fileNameEntry(const QString &)));
-
-			QPushButton * button = new QPushButton (tr("load image file"));
-			button->setObjectName("infoViewButton");
-			connect(button, SIGNAL(pressed()), this, SLOT(prepLoadImage()));
-			button->setEnabled(swappingEnabled);
-
-			vboxLayout->addWidget(comboBox);
-			vboxLayout->addWidget(button);
-
-			frame->setLayout(vboxLayout);
-			returnWidget = frame;
-
-			returnProp = "";
+            setupLoadImage(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget);
 			return true;
 		}
 	}
 
 	if (prop.compare("shape", Qt::CaseInsensitive) == 0) {
-		returnWidget = setUpDimEntry(true, returnWidget);
+		returnWidget = setUpDimEntry(true, !m_hasLogo, false, returnWidget);
+        returnWidget->setEnabled(swappingEnabled);
 		returnProp = tr("shape");
 		return true;
 	}
 
 	return PaletteItem::collectExtraInfo(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget);
-
 }
 
-void LogoItem::prepLoadImage() {
-	QList<QByteArray> supportedImageFormats = QImageReader::supportedImageFormats();
-	QString imagesStr = tr("Images");
-	imagesStr += " (";
-	foreach (QByteArray ba, supportedImageFormats) {
-		imagesStr += "*." + QString(ba) + " ";
-	}
-	if (!imagesStr.contains("svg")) {
-		imagesStr += "*.svg";
-	}
-	imagesStr += ")";
-	QString fileName = FolderUtils::getOpenFileName(
-		NULL,
-		tr("Select an image file to load"),
-		"",
-		imagesStr
-	);
-
-	if (fileName.isEmpty()) return;
-
-	prepLoadImageAux(fileName, true);
+bool LogoItem::checkImage(const QString & filename) {
+    Q_UNUSED(filename);
+    return true;
 }
 
 void LogoItem::prepLoadImageAux(const QString & fileName, bool addName)
 {
 	InfoGraphicsView * infoGraphicsView = InfoGraphicsView::getInfoGraphicsView(this);
 	if (infoGraphicsView != NULL) {
-		infoGraphicsView->loadLogoImage(this->id(), prop("shape"), m_aspectRatio, prop("lastfilename"), fileName, addName);
+		infoGraphicsView->loadLogoImage(this, prop("shape"), m_aspectRatio, prop("lastfilename"), fileName, addName);
 	}
 }
 
-void LogoItem::reloadImage(const QString & svg, const QSizeF & aspectRatio, const QString & fileName, bool addName) 
+bool LogoItem::reloadImage(const QString & svg, const QSizeF & aspectRatio, const QString & fileName, bool addName) 
 {
-	bool result = loadExtraRenderer(svg.toUtf8(), false);
+    QString shape = getShapeForRenderer(svg);
+	bool result = resetRenderer(shape);
 	if (result) {
 		if (aspectRatio == QSizeF(0, 0)) {
-			QRectF r = m_extraRenderer->viewBoxF();
+			QRectF r = fsvgRenderer()->viewBoxF();
 			m_aspectRatio.setWidth(r.width());
 			m_aspectRatio.setHeight(r.height());
 		}
 		else {
 			m_aspectRatio = aspectRatio;
 		}
-		modelPart()->setProp("aspectratio", m_aspectRatio);
-		modelPart()->setProp("shape", svg);
-		modelPart()->setProp("logo", "");
-		modelPart()->setProp("lastfilename", fileName);
+		modelPart()->setLocalProp("aspectratio", m_aspectRatio);
+		modelPart()->setLocalProp("shape", svg);
+		modelPart()->setLocalProp("logo", "");
+		modelPart()->setLocalProp("lastfilename", fileName);
+
+        QSizeF size = fsvgRenderer()->defaultSizeF();
+
+        double mmW = GraphicsUtils::pixels2mm(size.width(), GraphicsUtils::SVGDPI);
+        double mmH = GraphicsUtils::pixels2mm(size.height(), GraphicsUtils::SVGDPI);
+        modelPart()->setLocalProp("width", mmW);
+		modelPart()->setLocalProp("height", mmH);
+        modelPart()->setLocalProp("originalWidth", mmW);
+		modelPart()->setLocalProp("originalHeight", mmH);
+
 		if (addName) {
 			if (!getNewImageNames().contains(fileName, Qt::CaseInsensitive)) {
 				getNewImageNames().append(fileName);
-				bool wasBlocked = m_fileNameComboBox->blockSignals(true);
-				while (m_fileNameComboBox->count() > 0) {
-					m_fileNameComboBox->removeItem(0);
-				}
-				setFileNameItems();
-				m_fileNameComboBox->blockSignals(wasBlocked);
+                if (m_fileNameComboBox) {
+				    bool wasBlocked = m_fileNameComboBox->blockSignals(true);
+				    while (m_fileNameComboBox->count() > 0) {
+					    m_fileNameComboBox->removeItem(0);
+				    }
+				    setFileNameItems();
+				    m_fileNameComboBox->blockSignals(wasBlocked);
+                }
 			}
 		}
 		m_logo = "";
 
-		LayerHash layerHash;
-		resizeMM(GraphicsUtils::pixels2mm(m_aspectRatio.width(), FSvgRenderer::printerScale()),
-				 GraphicsUtils::pixels2mm(m_aspectRatio.height(), FSvgRenderer::printerScale()),
-				 layerHash);
+        setWidthAndHeight(qRound(mmW * 10) / 10.0, qRound(mmH * 10) / 10.0);
+        return true;
 	}
 	else {
 		// restore previous (not sure whether this is necessary)
-		loadExtraRenderer(prop("shape").toUtf8(), false);
-		unableToLoad(fileName);
+		resetRenderer(getShapeForRenderer(prop("shape")));
+		unableToLoad(fileName, tr("due to a rendering error"));
+        return false;
 	}
 }
 
@@ -310,14 +289,17 @@ void LogoItem::loadImage(const QString & fileName, bool addName)
 			svg = f.readAll();
 		}
 		if (svg.isEmpty()) {
-			unableToLoad(fileName);
+			unableToLoad(fileName, tr("because the svg is empty"));
 			return;
 		}
 
-		TextUtils::cleanSodipodi(svg);
+		if (svg.contains("coreldraw", Qt::CaseInsensitive) && svg.contains("cdata", Qt::CaseInsensitive)) {
+			unableToLoad(fileName, tr("because this appears to be a SVG file exported from CorelDRAW without choosing the 'presentation attributes' setting"));
+			return;
+		}
+
+        TextUtils::fixMuch(svg, true);
 		TextUtils::fixPixelDimensionsIn(svg);
-		TextUtils::fixViewboxOrigin(svg);
-		TextUtils::tspanRemove(svg);
 
 		QString errorStr;
 		int errorLine;
@@ -326,61 +308,67 @@ void LogoItem::loadImage(const QString & fileName, bool addName)
 		QDomDocument domDocument;
 
 		if (!domDocument.setContent(svg, true, &errorStr, &errorLine, &errorColumn)) {
-			unableToLoad(fileName);
+			unableToLoad(fileName, tr("due to an xml problem: %1 line:%2 column:%3").arg(errorStr).arg(errorLine).arg(errorColumn));
 			return;
 		}
 
 		QDomElement root = domDocument.documentElement();
 		if (root.isNull()) {
-			unableToLoad(fileName);
+			unableToLoad(fileName, tr("because the file has no root element"));
 			return;
 		}
 
 		if (root.tagName() != "svg") {
-			unableToLoad(fileName);
+			unableToLoad(fileName, tr("because the file has no <svg> element"));
 			return;
 		}
 
-		QStringList exceptions;
-		exceptions << "none" << "";
-		QString toColor(colorString());
-		SvgFileSplitter::changeColors(root, toColor, exceptions);
+        if (m_standardizeColors) {
+		    QStringList exceptions;
+		    exceptions << "none" << "";
+		    QString toColor(colorString());
+		    SvgFileSplitter::changeColors(root, toColor, exceptions);
+            // todo: change opacity?
+        }
 
 		bool isIllustrator = TextUtils::isIllustratorDoc(domDocument);
 
 		QString viewBox = root.attribute("viewBox");
 		if (viewBox.isEmpty()) {
 			bool ok1, ok2;
-			double w = TextUtils::convertToInches(root.attribute("width"), &ok1, isIllustrator) * FSvgRenderer::printerScale();
-			double h = TextUtils::convertToInches(root.attribute("height"), &ok2, isIllustrator) * FSvgRenderer::printerScale();
+			double w = TextUtils::convertToInches(root.attribute("width"), &ok1, isIllustrator) * GraphicsUtils::SVGDPI;
+			double h = TextUtils::convertToInches(root.attribute("height"), &ok2, isIllustrator) * GraphicsUtils::SVGDPI;
 			if (!ok1 || !ok2) {
-				unableToLoad(fileName);
+				unableToLoad(fileName, tr("because of an improper width or height attribute"));
 				return;
 			}
 
 			root.setAttribute("viewBox", QString("0 0 %1 %2").arg(w).arg(h));
 		}
 
-		QList<QDomNode> rootChildren;
-		QDomNode rootChild = root.firstChild();
-		while (!rootChild.isNull()) {
-			rootChildren.append(rootChild);
-			rootChild = rootChild.nextSibling();
-		}
+        QDomElement layerElement = TextUtils::findElementWithAttribute(root, "id", layerName());
+        if (layerElement.isNull()) {
+		    QList<QDomNode> rootChildren;
+		    QDomNode rootChild = root.firstChild();
+		    while (!rootChild.isNull()) {
+			    rootChildren.append(rootChild);
+			    rootChild = rootChild.nextSibling();
+		    }
 
-		QDomElement topG = domDocument.createElement("g");
-		topG.setAttribute("id", layerName());
-		root.appendChild(topG);
-		foreach (QDomNode node, rootChildren) {
-			topG.appendChild(node);
-		}
+		    QDomElement topG = domDocument.createElement("g");
+		    topG.setAttribute("id", layerName());
+		    root.appendChild(topG);
+		    foreach (QDomNode node, rootChildren) {
+			    topG.appendChild(node);
+		    }
+        }
 
 		svg = TextUtils::removeXMLEntities(domDocument.toString());
 	}
 	else {
 		QImage image(fileName);
 		if (image.isNull()) {
-			unableToLoad(fileName);
+			unableToLoad(fileName, tr("for unknown reasons--possibly the image file is corrupted"));
 			return;
 		}
 
@@ -393,8 +381,7 @@ void LogoItem::loadImage(const QString & fileName, bool addName)
 		gpg.setMinRunSize(1, 1);
 		double res = image.dotsPerMeterX() / GraphicsUtils::InchesPerMeter;
 		gpg.scanImage(image, image.width(), image.height(), 1, res, colorString(), false, false, QSizeF(0, 0), 0, QPointF(0, 0));
-		QStringList newSvgs = gpg.newSVGs();
-		if (newSvgs.count() < 1) {
+		if (gpg.newSVGs().count() < 1) {
 			QMessageBox::information(
 				NULL,
 				tr("Unable to display"),
@@ -403,30 +390,27 @@ void LogoItem::loadImage(const QString & fileName, bool addName)
 			return;
 		}
 
-		QDomDocument doc;
-		foreach (QString newSvg, newSvgs) {
-			TextUtils::mergeSvg(doc, newSvg, layerName());
-		}
-		svg = TextUtils::mergeSvgFinish(doc);
+        svg = gpg.mergeSVGs("", layerName());
 	}
 
 	reloadImage(svg, QSizeF(0, 0), fileName, addName);
 }
 
-void LogoItem::resizeMM(double mmW, double mmH, const LayerHash & viewLayers) {
+bool LogoItem::resizeMM(double mmW, double mmH, const LayerHash & viewLayers) 
+{
 	Q_UNUSED(viewLayers);
 
 	if (mmW == 0 || mmH == 0) {
-		return;
+		return false;
 	}
 
-	DebugDialog::debug(QString("resize mm %1 %2").arg(mmW).arg(mmH));
+	// DebugDialog::debug(QString("resize mm %1 %2").arg(mmW).arg(mmH));
 
 	QRectF r = this->boundingRect();
-	if (qAbs(GraphicsUtils::pixels2mm(r.width(), FSvgRenderer::printerScale()) - mmW) < .001 &&
-		qAbs(GraphicsUtils::pixels2mm(r.height(), FSvgRenderer::printerScale()) - mmH) < .001) 
+	if (qAbs(GraphicsUtils::pixels2mm(r.width(), GraphicsUtils::SVGDPI) - mmW) < .001 &&
+		qAbs(GraphicsUtils::pixels2mm(r.height(), GraphicsUtils::SVGDPI) - mmH) < .001) 
 	{
-		return;
+		return false;
 	}
 
 	double inW = GraphicsUtils::mm2mils(mmW) / 1000;
@@ -435,7 +419,7 @@ void LogoItem::resizeMM(double mmW, double mmH, const LayerHash & viewLayers) {
 	// TODO: deal with aspect ratio
 
 	QString svg = prop("shape");
-	if (svg.isEmpty()) return;
+	if (svg.isEmpty()) return false;
 
 	QString errorStr;
 	int errorLine;
@@ -443,31 +427,33 @@ void LogoItem::resizeMM(double mmW, double mmH, const LayerHash & viewLayers) {
 
 	QDomDocument domDocument;
 	if (!domDocument.setContent(svg, &errorStr, &errorLine, &errorColumn)) {
-		return;
+		return false;
 	}
 
 	QDomElement root = domDocument.documentElement();
 	if (root.isNull()) {
-		return;
+		return false;
 	}
 
 	if (root.tagName() != "svg") {
-		return;
+		return false;
 	}
 
 	root.setAttribute("width", QString::number(inW) + "in");
 	root.setAttribute("height", QString::number(inH) + "in");
 
-	svg = TextUtils::removeXMLEntities(domDocument.toString());			
+	svg = TextUtils::removeXMLEntities(domDocument.toString());	
+    QString shape = getShapeForRenderer(svg);
 
-	bool result = loadExtraRenderer(svg.toUtf8(), false);
+	bool result = resetRenderer(shape);
 	if (result) {
-		modelPart()->setProp("shape", svg);
-		modelPart()->setProp("width", mmW);
-		modelPart()->setProp("height", mmH);
+		modelPart()->setLocalProp("shape", svg);
+		modelPart()->setLocalProp("width", mmW);
+		modelPart()->setLocalProp("height", mmH);
 	}
 
 	setWidthAndHeight(qRound(mmW * 10) / 10.0, qRound(mmH * 10) / 10.0);
+    return true;
 }
 
 void LogoItem::setProp(const QString & prop, const QString & value) {
@@ -482,12 +468,9 @@ void LogoItem::setProp(const QString & prop, const QString & value) {
 void LogoItem::setLogo(QString logo, bool force) {
 	if (!force && m_logo.compare(logo) == 0) return;
 
-	switch (this->m_viewIdentifier) {
-		case ViewIdentifierClass::PCBView:
-			break;
-		default:
-			return;
-	}
+    if (!isEverVisible()) {
+        return;
+    }
 
 	QString svg;
 	QFile f(m_originalFilename);
@@ -499,7 +482,7 @@ void LogoItem::setLogo(QString logo, bool force) {
 
 	QSizeF oldSize = m_size;
 	QXmlStreamReader streamReader(svg);
-	QSizeF oldSvgSize = m_extraRenderer ? m_extraRenderer->viewBoxF().size() : QSizeF(0, 0);
+	QSizeF oldSvgSize = fsvgRenderer() ? fsvgRenderer()->viewBoxF().size() : QSizeF(0, 0);
 	
 	DebugDialog::debug(QString("size %1 %2, %3 %4").arg(m_size.width()).arg(m_size.height()).arg(oldSvgSize.width()).arg(oldSvgSize.height()));
 
@@ -509,18 +492,18 @@ void LogoItem::setLogo(QString logo, bool force) {
 	bool ok = rerender(svg);
 
 	m_logo = logo;
-	modelPart()->setProp("logo", logo);
-	modelPart()->setProp("shape", svg);
+	modelPart()->setLocalProp("logo", logo);
+	modelPart()->setLocalProp("shape", svg);
 	if (ok && !force) {
-		QSizeF newSvgSize = m_extraRenderer->viewBoxF().size();
+		QSizeF newSvgSize = fsvgRenderer()->viewBoxF().size();
 		QSizeF newSize = newSvgSize * oldSize.height() / oldSvgSize.height();
 		DebugDialog::debug(QString("size %1 %2, %3 %4").arg(m_size.width()).arg(m_size.height()).arg(newSize.width()).arg(newSize.height()));
 		
 		// set the new text to approximately the same height as the original
 		// if the text is non-proportional that will be lost
 		LayerHash layerHash;
-		resizeMM(GraphicsUtils::pixels2mm(newSize.width(), FSvgRenderer::printerScale()),
-				 GraphicsUtils::pixels2mm(newSize.height(), FSvgRenderer::printerScale()),
+		resizeMM(GraphicsUtils::pixels2mm(newSize.width(), GraphicsUtils::SVGDPI),
+				 GraphicsUtils::pixels2mm(newSize.height(), GraphicsUtils::SVGDPI),
 				 layerHash);
 		//DebugDialog::debug(QString("size %1 %2").arg(m_size.width()).arg(m_size.height()));
 	}
@@ -528,9 +511,10 @@ void LogoItem::setLogo(QString logo, bool force) {
 
 bool LogoItem::rerender(const QString & svg)
 {
-	bool result = loadExtraRenderer(svg.toUtf8(), false);
+    QString newSvg;
+	bool result = resetRenderer(svg);
 	if (result) {
-		QRectF r = m_extraRenderer->viewBoxF();
+		QRectF r = fsvgRenderer()->viewBoxF();
 		m_aspectRatio.setWidth(r.width());
 		m_aspectRatio.setHeight(r.height());
 	}
@@ -613,10 +597,10 @@ QString LogoItem::hackSvg(const QString & svg, const QString & logo)
 			if (child.isText()) {
 				child.setNodeValue(logo);
 
-				modelPart()->setProp("width", logo.length() * 0.1 * 25.4);
+				modelPart()->setLocalProp("width", logo.length() * 0.1 * 25.4);
 				QString h = root.attribute("height");
 				bool ok;
-				modelPart()->setProp("height", TextUtils::convertToInches(h, &ok, false) * 25.4);
+				modelPart()->setLocalProp("height", TextUtils::convertToInches(h, &ok, false) * 25.4);
 				return doc.toString();
 			}
 		}
@@ -632,10 +616,10 @@ void LogoItem::widthEntry() {
 	if (edit == NULL) return;
 
 	double w = edit->text().toDouble();
-	double oldW = m_modelPart->prop("width").toDouble();
+	double oldW = m_modelPart->localProp("width").toDouble();
 	if (w == oldW) return;
 
-	double h = m_modelPart->prop("height").toDouble();
+	double h = m_modelPart->localProp("height").toDouble();
 	if (m_keepAspectRatio) {
 		h = w * m_aspectRatio.height() / m_aspectRatio.width();
 	}
@@ -653,7 +637,7 @@ void LogoItem::heightEntry() {
 	if (edit == NULL) return;
 
 	double h = edit->text().toDouble();
-	double oldH =  m_modelPart->prop("height").toDouble();
+	double oldH =  m_modelPart->localProp("height").toDouble();
 	if (h == oldH) return;
 
 	setHeight(h);
@@ -661,7 +645,7 @@ void LogoItem::heightEntry() {
 
 void LogoItem::setHeight(double h)
 {
-	double w = m_modelPart->prop("width").toDouble();
+	double w = m_modelPart->localProp("width").toDouble();
 	if (m_keepAspectRatio) {
 		w = h * m_aspectRatio.width() / m_aspectRatio.height();
 	}
@@ -672,54 +656,6 @@ void LogoItem::setHeight(double h)
 	}
 }
 
-void LogoItem::unableToLoad(const QString & fileName) {
-	QMessageBox::information(
-		NULL,
-		tr("Unable to load"),
-		tr("Unable to load image from %1").arg(fileName)
-	);
-}
-
-void LogoItem::keepAspectRatio(bool checkState) {
-	m_keepAspectRatio = checkState;
-}
-
-void LogoItem::fileNameEntry(const QString & filename) {
-	foreach (QString name, getImageNames()) {
-		if (filename.compare(name) == 0) {
-			QString f = FolderUtils::getApplicationSubFolderPath("parts") + "/svg/core/pcb/" + filename + ".svg";
-			return prepLoadImageAux(f, false);
-			break;
-		}
-	}
-
-	prepLoadImageAux(filename, true);
-}
-
-void LogoItem::setFileNameItems() {
-	if (m_fileNameComboBox == NULL) return;
-
-	m_fileNameComboBox->addItems(getImageNames());
-	m_fileNameComboBox->addItems(getNewImageNames());
-
-	int ix = 0;
-	foreach (QString name, getImageNames()) {
-		if (prop("lastfilename").contains(name)) {
-			m_fileNameComboBox->setCurrentIndex(ix);
-			return;
-		}
-		ix++;
-	}
-
-	foreach (QString name, getNewImageNames()) {
-		if (prop("lastfilename").contains(name)) {
-			m_fileNameComboBox->setCurrentIndex(ix);
-			return;
-		}
-		ix++;
-	}
-}
-
 bool LogoItem::stickyEnabled() {
 	return true;
 }
@@ -741,14 +677,6 @@ QString LogoItem::layerName()
 	return ViewLayer::viewLayerXmlNameFromID(layer());
 }
 
-QStringList & LogoItem::getImageNames() {
-	return ImageNames;
-}
-
-QStringList & LogoItem::getNewImageNames() {
-	return NewImageNames;
-}
-
 double LogoItem::minWidth() {
 	return ResizableBoard::CornerHandleSize * 2;
 }
@@ -785,7 +713,26 @@ void LogoItem::paintHover(QPainter *painter, const QStyleOptionGraphicsItem *opt
 
 ///////////////////////////////////////////////////////////////////////
 
-CopperLogoItem::CopperLogoItem( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+SchematicLogoItem::SchematicLogoItem( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+	: LogoItem(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
+{
+}
+
+SchematicLogoItem::~SchematicLogoItem() {
+}
+
+ViewLayer::ViewLayerID SchematicLogoItem::layer() {
+	return ViewLayer::Schematic;
+}
+
+QString SchematicLogoItem::colorString() {
+    return "black";
+}
+
+
+///////////////////////////////////////////////////////////////////////
+
+CopperLogoItem::CopperLogoItem( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
 	: LogoItem(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
 {
 	if (Copper1ImageNames.count() == 0) {
@@ -797,10 +744,10 @@ CopperLogoItem::CopperLogoItem( ModelPart * modelPart, ViewIdentifierClass::View
 	}
 
 	m_hasLogo = (modelPart->moduleID().endsWith(ModuleIDNames::LogoTextModuleIDName));
-	m_logo = modelPart->prop("logo").toString();
+	m_logo = modelPart->localProp("logo").toString();
 	if (m_hasLogo && m_logo.isEmpty()) {
 		m_logo = modelPart->properties().value("logo", "logo");
-		modelPart->setProp("logo", m_logo);
+		modelPart->setLocalProp("logo", m_logo);
 	}
 }
 
@@ -819,10 +766,6 @@ QStringList & CopperLogoItem::getImageNames() {
 	return isCopper0() ? Copper0ImageNames :  Copper1ImageNames;
 }
 
-QStringList & CopperLogoItem::getNewImageNames() {
-	return isCopper0() ? NewCopper0ImageNames :  NewCopper1ImageNames;
-}
-
 QString CopperLogoItem::hackSvg(const QString & svg, const QString & logo) {
 	QString newSvg = LogoItem::hackSvg(svg, logo);
 	if (!isCopper0()) return newSvg;
@@ -846,19 +789,190 @@ QString CopperLogoItem::flipSvg(const QString & svg)
 	return newSvg;
 }
 
-void CopperLogoItem::reloadImage(const QString & svg, const QSizeF & aspectRatio, const QString & fileName, bool addName) 
+bool CopperLogoItem::reloadImage(const QString & svg, const QSizeF & aspectRatio, const QString & fileName, bool addName) 
 {
 	if (isCopper0()) {
 		if (!svg.contains("_flipped_")) {
-			LogoItem::reloadImage(flipSvg(svg), aspectRatio, fileName, addName);
-			return;
+			return LogoItem::reloadImage(flipSvg(svg), aspectRatio, fileName, addName);
 		}
 	}
 
-	LogoItem::reloadImage(svg, aspectRatio, fileName, addName);
+	return LogoItem::reloadImage(svg, aspectRatio, fileName, addName);
 }
 
 bool CopperLogoItem::isCopper0() {
 	return modelPart()->properties().value("layer").contains("0");
 }
 
+////////////////////////////////////////////
+
+// todo:
+//
+// don't mess with colors at all?
+
+BoardLogoItem::BoardLogoItem(ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel) 
+    : LogoItem(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
+{
+    m_hasLogo = false;
+    m_svgOnly = true;
+    m_standardizeColors = false;
+	if (BoardImageNames.count() == 0) {
+		BoardImageNames << "circle_pcb";
+	}
+}
+
+BoardLogoItem::~BoardLogoItem() {
+}
+
+QString BoardLogoItem::getShapeForRenderer(const QString & svg) 
+{
+    return ResizableBoard::getShapeForRenderer(svg, m_viewLayerID);
+}
+
+ViewLayer::ViewLayerID BoardLogoItem::layer() {
+	return ViewLayer::Board;
+}
+
+QString BoardLogoItem::colorString() {
+	return ViewLayer::BoardColor;
+}
+
+QStringList & BoardLogoItem::getImageNames() {
+	return BoardImageNames;
+}
+
+QStringList & BoardLogoItem::getNewImageNames() {
+	return NewBoardImageNames;
+}
+
+bool BoardLogoItem::resizeMM(double mmW, double mmH, const LayerHash & viewLayers) 
+{
+	bool result = LogoItem::resizeMM(mmW, mmH, viewLayers);
+    if (!result) return result;
+
+    reloadLayerKin(mmW, mmH);
+    return result;
+}
+
+void BoardLogoItem::reloadLayerKin(double mmW, double mmH)
+{
+	foreach (ItemBase * itemBase, m_layerKin) {
+        if (itemBase->viewLayerID() == LogoItem::layer()) {
+		    QString svg = ResizableBoard::getShapeForRenderer(prop("shape"), LogoItem::layer());
+		    if (!svg.isEmpty()) {
+			    itemBase->prepareGeometryChange();
+			    if (itemBase->resetRenderer(svg)) {
+				    itemBase->modelPart()->setLocalProp("width", mmW);
+				    itemBase->modelPart()->setLocalProp("height", mmH);
+			    }
+			    break;
+		    }
+	    }
+    }
+}
+
+bool BoardLogoItem::canRetrieveLayer(ViewLayer::ViewLayerID viewLayerID) {
+    return LogoItem::canRetrieveLayer(viewLayerID) || viewLayerID == LogoItem::layer();
+}
+
+bool BoardLogoItem::reloadImage(const QString & svg, const QSizeF & aspectRatio, const QString & fileName, bool addName) 
+{
+    bool result;
+    if (!svg.contains(GerberGenerator::MagicBoardOutlineID, Qt::CaseInsensitive)) {
+        QString nsvg = setBoardOutline(svg);
+        result = LogoItem::reloadImage(nsvg, aspectRatio, fileName, addName);
+    }
+    else {
+        result = LogoItem::reloadImage(svg, aspectRatio, fileName, addName);
+    }
+    if (!result) return result;
+
+    reloadLayerKin(prop("width").toDouble(), prop("height").toDouble());
+    return result;
+}
+
+
+QString BoardLogoItem::setBoardOutline(const QString & svg) {
+    QString errorStr;
+	int errorLine;
+	int errorColumn;
+
+	QDomDocument domDocument;
+	if (!domDocument.setContent(svg, true, &errorStr, &errorLine, &errorColumn)) {
+		return svg;
+	}
+
+    QDomElement root = domDocument.documentElement();
+	if (root.tagName() != "svg") {
+		return svg;
+	}
+
+    QDomElement board = TextUtils::findElementWithAttribute(root, "id", "board");
+    if (board.isNull()) {
+        board = root;
+    }
+
+    QList<QDomElement> leaves;
+    TextUtils::collectLeaves(board, leaves);
+
+    if (leaves.count() == 1) {
+        QDomElement leaf = leaves.at(0);
+        leaf.setAttribute("id", GerberGenerator::MagicBoardOutlineID);
+        return TextUtils::removeXMLEntities(domDocument.toString());
+    }
+
+    int ix = 0;
+    QStringList ids;
+    foreach (QDomElement leaf, leaves) {
+        ids.append(leaf.attribute("id", ""));
+        leaf.setAttribute("id", QString("____%1____").arg(ix++));
+    }
+
+    QSvgRenderer renderer(domDocument.toByteArray());
+
+    ix = 0;
+    foreach (QDomElement leaf, leaves) {    
+        leaf.setAttribute("id", ids.at(ix++));
+    }
+
+    double maxArea = 0;
+    int maxIndex = -1;
+    for (int i = 0; i < leaves.count(); i++) {
+        QRectF r = renderer.boundsOnElement(QString("____%1____").arg(i));
+        if (r.width() * r.height() > maxArea) {
+            maxArea = r.width() * r.height();
+            maxIndex = i;
+        }
+    }
+
+    if (maxIndex >= 0) {
+        QDomElement leaf = leaves.at(maxIndex);
+        leaf.setAttribute("id", GerberGenerator::MagicBoardOutlineID);
+        return TextUtils::removeXMLEntities(domDocument.toString());
+    }
+
+    return svg;
+}
+
+bool BoardLogoItem::checkImage(const QString & filename) {
+    return ResizableBoard::checkImage(filename);
+}
+
+bool BoardLogoItem::collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget) 
+{
+	if (prop.compare("shape", Qt::CaseInsensitive) == 0) {
+        Board::collectExtraInfo(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget);
+		returnWidget = setUpDimEntry(true, true, false, returnWidget);  
+        returnWidget->setEnabled(swappingEnabled);
+
+        m_aspectRatioCheck->setEnabled(false);
+        m_aspectRatioCheck->setChecked(true);
+        m_aspectRatioCheck->setVisible(false);
+        m_aspectRatioLabel->setVisible(false);
+		returnProp = tr("shape");
+		return true;
+	}
+
+    return LogoItem::collectExtraInfo(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget);
+}
+
