@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5949 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-04-07 19:16:07 +0200 (Sat, 07 Apr 2012) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -42,13 +42,12 @@ class LogoItem : public ResizableBoard
 	Q_OBJECT
 
 public:
-	// after calling this constructor if you want to render the loaded svg (either from model or from file), MUST call <renderImage>
-	LogoItem(ModelPart *, ViewIdentifierClass::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
+	LogoItem(ModelPart *, ViewLayer::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
 	~LogoItem();
 
 	QString retrieveSvg(ViewLayer::ViewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi);
 	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget);
-	void resizeMM(double w, double h, const LayerHash & viewLayers);
+	bool resizeMM(double w, double h, const LayerHash & viewLayers);
 	QString getProperty(const QString & key);
 	void setLogo(QString logo, bool force);
 	const QString & logo();
@@ -56,7 +55,7 @@ public:
 	void setProp(const QString & prop, const QString & value);
 	bool hasPartLabel();
 	void loadImage(const QString & fileName, bool addName);
-	virtual void reloadImage(const QString & svg, const QSizeF & aspectRatio, const QString & fileName, bool addName);
+	virtual bool reloadImage(const QString & svg, const QSizeF & aspectRatio, const QString & fileName, bool addName);
 	bool stickyEnabled();
 	PluralType isPlural();
 	void addedToScene(bool temporary);
@@ -64,36 +63,34 @@ public:
 	void paintHover(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
 
 protected slots:
-	void prepLoadImage();
 	void logoEntry();
 	void widthEntry();
 	void heightEntry();
-	void keepAspectRatio(bool checkState);
-	void fileNameEntry(const QString & filename);
 
 protected:
 	virtual QString hackSvg(const QString & svg, const QString & logo);
 	void initImage();
-	void unableToLoad(const QString & fileName);
 	void prepLoadImageAux(const QString & fileName, bool addName);
-	void setFileNameItems();
 	virtual ViewLayer::ViewLayerID layer();
 	virtual QString colorString();
 	virtual QString layerName();
-	virtual QStringList & getImageNames();
-	virtual QStringList & getNewImageNames();
 	bool rerender(const QString & svg);
 	double minWidth();
 	double minHeight();
 	bool freeRotationAllowed(Qt::KeyboardModifiers modifiers);
 	ResizableBoard::Corner findCorner(QPointF p, Qt::KeyboardModifiers);
+    virtual QString getShapeForRenderer(const QString & svg);
+    virtual bool canRetrieveLayer(ViewLayer::ViewLayerID viewLayerID);
+    bool checkImage(const QString & filename);
+	QStringList & getImageNames();
+	QStringList & getNewImageNames();
 
 protected:
 	QString m_logo;
 	bool m_hasLogo;
 	QString m_originalFilename;
-	QComboBox * m_fileNameComboBox;
 	QTime m_inLogoEntry;
+    bool m_standardizeColors;
 };
 
 class CopperLogoItem : public LogoItem
@@ -101,20 +98,57 @@ class CopperLogoItem : public LogoItem
 Q_OBJECT
 	
 public:
-	// after calling this constructor if you want to render the loaded svg (either from model or from file), MUST call <renderImage>
-	CopperLogoItem(ModelPart *, ViewIdentifierClass::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
+	CopperLogoItem(ModelPart *, ViewLayer::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
 	~CopperLogoItem();
 
-	void reloadImage(const QString & svg, const QSizeF & aspectRatio, const QString & fileName, bool addName);
+	bool reloadImage(const QString & svg, const QSizeF & aspectRatio, const QString & fileName, bool addName);
+
+protected:
+	ViewLayer::ViewLayerID layer();
+	QString colorString();
+	QStringList & getImageNames();
+	QString hackSvg(const QString & svg, const QString & logo);
+	QString flipSvg(const QString & svg);
+	bool isCopper0();
+};
+
+class SchematicLogoItem : public LogoItem
+{
+Q_OBJECT
+	
+public:
+	SchematicLogoItem(ModelPart *, ViewLayer::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
+	~SchematicLogoItem();
+
+protected:
+	ViewLayer::ViewLayerID layer();
+	QString colorString();
+};
+
+class BoardLogoItem : public LogoItem
+{
+Q_OBJECT
+public:
+	BoardLogoItem(ModelPart *, ViewLayer::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
+	~BoardLogoItem();
+
+    bool resizeMM(double w, double h, const LayerHash & viewLayers);
+	bool reloadImage(const QString & svg, const QSizeF & aspectRatio, const QString & fileName, bool addName);
+	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget);
 
 protected:
 	ViewLayer::ViewLayerID layer();
 	QString colorString();
 	QStringList & getImageNames();
 	QStringList & getNewImageNames();
-	QString hackSvg(const QString & svg, const QString & logo);
-	QString flipSvg(const QString & svg);
-	bool isCopper0();
+    QString getShapeForRenderer(const QString & svg);
+    bool canRetrieveLayer(ViewLayer::ViewLayerID viewLayerID);
+    void reloadLayerKin(double mmW, double mmH);
+    QString setBoardOutline(const QString & svg);
+    bool checkImage(const QString & filename);
+
 };
 
+
+
 #endif
