@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5857 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-02-12 18:16:07 +0100 (Sun, 12 Feb 2012) $
+$Revision: 6505 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-03 10:14:52 +0200 (Wed, 03 Oct 2012) $
 
 ********************************************************************/
 
@@ -33,15 +33,18 @@ $Date: 2012-02-12 18:16:07 +0100 (Sun, 12 Feb 2012) $
 const QString ModuleIDNames::ModuleIDNameSuffix = "ModuleID";
 const QString ModuleIDNames::RulerModuleIDName = "RulerModuleID";
 const QString ModuleIDNames::BreadboardModuleIDName = "BreadboardModuleID";
-const QString ModuleIDNames::TinyBreadboardModuleIDName = "TinyBreadboardModuleID";
-const QString ModuleIDNames::RectangleModuleIDName = "RectanglePCBModuleID";
-const QString ModuleIDNames::TwoSidedRectangleModuleIDName = "TwoLayerRectanglePCBModuleID";
+const QString ModuleIDNames::FullPlusBreadboardModuleIDName = "Breadboard-RSR03MB102-ModuleID";
+const QString ModuleIDNames::RectanglePCBModuleIDName = "RectanglePCBModuleID";
+const QString ModuleIDNames::TwoSidedRectanglePCBModuleIDName = "TwoLayerRectanglePCBModuleID";
+const QString ModuleIDNames::EllipsePCBModuleIDName = "EllipsePCBModuleID";
+const QString ModuleIDNames::TwoSidedEllipsePCBModuleIDName = "TwoLayerEllipsePCBModuleID";
 const QString ModuleIDNames::NoteModuleIDName = "NoteModuleID";
 const QString ModuleIDNames::WireModuleIDName = "WireModuleID";
 const QString ModuleIDNames::JumperModuleIDName = "JumperModuleID";
 const QString ModuleIDNames::GroundPlaneModuleIDName = "GroundPlaneModuleID";
 const QString ModuleIDNames::GroundModuleIDName = "GroundModuleID";
 const QString ModuleIDNames::PowerModuleIDName = "PowerModuleID";
+const QString ModuleIDNames::NetLabelModuleIDName = "NetLabelModuleID";
 const QString ModuleIDNames::JustPowerModuleIDName = "JustPowerModuleID";
 const QString ModuleIDNames::ResistorModuleIDName = "ResistorModuleID";
 const QString ModuleIDNames::LogoTextModuleIDName = "LogoTextModuleID";
@@ -50,9 +53,14 @@ const QString ModuleIDNames::Copper1LogoTextModuleIDName = "Copper1LogoTextModul
 const QString ModuleIDNames::Copper1LogoImageModuleIDName = "Copper1LogoImageModuleID";
 const QString ModuleIDNames::Copper0LogoTextModuleIDName = "Copper0LogoTextModuleID";
 const QString ModuleIDNames::Copper0LogoImageModuleIDName = "Copper0LogoImageModuleID";
+const QString ModuleIDNames::SchematicLogoTextModuleIDName = "SchematicLogoTextModuleID";
+const QString ModuleIDNames::SchematicLogoImageModuleIDName = "SchematicLogoImageModuleID";
+const QString ModuleIDNames::BoardLogoImageModuleIDName = "BoardLogoImageModuleID";
+const QString ModuleIDNames::OneLayerBoardLogoImageModuleIDName = "OneLayerBoardLogoImageModuleID";
 const QString ModuleIDNames::HoleModuleIDName = "HoleModuleID";
 const QString ModuleIDNames::ViaModuleIDName = "ViaModuleID";
 const QString ModuleIDNames::PadModuleIDName = "PadModuleID";
+const QString ModuleIDNames::Copper0PadModuleIDName = "Copper0PadModuleID";
 const QString ModuleIDNames::CapacitorModuleIDName = "CapacitorModuleID";
 const QString ModuleIDNames::CrystalModuleIDName = "CrystalModuleID";
 const QString ModuleIDNames::ZenerDiodeModuleIDName = "ZenerDiodeModuleID";
@@ -66,4 +74,7 @@ const QString ModuleIDNames::PerfboardModuleIDName = "PerfboardModuleID";
 const QString ModuleIDNames::StripboardModuleIDName = "StripboardModuleID";
 const QString ModuleIDNames::SpacerModuleIDName = "__spacer__";
 const QString ModuleIDNames::SchematicFrameModuleIDName = "SchematicFrameModuleID";
+const QString ModuleIDNames::CopperBlockerModuleIDName = "BlockerModuleID";
+const QString ModuleIDNames::Copper0BlockerModuleIDName = "Copper0BlockerModuleID";
+const QString ModuleIDNames::Copper1BlockerModuleIDName = "Copper1BlockerModuleID";
 
