@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5857 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-02-12 18:16:07 +0100 (Sun, 12 Feb 2012) $
+$Revision: 6505 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-03 10:14:52 +0200 (Wed, 03 Oct 2012) $
 
 ********************************************************************/
 
@@ -35,15 +35,18 @@ public:
 	static const QString ModuleIDNameSuffix;
 	static const QString RulerModuleIDName;
 	static const QString BreadboardModuleIDName;
-	static const QString TinyBreadboardModuleIDName;
-	static const QString RectangleModuleIDName;
-	static const QString TwoSidedRectangleModuleIDName;
+	static const QString FullPlusBreadboardModuleIDName;
+	static const QString RectanglePCBModuleIDName;
+	static const QString TwoSidedRectanglePCBModuleIDName;
+	static const QString EllipsePCBModuleIDName;
+	static const QString TwoSidedEllipsePCBModuleIDName;
 	static const QString NoteModuleIDName;
 	static const QString WireModuleIDName;
 	static const QString JumperModuleIDName;
 	static const QString GroundPlaneModuleIDName;
 	static const QString GroundModuleIDName;
 	static const QString PowerModuleIDName;
+	static const QString NetLabelModuleIDName;
 	static const QString JustPowerModuleIDName;
 	static const QString ResistorModuleIDName;
 	static const QString LogoTextModuleIDName;
@@ -52,9 +55,14 @@ public:
 	static const QString Copper0LogoImageModuleIDName;
 	static const QString Copper1LogoTextModuleIDName;
 	static const QString Copper1LogoImageModuleIDName;
+	static const QString SchematicLogoTextModuleIDName;
+	static const QString SchematicLogoImageModuleIDName;
+	static const QString BoardLogoImageModuleIDName;
+	static const QString OneLayerBoardLogoImageModuleIDName;
 	static const QString HoleModuleIDName;
 	static const QString ViaModuleIDName;
 	static const QString PadModuleIDName;
+	static const QString Copper0PadModuleIDName;
 	static const QString CapacitorModuleIDName;
 	static const QString CrystalModuleIDName;
 	static const QString ZenerDiodeModuleIDName;
@@ -68,6 +76,9 @@ public:
 	static const QString StripboardModuleIDName;
 	static const QString SpacerModuleIDName;
 	static const QString SchematicFrameModuleIDName;
+    static const QString CopperBlockerModuleIDName;
+    static const QString Copper1BlockerModuleIDName;
+    static const QString Copper0BlockerModuleIDName;
 };
 
 #endif
