@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,20 +18,22 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5857 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-02-12 18:16:07 +0100 (Sun, 12 Feb 2012) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
 #include "mysterypart.h"
 #include "../utils/graphicsutils.h"
+#include "../utils/familypropertycombobox.h"
 #include "../fsvgrenderer.h"
 #include "../sketch/infographicsview.h"
 #include "../commands.h"
 #include "../utils/textutils.h"
 #include "../layerattributes.h"
 #include "partlabel.h"
+#include "pinheader.h"
 #include "../connectors/connectoritem.h"
 
 
@@ -49,24 +51,22 @@ static const int MaxSipPins = 64;
 static const int MinDipPins = 4;
 static const int MaxDipPins = 64;
 
+static HoleClassThing TheHoleThing;
 
 // TODO
 //	save into parts bin
 
-MysteryPart::MysteryPart( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+MysteryPart::MysteryPart( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
 	: PaletteItem(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
 {
-	m_changingSpacing = false;
-	m_chipLabel = modelPart->prop("chip label").toString();
+	m_chipLabel = modelPart->localProp("chip label").toString();
 	if (m_chipLabel.isEmpty()) {
 		m_chipLabel = modelPart->properties().value("chip label", "?");
-		modelPart->setProp("chip label", m_chipLabel);
-	}
-	m_spacing = modelPart->prop("spacing").toString();
-	if (m_spacing.isEmpty()) {
-		m_spacing = modelPart->properties().value("spacing", "300mil");
-		modelPart->setProp("spacing", m_spacing);
+		modelPart->setLocalProp("chip label", m_chipLabel);
 	}
+
+    setUpHoleSizes("mystery", TheHoleThing);
+
 }
 
 MysteryPart::~MysteryPart() {
@@ -78,63 +78,9 @@ void MysteryPart::setProp(const QString & prop, const QString & value) {
 		return;
 	}
 
-	if (prop.compare("spacing", Qt::CaseInsensitive) == 0) {
-		setSpacing(value, false);
-		return;
-	}
-
 	PaletteItem::setProp(prop, value);
 }
 
-void MysteryPart::setSpacing(QString spacing, bool force) {
-	if (!force && m_spacing.compare(spacing) == 0) return;
-	if (!isDIP()) return;
-
-	switch (this->m_viewIdentifier) {
-		case ViewIdentifierClass::BreadboardView:
-		case ViewIdentifierClass::PCBView:
-			{
-				InfoGraphicsView * infoGraphicsView = InfoGraphicsView::getInfoGraphicsView(this);
-				if (infoGraphicsView == NULL) break;
-
-				// hack the dom element and call setUpImage
-				FSvgRenderer::removeFromHash(moduleID(), "");
-				QDomElement element = LayerAttributes::getSvgElementLayers(modelPart()->domDocument(), m_viewIdentifier);
-				if (element.isNull()) break;
-
-				QString filename = element.attribute("image");
-				if (filename.isEmpty()) break;
-
-				if (spacing.indexOf(Digits) < 0) break;
-
-				QString newSpacing = Digits.cap(0);		
-				filename.replace(DigitsMil, newSpacing + "mil");
-				element.setAttribute("image", filename);
-
-				m_changingSpacing = true;
-				resetImage(infoGraphicsView);
-				m_changingSpacing = false;
-
-				if (m_viewIdentifier == ViewIdentifierClass::BreadboardView) {
-					if (modelPart()->properties().value("chip label", "").compare(m_chipLabel) != 0) {
-						setChipLabel(m_chipLabel, true);
-					}
-				}
-
-				updateConnections();
-			}
-			break;
-		default:
-			break;
-	}
-
-	m_spacing = spacing;
-	modelPart()->setProp("spacing", spacing);
-
-    if (m_partLabel) m_partLabel->displayTextsIf();
-
-}
-
 void MysteryPart::setChipLabel(QString chipLabel, bool force) {
 
 	if (!force && m_chipLabel.compare(chipLabel) == 0) return;
@@ -143,10 +89,10 @@ void MysteryPart::setChipLabel(QString chipLabel, bool force) {
 
 	QString svg;
 	switch (this->m_viewIdentifier) {
-		case ViewIdentifierClass::BreadboardView:
+		case ViewLayer::BreadboardView:
 			svg = makeSvg(chipLabel, true);
 			break;
-		case ViewIdentifierClass::SchematicView:
+		case ViewLayer::SchematicView:
 			svg = makeSvg(chipLabel, false);
 			svg = retrieveSchematicSvg(svg);
 			break;
@@ -154,9 +100,11 @@ void MysteryPart::setChipLabel(QString chipLabel, bool force) {
 			break;
 	}
 
-	loadExtraRenderer(svg, false);
+    if (!svg.isEmpty()) {
+	    resetRenderer(svg);
+    }
 
-	modelPart()->setProp("chip label", chipLabel);
+	modelPart()->setLocalProp("chip label", chipLabel);
 
     if (m_partLabel) m_partLabel->displayTextsIf();
 
@@ -210,18 +158,28 @@ QString MysteryPart::makeSvg(const QString & chipLabel, bool replace) {
 }
 
 QStringList MysteryPart::collectValues(const QString & family, const QString & prop, QString & value) {
-	if (prop.compare("spacing", Qt::CaseInsensitive) == 0) {
+	if (prop.compare("layout", Qt::CaseInsensitive) == 0) {
+        // TODO: translate these
+        QStringList values;
+        values << "Single Row" << "Double Row";
+        value = values.at(moduleID().contains("sip", Qt::CaseInsensitive) ? 0 : 1);
+        return values;
+    }
+
+	if (prop.compare("pin spacing", Qt::CaseInsensitive) == 0) {
 		QStringList values;
+        QString spacing;
+        TextUtils::getPinsAndSpacing(moduleID(), spacing);
 		if (isDIP()) {
 			foreach (QString f, spacings()) {
 				values.append(f);
 			}
 		}
 		else {
-			values.append(m_spacing);
+			values.append(spacing);
 		}
 
-		value = m_spacing;
+		value = spacing;
 		return values;
 	}
 
@@ -265,6 +223,10 @@ bool MysteryPart::collectExtraInfo(QWidget * parent, const QString & family, con
 		return true;
 	}
 
+    if (prop.compare("hole size", Qt::CaseInsensitive) == 0) {
+        return collectHoleSizeInfo(TheHoleThing.holeSizeValue, parent, swappingEnabled, returnProp, returnValue, returnWidget);
+	}
+
 	return PaletteItem::collectExtraInfo(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget);
 }
 
@@ -273,10 +235,6 @@ QString MysteryPart::getProperty(const QString & key) {
 		return m_chipLabel;
 	}
 
-	if (key.compare("spacing", Qt::CaseInsensitive) == 0) {
-		return m_spacing;
-	}
-
 	return PaletteItem::getProperty(key);
 }
 
@@ -288,7 +246,6 @@ void MysteryPart::addedToScene(bool temporary)
 {
 	if (this->scene()) {
 		setChipLabel(m_chipLabel, true);
-		setSpacing(m_spacing, true);
 	}
 
     PaletteItem::addedToScene(temporary);
@@ -300,10 +257,10 @@ const QString & MysteryPart::title() {
 
 bool MysteryPart::hasCustomSVG() {
 	switch (m_viewIdentifier) {
-		case ViewIdentifierClass::BreadboardView:
-		case ViewIdentifierClass::SchematicView:
-		case ViewIdentifierClass::IconView:
-		case ViewIdentifierClass::PCBView:
+		case ViewLayer::BreadboardView:
+		case ViewLayer::SchematicView:
+		case ViewLayer::IconView:
+		case ViewLayer::PCBView:
 			return true;
 		default:
 			return ItemBase::hasCustomSVG();
@@ -322,36 +279,6 @@ void MysteryPart::chipLabelEntry() {
 	}
 }
 
-ConnectorItem* MysteryPart::newConnectorItem(Connector *connector) {
-	if (m_changingSpacing) {
-		return connector->connectorItemByViewLayerID(viewIdentifier(), viewLayerID());
-	}
-
-	return PaletteItem::newConnectorItem(connector);
-}
-
-ConnectorItem* MysteryPart::newConnectorItem(ItemBase * layerKin, Connector *connector) {
-	if (m_changingSpacing) {
-		return connector->connectorItemByViewLayerID(viewIdentifier(), layerKin->viewLayerID());
-	}
-
-	return PaletteItem::newConnectorItem(layerKin, connector);
-}
-
-const QString & MysteryPart::spacing() {
-	return m_spacing;
-}
-
-bool MysteryPart::onlySpacingChanges(QMap<QString, QString> & propsMap) {
-	if (propsMap.value("spacing", "").compare(m_spacing) == 0) return false;
-
-	if (modelPart()->properties().value("pins", "").compare(propsMap.value("pins", "")) != 0) return false;
-
-	if (otherPropsChange(propsMap)) return false;
-
-	return true;
-}
-
 bool MysteryPart::isDIP() {
 	QString layout = modelPart()->properties().value("layout", "");
 	return (layout.indexOf("double", 0, Qt::CaseInsensitive) >= 0);
@@ -375,26 +302,47 @@ ItemBase::PluralType MysteryPart::isPlural() {
 
 QString MysteryPart::genSipFZP(const QString & moduleid)
 {
-	return PaletteItem::genFZP(moduleid, "mystery_part_sipFzpTemplate", MinSipPins, MaxSipPins, 1, false);
+    return genxFZP(moduleid, "mystery_part_sipFzpTemplate", MinSipPins, MaxSipPins, 1);
 }
 
 QString MysteryPart::genDipFZP(const QString & moduleid)
 {
-	return PaletteItem::genFZP(moduleid, "mystery_part_dipFzpTemplate", MinDipPins, MaxDipPins, 2, false);
+    return genxFZP(moduleid, "mystery_part_dipFzpTemplate", MinDipPins, MaxDipPins, 2);
+
+}
+
+QString MysteryPart::genxFZP(const QString & moduleid, const QString & templateName, int minPins, int maxPins, int step) {
+    QString spacingString;
+    TextUtils::getPinsAndSpacing(moduleid, spacingString);
+    QString result = PaletteItem::genFZP(moduleid, templateName, minPins, maxPins, step, false);
+   	result.replace(".percent.", "%");
+	result = result.arg(spacingString);
+	return hackFzpHoleSize(result, moduleid);
+}
+
+QString MysteryPart::hackFzpHoleSize(const QString & fzp, const QString & moduleid) {
+    int hsix = moduleid.lastIndexOf(HoleSizePrefix);
+    if (hsix >= 0) {
+        return PaletteItem::hackFzpHoleSize(fzp, moduleid, hsix);
+    }
+
+    return fzp;
 }
 
 QString MysteryPart::genModuleID(QMap<QString, QString> & currPropsMap)
 {
 	QString value = currPropsMap.value("layout");
+    bool single = value.contains("single", Qt::CaseInsensitive);
 	QString pins = currPropsMap.value("pins");
-	if (value.contains("single", Qt::CaseInsensitive)) {
-		return QString("mystery_part_%1").arg(pins);
+    QString spacing = currPropsMap.value("pin spacing", "300mil");
+	if (single) {
+		return QString("mystery_part_sip_%1_100mil").arg(pins);
 	}
 	else {
 		int p = pins.toInt();
 		if (p < 4) p = 4;
 		if (p % 2 == 1) p--;
-		return QString("mystery_part_%1_dip_300mil").arg(p);
+		return QString("mystery_part_dip_%1_%2").arg(p).arg(spacing);
 	}
 }
 
@@ -403,12 +351,6 @@ QString MysteryPart::makeSchematicSvg(const QString & expectedFileName)
 	bool sip = expectedFileName.contains("sip", Qt::CaseInsensitive);
 
 	QStringList pieces = expectedFileName.split("_");
-	if (sip) {
-		if (pieces.count() != 5) return "";
-	}
-	else {
-		if (pieces.count() != 4) return "";
-	}
 
 	int pins = pieces.at(2).toInt();
 	QStringList labels;
@@ -510,12 +452,9 @@ QString MysteryPart::makeBreadboardSvg(const QString & expectedFileName)
 
 QString MysteryPart::makeBreadboardDipSvg(const QString & expectedFileName) 
 {
-	QStringList pieces = expectedFileName.split("_");
-	if (pieces.count() != 6) return "";
-
-	int pins = pieces.at(2).toInt();
-	double spacing = TextUtils::convertToInches(pieces.at(4)) * 100;
-
+    QString spacingString;
+    int pins = TextUtils::getPinsAndSpacing(expectedFileName, spacingString);
+	double spacing = TextUtils::convertToInches(spacingString) * 100;
 
 	int increment = 10;
 
@@ -605,14 +544,95 @@ QString MysteryPart::makeBreadboardSipSvg(const QString & expectedFileName)
 bool MysteryPart::changePinLabels(bool singleRow, bool sip) {
 	Q_UNUSED(singleRow);
 
-	if (m_viewIdentifier != ViewIdentifierClass::SchematicView) return true;
+	if (m_viewIdentifier != ViewLayer::SchematicView) return true;
 
 	bool hasLocal = false;
 	QStringList labels = getPinLabels(hasLocal);
 	if (labels.count() == 0) return true;
 
 	QString svg = MysteryPart::makeSchematicSvg(labels, sip);
-	loadExtraRenderer(svg, false);
+	resetRenderer(svg);
 
 	return true;
-}
\ No newline at end of file
+}
+
+void MysteryPart::swapEntry(const QString & text) {
+
+    FamilyPropertyComboBox * comboBox = qobject_cast<FamilyPropertyComboBox *>(sender());
+    if (comboBox == NULL) return;
+
+    QString layout = m_propsMap.value("layout");
+
+    if (comboBox->prop().contains("layout", Qt::CaseInsensitive)) {
+        layout = text;
+    }
+
+    if (layout.isEmpty()) {
+        if (moduleID().contains("sip", Qt::CaseInsensitive)) {
+            layout = "single";
+        }
+    }
+
+    if (layout.contains("single", Qt::CaseInsensitive)) {
+        generateSwap(text, genModuleID, genSipFZP, makeBreadboardSvg, makeSchematicSvg, PinHeader::makePcbSvg);
+    }
+    else {
+        generateSwap(text, genModuleID, genDipFZP, makeBreadboardSvg, makeSchematicSvg, makePcbDipSvg);
+    }
+    PaletteItem::swapEntry(text);
+}
+
+QString MysteryPart::makePcbDipSvg(const QString & expectedFileName) 
+{
+    QString spacingString;
+	int pins = TextUtils::getPinsAndSpacing(expectedFileName, spacingString);
+    if (pins == 0) return "";  
+
+	QString header("<?xml version='1.0' encoding='UTF-8'?>\n"
+				    "<svg baseProfile='tiny' version='1.2' width='%1in' height='%2in' viewBox='0 0 %3 %4' xmlns='http://www.w3.org/2000/svg'>\n"
+				    "<desc>Fritzing footprint SVG</desc>\n"
+					"<g id='silkscreen'>\n"
+					"<line stroke='white' stroke-width='10' x1='10' x2='10' y1='10' y2='%5'/>\n"
+					"<line stroke='white' stroke-width='10' x1='10' x2='%6' y1='%5' y2='%5'/>\n"
+					"<line stroke='white' stroke-width='10' x1='%6' x2='%6' y1='%5' y2='10'/>\n"
+					"<line stroke='white' stroke-width='10' x1='10' x2='%7' y1='10' y2='10'/>\n"
+					"<line stroke='white' stroke-width='10' x1='%8' x2='%6' y1='10' y2='10'/>\n"
+					"</g>\n"
+					"<g id='copper1'><g id='copper0'>\n"
+					"<rect id='square' fill='none' height='55' stroke='rgb(255, 191, 0)' stroke-width='20' width='55' x='32.5' y='32.5'/>\n");
+
+	double outerBorder = 10;
+	double silkSplitTop = 100;
+	double offsetX = 60;
+	double offsetY = 60;
+	double spacing = TextUtils::convertToInches(spacingString) * GraphicsUtils::StandardFritzingDPI; 
+	double totalWidth = 120 + spacing;
+	double totalHeight = (100 * pins / 2) + (outerBorder * 2);
+	double center = totalWidth / 2;
+
+	QString svg = header.arg(totalWidth / GraphicsUtils::StandardFritzingDPI).arg(totalHeight / GraphicsUtils::StandardFritzingDPI).arg(totalWidth).arg(totalHeight)
+							.arg(totalHeight - outerBorder).arg(totalWidth - outerBorder)
+							.arg(center - (silkSplitTop / 2)).arg(center + (silkSplitTop / 2));
+
+	QString circle("<circle cx='%1' cy='%2' fill='none' id='connector%3pin' r='27.5' stroke='rgb(255, 191, 0)' stroke-width='20'/>\n");
+
+	int y = offsetY;
+	for (int i = 0; i < pins / 2; i++) {
+		svg += circle.arg(offsetX).arg(y).arg(i);
+		svg += circle.arg(totalWidth - offsetX).arg(y).arg(pins - 1 - i);
+		y += 100;
+	}
+
+	svg += "</g></g>\n";
+	svg += "</svg>\n";
+
+    int hsix = expectedFileName.indexOf(HoleSizePrefix);
+    if (hsix >= 0) {
+        return hackSvgHoleSizeAux(svg, expectedFileName);
+    }
+
+	return svg;
+}
+
+void MysteryPart::makeLocalModifications(QByteArray &, const QString &) {
+}
