@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5760 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-01-18 10:54:44 +0100 (Wed, 18 Jan 2012) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -40,7 +40,7 @@ class MysteryPart : public PaletteItem
 
 public:
 	// after calling this constructor if you want to render the loaded svg (either from model or from file), MUST call <renderImage>
-	MysteryPart(ModelPart *, ViewIdentifierClass::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
+	MysteryPart(ModelPart *, ViewLayer::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
 	~MysteryPart();
 
 	QString retrieveSvg(ViewLayer::ViewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi);
@@ -51,15 +51,13 @@ public:
 	QString chipLabel();
 	const QString & title();
 	bool hasCustomSVG();
-	void setSpacing(QString spacing, bool force);
-	const QString & spacing();
-	bool onlySpacingChanges(QMap<QString, QString> & propsMap);
 	PluralType isPlural();
 	void addedToScene(bool temporary);
 	bool changePinLabels(bool singleRow, bool sip);
 
 public slots:
 	void chipLabelEntry();
+	void swapEntry(const QString & text);
 
 public:
 	static QString genSipFZP(const QString & moduleid);
@@ -70,24 +68,27 @@ public:
 	static QString makeBreadboardSvg(const QString & expectedFileName);
 	static QString makeBreadboardSipSvg(const QString & expectedFileName);
 	static QString makeBreadboardDipSvg(const QString & expectedFileName);
+	static QString makePcbDipSvg(const QString & expectedFileName);
 
 protected:
 	QString makeSvg(const QString & chipLabel, bool replace);
-	ConnectorItem* newConnectorItem(class Connector *connector);
-	ConnectorItem* newConnectorItem(ItemBase * layerkin, Connector *connector);
 	QStringList collectValues(const QString & family, const QString & prop, QString & value);
 	virtual bool isDIP();
 	virtual bool otherPropsChange(const QMap<QString, QString> & propsMap);
 	virtual const QStringList & spacings();
 	virtual QString retrieveSchematicSvg(QString & svg);
+    void makeLocalModifications(QByteArray & svg, const QString & filename);
 
+protected:
+    static QString hackFzpHoleSize(const QString & fzp, const QString & moduleid); 
+    static QString genxFZP(const QString & moduleid, const QString & templateName, int minPins, int maxPins, int step);
+
+protected:
 	static int NoExcusePins;
 
 protected:
 	QString m_chipLabel;
 	QString m_title;
-	bool m_changingSpacing;
-	QString m_spacing;
 };
 
 #endif
