@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5855 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-02-11 10:23:15 +0100 (Sat, 11 Feb 2012) $
+$Revision: 6508 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-03 19:10:05 +0200 (Wed, 03 Oct 2012) $
 
 ********************************************************************/
 
@@ -209,7 +209,7 @@ QString LinkDialog::url() {
 
 /////////////////////////////////////////////
 
-Note::Note( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu* itemMenu)
+Note::Note( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu* itemMenu)
 	: ItemBase(modelPart, viewIdentifier, viewGeometry, id, itemMenu)
 {
 	m_charsAdded = 0;
@@ -461,6 +461,8 @@ void Note::forceFormat(int position, int charsAdded) {
 }
 
 void Note::contentsChangedSlot() {
+
+    //DebugDialog::debug(QString("contents changed ") + m_graphicsTextItem->document()->toPlainText());
 	if (m_charsAdded > 0) {
 		forceFormat(m_charsPosition, m_charsAdded);
 	}
@@ -743,28 +745,28 @@ QString Note::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QSt
 
 	switch (viewLayerID) {
 		case ViewLayer::BreadboardNote:
-			if (viewIdentifier() != ViewIdentifierClass::BreadboardView) return ___emptyString___;
+			if (viewIdentifier() != ViewLayer::BreadboardView) return "";
 			break;
 		case ViewLayer::PcbNote:
-			if (viewIdentifier() != ViewIdentifierClass::PCBView) return ___emptyString___;
+			if (viewIdentifier() != ViewLayer::PCBView) return "";
 			break;
 		case ViewLayer::SchematicNote:
-			if (viewIdentifier() != ViewIdentifierClass::SchematicView) return ___emptyString___;
+			if (viewIdentifier() != ViewLayer::SchematicView) return "";
 			break;
 		default:
-			return ___emptyString___;
+			return "";
 	}
 
 	QString svg = "<g>";
 
 	QString penColor = blackOnly ? "#000000" : m_pen.color().name();
-	double penWidth = m_pen.widthF() * dpi / FSvgRenderer::printerScale();
+	double penWidth = m_pen.widthF() * dpi / GraphicsUtils::SVGDPI;
 	QString brushColor = blackOnly ? "none" : m_brush.color().name();
 	svg += QString("<rect x='%1' y='%2' width='%3' height='%4' fill='%5' stroke='%6' stroke-width='%7' />")
 		.arg(penWidth / 2)
 		.arg(penWidth / 2)
-		.arg((m_rect.width() * dpi / FSvgRenderer::printerScale()) - penWidth)
-		.arg((m_rect.height() * dpi / FSvgRenderer::printerScale()) - penWidth)
+		.arg((m_rect.width() * dpi / GraphicsUtils::SVGDPI) - penWidth)
+		.arg((m_rect.height() * dpi / GraphicsUtils::SVGDPI) - penWidth)
 		.arg(brushColor)
 		.arg(penColor)
 		.arg(penWidth)
@@ -787,10 +789,10 @@ QString Note::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QSt
 			QString soFar;
 
 			svg += QString("<text  x='%1' y='%2' font-family='%3' stroke='none' fill='#000000' text-anchor='left' font-size='%4' >\n")
-				.arg((left + r.left()) * dpi / FSvgRenderer::printerScale())
-				.arg((top + r.top() + line.ascent()) * dpi / FSvgRenderer::printerScale())
+				.arg((left + r.left()) * dpi / GraphicsUtils::SVGDPI)
+				.arg((top + r.top() + line.ascent()) * dpi / GraphicsUtils::SVGDPI)
 				.arg("Droid Sans")
-				.arg(line.ascent() * dpi / FSvgRenderer::printerScale()) 
+				.arg(line.ascent() * dpi / GraphicsUtils::SVGDPI) 
 				;
 
 
@@ -831,3 +833,8 @@ QString Note::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QSt
 
 	return svg;	
 }
+
+ViewLayer::ViewIdentifier Note::useViewIdentifierForPixmap(ViewLayer::ViewIdentifier, bool) 
+{
+    return ViewLayer::IconView;
+}
