@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5857 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-02-12 18:16:07 +0100 (Sun, 12 Feb 2012) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -45,7 +45,7 @@ class Note : public ItemBase
 Q_OBJECT
 
 public:
-	Note(class ModelPart*, ViewIdentifierClass::ViewIdentifier, const ViewGeometry &, long id, QMenu * itemMenu);
+	Note(class ModelPart*, ViewLayer::ViewIdentifier, const ViewGeometry &, long id, QMenu * itemMenu);
 	
 	void saveGeometry();
 	bool itemMoved();
@@ -77,6 +77,7 @@ protected:
 	void disconnectSlots();
 	void forceFormat(int position, int charsAdded);
 	QString retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi);
+    ViewLayer::ViewIdentifier useViewIdentifierForPixmap(ViewLayer::ViewIdentifier, bool swappingEnabled);
 
 protected slots:
 	void contentsChangeSlot(int position, int charsAdded, int charsRemoved);
