@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5952 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-08 00:47:10 +0200 (Sun, 08 Apr 2012) $
+$Revision: 6505 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-03 10:14:52 +0200 (Wed, 03 Oct 2012) $
 
 ********************************************************************/
 
@@ -55,7 +55,7 @@ static QPointF RotationAxis;
 static QTransform OriginalTransform;
 
 
-PaletteItemBase::PaletteItemBase(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu ) :
+PaletteItemBase::PaletteItemBase(ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu ) :
 	ItemBase(modelPart, viewIdentifier, viewGeometry, id, itemMenu)
 {
 	m_inRotation = m_syncSelected = false;
@@ -68,11 +68,11 @@ PaletteItemBase::PaletteItemBase(ModelPart * modelPart, ViewIdentifierClass::Vie
 	setAcceptHoverEvents(true);
 
 	if (hasPartNumberProperty()) {
-		QString savedValue = modelPart->prop(ModelPartShared::PartNumberPropertyName).toString();
+		QString savedValue = modelPart->localProp(ModelPartShared::PartNumberPropertyName).toString();
 		if (savedValue.isEmpty()) {
 			savedValue = modelPart->properties().value(ModelPartShared::PartNumberPropertyName, "");
 			if (!savedValue.isEmpty()) {
-				modelPart->setProp(ModelPartShared::PartNumberPropertyName, savedValue);
+				modelPart->setLocalProp(ModelPartShared::PartNumberPropertyName, savedValue);
 			}
 		}
 	}
@@ -217,7 +217,7 @@ void PaletteItemBase::mousePressConnectorEvent(ConnectorItem * connectorItem, QG
 bool PaletteItemBase::acceptsMousePressConnectorEvent(ConnectorItem *, QGraphicsSceneMouseEvent * event) {
 	Q_UNUSED(event);
 	
-	//if (m_viewIdentifier != ViewIdentifierClass::PCBView) {
+	//if (m_viewIdentifier != ViewLayer::PCBView) {
 		return true;
 	//}
 }
@@ -275,8 +275,8 @@ void PaletteItemBase::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 	double deltaAngle = (a2 - a1) * 180 / M_PI;
 	//DebugDialog::debug(QString("original:%1 delta:%2").arg(originalAngle).arg(deltaAngle));
 	switch (m_viewIdentifier) {
-		case ViewIdentifierClass::BreadboardView:
-		case ViewIdentifierClass::PCBView:
+		case ViewLayer::BreadboardView:
+		case ViewLayer::PCBView:
 			{
 				double nearest = qRound((originalAngle + deltaAngle) / 45) * 45;
 				if (qAbs(originalAngle + deltaAngle - nearest) < 6) {
@@ -285,7 +285,7 @@ void PaletteItemBase::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 				}
 			}
 			break;
-		case ViewIdentifierClass::SchematicView:
+		case ViewLayer::SchematicView:
 			{
 				double nearest = qRound((originalAngle + deltaAngle) / 90) * 90;
 				deltaAngle = nearest - originalAngle;
@@ -379,19 +379,19 @@ void PaletteItemBase::collectWireConnectees(QSet<Wire *> & wires) {
 	}
 }
 
-bool PaletteItemBase::setUpImage(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec viewLayerSpec, bool doConnectors, LayerAttributes & layerAttributes, QString & error)
+bool PaletteItemBase::setUpImage(ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec viewLayerSpec, bool doConnectors, LayerAttributes & layerAttributes, QString & error)
 {
 	FSvgRenderer * renderer = ItemBase::setUpImage(modelPart, viewIdentifier, viewLayerID, viewLayerSpec, layerAttributes, error);
 	if (renderer == NULL) {
 		return false;
 	}
 
-	m_canFlipVertical = layerAttributes.canFlipVertical();
-	m_canFlipHorizontal = layerAttributes.canFlipHorizontal();
+	m_canFlipVertical = modelPart->canFlipVertical(viewIdentifier);
+	m_canFlipHorizontal = modelPart->canFlipHorizontal(viewIdentifier);
 	m_filename = layerAttributes.filename();
 	//DebugDialog::debug(QString("filename %1").arg(m_filename) );
-	setSticky(layerAttributes.sticky());
-	QString elementID = layerAttributes.layerName();
+	setSticky(modelPart->anySticky(viewIdentifier));
+	QString elementID = ViewLayer::viewLayerXmlNameFromID(viewLayerID);
 	setViewLayerID(elementID, viewLayers);
 
 	//DebugDialog::debug(QString("setting layer %1 view:%2 z:%3").arg(modelPart->title()).arg(viewIdentifier).arg(this->z()) );
@@ -412,20 +412,10 @@ bool PaletteItemBase::setUpImage(ModelPart * modelPart, ViewIdentifierClass::Vie
 	return true;
 }
 
-void PaletteItemBase::setSharedRendererEx(FSvgRenderer * newRenderer) {
-	if (newRenderer != renderer()) {
-		setSharedRenderer(newRenderer);
-	}
-	else {
-		update();
-	}
-	m_size = newRenderer->defaultSizeF();
-}
-
 void PaletteItemBase::setUpConnectors(FSvgRenderer * renderer, bool ignoreTerminalPoints) {
 	clearConnectorItemCache();
 
-	if (m_viewIdentifier == ViewIdentifierClass::PCBView && ViewLayer::isNonCopperLayer(m_viewLayerID)) {
+	if (m_viewIdentifier == ViewLayer::PCBView && ViewLayer::isNonCopperLayer(m_viewLayerID)) {
 		//DebugDialog::debug(QString("skip connectors: %1 vid:%2 vlid:%3")
 		//				   .arg(this->title())
 		//				   .arg(m_viewIdentifier) 
@@ -494,7 +484,7 @@ void PaletteItemBase::connectedMoved(ConnectorItem * from, ConnectorItem * to) {
 	if (from->connectorType() != Connector::Female) return;
 
 	// female connectors really only operate in breadboard view
-	if (m_viewIdentifier != ViewIdentifierClass::BreadboardView) return;
+	if (m_viewIdentifier != ViewLayer::BreadboardView) return;
 
 	QTransform t = this->transform();
 	if (t.isRotating()) {
@@ -586,7 +576,7 @@ void PaletteItemBase::contextMenuEvent(QGraphicsSceneContextMenuEvent *event) {
 
 
 LayerKinPaletteItem *PaletteItemBase::newLayerKinPaletteItem(PaletteItemBase * chief, ModelPart * modelPart, 
-															 ViewIdentifierClass::ViewIdentifier viewIdentifier,
+															 ViewLayer::ViewIdentifier viewIdentifier,
 															 const ViewGeometry & viewGeometry, long id,
 															 ViewLayer::ViewLayerID viewLayerID, 
 															 ViewLayer::ViewLayerSpec viewLayerSpec, 
@@ -658,7 +648,7 @@ bool PaletteItemBase::collectExtraInfo(QWidget * parent, const QString & family,
 
 		QLineEdit * lineEdit = new QLineEdit();
 		lineEdit->setEnabled(swappingEnabled);
-		QString current = m_modelPart->prop(ModelPartShared::PartNumberPropertyName).toString();
+		QString current = m_modelPart->localProp(ModelPartShared::PartNumberPropertyName).toString();
 		lineEdit->setText(current);
 		connect(lineEdit, SIGNAL(editingFinished()), this, SLOT(partPropertyEntry()));	
 		lineEdit->setObjectName("infoViewLineEdit");		
@@ -673,7 +663,7 @@ bool PaletteItemBase::collectExtraInfo(QWidget * parent, const QString & family,
 void PaletteItemBase::setProp(const QString & prop, const QString & value) 
 {	
 	if (prop.compare(ModelPartShared::PartNumberPropertyName) == 0) {
-		modelPart()->setProp(ModelPartShared::PartNumberPropertyName, value);
+		modelPart()->setLocalProp(ModelPartShared::PartNumberPropertyName, value);
 		if (m_partLabel) m_partLabel->displayTextsIf();
 		return;
 	}
@@ -687,7 +677,7 @@ void PaletteItemBase::partPropertyEntry() {
 
 	InfoGraphicsView * infoGraphicsView = InfoGraphicsView::getInfoGraphicsView(this);
 	if (infoGraphicsView != NULL) {
-		infoGraphicsView->setProp(this, ModelPartShared::PartNumberPropertyName, "", m_modelPart->prop(ModelPartShared::PartNumberPropertyName).toString(), lineEdit->text(), true);
+		infoGraphicsView->setProp(this, ModelPartShared::PartNumberPropertyName, "", m_modelPart->localProp(ModelPartShared::PartNumberPropertyName).toString(), lineEdit->text(), true);
 	}
 }
 
@@ -720,7 +710,7 @@ bool PaletteItemBase::freeRotationAllowed(Qt::KeyboardModifiers modifiers) {
 bool PaletteItemBase::inRotationLocation(QPointF scenePos, Qt::KeyboardModifiers modifiers, QPointF & returnPoint)
 {
 	if (!freeRotationAllowed(modifiers)) return false;
-	if (m_viewIdentifier == ViewIdentifierClass::SchematicView) return false;
+	if (m_viewIdentifier == ViewLayer::SchematicView) return false;
 
 	QRectF r = this->boundingRectWithoutLegs();
 	QPolygonF polygon;
@@ -758,6 +748,22 @@ void PaletteItemBase::checkFreeRotation(Qt::KeyboardModifiers modifiers, QPointF
 	}
 }
 
+QString PaletteItemBase::normalizeSvg(QString & svg, ViewLayer::ViewLayerID viewLayerID, bool blackOnly, double dpi)
+{
+	QString xmlName = ViewLayer::viewLayerXmlNameFromID(viewLayerID);
+	SvgFileSplitter splitter;
+	bool result = splitter.splitString(svg, xmlName);
+	if (!result) {
+		return "";
+	}
+	result = splitter.normalize(dpi, xmlName, blackOnly);
+	if (!result) {
+		return "";
+	}
+	return splitter.elementString(xmlName);
+}
+
+
 /*
 
 void PaletteItemBase::setPos(const QPointF & pos) {
@@ -771,3 +777,4 @@ void PaletteItemBase::setPos(double x, double y) {
 
 
 */
+
