@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5899 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-03-09 10:52:17 +0100 (Fri, 09 Mar 2012) $
+$Revision: 6565 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-15 12:10:48 +0200 (Mon, 15 Oct 2012) $
 
 ********************************************************************/
 
@@ -56,11 +56,12 @@ $Date: 2012-03-09 10:52:17 +0100 (Fri, 09 Mar 2012) $
 #include "led.h"
 #include "../utils/folderutils.h"
 #include "../utils/lockmanager.h"
+#include "../utils/textutils.h"
 
 static QString PartFactoryFolderPath;
 static QHash<QString, LockedFile *> LockedFiles;
 
-ItemBase * PartFactory::createPart( ModelPart * modelPart, ViewLayer::ViewLayerSpec viewLayerSpec, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, QMenu * wireMenu, bool doLabel)
+ItemBase * PartFactory::createPart( ModelPart * modelPart, ViewLayer::ViewLayerSpec viewLayerSpec, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, QMenu * wireMenu, bool doLabel)
 {
 	modelPart->setModelIndexFromMultiplied(id);			// make sure the model index is synched with the id; this is not always the case when parts are first created.
 	ItemBase * itemBase = createPartAux(modelPart, viewIdentifier, viewGeometry, id, itemMenu, wireMenu, doLabel);
@@ -70,7 +71,7 @@ ItemBase * PartFactory::createPart( ModelPart * modelPart, ViewLayer::ViewLayerS
 	return itemBase;
 }
 
-ItemBase * PartFactory::createPartAux( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, QMenu * wireMenu, bool doLabel)
+ItemBase * PartFactory::createPartAux( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, QMenu * wireMenu, bool doLabel)
 {
 	switch (modelPart->itemType()) {
 		case ModelPart::Wire:
@@ -100,6 +101,12 @@ ItemBase * PartFactory::createPartAux( ModelPart * modelPart, ViewIdentifierClas
 			if (modelPart->moduleID().startsWith("copper", Qt::CaseInsensitive)) {
 				return new CopperLogoItem(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel);
 			}
+            else if (modelPart->moduleID().contains("board", Qt::CaseInsensitive)) {
+                return new BoardLogoItem(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel);
+            }
+            else if (modelPart->moduleID().startsWith("Schematic", Qt::CaseInsensitive)) {
+                return new SchematicLogoItem(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel);
+            }
 			return new LogoItem(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel);
 		case ModelPart::Ruler:
 			return new Ruler(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel);
@@ -152,9 +159,12 @@ ItemBase * PartFactory::createPartAux( ModelPart * modelPart, ViewIdentifierClas
 					if (moduleID.endsWith(ModuleIDNames::SchematicFrameModuleIDName)) {
 						return new SchematicFrame(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel);
 					}
-					if (moduleID.compare(ModuleIDNames::PadModuleIDName) == 0) {
+					if (moduleID.endsWith(ModuleIDNames::PadModuleIDName)) {
 						return new Pad(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel);
 					}
+					if (moduleID.endsWith(ModuleIDNames::CopperBlockerModuleIDName)) {
+						return new CopperBlocker(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel);
+					}
 					// must get the subclasses first
 					if (modelPart->itemType() == ModelPart::Breadboard) {
 						return new Breadboard(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel);
@@ -181,124 +191,159 @@ ItemBase * PartFactory::createPartAux( ModelPart * modelPart, ViewIdentifierClas
 }
 
 QString PartFactory::getSvgFilename(ModelPart * modelPart, const QString & expectedFileName) {
-	Q_UNUSED(modelPart);
 
 	if (expectedFileName.startsWith("pcb/dip_", Qt::CaseInsensitive)) {
-		return getSvgFilenameAux(expectedFileName, &Dip::makePcbSvg);
+		return getSvgFilenameAux(expectedFileName, modelPart, &MysteryPart::makePcbDipSvg);
+	}
+
+	if (expectedFileName.startsWith("pcb/mystery_part_", Qt::CaseInsensitive)) {
+        if (expectedFileName.contains("dip")) {
+		    return getSvgFilenameAux(expectedFileName, modelPart, &MysteryPart::makePcbDipSvg);
+        }
+        return getSvgFilenameAux(expectedFileName, modelPart, &PinHeader::makePcbSvg);
 	}
 
 	if (expectedFileName.startsWith("breadboard/mystery_part_", Qt::CaseInsensitive)) {
-		return getSvgFilenameAux(expectedFileName, &MysteryPart::makeBreadboardSvg);
+		return getSvgFilenameAux(expectedFileName, modelPart, &MysteryPart::makeBreadboardSvg);
 	}
 
 	if (expectedFileName.startsWith("breadboard/screw_terminal_", Qt::CaseInsensitive)) {
-		return getSvgFilenameAux(expectedFileName, &ScrewTerminal::makeBreadboardSvg);
+		return getSvgFilenameAux(expectedFileName, modelPart, &ScrewTerminal::makeBreadboardSvg);
 	}
 
 	if (expectedFileName.startsWith("schematic/screw_terminal_", Qt::CaseInsensitive)) {
-		return getSvgFilenameAux(expectedFileName, &ScrewTerminal::makeSchematicSvg);
+		return getSvgFilenameAux(expectedFileName, modelPart, &ScrewTerminal::makeSchematicSvg);
 	}
 
 	if (expectedFileName.startsWith("pcb/screw_terminal_", Qt::CaseInsensitive)) {
-		return getSvgFilenameAux(expectedFileName, &ScrewTerminal::makePcbSvg);
+		return getSvgFilenameAux(expectedFileName, modelPart, &ScrewTerminal::makePcbSvg);
 	}
 
 	if (expectedFileName.startsWith("breadboard/generic_sip_", Qt::CaseInsensitive)) {
-		return getSvgFilenameAux(expectedFileName, &Dip::makeBreadboardSvg);
+		return getSvgFilenameAux(expectedFileName, modelPart, &Dip::makeBreadboardSvg);
 	}
 
 	if (expectedFileName.startsWith("schematic/mystery_part_", Qt::CaseInsensitive)) {
-		return getSvgFilenameAux(expectedFileName, &MysteryPart::makeSchematicSvg);
+		return getSvgFilenameAux(expectedFileName, modelPart, &MysteryPart::makeSchematicSvg);
 	}
 
 	if (expectedFileName.startsWith("schematic/generic_sip_", Qt::CaseInsensitive)) {
-		return getSvgFilenameAux(expectedFileName, &MysteryPart::makeSchematicSvg);
+		return getSvgFilenameAux(expectedFileName, modelPart, &MysteryPart::makeSchematicSvg);
+	}
+
+	if (expectedFileName.startsWith("pcb/generic_sip_", Qt::CaseInsensitive)) {
+		return getSvgFilenameAux(expectedFileName, modelPart, &PinHeader::makePcbSvg);
 	}
 
 	if (expectedFileName.startsWith("schematic/generic_ic_dip_", Qt::CaseInsensitive)) {
-		return getSvgFilenameAux(expectedFileName, &Dip::makeSchematicSvg);
+		return getSvgFilenameAux(expectedFileName, modelPart, &Dip::makeSchematicSvg);
 	}
 
 	if (expectedFileName.startsWith("breadboard/generic_ic_dip_", Qt::CaseInsensitive)) {
-		return getSvgFilenameAux(expectedFileName, &Dip::makeBreadboardSvg);
+		return getSvgFilenameAux(expectedFileName, modelPart, &Dip::makeBreadboardSvg);
+	}
+
+	if (expectedFileName.startsWith("pcb/generic_ic_dip_", Qt::CaseInsensitive)) {
+		return getSvgFilenameAux(expectedFileName, modelPart, &MysteryPart::makePcbDipSvg);
 	}
 
 	if (expectedFileName.startsWith("pcb/nsjumper_", Qt::CaseInsensitive)) {
-		return getSvgFilenameAux(expectedFileName, &PinHeader::makePcbSvg);
+		return getSvgFilenameAux(expectedFileName, modelPart, &PinHeader::makePcbSvg);
 	}
 
 	if (expectedFileName.startsWith("pcb/jumper_", Qt::CaseInsensitive)) {
-		return getSvgFilenameAux(expectedFileName, &PinHeader::makePcbSvg);
+		return getSvgFilenameAux(expectedFileName, modelPart, &PinHeader::makePcbSvg);
 	}
 
 	if (expectedFileName.startsWith("pcb/shrouded_", Qt::CaseInsensitive)) {
-		return getSvgFilenameAux(expectedFileName, &PinHeader::makePcbSvg);
+		return getSvgFilenameAux(expectedFileName, modelPart, &PinHeader::makePcbSvg);
+	}
+
+	if (expectedFileName.startsWith("pcb/molex_", Qt::CaseInsensitive)) {
+		return getSvgFilenameAux(expectedFileName, modelPart, &PinHeader::makePcbSvg);
+	}
+
+	if (expectedFileName.startsWith("pcb/longpad_", Qt::CaseInsensitive)) {
+		return getSvgFilenameAux(expectedFileName, modelPart, &PinHeader::makePcbSvg);
+	}
+
+	if (expectedFileName.startsWith("bread/molex_", Qt::CaseInsensitive)) {
+		return getSvgFilenameAux(expectedFileName, modelPart, &PinHeader::makeBreadboardSvg);
+	}
+
+	if (expectedFileName.startsWith("bread/longpad_", Qt::CaseInsensitive)) {
+		return getSvgFilenameAux(expectedFileName, modelPart, &PinHeader::makeBreadboardSvg);
 	}
 
 	if (expectedFileName.contains("pin_header", Qt::CaseInsensitive)) {
 		if (expectedFileName.contains("schematic", Qt::CaseInsensitive)) {
-			return getSvgFilenameAux(expectedFileName, &PinHeader::makeSchematicSvg);
+			return getSvgFilenameAux(expectedFileName, modelPart, &PinHeader::makeSchematicSvg);
 		}
 		else if (expectedFileName.contains("bread", Qt::CaseInsensitive)) {
-			return getSvgFilenameAux(expectedFileName, &PinHeader::makeBreadboardSvg);		
+			return getSvgFilenameAux(expectedFileName, modelPart, &PinHeader::makeBreadboardSvg);		
 		}
 		else if (expectedFileName.contains("pcb", Qt::CaseInsensitive)) {
-			return getSvgFilenameAux(expectedFileName, &PinHeader::makePcbSvg);		
+			return getSvgFilenameAux(expectedFileName, modelPart, &PinHeader::makePcbSvg);		
 		}
 	}
 
-	if (expectedFileName.contains("perfboard", Qt::CaseInsensitive)) {
+	if (expectedFileName.contains("perfboard", Qt::CaseInsensitive) || expectedFileName.contains("stripboard", Qt::CaseInsensitive)) {
 		if (expectedFileName.contains("icon")) return expectedFileName;
 
-		return getSvgFilenameAux(expectedFileName, &Perfboard::makeBreadboardSvg);		
-	}
-
-	if (expectedFileName.contains("stripboard", Qt::CaseInsensitive)) {
-		if (expectedFileName.contains("icon")) return expectedFileName;
-
-		return getSvgFilenameAux(expectedFileName, &Stripboard::makeBreadboardSvg);		
+		return getSvgFilenameAux(expectedFileName, modelPart, &Perfboard::makeBreadboardSvg);		
 	}
 
 	return "";
 }
 
-QString PartFactory::getSvgFilenameAux(const QString & expectedFileName, QString (*getSvg)(const QString &))
+bool PartFactory::svgFileExists(const QString & expectedFileName, QString & path) {
+	QString p = FolderUtils::getApplicationSubFolderPath("parts") + "/"+ ItemBase::SvgFilesDir + "/core/";
+	if (QFileInfo(p + expectedFileName).exists()) {
+        path = expectedFileName;
+        return true;
+    }
+
+	path = partPath() + expectedFileName;
+	QFileInfo info(path);
+	return info.exists();
+}
+
+QString PartFactory::getSvgFilenameAux(const QString & expectedFileName, const ModelPart * modelPart, GenSvg genSvg)
 {
-	QString path = FolderUtils::getApplicationSubFolderPath("parts") + "/"+ ItemBase::SvgFilesDir + "/core/";
-	if (QFileInfo(path + expectedFileName).exists()) return expectedFileName;
+    Q_UNUSED(modelPart);
 
-	path = PartFactoryFolderPath + "/svg/core/" + expectedFileName;
-	QFile file(path);
-	if (file.exists()) {
-		return path;
-	} 
+    QString path;
+    if (svgFileExists(expectedFileName, path)) return path;
 
-	QString svg = (*getSvg)(expectedFileName);
-	if (file.open(QFile::WriteOnly)) {
-		QTextStream stream(&file);
-		stream.setCodec("UTF-8");
-		stream << svg;
-		file.close();
+	QString svg = (*genSvg)(expectedFileName);
+	if (TextUtils::writeUtf8(path, svg)) {
 		return path;
 	}
 
 	return "";
 }
 
+
+bool PartFactory::fzpFileExists(const QString & moduleID, QString & path) {
+    QString expectedFileName = moduleID + FritzingPartExtension;
+	path = FolderUtils::getApplicationSubFolderPath("parts") + "/core/" + expectedFileName;
+	if (QFileInfo(path).exists()) {
+        path = expectedFileName;
+        return true;
+    }
+
+	path = fzpPath() + expectedFileName;
+	QFileInfo info(path);
+	return info.exists();
+}
+
 QString PartFactory::getFzpFilenameAux(const QString & moduleID, QString (*getFzp)(const QString &))
 {
-	QString path = PartFactoryFolderPath + "/core/" + moduleID + FritzingPartExtension;
-	QFile file(path);
-	if (file.exists()) {
-		return path;
-	}
+	QString path;
+    if (fzpFileExists(moduleID, path)) return path;
 
 	QString fzp = (*getFzp)(moduleID);
-	if (file.open(QFile::WriteOnly)) {
-		QTextStream stream(&file);
-		stream.setCodec("UTF-8");
-		stream << fzp;
-		file.close();
+	if (TextUtils::writeUtf8(path, fzp)) {
 		return path;
 	}
 
@@ -308,6 +353,10 @@ QString PartFactory::getFzpFilenameAux(const QString & moduleID, QString (*getFz
 
 QString PartFactory::getFzpFilename(const QString & moduleID) 
 {
+    QString filename = fzpPath() + moduleID + ".fzp";
+    QFileInfo info(filename);
+    if (info.exists()) return filename;
+
 	if (moduleID.endsWith(ModuleIDNames::PerfboardModuleIDName)) {
 		return getFzpFilenameAux(moduleID, &Perfboard::genFZP);
 	}
@@ -350,6 +399,7 @@ void PartFactory::initFolder()
 	QFileInfoList backupList;
 	LockManager::checkLockedFiles("partfactory", backupList, LockedFiles, true, LockManager::SlowTime);
 	FolderUtils::makePartFolderHierarchy(PartFactoryFolderPath, "core");
+	FolderUtils::makePartFolderHierarchy(PartFactoryFolderPath, "contrib");
 }
 
 void PartFactory::cleanup()
@@ -359,22 +409,6 @@ void PartFactory::cleanup()
 
 ModelPart * PartFactory::fixObsoleteModuleID(QDomDocument & domDocument, QDomElement & instance, QString & moduleIDRef, ModelBase * referenceModel) {
 	// TODO: less hard-coding
-	QRegExp oldDip("generic_ic_dip_(\\d{1,2})_(\\d{3}mil)");
-	if (oldDip.indexIn(moduleIDRef) == 0) {
-		QString spacing = oldDip.cap(2);
-		QString pins = oldDip.cap(1);
-		moduleIDRef = QString("generic_ic_dip_%1_300mil").arg(pins);
-		ModelPart * modelPart = referenceModel->retrieveModelPart(moduleIDRef);
-		if (modelPart != NULL) {
-			instance.setAttribute("moduleIdRef", moduleIDRef);
-			QDomElement prop = domDocument.createElement("property");
-			instance.appendChild(prop);
-			prop.setAttribute("name", "spacing");
-			prop.setAttribute("value", spacing);
-			return modelPart;
-		}
-	}
-
 	if (moduleIDRef.startsWith("generic_male")) {
 		ModelPart * modelPart = referenceModel->retrieveModelPart(moduleIDRef);
 		if (modelPart != NULL) {
@@ -405,3 +439,25 @@ ModelPart * PartFactory::fixObsoleteModuleID(QDomDocument & domDocument, QDomEle
 QString PartFactory::folderPath() {
 	return PartFactoryFolderPath;
 }
+
+QString PartFactory::fzpPath() {
+    return PartFactoryFolderPath + "/core/";
+}
+
+QString PartFactory::partPath() {
+    return PartFactoryFolderPath + "/svg/core/";
+}
+
+QString PartFactory::makeSipOrDipOr(const QStringList & labels, bool hasLayout, bool sip) 
+{		
+	if (hasLayout) {
+		return MysteryPart::makeSchematicSvg(labels, false);
+	}
+		
+    if (sip) {
+		return MysteryPart::makeSchematicSvg(labels, true);
+	}
+
+	return Dip::makeSchematicSvg(labels);
+}
+
