@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5721 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-01-03 16:53:58 +0100 (Tue, 03 Jan 2012) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -30,26 +30,31 @@ $Date: 2012-01-03 16:53:58 +0100 (Tue, 03 Jan 2012) $
 #include <QMenu>
 #include <QDomDocument>
 #include <QDomElement>
-#include "../viewidentifierclass.h"
 #include "../viewlayer.h"
+#include "paletteitem.h"
+
 
 class PartFactory
 {
 public:
-	static class ItemBase * createPart(class ModelPart *, ViewLayer::ViewLayerSpec, ViewIdentifierClass::ViewIdentifier, const class ViewGeometry & viewGeometry, long id, QMenu * itemMenu, QMenu * wireMenu, bool doLabel);
+	static class ItemBase * createPart(class ModelPart *, ViewLayer::ViewLayerSpec, ViewLayer::ViewIdentifier, const class ViewGeometry & viewGeometry, long id, QMenu * itemMenu, QMenu * wireMenu, bool doLabel);
 	static QString getSvgFilename(class ModelPart *, const QString & filename);
 	static QString getFzpFilename(const QString & moduleID);
 	static void initFolder();
 	static void cleanup();
 	static class ModelPart * fixObsoleteModuleID(QDomDocument & domDocument, QDomElement & instance, QString & moduleIDRef, class ModelBase * referenceModel);
 	static QString folderPath();
-
+	static QString fzpPath();
+	static QString partPath();
+    static bool svgFileExists(const QString & expectedFileName, QString & path);
+    static bool fzpFileExists(const QString & moduleID, QString & path);
+    static QString makeSipOrDipOr(const QStringList & labels, bool hasLayout, bool sip);
 
 
 protected:
-	static QString getFzpFilenameAux(const QString & moduleID, QString (*getFzp)(const QString &));
-	static QString getSvgFilenameAux(const QString & expectedFileName, QString (*getSvg)(const QString &));
-	static class ItemBase * createPartAux(class ModelPart *, ViewIdentifierClass::ViewIdentifier, const class ViewGeometry & viewGeometry, long id, QMenu * itemMenu, QMenu * wireMenu, bool doLabel);
+	static QString getFzpFilenameAux(const QString & moduleID, GenFzp);
+	static QString getSvgFilenameAux(const QString & expectedFileName, const ModelPart *, GenSvg);
+	static class ItemBase * createPartAux(class ModelPart *, ViewLayer::ViewIdentifier, const class ViewGeometry & viewGeometry, long id, QMenu * itemMenu, QMenu * wireMenu, bool doLabel);
 };
 
 #endif
