@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5832 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-02-03 16:20:27 +0100 (Fri, 03 Feb 2012) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -118,7 +118,7 @@ PartLabel::PartLabel(ItemBase * owner, QGraphicsItem * parent)
 
 	m_inactive = m_hidden = m_initialized = false;
 	m_displayKeys.append(LabelTextKey);
-	if (m_owner->hasPartNumberProperty() && m_owner->viewIdentifier() != ViewIdentifierClass::PCBView) {
+	if (m_owner->hasPartNumberProperty() && m_owner->viewIdentifier() != ViewLayer::PCBView) {
 		m_displayKeys.append(ModelPartShared::PartNumberPropertyName);
 	}
 
@@ -147,7 +147,7 @@ void PartLabel::showLabel(bool showIt, ViewLayer * viewLayer) {
 
 		bool flipped = (viewLayer->viewLayerID() == ViewLayer::Silkscreen0Label);
 
-		if (m_owner->viewIdentifier() != ViewIdentifierClass::PCBView) {
+		if (m_owner->viewIdentifier() != ViewLayer::PCBView) {
 			foreach (QString dk, m_owner->modelPart()->displayKeys()) {
 				if (!m_displayKeys.contains(dk)) {
 					m_displayKeys.append(dk);
@@ -444,7 +444,7 @@ void PartLabel::initMenu()
 	QMenu * rlmenu = m_menu.addMenu(tr("Flip/Rotate"));
 	QMenu * fsmenu = m_menu.addMenu(tr("Font Size"));
 
-	bool include45 = (m_owner != NULL) && (m_owner->viewIdentifier() == ViewIdentifierClass::PCBView);
+	bool include45 = (m_owner != NULL) && (m_owner->viewIdentifier() == ViewLayer::PCBView);
 
 	if (include45) {
 		QAction *rotate45cwAct = rlmenu->addAction(tr("Rotate 45\x00B0 Clockwise"));
@@ -892,10 +892,10 @@ void PartLabel::resetSvg()
 {
 
 	double w, h;
-	QString innerSvg = makeSvgAux(false, GraphicsUtils::StandardFritzingDPI, FSvgRenderer::printerScale(), w, h);
+	QString innerSvg = makeSvgAux(false, GraphicsUtils::StandardFritzingDPI, GraphicsUtils::SVGDPI, w, h);
 	if (innerSvg.isEmpty()) return;
 
-	QString svg = TextUtils::makeSVGHeader(FSvgRenderer::printerScale(), GraphicsUtils::StandardFritzingDPI, w, h) + innerSvg + "\n</svg>";
+	QString svg = TextUtils::makeSVGHeader(GraphicsUtils::SVGDPI, GraphicsUtils::StandardFritzingDPI, w, h) + innerSvg + "\n</svg>";
 
 	if (m_renderer == NULL) {
 		m_renderer = new QSvgRenderer(this);
