@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5932 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-03-29 12:53:10 +0200 (Thu, 29 Mar 2012) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -57,13 +57,13 @@ bool Perfboard::m_gotWarning = false;
 
 /////////////////////////////////////////////////////////////////////
 
-Perfboard::Perfboard( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+Perfboard::Perfboard( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
 	: Capacitor(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
 {
-	m_size = modelPart->prop("size").toString();
+	m_size = modelPart->localProp("size").toString();
 	if (m_size.isEmpty()) {
 		m_size = modelPart->properties().value("size", "20.20");
-		modelPart->setProp("size", m_size);
+		modelPart->setLocalProp("size", m_size);
 	}
 }
 
@@ -77,10 +77,11 @@ void Perfboard::setProp(const QString & prop, const QString & value)
 		return;
 	}
 	switch (this->m_viewIdentifier) {
-		case ViewIdentifierClass::BreadboardView:
+		case ViewLayer::BreadboardView:
 			if (value.compare(m_size) != 0) {
-				QString svg = makeBreadboardSvg(value);
-				loadExtraRenderer(svg, false);
+                QString temp = value;
+				QString svg = makeBreadboardSvg(temp);
+				reloadRenderer(svg, false);
 				//DebugDialog::debug(svg);
 			}
 			break;
@@ -90,7 +91,7 @@ void Perfboard::setProp(const QString & prop, const QString & value)
 	}
 
 	m_size = value;
-	modelPart()->setProp("size", value);
+	modelPart()->setLocalProp("size", value);
 
     if (m_partLabel) m_partLabel->displayTextsIf();
 }
@@ -321,7 +322,7 @@ void Perfboard::changeBoardSize()
 
     InfoGraphicsView * infoGraphicsView = InfoGraphicsView::getInfoGraphicsView(this);
     if (infoGraphicsView != NULL) {
-        infoGraphicsView->swap(modelPart()->properties().value("family"), "size", m_propsMap, this);
+        infoGraphicsView->swap(family(), "size", m_propsMap, this);
     }
 }
 
