@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5970 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-10 19:16:12 +0200 (Tue, 10 Apr 2012) $
+$Revision: 6505 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-03 10:14:52 +0200 (Wed, 03 Oct 2012) $
 
 ********************************************************************/
 
@@ -36,6 +36,7 @@ $Date: 2012-04-10 19:16:12 +0200 (Tue, 10 Apr 2012) $
 #include "../layerattributes.h"
 #include "moduleidnames.h"
 #include "partlabel.h"
+#include "../debugdialog.h"
 
 #include <qmath.h>
 #include <QRegExpValidator>
@@ -51,7 +52,7 @@ static QHash<QString, QColor> Tolerances;
 //	save into parts bin
 //	other manifestations of "220"?
 
-Resistor::Resistor( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+Resistor::Resistor( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
 	: Capacitor(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
 {
 	m_changingPinSpacing = false;
@@ -105,16 +106,16 @@ Resistor::Resistor( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier v
 		Tolerances.insert(PlusMinusSymbol + "20%", QColor(0xdb, 0xb4, 0x77));
 	}
 
-	m_ohms = modelPart->prop("resistance").toString();
+	m_ohms = modelPart->localProp("resistance").toString();
 	if (m_ohms.isEmpty()) {
 		m_ohms = modelPart->properties().value("resistance", "220");
-		modelPart->setProp("resistance", m_ohms);
+		modelPart->setLocalProp("resistance", m_ohms);
 	}
 
-	m_pinSpacing = modelPart->prop("pin spacing").toString();
+	m_pinSpacing = modelPart->localProp("pin spacing").toString();
 	if (m_pinSpacing.isEmpty()) {
 		m_pinSpacing = modelPart->properties().value("pin spacing", "400 mil");
-		modelPart->setProp("pin spacing", m_pinSpacing);
+		modelPart->setLocalProp("pin spacing", m_pinSpacing);
 	}
 
 	updateResistances(m_ohms);
@@ -134,14 +135,14 @@ void Resistor::setResistance(QString resistance, QString pinSpacing, bool force)
 	modelPart()->setLocalTitle(resistance + " " + OhmSymbol + " " + tr("Resistor"));
 
 	switch (this->m_viewIdentifier) {
-		case ViewIdentifierClass::BreadboardView:
+		case ViewLayer::BreadboardView:
 			if (force || resistance.compare(m_ohms) != 0) {
 				QString svg = makeSvg(resistance, m_viewLayerID);
 				//DebugDialog::debug(svg);
-				loadExtraRenderer(svg.toUtf8(), false);
+				reloadRenderer(svg, false);
 			}
 			break;
-		case ViewIdentifierClass::PCBView:
+		case ViewLayer::PCBView:
 			if (force || pinSpacing.compare(m_pinSpacing) != 0) {
 
 				InfoGraphicsView * infoGraphicsView = InfoGraphicsView::getInfoGraphicsView(this);
@@ -149,19 +150,16 @@ void Resistor::setResistance(QString resistance, QString pinSpacing, bool force)
 
 				if (modelPart()->properties().value("package").compare("tht", Qt::CaseInsensitive) == 0) 
 				{
-					// pinspacing is irrelevant for SMD resistors
-					QDomElement element = LayerAttributes::getSvgElementLayers(modelPart()->domDocument(), m_viewIdentifier);
-					if (element.isNull()) break;
-
-					// hack the dom element and call setUpImage
-					FSvgRenderer::removeFromHash(moduleID(), "");
+                    // pinspacing is irrelevant for SMD resistors
 					QString filename = PinSpacings.value(pinSpacing, "");
 					if (filename.isEmpty()) break;
 
-					element.setAttribute("image", filename);
+                    QString original = modelPart()->imageFileName(m_viewIdentifier);
+                    modelPart()->setImageFileName(m_viewIdentifier, filename);
 					m_changingPinSpacing = true;
 					resetImage(infoGraphicsView);
 					m_changingPinSpacing = false;
+                    modelPart()->setImageFileName(m_viewIdentifier, original);
 
 					updateConnections();
 				}
@@ -174,9 +172,9 @@ void Resistor::setResistance(QString resistance, QString pinSpacing, bool force)
 
 	m_ohms = resistance;
 	m_pinSpacing = pinSpacing;
-	modelPart()->setProp("resistance", resistance);
-	modelPart()->setProp("pin spacing", pinSpacing);
-	modelPart()->setProp("tolerance", tolerance);
+	modelPart()->setLocalProp("resistance", resistance);
+	modelPart()->setLocalProp("pin spacing", pinSpacing);
+	modelPart()->setLocalProp("tolerance", tolerance);
 
 	updateResistances(m_ohms);
     if (m_partLabel) m_partLabel->displayTextsIf();
@@ -193,18 +191,7 @@ QString Resistor::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString,
 	}
 
 	QString svg = makeSvg(m_ohms, viewLayerID);
-
-	QString xmlName = ViewLayer::viewLayerXmlNameFromID(viewLayerID);
-	SvgFileSplitter splitter;
-	bool result = splitter.splitString(svg, xmlName);
-	if (!result) {
-		return "";
-	}
-	result = splitter.normalize(dpi, xmlName, blackOnly);
-	if (!result) {
-		return "";
-	}
-	return splitter.elementString(xmlName);
+    return PaletteItemBase::normalizeSvg(svg, viewLayerID, blackOnly, dpi);
 }
 
 QString Resistor::makeSvg(const QString & resistance, ViewLayer::ViewLayerID viewLayerID) {
@@ -357,8 +344,8 @@ ConnectorItem* Resistor::newConnectorItem(ItemBase * layerKin, Connector *connec
 
 bool Resistor::hasCustomSVG() {
 	switch (m_viewIdentifier) {
-		case ViewIdentifierClass::BreadboardView:
-		case ViewIdentifierClass::IconView:
+		case ViewLayer::BreadboardView:
+		case ViewLayer::IconView:
 			return true;
 		default:
 			return ItemBase::hasCustomSVG();
@@ -404,7 +391,7 @@ void Resistor::setProp(const QString & prop, const QString & value)
 	}
 }
 
-bool Resistor::setUpImage(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec viewLayerSpec, bool doConnectors, LayerAttributes & layerAttributes, QString & error)
+bool Resistor::setUpImage(ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec viewLayerSpec, bool doConnectors, LayerAttributes & layerAttributes, QString & error)
 {
 	bool result = Capacitor::setUpImage(modelPart, viewIdentifier, viewLayers, viewLayerID, viewLayerSpec, doConnectors, layerAttributes, error);
 	if (viewLayerID == ViewLayer::Breadboard) {
@@ -416,3 +403,10 @@ bool Resistor::setUpImage(ModelPart * modelPart, ViewIdentifierClass::ViewIdenti
 	return result;
 }
 
+ViewLayer::ViewIdentifier Resistor::useViewIdentifierForPixmap(ViewLayer::ViewIdentifier vid, bool swappingEnabled) {
+    if (swappingEnabled && vid == ViewLayer::BreadboardView) {
+        return vid;
+    }
+
+    return ItemBase::useViewIdentifierForPixmap(vid, swappingEnabled);
+}
