@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,46 +18,76 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5949 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-07 19:16:07 +0200 (Sat, 07 Apr 2012) $
+$Revision: 6509 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-04 07:19:37 +0200 (Thu, 04 Oct 2012) $
 
 ********************************************************************/
 
 #include "resizableboard.h"
 #include "../utils/resizehandle.h"
 #include "../utils/graphicsutils.h"
+#include "../utils/folderutils.h"
+#include "../utils/textutils.h"
 #include "../fsvgrenderer.h"
 #include "../sketch/infographicsview.h"
 #include "../svg/svgfilesplitter.h"
 #include "../commands.h"
 #include "moduleidnames.h"
 #include "../layerattributes.h"
+#include "../debugdialog.h"
 
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 #include <QFrame>
 #include <QLabel>
 #include <QLineEdit>
+#include <QPushButton>
+#include <QImageReader>
+#include <QMessageBox>
 #include <QRegExp>
 #include <qmath.h>
 #include <qnumeric.h>
 
-static QString BoardLayerTemplate = "";
-static QString SilkscreenLayerTemplate = "";
+QList<QString> PaperSizeNames;
+QList<QSizeF> PaperSizeDimensions;
+
+QHash<QString, QString> BoardLayerTemplates;
+QHash<QString, QString> SilkscreenLayerTemplates;
 static const int LineThickness = 8;
 static const QRegExp HeightExpr("height=\\'\\d*px");
+static QString StandardCustomBoardExplanation;
+
+QStringList Board::BoardImageNames;
+QStringList Board::NewBoardImageNames;
 
 const double ResizableBoard::CornerHandleSize = 7.0;
-QString ResizableBoard::customShapeTranslated;
 
+static const double JND = (double) 0.01;
 
-QString Board::oneLayerTranslated;
-QString Board::twoLayersTranslated;
+QString Board::OneLayerTranslated;
+QString Board::TwoLayersTranslated;
 
-Board::Board( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+Board::Board( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
 	: PaletteItem(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
 {
+    m_svgOnly = true;
+	m_fileNameComboBox = NULL;
+    if (isBoard(modelPart)) {
+        if (modelPart->localProp("layers").isNull()) {
+            modelPart->setLocalProp("layers", modelPart->properties().value("layers"));
+        }
+        if (itemType() == ModelPart::Board && !modelPart->properties().keys().contains("filename")) {
+            // deal with old style custom boards
+            modelPart->modelPartShared()->setProperty("filename", "");
+        }
+    }
+
+    if (StandardCustomBoardExplanation.isEmpty()) {
+        StandardCustomBoardExplanation = tr("\n\nA custom board svg typically has one silkscreen layer and one board layer.\n") +
+                                            tr("Have a look at the circle_pcb.svg file in your Fritzing installation folder at parts/svg/core/pcb/.\n\n");
+    }
+
 }
 
 Board::~Board() {
@@ -73,33 +103,52 @@ void Board::paintHover(QPainter *painter, const QStyleOptionGraphicsItem *option
 	painter->restore();
 }
 
-
 QStringList Board::collectValues(const QString & family, const QString & prop, QString & value) {
 	if (prop.compare("layers", Qt::CaseInsensitive) == 0) {
+        QString realValue = modelPart()->localProp("layers").toString();
+        if (!realValue.isEmpty()) {
+            value = realValue;
+        }
 		QStringList result;
-		if (oneLayerTranslated.isEmpty()) {
-			oneLayerTranslated = tr("one layer (single-sided)");
+		if (OneLayerTranslated.isEmpty()) {
+			OneLayerTranslated = tr("one layer (single-sided)");
 		}
-		if (twoLayersTranslated.isEmpty()) {
-			twoLayersTranslated = tr("two layers (double-sided)");
+		if (TwoLayersTranslated.isEmpty()) {
+			TwoLayersTranslated = tr("two layers (double-sided)");
 		}
 
-		result.append(oneLayerTranslated);
-		result.append(twoLayersTranslated);
+		result.append(OneLayerTranslated);
+		result.append(TwoLayersTranslated);
 
 		if (value == "1") {
-			value = oneLayerTranslated;
+			value = OneLayerTranslated;
 		}
 		else if (value == "2") {
-			value = twoLayersTranslated;
+			value = TwoLayersTranslated;
 		}
 
 		return result;
 	}
 
-	return PaletteItem::collectValues(family, prop, value);
+
+	QStringList result = PaletteItem::collectValues(family, prop, value);
+    if (prop.compare("shape", Qt::CaseInsensitive) == 0 && isBoard(this) && !this->moduleID().contains(ModuleIDNames::BoardLogoImageModuleIDName)) {
+        result.removeAll("Custom Shape");
+    }
+
+    return result;
+
 }
 
+bool Board::collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget) 
+{
+	if (prop.compare("filename", Qt::CaseInsensitive) == 0 && isBoard(this)) {
+        setupLoadImage(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget);
+		return true;
+	}
+
+	return PaletteItem::collectExtraInfo(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget);
+}
 
 bool Board::rotation45Allowed() {
 	return false;
@@ -117,17 +166,268 @@ bool Board::canFindConnectorsUnder() {
 	return false;
 }
 
+
+bool Board::isBoard(ItemBase * itemBase) {
+    if (qobject_cast<Board *>(itemBase) == NULL) return false;
+
+    return isBoard(itemBase->modelPart());
+}
+
+bool Board::isBoard(ModelPart * modelPart) {
+    if (modelPart == NULL) return false;
+
+    switch (modelPart->itemType()) {
+        case ModelPart::Board:
+            return true;
+        case ModelPart::ResizableBoard:
+            return true;
+        case ModelPart::Logo:
+            return modelPart->family().contains("pcb", Qt::CaseInsensitive);
+        default:
+            return false;
+    }
+}
+
+void Board::setupLoadImage(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget) 
+{
+    Q_UNUSED(returnValue);
+    Q_UNUSED(value);
+    Q_UNUSED(prop);
+    Q_UNUSED(family);
+    Q_UNUSED(parent);
+
+	returnProp = tr("image file");
+
+	QFrame * frame = new QFrame();
+	frame->setObjectName("infoViewPartFrame");
+	QVBoxLayout * vboxLayout = new QVBoxLayout();
+	vboxLayout->setContentsMargins(0, 0, 0, 0);
+	vboxLayout->setSpacing(0);
+	vboxLayout->setMargin(0);
+
+	QComboBox * comboBox = new QComboBox();
+	comboBox->setObjectName("infoViewComboBox");
+	comboBox->setEditable(false);
+	comboBox->setEnabled(swappingEnabled);
+	m_fileNameComboBox = comboBox;
+
+	setFileNameItems();
+
+	connect(comboBox, SIGNAL(currentIndexChanged(const QString &)), this, SLOT(fileNameEntry(const QString &)));
+
+	QPushButton * button = new QPushButton (tr("load image file"));
+	button->setObjectName("infoViewButton");
+	connect(button, SIGNAL(pressed()), this, SLOT(prepLoadImage()));
+	button->setEnabled(swappingEnabled);
+
+	vboxLayout->addWidget(comboBox);
+	vboxLayout->addWidget(button);
+
+	frame->setLayout(vboxLayout);
+	returnWidget = frame;
+
+	returnProp = "";
+}
+
+void Board::setFileNameItems() {
+	if (m_fileNameComboBox == NULL) return;
+
+	m_fileNameComboBox->addItems(getImageNames());
+	m_fileNameComboBox->addItems(getNewImageNames());
+
+	int ix = 0;
+	foreach (QString name, getImageNames()) {
+		if (prop("lastfilename").contains(name)) {
+			m_fileNameComboBox->setCurrentIndex(ix);
+			return;
+		}
+		ix++;
+	}
+
+	foreach (QString name, getNewImageNames()) {
+		if (prop("lastfilename").contains(name)) {
+			m_fileNameComboBox->setCurrentIndex(ix);
+			return;
+		}
+		ix++;
+	}
+}
+
+QStringList & Board::getImageNames() {
+	return BoardImageNames;
+}
+
+QStringList & Board::getNewImageNames() {
+	return NewBoardImageNames;
+}
+
+void Board::fileNameEntry(const QString & filename) {
+	foreach (QString name, getImageNames()) {
+		if (filename.compare(name) == 0) {
+			QString f = FolderUtils::getApplicationSubFolderPath("parts") + "/svg/core/pcb/" + filename + ".svg";
+			return prepLoadImageAux(f, false);
+			break;
+		}
+	}
+
+	prepLoadImageAux(filename, true);
+}
+
+void Board::prepLoadImage() {
+	QString imagesStr = tr("Images");
+	imagesStr += " (";
+    if (!m_svgOnly) {
+	    QList<QByteArray> supportedImageFormats = QImageReader::supportedImageFormats();
+	    foreach (QByteArray ba, supportedImageFormats) {
+		    imagesStr += "*." + QString(ba) + " ";
+	    }
+    }
+	if (!imagesStr.contains("svg")) {
+		imagesStr += "*.svg";
+	}
+	imagesStr += ")";
+	QString fileName = FolderUtils::getOpenFileName(
+		NULL,
+		tr("Select an image file to load"),
+		"",
+		imagesStr
+	);
+
+	if (fileName.isEmpty()) return;
+
+    if (!checkImage(fileName)) return;
+
+	prepLoadImageAux(fileName, true);
+}
+
+bool Board::checkImage(const QString & filename) {
+    QFile file(filename);
+    
+	QString errorStr;
+	int errorLine;
+	int errorColumn;
+
+	QDomDocument domDocument;
+
+	if (!domDocument.setContent(&file, true, &errorStr, &errorLine, &errorColumn)) {
+		unableToLoad(filename, tr("due to an xml problem: %1 line:%2 column:%3").arg(errorStr).arg(errorLine).arg(errorColumn));
+		return false;
+	}
+
+    QDomElement root = domDocument.documentElement();
+	if (root.tagName() != "svg") {
+		unableToLoad(filename, tr("because the xml is not correctly formatted"));
+		return false;
+	}
+
+    QList<QDomElement> elements;
+    TextUtils::findElementsWithAttribute(root, "id", elements);
+    int layers = 0;
+    int boardLayers = 0;
+    int silk1Layers = 0;
+    bool boardHasChildren = false;
+    foreach (QDomElement element, elements) {
+        QString id = element.attribute("id");
+        ViewLayer::ViewLayerID viewLayerID = ViewLayer::viewLayerIDFromXmlString(id);
+        if (viewLayerID != ViewLayer::UnknownLayer) {
+            layers++;
+            if (viewLayerID == ViewLayer::Board) {
+                boardLayers++;
+                if (element.childNodes().count() > 0) {
+                    boardHasChildren = true;
+                }
+            }
+            if (viewLayerID == ViewLayer::Silkscreen1) {
+                silk1Layers++;
+            }
+        }
+    }
+
+    if (boardLayers == 1 && !boardHasChildren) {
+        unableToLoad(filename, tr("the <board> element contains no shape elements") + StandardCustomBoardExplanation);
+        return false;
+    }
+
+    if ((boardLayers == 1) && (silk1Layers == 1)) return true;
+
+    if (boardLayers > 1) {
+        unableToLoad(filename, tr("because there are multiple <board> layers") + StandardCustomBoardExplanation);
+        return false;
+    }
+
+    if (silk1Layers > 1) {
+        unableToLoad(filename, tr("because there are multiple <silkscreen> layers") + StandardCustomBoardExplanation);
+        return false;
+    }
+
+    if (layers > 0 && boardLayers == 0) {
+        unableToLoad(filename, tr("because there is no <board> layer") + StandardCustomBoardExplanation);
+        return false;
+    }
+
+    if (layers == 0 && root.childNodes().count() == 0) {
+        unableToLoad(filename, tr("the svg contains no shape elements") + StandardCustomBoardExplanation);
+        return false;
+    }
+
+    if (layers == 0 || (boardLayers == 1 && silk1Layers == 0)) {
+        return canLoad(filename, tr("but the pcb itself will have no silkscreen layer") + StandardCustomBoardExplanation);
+    }
+
+    unableToLoad(filename, tr("the svg doesn't fit the custom board format") + StandardCustomBoardExplanation);
+    return false;
+}
+
+void Board::unableToLoad(const QString & fileName, const QString & reason) {
+	QMessageBox::information(
+		NULL,
+		tr("Unable to load"),
+		tr("Unable to load image from %1 %2").arg(fileName).arg(reason)
+	);
+}
+
+bool Board::canLoad(const QString & fileName, const QString & reason) {
+    QMessageBox::StandardButton answer = QMessageBox::question(
+		NULL,
+		tr("Can load, but"),
+		tr("The image from %1 can be loaded, but %2\nUse the file?").arg(fileName).arg(reason),
+		QMessageBox::Yes | QMessageBox::No,
+		QMessageBox::No
+	);
+	return answer == QMessageBox::Yes;
+}
+
+void Board::prepLoadImageAux(const QString & fileName, bool addName)
+{
+	InfoGraphicsView * infoGraphicsView = InfoGraphicsView::getInfoGraphicsView(this);
+	if (infoGraphicsView != NULL) {
+		infoGraphicsView->loadLogoImage(this, "", QSizeF(0,0), "", fileName, addName);
+	}
+}
+
+ViewLayer::ViewIdentifier Board::useViewIdentifierForPixmap(ViewLayer::ViewIdentifier vid, bool) 
+{
+    if (vid == ViewLayer::PCBView) {
+        return ViewLayer::IconView;
+    }
+
+    return ViewLayer::UnknownView;
+}
+
 ///////////////////////////////////////////////////////////
 
-ResizableBoard::ResizableBoard( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+ResizableBoard::ResizableBoard( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
 	: Board(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
 {
 	fixWH();
 
 	m_keepAspectRatio = false;
 	m_widthEditor = m_heightEditor = NULL;
+    m_aspectRatioCheck = NULL;
+    m_aspectRatioLabel = NULL;
+    m_revertButton = NULL;
+    m_paperSizeComboBox = NULL;
 
-	m_silkscreenRenderer = NULL;
 	m_corner = ResizableBoard::NO_CORNER;
 	m_currentScale = 1.0;
 	m_decimalsAfter = 1;
@@ -147,32 +447,29 @@ void ResizableBoard::addedToScene(bool temporary) {
 }
 
 void ResizableBoard::loadTemplates() {
-	if (BoardLayerTemplate.isEmpty()) {
-		QFile file(":/resources/templates/resizableBoard_boardLayerTemplate.txt");
-		file.open(QFile::ReadOnly);
-		BoardLayerTemplate = file.readAll();
-		file.close();
-	}
-	if (SilkscreenLayerTemplate.isEmpty()) {
-		QFile file(":/resources/templates/resizableBoard_silkscreenLayerTemplate.txt");
-		file.open(QFile::ReadOnly);
-		SilkscreenLayerTemplate = file.readAll();
-		file.close();
-	}
+    if (!BoardLayerTemplates.value(moduleID(), "").isEmpty()) return;
+
+    QFile file(m_filename);
+    if (!file.open(QIODevice::ReadOnly)) return;
+
+    QString svg = file.readAll();
+    if (svg.isEmpty()) return;
+
+    BoardLayerTemplates.insert(moduleID(), getShapeForRenderer(svg, ViewLayer::Board));
+    SilkscreenLayerTemplates.insert(moduleID(), getShapeForRenderer(svg, ViewLayer::Silkscreen1));
 }
 
 double ResizableBoard::minWidth() {
-	return 0.5 * FSvgRenderer::printerScale();
+	return 0.5 * GraphicsUtils::SVGDPI;
 }
 
 double ResizableBoard::minHeight() {
-	return 0.5 * FSvgRenderer::printerScale();
+	return 0.5 * GraphicsUtils::SVGDPI;
 }
 
 
 void ResizableBoard::mousePressEvent(QGraphicsSceneMouseEvent * event) 
 {
-
 	m_corner = ResizableBoard::NO_CORNER;
 
 	if (m_spaceBarWasPressed) {
@@ -345,54 +642,56 @@ void ResizableBoard::mouseReleaseEvent(QGraphicsSceneMouseEvent * event) {
 	}
 }
 
-bool ResizableBoard::setUpImage(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec viewLayerSpec, bool doConnectors, LayerAttributes & layerAttributes, QString & error)
+bool ResizableBoard::setUpImage(ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec viewLayerSpec, bool doConnectors, LayerAttributes & layerAttributes, QString & error)
 {
 	bool result = Board::setUpImage(modelPart, viewIdentifier, viewLayers, viewLayerID, viewLayerSpec, doConnectors, layerAttributes, error);
 
 	return result;
 }
 
-ViewIdentifierClass::ViewIdentifier ResizableBoard::theViewIdentifier() {
-	return ViewIdentifierClass::PCBView;
+ViewLayer::ViewIdentifier ResizableBoard::theViewIdentifier() {
+	return ViewLayer::PCBView;
 }
 
 void ResizableBoard::resizePixels(double w, double h, const LayerHash & viewLayers) {
-	resizeMM(GraphicsUtils::pixels2mm(w, FSvgRenderer::printerScale()), GraphicsUtils::pixels2mm(h, FSvgRenderer::printerScale()), viewLayers);
+	resizeMM(GraphicsUtils::pixels2mm(w, GraphicsUtils::SVGDPI), GraphicsUtils::pixels2mm(h, GraphicsUtils::SVGDPI), viewLayers);
 }
 
-void ResizableBoard::resizeMM(double mmW, double mmH, const LayerHash & viewLayers) {
+bool ResizableBoard::resizeMM(double mmW, double mmH, const LayerHash & viewLayers) {
 	if (mmW == 0 || mmH == 0) {
 		QString error;
 		LayerAttributes layerAttributes;
 		setUpImage(modelPart(), m_viewIdentifier, viewLayers, m_viewLayerID, m_viewLayerSpec, true, layerAttributes, error);
-		modelPart()->setProp("height", QVariant());
-		modelPart()->setProp("width", QVariant());
+		modelPart()->setLocalProp("height", QVariant());
+		modelPart()->setLocalProp("width", QVariant());
 		// do the layerkin
-		return;
+		return false;
 	}
 
 	QRectF r = this->boundingRect();
-	if (qAbs(GraphicsUtils::pixels2mm(r.width(), FSvgRenderer::printerScale()) - mmW) < .001 &&
-		qAbs(GraphicsUtils::pixels2mm(r.height(), FSvgRenderer::printerScale()) - mmH) < .001) 
+	if (qAbs(GraphicsUtils::pixels2mm(r.width(), GraphicsUtils::SVGDPI) - mmW) < .001 &&
+		qAbs(GraphicsUtils::pixels2mm(r.height(), GraphicsUtils::SVGDPI) - mmH) < .001) 
 	{
-		return;
+		return false;
 	}
 
 	resizeMMAux(mmW, mmH);
+    return true;
 }
 
 
-void ResizableBoard::resizeMMAux(double mmW, double mmH) {
-
+void ResizableBoard::resizeMMAux(double mmW, double mmH)
+{
 	double milsW = GraphicsUtils::mm2mils(mmW);
 	double milsH = GraphicsUtils::mm2mils(mmH);
 
 	QString s = makeFirstLayerSvg(mmW, mmH, milsW, milsH);
 
-	bool result = loadExtraRenderer(s.toUtf8(), false);
-	if (result) {
-		modelPart()->setProp("width", mmW);
-		modelPart()->setProp("height", mmH);
+    bool result = resetRenderer(s);
+    if (result) {
+
+		modelPart()->setLocalProp("width", mmW);
+		modelPart()->setLocalProp("height", mmH);
 
 		double tens = pow(10.0, m_decimalsAfter);
 		setWidthAndHeight(qRound(mmW * tens) / tens, qRound(mmH * tens) / tens);
@@ -402,59 +701,45 @@ void ResizableBoard::resizeMMAux(double mmW, double mmH) {
 	foreach (ItemBase * itemBase, m_layerKin) {
 		QString s = makeNextLayerSvg(itemBase->viewLayerID(), mmW, mmH, milsW, milsH);
 		if (!s.isEmpty()) {
-			if (m_silkscreenRenderer == NULL) {
-				m_silkscreenRenderer = new FSvgRenderer(itemBase);
-			}
-			itemBase->prepareGeometryChange();
-			bool result = m_silkscreenRenderer->loadSvgString(s);
-			if (result) {
-				qobject_cast<PaletteItemBase *>(itemBase)->setSharedRendererEx(m_silkscreenRenderer);
-				itemBase->modelPart()->setProp("width", mmW);
-				itemBase->modelPart()->setProp("height", mmH);
+            result = itemBase->resetRenderer(s);
+            if (result) {
+				itemBase->modelPart()->setLocalProp("width", mmW);
+				itemBase->modelPart()->setLocalProp("height", mmH);
 			}
 			break;
 		}
 	}
+
 }
 
 void ResizableBoard::loadLayerKin( const LayerHash & viewLayers, ViewLayer::ViewLayerSpec viewLayerSpec) {
 
 	loadTemplates();				
 	Board::loadLayerKin(viewLayers, viewLayerSpec);
-	double w =  m_modelPart->prop("width").toDouble();
+	double w =  m_modelPart->localProp("width").toDouble();
 	if (w != 0) {
-		resizeMM(w, m_modelPart->prop("height").toDouble(), viewLayers);
+		resizeMM(w, m_modelPart->localProp("height").toDouble(), viewLayers);
 	}
 }
 
 void ResizableBoard::setInitialSize() {
-	double w =  m_modelPart->prop("width").toDouble();
+	double w =  m_modelPart->localProp("width").toDouble();
 	if (w == 0) {
 		// set the size so the infoGraphicsView will display the size as you drag
 		QSizeF sz = this->boundingRect().size();
-		modelPart()->setProp("width", GraphicsUtils::pixels2mm(sz.width(), FSvgRenderer::printerScale())); 
-		modelPart()->setProp("height", GraphicsUtils::pixels2mm(sz.height(), FSvgRenderer::printerScale())); 
+		modelPart()->setLocalProp("width", GraphicsUtils::pixels2mm(sz.width(), GraphicsUtils::SVGDPI)); 
+		modelPart()->setLocalProp("height", GraphicsUtils::pixels2mm(sz.height(), GraphicsUtils::SVGDPI)); 
 	}
 }
 
 QString ResizableBoard::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi)
 {
-	double w = m_modelPart->prop("width").toDouble();
+	double w = m_modelPart->localProp("width").toDouble();
 	if (w != 0) {
-		double h = m_modelPart->prop("height").toDouble();
+		double h = m_modelPart->localProp("height").toDouble();
 		QString xml = makeLayerSvg(viewLayerID, w, h, GraphicsUtils::mm2mils(w), GraphicsUtils::mm2mils(h));
 		if (!xml.isEmpty()) {
-			QString xmlName = ViewLayer::viewLayerXmlNameFromID(viewLayerID);
-			SvgFileSplitter splitter;
-			bool result = splitter.splitString(xml, xmlName);
-			if (!result) {
-				return "";
-			}
-			result = splitter.normalize(dpi, xmlName, blackOnly);
-			if (!result) {
-				return "";
-			}
-			return splitter.elementString(xmlName);
+			return PaletteItemBase::normalizeSvg(xml, viewLayerID, blackOnly, dpi);
 		}
 	}
 
@@ -462,8 +747,8 @@ QString ResizableBoard::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QS
 }
 
 QSizeF ResizableBoard::getSizeMM() {
-	double w = m_modelPart->prop("width").toDouble();
-	double h = m_modelPart->prop("height").toDouble();
+	double w = m_modelPart->localProp("width").toDouble();
+	double h = m_modelPart->localProp("height").toDouble();
 	return QSizeF(w, h);
 }
 
@@ -492,22 +777,56 @@ QString ResizableBoard::makeFirstLayerSvg(double mmW, double mmH, double milsW,
 }
 
 QString ResizableBoard::makeBoardSvg(double mmW, double mmH, double milsW, double milsH) {
-	return BoardLayerTemplate
-		.arg(mmW).arg(mmH)			
-		.arg(milsW).arg(milsH)
-		.arg(milsW - LineThickness).arg(milsH - LineThickness);
+    Q_UNUSED(milsW);
+    Q_UNUSED(milsH);
+    return makeSvg(mmW, mmH, BoardLayerTemplates.value(moduleID()));
 }
 
 QString ResizableBoard::makeSilkscreenSvg(double mmW, double mmH, double milsW, double milsH) {
-	return SilkscreenLayerTemplate
-		.arg(mmW).arg(mmH)
-		.arg(milsW).arg(milsH)
-		.arg(milsW - LineThickness).arg(milsH - LineThickness);
+    Q_UNUSED(milsW);
+    Q_UNUSED(milsH);
+    return makeSvg(mmW, mmH, SilkscreenLayerTemplates.value(moduleID()));
+}
+
+QString ResizableBoard::makeSvg(double mmW, double mmH, const QString & layerTemplate)
+{
+    if (layerTemplate.isEmpty()) return "";
+
+    QDomDocument doc;
+    if (!doc.setContent(layerTemplate)) return "";
+
+    QDomElement root = doc.documentElement();
+    QString mmString("%1mm");
+    root.setAttribute("width", mmString.arg(mmW));
+    root.setAttribute("height", mmString.arg(mmH));
+    root.setAttribute("viewBox", QString("0 0 %1 %2").arg(mmW).arg(mmH));
+    QList<QDomElement> leaves;
+    TextUtils::collectLeaves(root, leaves);
+    if (leaves.count() > 1) return "";
+
+    QDomElement leaf = leaves.at(0);
+
+    bool ok;
+    double strokeWidth = leaf.attribute("stroke-width").toDouble(&ok);
+    if (!ok) return "";
+
+    if (layerTemplate.contains("<ellipse")) {
+        leaf.setAttribute("cx", mmW / 2);
+        leaf.setAttribute("cy", mmH / 2);
+        leaf.setAttribute("rx", (mmW - strokeWidth) / 2);
+        leaf.setAttribute("ry", (mmH - strokeWidth) / 2);
+    }
+    else if (layerTemplate.contains("<rect")) {
+        leaf.setAttribute("width", mmW - strokeWidth);
+        leaf.setAttribute("height", mmH - strokeWidth);
+    }
+    
+    return doc.toString();
 }
 
 void ResizableBoard::saveParams() {
-	double w = modelPart()->prop("width").toDouble();
-	double h = modelPart()->prop("height").toDouble();
+	double w = modelPart()->localProp("width").toDouble();
+	double h = modelPart()->localProp("height").toDouble();
 	m_boardSize = QSizeF(w, h);
 	m_boardPos = pos();
 }
@@ -529,7 +848,7 @@ bool ResizableBoard::collectExtraInfo(QWidget * parent, const QString & family,
 
 		returnProp = tr("shape");
 
-		if (!m_modelPart->prop("height").isValid()) { 
+		if (!m_modelPart->localProp("height").isValid()) { 
 			// display uneditable width and height
 			QFrame * frame = new QFrame();
 			frame->setObjectName("infoViewPartFrame");		
@@ -542,12 +861,12 @@ bool ResizableBoard::collectExtraInfo(QWidget * parent, const QString & family,
 
 			double tens = pow(10.0, m_decimalsAfter);
 			QRectF r = this->boundingRect();
-			double w = qRound(GraphicsUtils::pixels2mm(r.width(), FSvgRenderer::printerScale()) * tens) / tens;
+			double w = qRound(GraphicsUtils::pixels2mm(r.width(), GraphicsUtils::SVGDPI) * tens) / tens;
 			QLabel * l1 = new QLabel(tr("width: %1mm").arg(w));	
 			l1->setMargin(0);
 			l1->setObjectName("infoViewLabel");		
 
-			double h = qRound(GraphicsUtils::pixels2mm(r.height(), FSvgRenderer::printerScale()) * tens) / tens;
+			double h = qRound(GraphicsUtils::pixels2mm(r.height(), GraphicsUtils::SVGDPI) * tens) / tens;
 			QLabel * l2 = new QLabel(tr("height: %1mm").arg(h));
 			l2->setMargin(0);
 			l2->setObjectName("infoViewLabel");		
@@ -563,7 +882,8 @@ bool ResizableBoard::collectExtraInfo(QWidget * parent, const QString & family,
 			return true;
 		}
 
-		returnWidget = setUpDimEntry(false, returnWidget);
+		returnWidget = setUpDimEntry(false, false, false, returnWidget);
+        returnWidget->setEnabled(swappingEnabled);
 		return true;
 	}
 
@@ -571,16 +891,19 @@ bool ResizableBoard::collectExtraInfo(QWidget * parent, const QString & family,
 }
 
 QStringList ResizableBoard::collectValues(const QString & family, const QString & prop, QString & value) {
-	QStringList result = Board::collectValues(family, prop, value);
+	return Board::collectValues(family, prop, value);
+}
 
-	if (prop.compare("shape", Qt::CaseInsensitive) == 0) {
-		if (customShapeTranslated.isEmpty()) {
-			customShapeTranslated = tr("Import Shape...");
-		}
-		result.append(customShapeTranslated);
+void ResizableBoard::paperSizeChanged(int index) {
+    QComboBox * comboBox = qobject_cast<QComboBox *>(sender());
+    if (comboBox == NULL) return;
+
+    QModelIndex modelIndex = comboBox->model()->index(index,0);  
+    QSizeF size = comboBox->model()->data(modelIndex, Qt::UserRole).toSizeF();
+	InfoGraphicsView * infoGraphicsView = InfoGraphicsView::getInfoGraphicsView(this);
+	if (infoGraphicsView != NULL) {
+		infoGraphicsView->resizeBoard(size.width(), size.height(), true);
 	}
-
-	return result;
 }
 
 void ResizableBoard::widthEntry() {
@@ -588,10 +911,10 @@ void ResizableBoard::widthEntry() {
 	if (edit == NULL) return;
 
 	double w = edit->text().toDouble();
-	double oldW = m_modelPart->prop("width").toDouble();
+	double oldW = m_modelPart->localProp("width").toDouble();
 	if (w == oldW) return;
 
-	double h =  m_modelPart->prop("height").toDouble();
+	double h =  m_modelPart->localProp("height").toDouble();
 
 	InfoGraphicsView * infoGraphicsView = InfoGraphicsView::getInfoGraphicsView(this);
 	if (infoGraphicsView != NULL) {
@@ -604,10 +927,10 @@ void ResizableBoard::heightEntry() {
 	if (edit == NULL) return;
 
 	double h = edit->text().toDouble();
-	double oldH =  m_modelPart->prop("height").toDouble();
+	double oldH =  m_modelPart->localProp("height").toDouble();
 	if (h == oldH) return;
 
-	double w =  m_modelPart->prop("width").toDouble();
+	double w =  m_modelPart->localProp("width").toDouble();
 
 	InfoGraphicsView * infoGraphicsView = InfoGraphicsView::getInfoGraphicsView(this);
 	if (infoGraphicsView != NULL) {
@@ -767,11 +1090,11 @@ void ResizableBoard::setKinCursor(Qt::CursorShape cursor) {
 	}
 }
 
-QFrame * ResizableBoard::setUpDimEntry(bool includeProportion, QWidget * & returnWidget)
+QFrame * ResizableBoard::setUpDimEntry(bool includeAspectRatio, bool includeRevert, bool includePaperSizes, QWidget * & returnWidget)
 {
 	double tens = pow(10.0, m_decimalsAfter);
-	double w = qRound(m_modelPart->prop("width").toDouble() * tens) / tens;	// truncate to 1 decimal point
-	double h = qRound(m_modelPart->prop("height").toDouble() * tens) / tens;  // truncate to 1 decimal point
+	double w = qRound(m_modelPart->localProp("width").toDouble() * tens) / tens;	// truncate to 1 decimal point
+	double h = qRound(m_modelPart->localProp("height").toDouble() * tens) / tens;  // truncate to 1 decimal point
 
 	QFrame * frame = new QFrame();
 	frame->setObjectName("infoViewPartFrame");
@@ -834,25 +1157,68 @@ QFrame * ResizableBoard::setUpDimEntry(bool includeProportion, QWidget * & retur
 	vboxLayout->addWidget(subframe1);
 	vboxLayout->addWidget(subframe2);
 
-	if (includeProportion) {
+	if (includeAspectRatio || includeRevert || includePaperSizes) {
 		QFrame * subframe3 = new QFrame();
 		QHBoxLayout * hboxLayout3 = new QHBoxLayout();
 		hboxLayout3->setAlignment(Qt::AlignLeft);
 		hboxLayout3->setContentsMargins(0, 0, 0, 0);
 		hboxLayout3->setSpacing(0);
 	
-		QLabel * l3 = new QLabel(tr("keep in proportion"));
-		l3->setMargin(0);
-		l3->setObjectName("infoViewLabel");
-		QCheckBox * checkBox = new QCheckBox();
-		checkBox->setChecked(m_keepAspectRatio);
-		checkBox->setObjectName("infoViewCheckBox");
+		if (includeAspectRatio) {
+			QLabel * l3 = new QLabel(tr("keep aspect ratio"));
+			l3->setMargin(0);
+			l3->setObjectName("infoViewLabel");
+			QCheckBox * checkBox = new QCheckBox();
+			checkBox->setChecked(m_keepAspectRatio);
+			checkBox->setObjectName("infoViewCheckBox");
+
+			hboxLayout3->addWidget(l3);
+			hboxLayout3->addWidget(checkBox);
+			connect(checkBox, SIGNAL(toggled(bool)), this, SLOT(keepAspectRatio(bool)));
+			m_aspectRatioCheck = checkBox;
+			m_aspectRatioLabel = l3;
+	    }
+	    if (includeRevert) {
+			QPushButton * pb = new QPushButton(tr("Revert"));
+			pb->setObjectName("infoViewButton");
+			hboxLayout3->addWidget(pb);
+			connect(pb, SIGNAL(clicked(bool)), this, SLOT(revertSize(bool)));
+			double w = modelPart()->localProp("width").toDouble();
+			double ow = modelPart()->localProp("originalWidth").toDouble();
+			double h = modelPart()->localProp("height").toDouble();
+			double oh = modelPart()->localProp("originalHeight").toDouble();
+			pb->setEnabled(qAbs(w - ow) > JND || qAbs(h - oh) > JND);
+			m_revertButton = pb;
+	    }
+        if (includePaperSizes) {
+            initPaperSizes();
+
+			QLabel * l3 = new QLabel(tr("size"));
+			l3->setMargin(0);
+			l3->setObjectName("infoViewLabel");
+
+            m_paperSizeComboBox = new QComboBox();
+	        m_paperSizeComboBox->setObjectName("infoViewComboBox");
+	        m_paperSizeComboBox->setEditable(false);
+            m_paperSizeComboBox->setMinimumWidth(150);
+            m_paperSizeComboBox->addItem(tr("custom"));
+            for (int i = 0; i < PaperSizeNames.count(); i++) {
+                QSizeF dim = PaperSizeDimensions.at(i);
+                m_paperSizeComboBox->addItem(PaperSizeNames.at(i), dim);
+            }
+
+            QModelIndex modelIndex = m_paperSizeComboBox->model()->index(0,0);  
+            m_paperSizeComboBox->model()->setData(modelIndex, 0, Qt::UserRole - 1);           // to make it selectable again use Qt::ItemIsSelectable | Qt::ItemIsEnabled)
+
+            updatePaperSizes(w, h);
+            connect(m_paperSizeComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(paperSizeChanged(int)));
+
+            hboxLayout3->addWidget(l3);
+            hboxLayout3->addWidget(m_paperSizeComboBox);
+
+        }
 
-		hboxLayout3->addWidget(l3);
-		hboxLayout3->addWidget(checkBox);
 		subframe3->setLayout(hboxLayout3);
-		connect(checkBox, SIGNAL(toggled(bool)), this, SLOT(keepAspectRatio(bool)));
-		m_aspectRatioCheck = checkBox;
 
 		vboxLayout->addWidget(subframe3);
 	}
@@ -864,8 +1230,8 @@ QFrame * ResizableBoard::setUpDimEntry(bool includeProportion, QWidget * & retur
 
 void ResizableBoard::fixWH() {
 	bool okw, okh;
-	QString wstr = m_modelPart->prop("width").toString();
-	QString hstr = m_modelPart->prop("height").toString();
+	QString wstr = m_modelPart->localProp("width").toString();
+	QString hstr = m_modelPart->localProp("height").toString();
 	double w = wstr.toDouble(&okw);
 	double h = hstr.toDouble(&okh);
 
@@ -877,8 +1243,8 @@ void ResizableBoard::fixWH() {
 		DebugDialog::debug("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!");
 		DebugDialog::debug("bad width or height in ResizableBoard or subclass " + wstr + " " + hstr);
 		DebugDialog::debug("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!");
-		m_modelPart->setProp("width", "");
-		m_modelPart->setProp("height", "");
+		m_modelPart->setLocalProp("width", "");
+		m_modelPart->setLocalProp("height", "");
 	}
 }
 
@@ -890,4 +1256,75 @@ void ResizableBoard::setWidthAndHeight(double w, double h)
 	if (m_heightEditor) {
 		m_heightEditor->setText(QString::number(h));
 	}
+    updatePaperSizes(w, h);
 }
+
+QString ResizableBoard::getShapeForRenderer(const QString & svg, ViewLayer::ViewLayerID viewLayerID) 
+{
+    QString xmlName = ViewLayer::viewLayerXmlNameFromID(viewLayerID);
+	SvgFileSplitter splitter;
+    QString xml = svg;
+	bool result = splitter.splitString(xml, xmlName);
+	if (result) {
+        xml = splitter.elementString(xmlName);
+    }
+    else {
+		xml = "";
+	}
+
+    QString header("<?xml version='1.0' encoding='UTF-8'?>\n"
+                    "<svg ");
+    QDomNamedNodeMap map = splitter.domDocument().documentElement().attributes();
+    for (int i = 0; i < map.count(); i++) {
+        QDomNode node = map.item(i);
+        header += node.nodeName() + "='" + node.nodeValue() + "' ";
+    }
+    header += ">\n";
+
+    header = header + xml + "\n</svg>";
+    //DebugDialog::debug(header);
+	return header;
+}
+
+void ResizableBoard::keepAspectRatio(bool checkState) {
+	m_keepAspectRatio = checkState;
+}
+
+void ResizableBoard::revertSize(bool) {
+    double ow = modelPart()->localProp("originalWidth").toDouble();
+    double oh = modelPart()->localProp("originalHeight").toDouble();
+
+    InfoGraphicsView * infoGraphicsView = InfoGraphicsView::getInfoGraphicsView(this);
+	if (infoGraphicsView != NULL) {
+		infoGraphicsView->resizeBoard(ow, oh, true);
+        m_revertButton->setEnabled(false);
+	}
+}
+
+void ResizableBoard::updatePaperSizes(double w, double h) {
+    if (m_paperSizeComboBox ==  NULL) return;
+
+    int currentIndex = 0;
+    for (int i = 0; i < PaperSizeNames.count(); i++) {
+        QSizeF dim = PaperSizeDimensions.at(i);
+        if (qAbs(w - dim.width()) < 0.1 && qAbs(h - dim.height()) < 0.1) {
+            currentIndex = i + 1;
+        }
+    }
+
+    QString custom = tr("custom");
+    if (currentIndex == 0) {
+        custom =  QString("%1x%2").arg(w).arg(h);
+    }
+    m_paperSizeComboBox->setItemText(0, custom);
+    m_paperSizeComboBox->setCurrentIndex(currentIndex);
+}
+
+void ResizableBoard::initPaperSizes() {
+    if (PaperSizeNames.count() == 0) {
+        PaperSizeNames << tr("A0 (1030x1456)") << tr("A1 (728x1030)") << tr("A2 (515x728)") << tr("A3 (364x515)") << tr("A4 (257x364)") << tr("A5 (182x257)") << tr("A6 (128x182)") 
+            << tr("Letter (8.5x11)") << tr("Legal (8.5x14)") << tr("Ledger (17x11)") << tr("Tabloid (11x17");
+        PaperSizeDimensions << QSizeF(1030,1456) << QSizeF(728,1030) << QSizeF(515,728) << QSizeF(364,515) << QSizeF(257,364) << QSizeF(182,257) << QSizeF(128,182) 
+            << QSizeF(215.9,279.4) << QSizeF(215.9,355.6) << QSizeF(432,279) << QSizeF(279,432);
+    }
+}
\ No newline at end of file
