@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5949 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-07 19:16:07 +0200 (Sat, 07 Apr 2012) $
+$Revision: 6509 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-04 07:19:37 +0200 (Thu, 04 Oct 2012) $
 
 ********************************************************************/
 
@@ -33,7 +33,10 @@ $Date: 2012-04-07 19:16:07 +0200 (Sat, 07 Apr 2012) $
 #include <QVariant>
 #include <QLineEdit>
 #include <QCursor>
+#include <QLabel>
 #include <QCheckBox>
+#include <QComboBox>
+#include <QPushButton>
 
 #include "paletteitem.h"
 
@@ -43,7 +46,7 @@ class Board : public PaletteItem
 
 public:
 	// after calling this constructor if you want to render the loaded svg (either from model or from file), MUST call <renderImage>
-	Board(ModelPart *, ViewIdentifierClass::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
+	Board(ModelPart *, ViewLayer::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
 	~Board();
 
 	QStringList collectValues(const QString & family, const QString & prop, QString & value);
@@ -52,10 +55,38 @@ public:
 	bool stickyEnabled();
 	PluralType isPlural();
 	bool canFindConnectorsUnder();
+	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget);
+
+protected:
+    void setupLoadImage(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget);
+	void setFileNameItems();
+	virtual QStringList & getImageNames();
+	virtual QStringList & getNewImageNames();
+    virtual bool checkImage(const QString & filename);
+	void unableToLoad(const QString & fileName, const QString & reason);
+	bool canLoad(const QString & fileName, const QString & reason);
+	virtual void prepLoadImageAux(const QString & fileName, bool addName);
+    ViewLayer::ViewIdentifier useViewIdentifierForPixmap(ViewLayer::ViewIdentifier, bool swappingEnabled);
 
 public:
-	static QString oneLayerTranslated;
-	static QString twoLayersTranslated;
+	static QString OneLayerTranslated;
+	static QString TwoLayersTranslated;
+
+public:
+    static bool isBoard(ItemBase *);
+    static bool isBoard(ModelPart *);
+
+protected slots:
+	void prepLoadImage();
+	void fileNameEntry(const QString & filename);
+
+protected:
+    QPointer<QComboBox> m_fileNameComboBox;
+    bool m_svgOnly;
+
+protected:
+    static QStringList BoardImageNames;
+    static QStringList NewBoardImageNames;
 };
 
 class ResizableBoard : public Board 
@@ -64,11 +95,11 @@ class ResizableBoard : public Board
 
 public:
 	// after calling this constructor if you want to render the loaded svg (either from model or from file), MUST call <renderImage>
-	ResizableBoard(ModelPart *, ViewIdentifierClass::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
+	ResizableBoard(ModelPart *, ViewLayer::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
 	~ResizableBoard();
 
-	bool setUpImage(ModelPart* modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID, ViewLayer::ViewLayerSpec, bool doConnectors, LayerAttributes &, QString & error);
-	virtual void resizeMM(double w, double h, const LayerHash & viewLayers);
+	bool setUpImage(ModelPart* modelPart, ViewLayer::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID, ViewLayer::ViewLayerSpec, bool doConnectors, LayerAttributes &, QString & error);
+	virtual bool resizeMM(double w, double h, const LayerHash & viewLayers);
 	void resizePixels(double w, double h, const LayerHash & viewLayers);
  	void loadLayerKin(const LayerHash & viewLayers, ViewLayer::ViewLayerSpec);
 	virtual void setInitialSize();
@@ -83,12 +114,12 @@ public:
 	void paintSelected(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
 	bool inResize();
 
-public:
-	static QString customShapeTranslated;
-
 public slots:
-	void widthEntry();
-	void heightEntry();
+	virtual void widthEntry();
+	virtual void heightEntry();
+	void keepAspectRatio(bool checkState);
+	void revertSize(bool);
+    virtual void paperSizeChanged(int);
 
 protected:
 	enum Corner {
@@ -108,11 +139,12 @@ protected:
 	void hoverMoveEvent(QGraphicsSceneHoverEvent * event );
 	QString makeBoardSvg(double mmW, double mmH, double milsW, double milsH);
 	QString makeSilkscreenSvg(double mmW, double mmH, double milsW, double milsH);
+    QString makeSvg(double mmW, double mmH, const QString & layerTemplate);
 	QStringList collectValues(const QString & family, const QString & prop, QString & value);
 	virtual void loadTemplates();
 	virtual double minWidth();
 	virtual double minHeight();
-	virtual ViewIdentifierClass::ViewIdentifier theViewIdentifier();
+	virtual ViewLayer::ViewIdentifier theViewIdentifier();
 	virtual QString makeLayerSvg(ViewLayer::ViewLayerID viewLayerID, double mmW, double mmH, double milsW, double milsH);
 	virtual QString makeFirstLayerSvg(double mmW, double mmH, double milsW, double milsH);
 	virtual QString makeNextLayerSvg(ViewLayer::ViewLayerID, double mmW, double mmH, double milsW, double milsH);
@@ -120,15 +152,17 @@ protected:
 	virtual ResizableBoard::Corner findCorner(QPointF p, Qt::KeyboardModifiers);
 	void setKinCursor(QCursor &);
 	void setKinCursor(Qt::CursorShape);
-	QFrame * setUpDimEntry(bool includeProportion, QWidget * & returnWidget);
+	QFrame * setUpDimEntry(bool includeAspectRatio, bool includeRevert, bool includePaperSizes, QWidget * & returnWidget);
 	void fixWH();
 	void setWidthAndHeight(double w, double h);
+    QString getShapeForRenderer(const QString & svg, ViewLayer::ViewLayerID viewLayerID);
+    void initPaperSizes();
+    void updatePaperSizes(double width, double height);
 
 protected:
 	static const double CornerHandleSize;
 
 	Corner m_corner;
-	class FSvgRenderer * m_silkscreenRenderer;
 	QSizeF m_boardSize;
 	QPointF m_boardPos;
 	QPointer<QLineEdit> m_widthEditor;
@@ -137,6 +171,9 @@ protected:
 	QSizeF m_aspectRatio;
 	double m_currentScale;
 	QPointer<QCheckBox> m_aspectRatioCheck;
+    QPointer<QLabel> m_aspectRatioLabel;
+    QPointer<QPushButton> m_revertButton;
+    QPointer<QComboBox> m_paperSizeComboBox;
 
 	QPointF m_resizeMousePos;
 	QSizeF m_resizeStartSize;
@@ -146,6 +183,7 @@ protected:
 	QPointF m_resizeStartTopRight;
 	QPointF m_resizeStartBottomLeft;
 	int m_decimalsAfter;
+
 };
 
 #endif
