@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5857 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-02-12 18:16:07 +0100 (Sun, 12 Feb 2012) $
+$Revision: 6505 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-03 10:14:52 +0200 (Wed, 03 Oct 2012) $
 
 ********************************************************************/
 
@@ -46,18 +46,18 @@ static const int IndexIn = 1;
 
 static QString DefaultWidth = "";
 
-Ruler::Ruler( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+Ruler::Ruler( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
 	: PaletteItem(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
 {
 	m_widthEditor = NULL;
 	m_unitsEditor = NULL;
 	m_widthValidator = NULL;
-	QString w = modelPart->prop("width").toString();
+	QString w = modelPart->localProp("width").toString();
 	if (w.isEmpty()) {
 		if (DefaultWidth.isEmpty()) {
 			DefaultWidth = modelPart->properties().value("width", "10cm");
 		}
-		m_modelPart->setProp("width", DefaultWidth);
+		m_modelPart->setLocalProp("width", DefaultWidth);
 	}
 }
 
@@ -77,9 +77,9 @@ void Ruler::resizeMM(double magnitude, double unitsFlag, const LayerHash & viewL
 
 	QString s = makeSvg(newW);
 
-	bool result = loadExtraRenderer(s.toUtf8(), false);
+	bool result = resetRenderer(s);
 	if (result) {
-        modelPart()->setProp("width", QVariant(QString::number(magnitude) + units));
+        modelPart()->setLocalProp("width", QVariant(QString::number(magnitude) + units));
 	}
 	//	DebugDialog::debug(QString("fast load result %1 %2").arg(result).arg(s));
 
@@ -87,7 +87,7 @@ void Ruler::resizeMM(double magnitude, double unitsFlag, const LayerHash & viewL
 
 QString Ruler::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi) 
 {
-	double w = TextUtils::convertToInches(m_modelPart->prop("width").toString());
+	double w = TextUtils::convertToInches(m_modelPart->localProp("width").toString());
 	if (w != 0) {
 		QString xml;
 		switch (viewLayerID) {
@@ -101,17 +101,7 @@ QString Ruler::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QS
 		}
 
 		if (!xml.isEmpty()) {
-			QString xmlName = ViewLayer::viewLayerXmlNameFromID(viewLayerID);
-			SvgFileSplitter splitter;
-			bool result = splitter.splitString(xml, xmlName);
-			if (!result) {
-				return "";
-			}
-			result = splitter.normalize(dpi, xmlName, blackOnly);
-			if (!result) {
-				return "";
-			}
-			return splitter.elementString(xmlName);
+			 return PaletteItemBase::normalizeSvg(xml, viewLayerID, blackOnly, dpi);
 		}
 	}
 
@@ -122,7 +112,7 @@ QString Ruler::makeSvg(double inches) {
 	double cm = 1 / 2.54;
 	double offset = 0.125;
 	double mmW = inches * 25.4;
-	QString svg = TextUtils::makeSVGHeader(FSvgRenderer::printerScale(), GraphicsUtils::StandardFritzingDPI, (inches + offset + offset) * FSvgRenderer::printerScale(), FSvgRenderer::printerScale());
+	QString svg = TextUtils::makeSVGHeader(GraphicsUtils::SVGDPI, GraphicsUtils::StandardFritzingDPI, (inches + offset + offset) * GraphicsUtils::SVGDPI, GraphicsUtils::SVGDPI);
 	svg += "<g font-family='DroidSans' text-anchor='middle' font-size='100' stroke-width='1px' stroke='black'>";
 	int counter = 0;
 	for (int i = 0; i <= qCeil(mmW); i++) {
@@ -187,6 +177,10 @@ QString Ruler::makeSvg(double inches) {
 		}
 	}
 
+    svg += QString("<line x1='%1' y1='%2' x2='%3' y2='%2' stroke-width='1px' stroke='black' />\n")
+        .arg(offset * GraphicsUtils::StandardFritzingDPI)
+        .arg((GraphicsUtils::StandardFritzingDPI / 2) - 40)
+        .arg((inches + offset) * GraphicsUtils::StandardFritzingDPI);
 	svg += "<g font-size='40'>\n";
 	svg += QString("<text x='%1' y='%2'>1/10</text>").arg((GraphicsUtils::StandardFritzingDPI * offset / 2.0) + 7).arg(780);
 	svg += QString("<text x='%1' y='%2'>1/16</text>").arg((GraphicsUtils::StandardFritzingDPI * offset / 2.0) + 7).arg(990);
@@ -199,9 +193,9 @@ QString Ruler::makeSvg(double inches) {
 
 bool Ruler::hasCustomSVG() {
 	switch (m_viewIdentifier) {
-		case ViewIdentifierClass::PCBView:
-		case ViewIdentifierClass::SchematicView:
-		case ViewIdentifierClass::BreadboardView:
+		case ViewLayer::PCBView:
+		case ViewLayer::SchematicView:
+		case ViewLayer::BreadboardView:
 			return true;
 		default:
 			return ItemBase::hasCustomSVG();
@@ -215,17 +209,18 @@ bool Ruler::collectExtraInfo(QWidget * parent, const QString & family, const QSt
 	if (prop.compare("width", Qt::CaseInsensitive) == 0) {
 		returnProp = tr("width");
 
-		int units = m_modelPart->prop("width").toString().contains("cm") ? IndexCm : IndexIn;
+		int units = m_modelPart->localProp("width").toString().contains("cm") ? IndexCm : IndexIn;
 		QLineEdit * e1 = new QLineEdit();
 		QDoubleValidator * validator = new QDoubleValidator(e1);
 		validator->setRange(1.0, 20 * ((units == IndexCm) ? 2.54 : 1), 2);
 		validator->setNotation(QDoubleValidator::StandardNotation);
 		e1->setValidator(validator);
 		e1->setEnabled(swappingEnabled);
-		QString temp = m_modelPart->prop("width").toString();
+		QString temp = m_modelPart->localProp("width").toString();
 		temp.chop(2);
 		e1->setText(temp);
-		e1->setObjectName("infoViewLineEdit");		
+		e1->setObjectName("infoViewLineEdit");	
+        e1->setMaximumWidth(80);
 
 		m_widthEditor = e1;
 		m_widthValidator = validator;
@@ -237,7 +232,8 @@ bool Ruler::collectExtraInfo(QWidget * parent, const QString & family, const QSt
 		comboBox->addItem("in");
 		comboBox->setCurrentIndex(units);
 		m_unitsEditor = comboBox;
-		comboBox->setObjectName("infoViewComboBox");		
+		comboBox->setObjectName("infoViewComboBox");	
+        comboBox->setMinimumWidth(60);
 
 
 		QHBoxLayout * hboxLayout = new QHBoxLayout();
@@ -288,12 +284,12 @@ void Ruler::widthEntry() {
 void Ruler::unitsEntry(const QString & units) {
 	double inches = TextUtils::convertToInches(prop("width"));
 	if (units == "in") {
-        modelPart()->setProp("width", QVariant(QString::number(inches) + "in"));
+        modelPart()->setLocalProp("width", QVariant(QString::number(inches) + "in"));
 		m_widthEditor->setText(QString::number(inches));
 		m_widthValidator->setTop(20);
 	}
 	else {
-        modelPart()->setProp("width", QVariant(QString::number(inches * 2.54) + "cm"));
+        modelPart()->setLocalProp("width", QVariant(QString::number(inches * 2.54) + "cm"));
 		m_widthEditor->setText(QString::number(inches * 2.54));
 		m_widthValidator->setTop(20 * 2.54);
 	}
@@ -318,7 +314,7 @@ void Ruler::addedToScene(bool temporary)
 	if (this->scene()) {
 		LayerHash viewLayers;
 		QString w = prop("width");
-		modelPart()->setProp("width", "");							// makes sure resizeMM will do the work
+		modelPart()->setLocalProp("width", "");							// makes sure resizeMM will do the work
 		double inches = TextUtils::convertToInches(w);
 		if (w.endsWith("cm")) {
 			resizeMM(inches * 2.54, IndexCm, viewLayers);
@@ -339,3 +335,8 @@ bool Ruler::hasPartNumberProperty()
 bool Ruler::canFindConnectorsUnder() {
 	return false;
 }
+
+ViewLayer::ViewIdentifier Ruler::useViewIdentifierForPixmap(ViewLayer::ViewIdentifier, bool) 
+{
+    return ViewLayer::IconView;
+}
