@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5836 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-02-04 11:42:07 +0100 (Sat, 04 Feb 2012) $
+$Revision: 6509 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-04 07:19:37 +0200 (Thu, 04 Oct 2012) $
 
 ********************************************************************/
 
@@ -65,7 +65,7 @@ static double FontSize = 11;
 QHash<QString, QString> FrameProps;
 static const QString DisplayFormat("dd MMM yyyy hh:mm:ss");
 
-SchematicFrame::SchematicFrame( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+SchematicFrame::SchematicFrame( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
 	: ResizableBoard(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
 {
 	if (FrameProps.count() == 0) {
@@ -78,18 +78,18 @@ SchematicFrame::SchematicFrame( ModelPart * modelPart, ViewIdentifierClass::View
 	}
 
 	foreach (QString prop, FrameProps.keys()) {
-		if (modelPart->prop(prop).toString().isEmpty()) {
-			modelPart->setProp(prop, modelPart->properties().value(prop));
+		if (modelPart->localProp(prop).toString().isEmpty()) {
+			modelPart->setLocalProp(prop, modelPart->properties().value(prop));
 		}
 	}
 
-	if (modelPart->prop("date").toString().isEmpty()) {
+	if (modelPart->localProp("date").toString().isEmpty()) {
 		QDateTime dt = QDateTime::currentDateTime();
-		modelPart->setProp("date", QString::number(dt.toTime_t()));
+		modelPart->setLocalProp("date", QString::number(dt.toTime_t()));
 	}
 
-	if (modelPart->prop("sheet").toString().isEmpty()) {
-		modelPart->setProp("sheet","1/1");
+	if (modelPart->localProp("sheet").toString().isEmpty()) {
+		modelPart->setLocalProp("sheet","1/1");
 	}
 
 	m_wrapInitialized = false;
@@ -160,7 +160,7 @@ QString SchematicFrame::makeLayerSvg(ViewLayer::ViewLayerID viewLayerID, double
 		font.setWeight(QFont::Normal);
 		font.setPointSizeF(72.0 * FontSize / GraphicsUtils::StandardFritzingDPI);
 		m_textEdit->setFont(font);
-		m_textEdit->setLineWrapColumnOrWidth(FSvgRenderer::printerScale() * (OriginalWidth - Margin) / GraphicsUtils::StandardFritzingDPI);  
+		m_textEdit->setLineWrapColumnOrWidth(GraphicsUtils::SVGDPI * (OriginalWidth - Margin) / GraphicsUtils::StandardFritzingDPI);  
 	}
 
 
@@ -196,7 +196,7 @@ QString SchematicFrame::makeLayerSvg(ViewLayer::ViewLayerID viewLayerID, double
 
 
 	QDateTime dt;
-	dt.setTime_t(modelPart()->prop("date").toUInt());
+	dt.setTime_t(modelPart()->localProp("date").toUInt());
 	hash.insert("date", dt.toString(DisplayFormat));
 
 	return TextUtils::convertExtendedChars(TextUtils::replaceTextElements(svg, hash));
@@ -217,16 +217,16 @@ QString SchematicFrame::makeFirstLayerSvg(double mmW, double mmH, double milsW,
 	return makeLayerSvg(ViewLayer::SchematicFrame, mmW, mmH, milsW, milsH);
 }
 
-ViewIdentifierClass::ViewIdentifier SchematicFrame::theViewIdentifier() {
-	return ViewIdentifierClass::SchematicView;
+ViewLayer::ViewIdentifier SchematicFrame::theViewIdentifier() {
+	return ViewLayer::SchematicView;
 }
 
 double SchematicFrame::minWidth() {
-	return OriginalWidth * FSvgRenderer::printerScale() / GraphicsUtils::StandardFritzingDPI;
+	return OriginalWidth * GraphicsUtils::SVGDPI / GraphicsUtils::StandardFritzingDPI;
 }
 
 double SchematicFrame::minHeight() {
-	return OriginalHeight * FSvgRenderer::printerScale() / GraphicsUtils::StandardFritzingDPI;
+	return OriginalHeight * GraphicsUtils::SVGDPI / GraphicsUtils::StandardFritzingDPI;
 }
 
 void SchematicFrame::addedToScene(bool temporary)
@@ -234,11 +234,11 @@ void SchematicFrame::addedToScene(bool temporary)
 	if (prop("filename").isEmpty()) {
 		InfoGraphicsView * infoGraphicsView = InfoGraphicsView::getInfoGraphicsView(this);
 		if (infoGraphicsView != NULL) {
-			modelPart()->setProp("filename", infoGraphicsView->filenameIf());
+			modelPart()->setLocalProp("filename", infoGraphicsView->filenameIf());
 		}
 	}
     ResizableBoard::addedToScene(temporary);
-	resizeMMAux(m_modelPart->prop("width").toDouble(), m_modelPart->prop("height").toDouble());
+	resizeMMAux(m_modelPart->localProp("width").toDouble(), m_modelPart->localProp("height").toDouble());
 }
 
 QString SchematicFrame::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi)
@@ -270,7 +270,14 @@ bool SchematicFrame::makeLineEdit(QWidget * parent, const QString & family, cons
 
 bool SchematicFrame::collectExtraInfo(QWidget * parent, const QString & family, const QString & propp, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget) 
 {
-	if (propp.compare("date", Qt::CaseInsensitive) == 0) {
+	if (propp.compare("shape", Qt::CaseInsensitive) == 0) {
+		returnWidget = setUpDimEntry(false, false, true, returnWidget);
+        returnWidget->setEnabled(swappingEnabled);
+		returnProp = tr("shape");
+		return true;
+	}
+
+    if (propp.compare("date", Qt::CaseInsensitive) == 0) {
 		QDateTimeEdit * dateTimeEdit = new QDateTimeEdit(QDateTime::currentDateTime(), parent);
 		QString d = prop("date");
 		if (!d.isEmpty()) {
@@ -349,8 +356,8 @@ void SchematicFrame::setProp(const QString & prop, const QString & value)
 	ResizableBoard::setProp(prop, value);
 
 	if (FrameProps.keys().contains(prop)) {
-		modelPart()->setProp(prop, value);
-		resizeMMAux(modelPart()->prop("width").toDouble(), modelPart()->prop("height").toDouble());
+		modelPart()->setLocalProp(prop, value);
+		resizeMMAux(modelPart()->localProp("width").toDouble(), modelPart()->localProp("height").toDouble());
 	}
 
 }
@@ -385,11 +392,11 @@ bool SchematicFrame::hasPartNumberProperty()
 }
 
 void SchematicFrame::setInitialSize() {
-	double w = m_modelPart->prop("width").toDouble();
+	double w = m_modelPart->localProp("width").toDouble();
 	if (w == 0) {
 		// set the size so the infoGraphicsView will display the size as you drag
-		modelPart()->setProp("width", 25.4 * OriginalWidth / GraphicsUtils::StandardFritzingDPI); 
-		modelPart()->setProp("height", 25.4 * OriginalHeight / GraphicsUtils::StandardFritzingDPI); 
+		modelPart()->setLocalProp("width", 25.4 * OriginalWidth / GraphicsUtils::StandardFritzingDPI); 
+		modelPart()->setLocalProp("height", 25.4 * OriginalHeight / GraphicsUtils::StandardFritzingDPI); 
 	}
 }
 
@@ -438,3 +445,12 @@ void SchematicFrame::sheetEntry(int value) {
 		infoGraphicsView->setProp(this, "sheet", tr("sheet"), prop("sheet"), strings.at(0) + "/" + strings[1], true);
 	}
 }
+
+ViewLayer::ViewIdentifier SchematicFrame::useViewIdentifierForPixmap(ViewLayer::ViewIdentifier vid, bool) 
+{
+    if (vid == ViewLayer::SchematicView) {
+        return ViewLayer::IconView;
+    }
+
+    return ViewLayer::UnknownView;
+}
