@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5653 $:
+$Revision: 6422 $:
 $Author: cohen@irascible.com $:
-$Date: 2011-12-01 17:19:24 +0100 (Thu, 01 Dec 2011) $
+$Date: 2012-09-15 07:44:26 +0200 (Sat, 15 Sep 2012) $
 
 ********************************************************************/
 
@@ -34,6 +34,7 @@ $Date: 2011-12-01 17:19:24 +0100 (Thu, 01 Dec 2011) $
 #include "../connectors/connectoritem.h"
 #include "../connectors/busshared.h"
 #include "../connectors/connectorshared.h"
+#include "../debugdialog.h"
 
 #include <QCursor>
 #include <QBitmap>
@@ -50,10 +51,12 @@ $Date: 2011-12-01 17:19:24 +0100 (Thu, 01 Dec 2011) $
 static QCursor * SpotFaceCutterCursor = NULL;
 static QCursor * MagicWandCursor = NULL;
 
-static bool ShiftDown;
+static bool ShiftDown = false;
 static QPointF OriginalShiftPos;
+static bool ShiftX = false;
+static bool ShiftY = false;
 static bool SpaceBarWasPressed = false;
-
+static const double MinMouseMove = 2;
 
 /////////////////////////////////////////////////////////////////////
 
@@ -133,8 +136,8 @@ void Stripbit::mousePressEvent(QGraphicsSceneMouseEvent *event)
 	}
 
 	if (event->modifiers() & Qt::ShiftModifier) {
-		DebugDialog::debug("got shift down");
 		ShiftDown = true;
+        ShiftX = ShiftY = false;
 		OriginalShiftPos = event->scenePos();
 	}
 
@@ -168,19 +171,30 @@ void Stripbit::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 	Stripbit * other = NULL;
 	QPointF p = event->scenePos();
 	if (ShiftDown) {
-		if (qAbs(p.x() - OriginalShiftPos.x()) >= qAbs(p.y() - OriginalShiftPos.y())) {
+		if (ShiftX) {
 			// moving along x, constrain y
 			p.setY(OriginalShiftPos.y());
 		}
-		else {
+		else if (ShiftY) {
 			// moving along y, constrain x
 			p.setX(OriginalShiftPos.x());
 		}
+        else {
+            double dx = qAbs(p.x() - OriginalShiftPos.x());
+            double dy = qAbs(p.y() - OriginalShiftPos.y());
+            if (dx - dy > MinMouseMove) {
+                ShiftX = true;
+            }
+            else if (dy - dx > MinMouseMove) {
+                ShiftY = true;
+            }
+        }
 	}
 
 
 	if (!ShiftDown && (event->modifiers() & Qt::ShiftModifier)) {
 		ShiftDown = true;
+        ShiftX = ShiftY = false;
 		OriginalShiftPos = event->scenePos();
 	}
 
@@ -270,10 +284,10 @@ int Stripbit::x() {
 
 /////////////////////////////////////////////////////////////////////
 
-Stripboard::Stripboard( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+Stripboard::Stripboard( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
 	: Perfboard(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
 {
-	if (!viewIdentifier == ViewIdentifierClass::BreadboardView) return;
+	if (!viewIdentifier == ViewLayer::BreadboardView) return;
 
 	int x, y;
 	getXY(x, y, m_size);
@@ -324,11 +338,11 @@ QString Stripboard::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QStrin
 
 		stripSvg += QString("<path stroke='none' stroke-width='0' fill='%6' " 
 						"d='m%1,%2 %3,0 0,%4 -%3,0z m0,%4a%5,%5  0,1,0 0,-%4z  m%3,-%4a%5,%5 0,1,0 0,%4z'/>\n")
-					.arg(p.x() * dpi / FSvgRenderer::printerScale())
-					.arg(p.y() * dpi / FSvgRenderer::printerScale())
-					.arg(r.width() * dpi / FSvgRenderer::printerScale() )
-					.arg(r.height() * dpi / FSvgRenderer::printerScale())
-					.arg(r.height() * dpi * .5 / FSvgRenderer::printerScale()) 
+					.arg(p.x() * dpi / GraphicsUtils::SVGDPI)
+					.arg(p.y() * dpi / GraphicsUtils::SVGDPI)
+					.arg(r.width() * dpi / GraphicsUtils::SVGDPI )
+					.arg(r.height() * dpi / GraphicsUtils::SVGDPI)
+					.arg(r.height() * dpi * .5 / GraphicsUtils::SVGDPI) 
 					.arg(blackOnly ? "black" : "#c49c59")
 				;
 	}
@@ -454,11 +468,6 @@ QString Stripboard::genModuleID(QMap<QString, QString> & currPropsMap)
 	return size + ModuleIDNames::StripboardModuleIDName;
 }
 
-QString Stripboard::makeBreadboardSvg(const QString & size) 
-{
-	return Perfboard::makeBreadboardSvg(size);
-}
-
 void Stripboard::initCutting(Stripbit *) 
 {
 	m_beforeCut.clear();
@@ -560,7 +569,7 @@ void Stripboard::reinitBuses(bool triggerUndo)
 
 	modelPart()->clearBuses();
 	modelPart()->initBuses();
-	modelPart()->setProp("buses",  busPropertyString);
+	modelPart()->setLocalProp("buses",  busPropertyString);
 
 	
 	QList<ConnectorItem *> visited;
