@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5675 $:
-$Author: cohen@irascible.com $:
-$Date: 2011-12-14 04:57:40 +0100 (Wed, 14 Dec 2011) $
+$Revision: 6507 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-03 18:19:43 +0200 (Wed, 03 Oct 2012) $
 
 ********************************************************************/
 
@@ -30,12 +30,34 @@ $Date: 2011-12-14 04:57:40 +0100 (Wed, 14 Dec 2011) $
 
 #include "paletteitem.h"
 
+/*
+#include <QTime>
+
+class FocusBugLineEdit : public QLineEdit {
+    Q_OBJECT
+
+public:
+	FocusBugLineEdit(QWidget * parent = NULL);
+	~FocusBugLineEdit();
+
+signals:
+	void safeEditingFinished();
+
+protected slots:
+	void editingFinishedSlot();
+	
+protected:
+	QTime m_lastEditingFinishedEmit; 					
+
+};
+*/
+
 class SymbolPaletteItem : public PaletteItem 
 {
 	Q_OBJECT
 
 public:
-	SymbolPaletteItem(ModelPart *, ViewIdentifierClass::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
+	SymbolPaletteItem(ModelPart *, ViewLayer::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
 	~SymbolPaletteItem();
 
 	ConnectorItem* newConnectorItem(class Connector *connector);
@@ -51,24 +73,34 @@ public:
 	PluralType isPlural();
 	void addedToScene(bool temporary);
 	bool hasPartNumberProperty();
+	bool isNetLabel();
+	bool hasPartLabel();
+    QString getLabel();
 
 public:
 	static double DefaultVoltage;
 
 public slots:
 	void voltageEntry(const QString & text);
+	void labelEntry();
 
 protected:
 	void removeMeFromBus(double voltage);
 	double useVoltage(ConnectorItem * connectorItem);
 	QString makeSvg();
+	QString makeNetLabelSvg();
 	QString replaceTextElement(QString svg);
+    ViewLayer::ViewIdentifier useViewIdentifierForPixmap(ViewLayer::ViewIdentifier, bool swappingEnabled);
+    void setLabel(const QString &);
+    QString getDirection();
+    QString retrieveNetLabelSvg(ViewLayer::ViewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi);
 
 protected:
 	double m_voltage;
 	QPointer<ConnectorItem> m_connector0;
 	QPointer<ConnectorItem> m_connector1;
 	bool m_voltageReference;
+	bool m_isNetLabel;
 };
 
 #endif
