@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5721 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-01-03 16:53:58 +0100 (Tue, 03 Jan 2012) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -37,7 +37,7 @@ const int TraceWire::MaxTraceWidthMils = 128;
 
 /////////////////////////////////////////////////////////
 
-TraceWire::TraceWire( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu * itemMenu  ) 
+TraceWire::TraceWire( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu * itemMenu  ) 
 	: ClipableWire(modelPart, viewIdentifier,  viewGeometry,  id, itemMenu, true)
 {
 	m_canChainMultiple = true;
@@ -56,6 +56,7 @@ QComboBox * TraceWire::createWidthComboBox(double m, QWidget * parent)
 	QIntValidator * intValidator = new QIntValidator(comboBox);
 	intValidator->setRange(MinTraceWidthMils, MaxTraceWidthMils);
 	comboBox->setValidator(intValidator);
+    comboBox->setToolTip(tr("Select from the dropdown, or type in any value from %1 to %2").arg(MinTraceWidthMils).arg(MaxTraceWidthMils));
 
 	int ix = 0;
 	if (!Wire::widths.contains(m)) {
@@ -146,7 +147,6 @@ bool TraceWire::canSwitchLayers() {
 	QList<Wire *> wires;
 	QList<ConnectorItem *> ends;
 	collectChained(wires, ends);
-	if (ends.count() < 2) return false;   // should never happen, since traces have to be connected at both ends
 
 	foreach (ConnectorItem * end, ends) {
 		if (end->getCrossLayerConnectorItem() == NULL) return false;
