@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5859 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-02-13 13:29:26 +0100 (Mon, 13 Feb 2012) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -32,12 +32,37 @@ $Date: 2012-02-13 13:29:26 +0100 (Mon, 13 Feb 2012) $
 #include "../connectors/connectoritem.h"
 #include "../connectors/svgidlayer.h"
 
+#include <QSettings>
 
-Via::Via( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+static HoleClassThing TheHoleThing;
+
+const QString Via::AutorouteViaHoleSize = "autorouteViaHoleSize";
+const QString Via::AutorouteViaRingThickness = "autorouteViaRingThickness";
+QString Via::DefaultAutorouteViaHoleSize;
+QString Via::DefaultAutorouteViaRingThickness;
+
+Via::Via( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
 	: Hole(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
 {
-	m_holeSettings.holeDiameterRange = Via::holeDiameterRange;
-	m_holeSettings.ringThicknessRange = Via::ringThicknessRange;
+	QSettings settings;
+	QString ringThickness = settings.value(AutorouteViaRingThickness, "").toString();
+	QString holeSize = settings.value(AutorouteViaHoleSize, "").toString();
+
+    bool holeSizeWasEmpty = holeSize.isEmpty();
+    bool ringThicknessWasEmpty = holeSize.isEmpty();
+
+    PaletteItem::setUpHoleSizes("via", TheHoleThing);
+
+	if (ringThicknessWasEmpty) {
+		settings.setValue(AutorouteViaRingThickness, TheHoleThing.ringThickness);
+		DefaultAutorouteViaRingThickness = TheHoleThing.ringThickness;
+	}
+
+	if (holeSizeWasEmpty) {
+		settings.setValue(AutorouteViaHoleSize, TheHoleThing.holeSize);
+		DefaultAutorouteViaHoleSize = TheHoleThing.holeSize;
+	}
+
 	//DebugDialog::debug(QString("creating via %1 %2 %3").arg((long) this, 0, 16).arg(id).arg(m_viewIdentifier));
 }
 
@@ -45,11 +70,23 @@ Via::~Via() {
 	//DebugDialog::debug(QString("deleting via %1 %2 %3").arg((long) this, 0, 16).arg(m_id).arg(m_viewIdentifier));
 }
 
+void Via::initHoleSettings(HoleSettings & holeSettings) 
+{
+    // called only by AutorouterSettingsDialog
+    PaletteItem::initHoleSettings(holeSettings, &TheHoleThing);
+}
+
 void Via::setBoth(const QString & holeDiameter, const QString & ringThickness) {
-	if (this->m_viewIdentifier != ViewIdentifierClass::PCBView) return;
+	if (this->m_viewIdentifier != ViewLayer::PCBView) return;
 
 	ItemBase * otherLayer = setBothSvg(holeDiameter, ringThickness);
-	resetConnectors(otherLayer, m_otherLayerRenderer);
+	resetConnectors(otherLayer, otherLayer->fsvgRenderer());
+
+    double hd = TextUtils::convertToInches(holeDiameter) * GraphicsUtils::SVGDPI;
+    double rt = TextUtils::convertToInches(ringThickness) * GraphicsUtils::SVGDPI;
+    ConnectorItem * ci = connectorItem();
+    ci->setRadius((hd / 2) + (rt / 2), rt);
+    ci->getCrossLayerConnectorItem()->setRadius((hd / 2) + (rt / 2), rt);
 }
 
 
@@ -57,18 +94,6 @@ QString Via::makeID() {
 	return "connector0pin";
 }
 
-QPointF Via::ringThicknessRange(const QString & holeDiameter) {
-	Q_UNUSED(holeDiameter);
-	QPointF p(.001, 10.0);
-	return p;
-}
-
-QPointF Via::holeDiameterRange(const QString & ringThickness) {
-	Q_UNUSED(ringThickness);
-	QPointF p(.001, 20.0);
-	return p;
-}
-
 void Via::setAutoroutable(bool ar) {
 	m_viewGeometry.setAutoroutable(ar);
 }
