@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,20 +18,22 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5721 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-03 16:53:58 +0100 (Tue, 03 Jan 2012) $
+$Revision: 6497 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-30 08:56:08 +0200 (Sun, 30 Sep 2012) $
 
 ********************************************************************/
 
 #include "virtualwire.h"
 #include "../connectors/connectoritem.h"
+#include "../model/modelpart.h"
 
-VirtualWire::VirtualWire( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu * itemMenu  ) 
+VirtualWire::VirtualWire( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu * itemMenu  ) 
 	: ClipableWire(modelPart, viewIdentifier,  viewGeometry,  id, itemMenu, false)
 {
-	m_colorWasNamed = false;
 	// note: at this point in fritzing development, the VirtualWire class is only ever used for ratsnest wires
+	modelPart->setLocalProp("ratsnest", "true");
+	m_colorWasNamed = false;
 	setFlag(QGraphicsItem::ItemIsSelectable, false);
 }
 
@@ -49,7 +51,7 @@ void VirtualWire::connectionChange(ConnectorItem * onMe, ConnectorItem * onIt, b
 	checkVisibility(onMe, onIt, connect);
 }
 
-FSvgRenderer * VirtualWire::setUpConnectors(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier) {
+FSvgRenderer * VirtualWire::setUpConnectors(ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier) {
 	FSvgRenderer * renderer = Wire::setUpConnectors(modelPart, viewIdentifier);
 	hideConnectors();
 	return renderer;
