@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5895 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-03-06 01:43:16 +0100 (Tue, 06 Mar 2012) $
+$Revision: 6537 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-08 23:10:40 +0200 (Mon, 08 Oct 2012) $
 
 ********************************************************************/
 
@@ -136,11 +136,11 @@ Wire * WireAction::wire() {
 
 /////////////////////////////////////////////////////////////
 
-Wire::Wire( ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu* itemMenu, bool initLabel)
+Wire::Wire( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu* itemMenu, bool initLabel)
 	: ItemBase(modelPart, viewIdentifier, viewGeometry, id, itemMenu)
 {
 	m_bezier = NULL;
-	m_canHaveCurve = true;
+	m_displayBendpointCursor = m_canHaveCurve = true;
 	m_hoverStrokeWidth = DefaultHoverStrokeWidth;
 	m_connector0 = m_connector1 = NULL;
 	m_partLabel = initLabel ? new PartLabel(this, NULL) : NULL;
@@ -432,6 +432,7 @@ void Wire::initDragEnd(ConnectorItem * connectorItem, QPointF scenePos) {
 	saveGeometry();
 	QLineF line = this->line();
 	m_drag0 = (connectorItem == m_connector0);
+    debugInfo("setting drag end to true");
 	m_dragEnd = true;
 	m_dragCurve = false;
 	if (m_drag0) {
@@ -487,6 +488,8 @@ void Wire::mouseMoveEventAux(QPointF eventPos, Qt::KeyboardModifiers modifiers)
 		return;
 	}
 
+    //debugInfo("dragging wire");
+
 	ConnectorItem * whichConnectorItem;
 	ConnectorItem * otherConnectorItem;
 	if (m_drag0) {
@@ -554,40 +557,65 @@ void Wire::mouseMoveEventAux(QPointF eventPos, Qt::KeyboardModifiers modifiers)
 	}
 	setConnector1Rect();
 
-	bool chained = false;
+
+    QSet<ConnectorItem *> allTo;
+    allTo.insert(whichConnectorItem);
 	foreach (ConnectorItem * toConnectorItem, whichConnectorItem->connectedToItems()) {
 		Wire * chainedWire = qobject_cast<Wire *>(toConnectorItem->attachedTo());
 		if (chainedWire == NULL) continue;
 
-		chainedWire->simpleConnectedMoved(whichConnectorItem, toConnectorItem);
-		chained = true;
+        allTo.insert(toConnectorItem);
+        foreach (ConnectorItem * subTo, toConnectorItem->connectedToItems()) {
+            allTo.insert(subTo);
+        }
 	}
+    allTo.remove(whichConnectorItem);
+
+	if (allTo.count() == 0) {
+        // TODO: this could all be determined once in advance
 
-	if (!chained) {
 		// don't allow wire to connect back to something the other end is already directly connected to
 		QList<Wire *> wires;
 		QList<ConnectorItem *> ends;
-		collectChained(otherConnectorItem, wires, ends);
-		for (int i = 0; i < wires.count(); i++) {
-			Wire * w = wires[i];
-			collectChained(w->m_connector1, wires, ends);
-			collectChained(w->m_connector0, wires, ends);
-		}
-		ends.append(otherConnectorItem);
-		foreach (Wire * w, wires) {
-			ends.append(w->connector0());
-			ends.append(w->connector1());
-		}
+		collectChained(wires, ends);
+
+        // but allow to restore connections at this end (collect chained above got both ends of this wire) 
 		foreach (ConnectorItem * toConnectorItem, whichConnectorItem->connectedToItems()) {
 			ends.removeOne(toConnectorItem);
 		}
 
+        QList<ConnectorItem *> moreEnds;
+        foreach (ConnectorItem * end, ends) {
+            foreach (ConnectorItem * eci, end->connectedToItems()) {
+                moreEnds.append(eci);
+            }
+        }
+      
+        ends.append(moreEnds);
+        foreach (Wire * w, wires) {
+			ends << w->connector0() << w->connector1();
+		}
+        
 		ConnectorItem * originatingConnector = NULL;
 		if (otherConnectorItem && otherConnectorItem->connectionsCount() > 0) {
 			originatingConnector = otherConnectorItem->connectedToItems()[0];
 		}
+
+        // but allow to restore connections at this end (collect chained above got both ends of this wire) 
+		foreach (ConnectorItem * toConnectorItem, whichConnectorItem->connectedToItems()) {
+			ends.removeOne(toConnectorItem);
+		}
+
 		whichConnectorItem->findConnectorUnder(false, true, ends, true, originatingConnector);
 	}
+    else {
+        foreach (ConnectorItem * toConnectorItem, allTo) {
+            Wire * chained = qobject_cast<Wire *>(toConnectorItem->attachedTo());
+            if (chained) {
+                chained->simpleConnectedMoved(whichConnectorItem, toConnectorItem);
+            }
+        }
+    }
 }
 
 void Wire::setConnector0Rect() {
@@ -621,6 +649,7 @@ void Wire::mouseReleaseEvent(QGraphicsSceneMouseEvent *event) {
 		return;
 	}
 
+    debugInfo("wire release drag");
 	if (releaseDrag()) return;
 
 	ItemBase::mouseReleaseEvent(event);
@@ -640,6 +669,7 @@ bool Wire::releaseDrag() {
 		return true;
 	}
 
+    debugInfo("clearing drag end");
 	m_dragEnd = false;
 
 	ConnectorItem * from = (m_drag0) ? m_connector0 : m_connector1;
@@ -692,7 +722,7 @@ void Wire::setExtras(const QDomElement & element, InfoGraphicsView * infoGraphic
 	else {
 		w = element.attribute("mils").toDouble(&ok);
 		if (ok) {
-			double wpix = GraphicsUtils::mils2pixels(w, FSvgRenderer::printerScale());
+			double wpix = GraphicsUtils::mils2pixels(w, GraphicsUtils::SVGDPI);
 			setWireWidth(wpix, infoGraphicsView, infoGraphicsView->getWireStrokeWidth(this, wpix));
 		}
 	}
@@ -915,7 +945,7 @@ void Wire::connectedMoved(ConnectorItem * from, ConnectorItem * to) {
 }
 
 
-FSvgRenderer * Wire::setUpConnectors(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier viewIdentifier) 
+FSvgRenderer * Wire::setUpConnectors(ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier) 
 {
 	clearConnectorItemCache();
 
@@ -1056,10 +1086,6 @@ void Wire::setRatsnest(bool ratsnest) {
 	m_viewGeometry.setRatsnest(ratsnest);
 }
 
-bool Wire::getRatsnest() {
-	return m_viewGeometry.getRatsnest();
-}
-
 void Wire::setAutoroutable(bool ar) {
 	m_viewGeometry.setAutoroutable(ar);
 }
@@ -1116,7 +1142,7 @@ double Wire::shadowWidth() {
 }
 
 double Wire::mils() {
-	return 1000 * m_pen.widthF() / FSvgRenderer::printerScale();
+	return 1000 * m_pen.widthF() / GraphicsUtils::SVGDPI;
 }
 
 void Wire::setColorString(QString colorName, double op) {
@@ -1157,14 +1183,20 @@ QString Wire::colorString() {
 void Wire::initNames() {
 	if (colorNames.count() > 0) return;
 
-	widths << 16 << 24 << 32 << 48;
-	widthTrans.insert(widths[0], tr("thin (16 mil)"));
-	widthTrans.insert(widths[1], tr("standard (24 mil)"));
-	widthTrans.insert(widths[2], tr("thick (32 mil)"));
-	widthTrans.insert(widths[3], tr("extra thick (48 mil)"));
+	widths << 8 << 12 << 16 << 24 << 32 << 48;
+    int i = 0;
+	widthTrans.insert(widths[i++], tr("super fine (8 mil)"));
+	widthTrans.insert(widths[i++], tr("extra thin (12 mil)"));
+
+	THIN_TRACE_WIDTH = GraphicsUtils::mils2pixels(widths[i], GraphicsUtils::SVGDPI);
+	widthTrans.insert(widths[i++], tr("thin (16 mil)"));
+
+	STANDARD_TRACE_WIDTH = GraphicsUtils::mils2pixels(widths[i], GraphicsUtils::SVGDPI);
+	widthTrans.insert(widths[i++], tr("standard (24 mil)"));
+
+	widthTrans.insert(widths[i++], tr("thick (32 mil)"));
+	widthTrans.insert(widths[i++], tr("extra thick (48 mil)"));
 
-	THIN_TRACE_WIDTH = GraphicsUtils::mils2pixels(widths[0], FSvgRenderer::printerScale());
-	STANDARD_TRACE_WIDTH = GraphicsUtils::mils2pixels(widths[1], FSvgRenderer::printerScale());
 	HALF_STANDARD_TRACE_WIDTH = STANDARD_TRACE_WIDTH / 2.0;
 
     // need a list because a hash table doesn't guarantee order 
@@ -1242,7 +1274,7 @@ bool Wire::canChangeColor() {
 	if (getRatsnest()) return false;
 	if (!getTrace()) return true;
 
-	return (this->m_viewIdentifier == ViewIdentifierClass::SchematicView);
+	return (this->m_viewIdentifier == ViewLayer::SchematicView);
 }
 
 void Wire::collectDirectWires(QList<Wire *> & wires) {
@@ -1391,7 +1423,7 @@ bool Wire::connectionIsAllowed(ConnectorItem * to) {
 
 	if (w->getRatsnest()) return false;
 
-	return m_viewIdentifier != ViewIdentifierClass::BreadboardView;
+	return m_viewIdentifier != ViewLayer::BreadboardView;
 }
 
 bool Wire::isGrounded() {
@@ -1433,7 +1465,7 @@ bool Wire::collectExtraInfo(QWidget * parent, const QString & family, const QStr
 			QString englishCurrColor = colorString();
 			foreach(QString transColorName, Wire::colorNames) {
 				QString englishColorName = Wire::colorTrans.value(transColorName);
-				bool ok = (this->m_viewIdentifier != ViewIdentifierClass::SchematicView || englishColorName.compare("white", Qt::CaseInsensitive) != 0);
+				bool ok = (this->m_viewIdentifier != ViewLayer::SchematicView || englishColorName.compare("white", Qt::CaseInsensitive) != 0);
 				if (ok) {
 					comboBox->addItem(transColorName, QVariant(englishColorName));
 					if (englishColorName.compare(englishCurrColor, Qt::CaseInsensitive) == 0) {
@@ -1523,19 +1555,7 @@ void Wire::addedToScene(bool temporary) {
 	InfoGraphicsView * infoGraphicsView = InfoGraphicsView::getInfoGraphicsView(this);
 	if (infoGraphicsView == NULL) return;
 
-	bool succeeded = connect(this, SIGNAL(wireChangedSignal(Wire*, const QLineF & , const QLineF & , QPointF, QPointF, ConnectorItem *, ConnectorItem *)	),
-			infoGraphicsView, SLOT(wireChangedSlot(Wire*, const QLineF & , const QLineF & , QPointF, QPointF, ConnectorItem *, ConnectorItem *)),
-			Qt::DirectConnection);		// DirectConnection means call the slot directly like a subroutine, without waiting for a thread or queue
-	succeeded = connect(this, SIGNAL(wireChangedCurveSignal(Wire*, const Bezier *, const Bezier *, bool)),
-			infoGraphicsView, SLOT(wireChangedCurveSlot(Wire*, const Bezier *, const Bezier *, bool)),
-			Qt::DirectConnection);		// DirectConnection means call the slot directly like a subroutine, without waiting for a thread or queue
-	succeeded = succeeded && connect(this, SIGNAL(wireSplitSignal(Wire*, QPointF, QPointF, const QLineF & )),
-			infoGraphicsView, SLOT(wireSplitSlot(Wire*, QPointF, QPointF, const QLineF & )));
-	succeeded = succeeded && connect(this, SIGNAL(wireJoinSignal(Wire*, ConnectorItem *)),
-			infoGraphicsView, SLOT(wireJoinSlot(Wire*, ConnectorItem*)));
-	if (!succeeded) {
-		DebugDialog::debug("wire signal connect failed");
-	}
+	infoGraphicsView->newWire(this);
 }
 
 void Wire::setConnectorDimensions(double width, double height) 
@@ -1626,7 +1646,7 @@ void Wire::setPen(const QPen &pen)
 }
 
 bool Wire::canHaveCurve() {
-	return m_canHaveCurve && (m_viewIdentifier == ViewIdentifierClass::BreadboardView);
+	return m_canHaveCurve && (m_viewIdentifier == ViewLayer::BreadboardView);
 }
 
 void Wire::dragCurve(QPointF eventPos, Qt::KeyboardModifiers)
@@ -1724,7 +1744,7 @@ void Wire::updateCursor(Qt::KeyboardModifiers modifiers)
 	else if (infoGraphicsView != NULL && infoGraphicsView->curvyWiresIndicated(modifiers)) {
 		CursorMaster::instance()->addCursor(this, *CursorMaster::MakeCurveCursor);
 	}
-	else {
+	else if (m_displayBendpointCursor) {
 		CursorMaster::instance()->addCursor(this, *CursorMaster::NewBendpointCursor);
 	}
 }
@@ -1733,3 +1753,16 @@ bool Wire::canChainMultiple()
 {
 	return m_canChainMultiple;
 }
+
+ViewLayer::ViewIdentifier Wire::useViewIdentifierForPixmap(ViewLayer::ViewIdentifier vid, bool) 
+{
+    if (vid == ViewLayer::BreadboardView) {
+        return ViewLayer::IconView;
+    }
+
+    return ViewLayer::UnknownView;
+}
+
+void Wire::setDisplayBendpointCursor(bool dbc) {
+	m_displayBendpointCursor = dbc;
+}
