@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5309 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2011-07-30 21:17:22 +0200 (Sat, 30 Jul 2011) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -32,7 +32,6 @@ $Date: 2011-07-30 21:17:22 +0200 (Sat, 30 Jul 2011) $
 #include <QString>
 #include <QDomElement>
 
-#include "viewidentifierclass.h"
 #include "viewlayer.h"
 
 class LayerAttributes {
@@ -42,29 +41,12 @@ public:
 	
 	const QString & filename();
 	void setFilename(const QString &);
-	const QString & layerName();
-	bool sticky();
-	bool multiLayer();
-	bool getSvgElementID(QDomDocument * , ViewIdentifierClass::ViewIdentifier, ViewLayer::ViewLayerID );
-	bool canFlipHorizontal();
-	bool canFlipVertical();
 	const QByteArray & loaded();
 	void clearLoaded();
 	void setLoaded(const QByteArray &);
 
-public:
-	static QDomElement getSvgElementLayers(QDomDocument * doc, ViewIdentifierClass::ViewIdentifier viewIdentifier );
-
-protected:
-	static QDomElement getSvgElementLayer(QDomDocument *, ViewIdentifierClass::ViewIdentifier, ViewLayer::ViewLayerID, int & layerCount );
-
 protected:
 	QString m_filename;
-	QString m_layerName;
-	bool m_multiLayer;
-	bool m_sticky;
-	bool m_canFlipHorizontal;
-	bool m_canFlipVertical;
 	QByteArray m_loaded;
 };
 
