@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5922 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-03-19 20:11:41 +0100 (Mon, 19 Mar 2012) $
+$Revision: 6567 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-15 15:13:22 +0200 (Mon, 15 Oct 2012) $
 
 ********************************************************************/
 
@@ -28,11 +28,13 @@ $Date: 2012-03-19 20:11:41 +0100 (Mon, 19 Mar 2012) $
 #include "../debugdialog.h"
 #include "../items/partfactory.h"
 #include "../items/moduleidnames.h"
+#include "../utils/textutils.h"
 #include "../version/version.h"
 #include "../viewgeometry.h"
 
 #include <QMessageBox>
 
+QList<QString> ModelBase::CoreList;
 
 /////////////////////////////////////////////////
 
@@ -49,6 +51,11 @@ ModelBase::ModelBase( bool makeRoot )
 
 ModelBase::~ModelBase() {
 	if (m_root) {
+        ModelPartShared * modelPartShared = m_root->modelPartShared();
+        if (modelPartShared) {
+            m_root->setModelPartShared(NULL);
+            delete modelPartShared;
+        }
 		delete m_root;
 	}
 }
@@ -62,8 +69,8 @@ ModelPart * ModelBase::retrieveModelPart(const QString & /* moduleID */)  {
 }
 
 // loads a model from an fz file--assumes a reference model exists with all parts
-bool ModelBase::load(const QString & fileName, ModelBase * refModel, QList<ModelPart *> & modelParts) {
-	m_referenceModel = refModel;
+bool ModelBase::loadFromFile(const QString & fileName, ModelBase * referenceModel, QList<ModelPart *> & modelParts, bool checkViews) {
+	m_referenceModel = referenceModel;
 
     QFile file(fileName);
     if (!file.open(QFile::ReadOnly | QFile::Text)) {
@@ -104,6 +111,7 @@ bool ModelBase::load(const QString & fileName, ModelBase * refModel, QList<Model
 
 	bool checkForRats = true;
 	bool checkForTraces = true;
+    bool checkForMysteryParts = true;
 	m_fritzingVersion = root.attribute("fritzingVersion");
 	if (m_fritzingVersion.length() > 0) {
 		// with version 0.4.3 ratsnests in fz files are obsolete
@@ -119,6 +127,10 @@ bool ModelBase::load(const QString & fileName, ModelBase * refModel, QList<Model
 		versionThingRats.minorVersion = 6;
 		versionThingRats.minorSubVersion = 4;
 		checkForTraces = !Version::greaterThan(versionThingRats, versionThingFz);
+        // with version 0.7.6 mystery part spacing implementation changes
+		versionThingRats.minorVersion = 7;
+		versionThingRats.minorSubVersion = 5;
+		checkForMysteryParts = !Version::greaterThan(versionThingRats, versionThingFz);
 	}
 
 	ModelPartSharedRoot * modelPartSharedRoot = this->rootModelPartShared();
@@ -146,7 +158,6 @@ bool ModelBase::load(const QString & fileName, ModelBase * refModel, QList<Model
 		modelPartSharedRoot->setSearchTerm(searchTerm);
 	}
 
-
     QDomElement views = root.firstChildElement("views");
 	emit loadedViews(this, views);
 
@@ -185,7 +196,15 @@ bool ModelBase::load(const QString & fileName, ModelBase * refModel, QList<Model
 		}
 	}
 
-	bool result = loadInstances(domDocument, instances, modelParts);
+	if (checkForMysteryParts) {
+		QDomElement instance = instances.firstChildElement("instance");
+   		while (!instance.isNull()) {
+			checkMystery(instance);
+			instance = instance.nextSiblingElement("instance");
+		}
+	}
+
+	bool result = loadInstances(domDocument, instances, modelParts, checkViews);
 	emit loadedInstances(this, instances);
 	return result;
 }
@@ -194,7 +213,7 @@ ModelPart * ModelBase::fixObsoleteModuleID(QDomDocument & domDocument, QDomEleme
 	return PartFactory::fixObsoleteModuleID(domDocument, instance, moduleIDRef, m_referenceModel);
 }
 
-bool ModelBase::loadInstances(QDomDocument & domDocument, QDomElement & instances, QList<ModelPart *> & modelParts)
+bool ModelBase::loadInstances(QDomDocument & domDocument, QDomElement & instances, QList<ModelPart *> & modelParts, bool checkViews)
 {
 	QHash<QString, QString> missingModules;
    	QDomElement instance = instances.firstChildElement("instance");
@@ -202,6 +221,20 @@ bool ModelBase::loadInstances(QDomDocument & domDocument, QDomElement & instance
    	while (!instance.isNull()) {
 		emit loadingInstance(this, instance);
 
+        if (checkViews) {
+            QDomElement views = instance.firstChildElement("views");
+            QDomElement view = views.firstChildElement();
+            if (views.isNull() || view.isNull()) {
+                // do not load a part with no views
+                //QString text;
+                //QTextStream stream(&text);
+                //instance.save(stream, 0);
+                //DebugDialog::debug(text);
+                instance = instance.nextSiblingElement("instance");
+                continue;
+            }
+        }
+
    		// for now assume all parts are in the palette
    		QString moduleIDRef = instance.attribute("moduleIdRef");
 		if (moduleIDRef.compare(ModuleIDNames::SpacerModuleIDName) == 0) {
@@ -219,8 +252,10 @@ bool ModelBase::loadInstances(QDomDocument & domDocument, QDomElement & instance
 			DebugDialog::debug(QString("module id %1 not found in database").arg(moduleIDRef));
 			modelPart = fixObsoleteModuleID(domDocument, instance, moduleIDRef);
 			if (modelPart == NULL) {
-				if (genFZP(moduleIDRef, m_referenceModel)) {
-					modelPart = m_referenceModel->retrieveModelPart(moduleIDRef);
+                modelPart = genFZP(moduleIDRef, m_referenceModel);
+				if (modelPart != NULL) {
+                    instance.setAttribute("moduleIdRef", modelPart->moduleID());
+                    moduleIDRef = modelPart->moduleID();
 				}
 				if (modelPart == NULL) {
 					missingModules.insert(moduleIDRef, instance.attribute("path"));
@@ -271,7 +306,7 @@ bool ModelBase::loadInstances(QDomDocument & domDocument, QDomElement & instance
 			if (nodeName.compare("originalModelIndex") == 0) continue;
 			if (nodeName.compare("path") == 0) continue;
 
-			modelPart->setProp(nodeName, node.nodeValue());
+			modelPart->setLocalProp(nodeName, node.nodeValue());
 		}
 
 		// "property" loop replaces previous QDomNamedNodeMap loop (jc, 22 Oct 2009)
@@ -281,7 +316,7 @@ bool ModelBase::loadInstances(QDomDocument & domDocument, QDomElement & instance
 			if (!name.isEmpty()) {
 				QString value = prop.attribute("value");
 				if (!value.isEmpty()) {
-					modelPart->setProp(name, value);
+					modelPart->setLocalProp(name, value);
 				}
 			}
 
@@ -311,6 +346,7 @@ ModelPart * ModelBase::addModelPart(ModelPart * parent, ModelPart * copyChild) {
 	modelPart->copyNew(copyChild);
 	modelPart->setParent(parent);
 	modelPart->initConnectors();
+    modelPart->flipSMDAnd();
 	return modelPart;
 }
 
@@ -383,9 +419,9 @@ void ModelBase::save(const QString & fileName, QXmlStreamWriter & streamWriter,
     }
 }
 
-bool ModelBase::paste(ModelBase * refModel, QByteArray & data, QList<ModelPart *> & modelParts, QHash<QString, QRectF> & boundingRects, bool preserveIndex)
+bool ModelBase::paste(ModelBase * referenceModel, QByteArray & data, QList<ModelPart *> & modelParts, QHash<QString, QRectF> & boundingRects, bool preserveIndex)
 {
-	m_referenceModel = refModel;
+	m_referenceModel = referenceModel;
 
 	QDomDocument domDocument;
 	QString errorStr;
@@ -440,7 +476,7 @@ bool ModelBase::paste(ModelBase * refModel, QByteArray & data, QList<ModelPart *
 	//file.write(domDocument.toByteArray());
 	//file.close();
 
-	return loadInstances(domDocument, instances, modelParts);
+	return loadInstances(domDocument, instances, modelParts, true);
 }
 
 void ModelBase::renewModelIndexes(QDomElement & parentElement, const QString & childName, QHash<long, long> & oldToNew)
@@ -491,13 +527,13 @@ void ModelBase::setReportMissingModules(bool b) {
 	m_reportMissingModules = b;
 }
 
-bool ModelBase::genFZP(const QString & moduleID, ModelBase * refModel) {
+ModelPart * ModelBase::genFZP(const QString & moduleID, ModelBase * referenceModel) {
 	QString path = PartFactory::getFzpFilename(moduleID);
-	if (path.isEmpty()) return false;
+	if (path.isEmpty()) return NULL;
 
-	ModelPart* mp = refModel->addPart(path, true, true);
+	ModelPart* mp = referenceModel->addPart(path, true, true);
 	if (mp) mp->setCore(true);
-	return mp != NULL;
+	return mp;
 }
 
 ModelPartSharedRoot * ModelBase::rootModelPartShared() {
@@ -627,3 +663,48 @@ void ModelBase::checkTraces(QDomElement & instance) {
 const QString & ModelBase::fritzingVersion() {
 	return m_fritzingVersion;
 }
+
+void ModelBase::setReferenceModel(ModelBase * modelBase) {
+    m_referenceModel = modelBase;
+}
+
+void ModelBase::checkMystery(QDomElement & instance) 
+{
+	QString moduleIDRef = instance.attribute("moduleIdRef");
+    bool mystery = false;
+    bool sip = false;
+    bool dip = false;
+	if (moduleIDRef.contains("mystery", Qt::CaseInsensitive)) mystery = true;	
+    else if (moduleIDRef.contains("sip", Qt::CaseInsensitive)) sip = true;    
+    else if (moduleIDRef.contains("dip", Qt::CaseInsensitive)) dip = true;
+    else return;
+
+    QString spacing;
+    int pins = TextUtils::getPinsAndSpacing(moduleIDRef, spacing);
+
+    QDomElement prop = instance.firstChildElement("property");
+    while (!prop.isNull()) {
+        if (prop.attribute("name", "").compare("spacing") == 0) {
+            QString trueSpacing = prop.attribute("value", "");
+            if (trueSpacing.isEmpty()) trueSpacing = "300mil";
+
+            if (moduleIDRef.contains(spacing)) {
+                moduleIDRef.replace(spacing, trueSpacing);
+                instance.setAttribute("moduleIdRef", moduleIDRef);
+                return;
+            }
+
+            // if we're here, it's a single sided mystery part.
+            moduleIDRef = QString("mystery_part_sip_%1_100mil").arg(pins);
+            instance.setAttribute("moduleIdRef", moduleIDRef);
+            return;
+        }
+        prop = prop.nextSiblingElement("property");
+    }
+}
+
+bool ModelBase::onCoreList(const QString & moduleID) {
+    // CoreList contains db entries that are (presumably) overridden by an fzp in the parts folder
+    return CoreList.contains(moduleID);
+
+}
