@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5922 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-03-19 20:11:41 +0100 (Mon, 19 Mar 2012) $
+$Revision: 6565 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-15 12:10:48 +0200 (Mon, 15 Oct 2012) $
 
 ********************************************************************/
 
@@ -42,16 +42,20 @@ public:
 	ModelPartSharedRoot * rootModelPartShared();
 	virtual ModelPart* retrieveModelPart(const QString & moduleID);
 	virtual ModelPart * addModelPart(ModelPart * parent, ModelPart * copyChild);
-	virtual bool load(const QString & fileName, ModelBase* refModel, QList<ModelPart *> & modelParts);
+    bool loadFromFile(const QString & fileName, ModelBase* referenceModel, QList<ModelPart *> & modelParts, bool checkInstances);
 	void save(const QString & fileName, bool asPart);
 	void save(const QString & fileName, class QXmlStreamWriter &, bool asPart);
 	virtual ModelPart * addPart(QString newPartPath, bool addToReference);
 	virtual bool addPart(ModelPart * modelPart, bool update);
 	virtual ModelPart * addPart(QString newPartPath, bool addToReference, bool updateIdAlreadyExists);
-	bool paste(ModelBase * refModel, QByteArray & data, QList<ModelPart *> & modelParts, QHash<QString, QRectF> & boundingRects, bool preserveIndex);
+	bool paste(ModelBase * referenceModel, QByteArray & data, QList<ModelPart *> & modelParts, QHash<QString, QRectF> & boundingRects, bool preserveIndex);
 	void setReportMissingModules(bool);
-	bool genFZP(const QString & moduleID, ModelBase * refModel);
+	ModelPart * genFZP(const QString & moduleID, ModelBase * referenceModel);
 	const QString & fritzingVersion();
+    void setReferenceModel(ModelBase *);
+
+public:
+    static bool onCoreList(const QString & moduleID);
 
 signals:
 	void loadedViews(ModelBase *, QDomElement & views);
@@ -62,16 +66,21 @@ signals:
 
 protected:
 	void renewModelIndexes(QDomElement & root, const QString & childName, QHash<long, long> & oldToNew);
-	bool loadInstances(QDomDocument &, QDomElement & root, QList<ModelPart *> & modelParts);
+	bool loadInstances(QDomDocument &, QDomElement & root, QList<ModelPart *> & modelParts, bool checkViews);
 	ModelPart * fixObsoleteModuleID(QDomDocument & domDocument, QDomElement & instance, QString & moduleIDRef);
 	static bool isRatsnest(QDomElement & instance);
 	static void checkTraces(QDomElement & instance);
+	static void checkMystery(QDomElement & instance);
 
 protected:
 	QPointer<ModelPart> m_root;
 	QPointer<ModelBase> m_referenceModel;
 	bool m_reportMissingModules;
 	QString m_fritzingVersion;
+
+protected:
+    static QList<QString> CoreList;
+
 };
 
 #endif
