@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5945 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-07 00:49:26 +0200 (Sat, 07 Apr 2012) $
+$Revision: 6501 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-02 11:19:01 +0200 (Tue, 02 Oct 2012) $
 
 ********************************************************************/
 
@@ -32,7 +32,6 @@ $Date: 2012-04-07 00:49:26 +0200 (Sat, 07 Apr 2012) $
 #include "../version/version.h"
 #include "../utils/folderutils.h"
 #include "../items/itembase.h"
-#include "../items/virtualwire.h"
 
 #include <QDomElement>
 #include <QBitArray>
@@ -47,6 +46,7 @@ InstanceTitleIncrementHash NullInstanceTitleIncrements;
 
 static const QRegExp InstanceTitleRegExp("^(.*[^\\d])(\\d+)$");
 
+static const QList<ViewImage *> EmptyViewImages;
 
 ////////////////////////////////////////
 
@@ -56,15 +56,14 @@ ModelPart::ModelPart(ItemType type)
 	commonInit(type);
 	m_modelPartShared = NULL;
 	m_index = m_nextIndex++;
-	m_originalModelPartShared = false;  // TODO: make this a QSharedPointer
 }
 
-ModelPart::ModelPart(QDomDocument * domDocument, const QString & path, ItemType type)
+ModelPart::ModelPart(QDomDocument & domDocument, const QString & path, ItemType type)
 	: QObject()
 {
 	commonInit(type);
 	m_modelPartShared = new ModelPartShared(domDocument, path);
-	m_originalModelPartShared = true;		// TODO: make this a QSharedPointer
+    m_modelPartShared->addOwner(this);
 }
 
 void ModelPart::commonInit(ItemType type) {
@@ -87,12 +86,6 @@ ModelPart::~ModelPart() {
 		delete itih;
 	}
 
-	if (m_originalModelPartShared) {		// TODO: make this a QSharedPointer
-		if (m_modelPartShared) {
-			delete m_modelPartShared;
-		}
-	}
-
 	foreach (Connector * connector, m_connectorHash.values()) {
 		delete connector;
 	}
@@ -105,7 +98,7 @@ ModelPart::~ModelPart() {
 	clearBuses();
 }
 
-const QString & ModelPart::moduleID() {
+const QString & ModelPart::moduleID() const {
 	if (m_modelPartShared != NULL) return m_modelPartShared->moduleID();
 
 	return ___emptyString___;
@@ -123,6 +116,12 @@ const QString & ModelPart::author() {
 	return ___emptyString___;
 }
 
+const QString & ModelPart::taxonomy() {
+	if (m_modelPartShared != NULL) return m_modelPartShared->taxonomy();
+
+	return ___emptyString___;
+}
+
 const QString & ModelPart::uri() {
 	if (m_modelPartShared != NULL) return m_modelPartShared->uri();
 
@@ -146,6 +145,7 @@ void ModelPart::copy(ModelPart * modelPart) {
 
 	m_type = modelPart->itemType();
 	m_modelPartShared = modelPart->modelPartShared();
+    if (m_modelPartShared) m_modelPartShared->addOwner(this);
 	m_locationFlags = modelPart->m_locationFlags;
 }
 
@@ -160,7 +160,7 @@ void ModelPart::copyStuff(ModelPart * modelPart) {
 ModelPartShared * ModelPart::modelPartShared() {
 	if(!m_modelPartShared) {
 		m_modelPartShared = new ModelPartShared();
-		m_originalModelPartShared = true;		// TODO: make this a QSharedPointer
+        m_modelPartShared->addOwner(this);
 	}
 	return m_modelPartShared;
 }
@@ -170,7 +170,8 @@ ModelPartSharedRoot * ModelPart::modelPartSharedRoot() {
 }
 
 void ModelPart::setModelPartShared(ModelPartShared * modelPartShared) {
-	m_modelPartShared = modelPartShared;
+	m_modelPartShared = modelPartShared;    
+    if (modelPartShared) m_modelPartShared->addOwner(this);
 }
 
 void ModelPart::addViewItem(ItemBase * item) {
@@ -189,6 +190,14 @@ ItemBase * ModelPart::viewItem(QGraphicsScene * scene) {
 	return NULL;
 }
 
+ItemBase * ModelPart::viewItem(ViewLayer::ViewIdentifier viewIdentifier) {
+	foreach (ItemBase * itemBase, m_viewItems) {
+		if (itemBase->viewIdentifier() == viewIdentifier) return itemBase;
+	}
+
+	return NULL;
+}
+
 void ModelPart::saveInstances(const QString & fileName, QXmlStreamWriter & streamWriter, bool startDocument) {
 	if (startDocument) {
 		streamWriter.writeStartDocument();
@@ -213,7 +222,7 @@ void ModelPart::saveInstances(const QString & fileName, QXmlStreamWriter & strea
 		streamWriter.writeStartElement("instances");
 	}
 
-	if (m_viewItems.size() > 0) {
+	if (parent() != NULL) {  // m_viewItems.size() > 0
 		saveInstance(streamWriter);
 	}
 
@@ -240,7 +249,9 @@ void ModelPart::saveInstances(const QString & fileName, QXmlStreamWriter & strea
 
 void ModelPart::saveInstance(QXmlStreamWriter & streamWriter) 
 {
-	if (qobject_cast<VirtualWire *>(m_viewItems.at(0)) != NULL) return;				// don't save virtual wires
+	if (localProp("ratsnest").toBool()) {
+		return;				// don't save virtual wires
+	}
 
 	streamWriter.writeStartElement("instance");
 	if (m_modelPartShared != NULL) {
@@ -481,6 +492,13 @@ const QDomElement & ModelPart::instanceDomElement() {
 	return m_instanceDomElement;
 }
 
+const QString & ModelPart::fritzingVersion() {
+
+	if (m_modelPartShared != NULL) return m_modelPartShared->fritzingVersion();
+
+	return ___emptyString___;
+}
+
 const QString & ModelPart::title() {
 	if (!m_localTitle.isEmpty()) return m_localTitle;
 
@@ -588,16 +606,50 @@ void ModelPart::setLocationFlag(bool setting, LocationFlag flag) {
 	}
 }
 
-bool ModelPart::hasViewIdentifier(ViewIdentifierClass::ViewIdentifier viewIdentifier) {
-	QDomDocument * doc = domDocument();
-	if (doc == NULL) return false;
+bool ModelPart::hasViewIdentifier(ViewLayer::ViewIdentifier viewIdentifier) {
+    if (m_modelPartShared) return m_modelPartShared->hasViewIdentifier(viewIdentifier);
 
-	QDomElement viewsElems = doc->documentElement().firstChildElement("views");
-	if(viewsElems.isNull()) return false;
+    return false;
 
-	return !viewsElems.firstChildElement(ViewIdentifierClass::viewIdentifierXmlName(viewIdentifier)).isNull();
 }
 
+bool ModelPart::canFlipVertical(ViewLayer::ViewIdentifier viewIdentifier) {
+    if (m_modelPartShared) return m_modelPartShared->canFlipVertical(viewIdentifier);
+
+    return false;
+
+}
+
+bool ModelPart::canFlipHorizontal(ViewLayer::ViewIdentifier viewIdentifier) {
+    if (m_modelPartShared) return m_modelPartShared->canFlipHorizontal(viewIdentifier);
+
+    return false;
+}
+
+LayerList ModelPart::viewLayers(ViewLayer::ViewIdentifier viewIdentifier) {
+    if (m_modelPartShared) return m_modelPartShared->viewLayers(viewIdentifier);
+
+    LayerList layerList;
+    return layerList;
+}
+
+QString ModelPart::imageFileName(ViewLayer::ViewIdentifier viewIdentifier) {
+    if (m_modelPartShared) return m_modelPartShared->imageFileName(viewIdentifier);
+
+    return "";
+}
+
+QString ModelPart::imageFileName(ViewLayer::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID) {
+    if (m_modelPartShared) return m_modelPartShared->imageFileName(viewIdentifier, viewLayerID);
+
+    return "";
+}
+
+bool ModelPart::anySticky(ViewLayer::ViewIdentifier viewIdentifier) {
+    if (m_modelPartShared) return m_modelPartShared->anySticky(viewIdentifier);
+
+    return false;
+}
 
 QList<ModelPart*> ModelPart::getAllParts() {
 	QList<ModelPart*> retval;
@@ -759,22 +811,23 @@ void ModelPart::setOrderedChildren(QList<QObject*> children) {
 	m_orderedChildren = children;
 }
 
-void ModelPart::setProp(const char * name, const QVariant & value) {
-	setProperty(name, value);
+void ModelPart::setLocalProp(const char * name, const QVariant & value) {
+    //DebugDialog::debug(QString("mp set prop %1 %2").arg(name).arg(value.toString()));
+	QObject::setProperty(name, value);
 }
 
-QVariant ModelPart::prop(const char * name) const {
+QVariant ModelPart::localProp(const char * name) const {
 	return property(name);
 }
 
-void ModelPart::setProp(const QString & name, const QVariant & value) {
+void ModelPart::setLocalProp(const QString & name, const QVariant & value) {
 	QByteArray b = name.toLatin1();
-	setProp(b.data(), value);
+	setLocalProp(b.data(), value);
 }
 
-QVariant ModelPart::prop(const QString & name) const {
+QVariant ModelPart::localProp(const QString & name) const {
 	QByteArray b = name.toLatin1();
-	return prop(b.data());
+	return localProp(b.data());
 }
 
 const QStringList & ModelPart::possibleFolders() {
@@ -797,10 +850,6 @@ bool ModelPart::isObsolete() {
 	return false;
 }
 
-void ModelPart::setFlippedSMD(bool f) {
-	if (m_modelPartShared != NULL) m_modelPartShared->setFlippedSMD(f);
-}
-
 bool ModelPart::flippedSMD() {
 	if (m_modelPartShared != NULL) {
 		return m_modelPartShared->flippedSMD();
@@ -817,25 +866,19 @@ bool ModelPart::needsCopper1() {
 	return false;
 }
 
-QDomDocument* ModelPart::domDocument() {
-	if (m_modelPartShared == NULL) return NULL;
-
-	return m_modelPartShared->domDocument();
-}
-
-bool ModelPart::hasViewFor(ViewIdentifierClass::ViewIdentifier viewIdentifier) {
+bool ModelPart::hasViewFor(ViewLayer::ViewIdentifier viewIdentifier) {
 	if (m_modelPartShared == NULL) return false;
 
 	return m_modelPartShared->hasViewFor(viewIdentifier);
 }
 
-bool ModelPart::hasViewFor(ViewIdentifierClass::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID) {
+bool ModelPart::hasViewFor(ViewLayer::ViewIdentifier viewIdentifier, ViewLayer::ViewLayerID viewLayerID) {
 	if (m_modelPartShared == NULL) return false;
 
 	return m_modelPartShared->hasViewFor(viewIdentifier, viewLayerID);
 }
 
-QString ModelPart::hasBaseNameFor(ViewIdentifierClass::ViewIdentifier viewIdentifier) {
+QString ModelPart::hasBaseNameFor(ViewLayer::ViewIdentifier viewIdentifier) {
 	if (m_modelPartShared == NULL) return ___emptyString___;
 
 	return m_modelPartShared->hasBaseNameFor(viewIdentifier);
@@ -861,6 +904,18 @@ void ModelPart::setConnectorLocalName(const QString & id, const QString & name)
 	}
 }
 
+QString ModelPart::connectorLocalName(const QString & id)
+{
+	if (id.isEmpty()) return "";
+
+	Connector * connector = m_connectorHash.value(id, NULL);
+	if (connector) {
+		return connector->connectorLocalName();
+	}
+
+	return "";
+}
+
 QString ModelPart::family(){
 	if (m_modelPartShared) return m_modelPartShared->family();
 
@@ -870,3 +925,58 @@ QString ModelPart::family(){
 bool ModelPart::hasViewItems() {
 	return (m_viewItems.count() > 0);
 }
+
+void ModelPart::setDBID(qulonglong dbid) {
+    if (m_modelPartShared) m_modelPartShared->setDBID(dbid);
+}
+
+qulonglong ModelPart::dbid() {
+    if (m_modelPartShared) return m_modelPartShared->dbid();
+
+    return 0;
+}
+
+const QList<ViewImage *> ModelPart::viewImages() {
+    if (m_modelPartShared) return m_modelPartShared->viewImages();
+
+    return EmptyViewImages;
+}
+
+void ModelPart::setViewImage(ViewImage * viewImage) {
+    if (m_modelPartShared) m_modelPartShared->setViewImage(viewImage);
+}
+
+void ModelPart::setTag(const QString & tag)
+{
+    if (m_modelPartShared) m_modelPartShared->setTag(tag);
+}
+
+void ModelPart::setProperty(const QString & name, const QString &value)
+{
+    if (m_modelPartShared) m_modelPartShared->setProperty(name, value);
+}
+
+void ModelPart::addConnector(Connector * connector) {
+    m_connectorHash.insert(connector->connectorSharedID(), connector);
+
+    if (m_modelPartShared) m_modelPartShared->addConnector(connector->connectorShared());
+}
+
+void ModelPart::flipSMDAnd() {
+    if (m_modelPartShared) m_modelPartShared->flipSMDAnd();
+}
+
+void ModelPart::setImageFileName(ViewLayer::ViewIdentifier viewIdentifier, const QString & filename) {
+    if (m_modelPartShared) m_modelPartShared->setImageFileName(viewIdentifier, filename);
+}
+
+void ModelPart::lookForZeroConnector() {
+    if (m_modelPartShared) m_modelPartShared->lookForZeroConnector();
+}
+
+bool ModelPart::hasZeroConnector() {
+    if (m_modelPartShared) return m_modelPartShared->hasZeroConnector();
+
+    return false;
+}
+
