@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5945 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-07 00:49:26 +0200 (Sat, 07 Apr 2012) $
+$Revision: 6501 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-02 11:19:01 +0200 (Tue, 02 Oct 2012) $
 
 ********************************************************************/
 
@@ -38,11 +38,11 @@ $Date: 2012-04-07 00:49:26 +0200 (Sat, 07 Apr 2012) $
 #include <QHash>
 #include <QList>
 #include <QPointer>
+#include <QSharedPointer>
 
 #include "modelpartshared.h"
 #include "../connectors/connector.h"
 #include "../connectors/bus.h"
-#include "../utils/svgandpartfilepath.h"
 
 class ModelPart : public QObject
 {
@@ -77,13 +77,13 @@ public:
 	Q_DECLARE_FLAGS(LocationFlags, LocationFlag)
 
 public:
-	ModelPart(QDomDocument *, const QString& path, ItemType type);
+	ModelPart(QDomDocument &, const QString& path, ItemType type);
 	ModelPart(ItemType type = ModelPart::Unknown);
 	~ModelPart();
 
 	ModelPart::ItemType itemType() const;
 	void setItemType(ItemType);
-	const QString & moduleID();
+	const QString & moduleID() const;
 	void copy(ModelPart *);
 	void copyNew(ModelPart *);
 	void copyStuff(ModelPart * modelPart);
@@ -95,6 +95,7 @@ public:
 	void addViewItem(class ItemBase *);
 	void removeViewItem(class ItemBase *);
 	class ItemBase * viewItem(QGraphicsScene * scene);
+	class ItemBase * viewItem(ViewLayer::ViewIdentifier);
 	bool hasViewItems();
 	void initConnectors(bool force=false);
 	const QHash<QString, QPointer<Connector> > & connectors();
@@ -105,6 +106,8 @@ public:
 	const QDomElement & instanceDomElement();
 	Connector * getConnector(const QString & id);
 
+    const QString & fritzingVersion();
+
 	const QString & title();
 	const QString & description();
 	const QString & url();
@@ -112,7 +115,7 @@ public:
 	const QStringList & displayKeys();
 	const QHash<QString,QString> & properties() const;
 	const QHash<QString, QPointer<Bus> > & buses();
-	QDomDocument * domDocument();
+	const QString & taxonomy();
 	const QString & version();
 	const QString & path();
 	const QString & label();
@@ -121,6 +124,8 @@ public:
 	const QString & uri();
 	const QDate & date();
 	QString family();
+    void setDBID(qulonglong);
+    qulonglong dbid();
 
 	Bus * bus(const QString & busID);
 	bool ignoreTerminalPoints();
@@ -135,7 +140,15 @@ public:
 	void setFzz(bool alien);
 	void setLocationFlag(bool setting, LocationFlag flag);
 
-	bool hasViewIdentifier(ViewIdentifierClass::ViewIdentifier viewIdentifier);
+	bool hasViewIdentifier(ViewLayer::ViewIdentifier);
+	bool canFlipVertical(ViewLayer::ViewIdentifier);
+	bool canFlipHorizontal(ViewLayer::ViewIdentifier);
+	bool anySticky(ViewLayer::ViewIdentifier);
+    QString imageFileName(ViewLayer::ViewIdentifier);
+    void setImageFileName(ViewLayer::ViewIdentifier, const QString & filename);
+    QString imageFileName(ViewLayer::ViewIdentifier, ViewLayer::ViewLayerID);
+    LayerList viewLayers(ViewLayer::ViewIdentifier);
+    void setViewImage(struct ViewImage *);
 
 	QList<ModelPart*> getAllParts();
 	QList<ModelPart*> getAllNonCoreParts();
@@ -148,24 +161,31 @@ public:
 	QString getNextTitle(const QString & candidate);
 
 	void setOrderedChildren(QList<QObject*> children);
-	void setProp(const QString & name, const QVariant & value);
-	QVariant prop(const QString & name) const;
-	void setProp(const char * name, const QVariant & value);
-	QVariant prop(const char * name) const;
-
+	void setLocalProp(const QString & name, const QVariant & value);
+	QVariant localProp(const QString & name) const;
+	void setLocalProp(const char * name, const QVariant & value);
+	QVariant localProp(const char * name) const;
+    void setTag(const QString &tag);
+	void setProperty(const QString & key, const QString & value);
+    
 	const QString & replacedby();
 	bool isObsolete();
 
-	void setFlippedSMD(bool);
 	bool flippedSMD();
 	bool needsCopper1();
-	bool hasViewFor(ViewIdentifierClass::ViewIdentifier);
-	bool hasViewFor(ViewIdentifierClass::ViewIdentifier, ViewLayer::ViewLayerID);
-	QString hasBaseNameFor(ViewIdentifierClass::ViewIdentifier);
+	bool hasViewFor(ViewLayer::ViewIdentifier);
+	bool hasViewFor(ViewLayer::ViewIdentifier, ViewLayer::ViewLayerID);
+	QString hasBaseNameFor(ViewLayer::ViewIdentifier);
 	void initBuses();
 	void clearBuses();
 	void setConnectorLocalName(const QString & id, const QString & name);
+	QString connectorLocalName(const QString & id);
 	void setLocalTitle(const QString &);
+    const QList<ViewImage *> viewImages();
+    void addConnector(Connector *);
+    void flipSMDAnd();
+    void lookForZeroConnector();
+    bool hasZeroConnector();
 
 public:
 	static long nextIndex();
@@ -198,7 +218,6 @@ protected:
 	QDomElement m_instanceDomElement;	// only used at load time (so far)
 
 	LocationFlags m_locationFlags;
-	bool m_originalModelPartShared;
 	bool m_indexSynched;
 
 	QString m_instanceTitle;
