@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5721 $:
+$Revision: 6417 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-01-03 16:53:58 +0100 (Tue, 03 Jan 2012) $
+$Date: 2012-09-14 23:34:09 +0200 (Fri, 14 Sep 2012) $
 
 ********************************************************************/
 
@@ -35,22 +35,30 @@ $Date: 2012-01-03 16:53:58 +0100 (Tue, 03 Jan 2012) $
 #include <QDate>
 #include <QPointer>
 
-#include "../viewidentifierclass.h"
 #include "../viewlayer.h"
 
+struct ViewImage {
+    ViewLayer::ViewIdentifier viewIdentifier;
+    qulonglong layers;
+    qulonglong sticky;
+    qulonglong flipped;
+    QString image;
+    bool canFlipHorizontal;
+    bool canFlipVertical;
+
+    ViewImage(ViewLayer::ViewIdentifier);
+};
+
 class ModelPartShared : public QObject
 {
 Q_OBJECT
 public:
 	ModelPartShared();
-	ModelPartShared(QDomDocument *, const QString & path);
+	ModelPartShared(QDomDocument &, const QString & path);
 	~ModelPartShared();
 
-	bool partlyLoaded();
-	void setPartlyLoaded(bool);
-
-	void setDomDocument(QDomDocument *);
-	QDomDocument * domDocument();
+	bool setDomDocument(QDomDocument &);
+	//QDomDocument * domDocument();
 
 	void copy(ModelPartShared* other);
 
@@ -74,6 +82,22 @@ public:
 	void setDate(QDate date);
 	const QString & dateAsStr();
 	void setDate(QString date);
+    void setDBID(qulonglong);
+    qulonglong dbid();
+    const QString & fritzingVersion();
+    void setFritzingVersion(const QString & fv);
+
+    const QList<ViewImage *> viewImages();
+    QString imageFileName(ViewLayer::ViewIdentifier, ViewLayer::ViewLayerID);
+    void setImageFileName(ViewLayer::ViewIdentifier, const QString & filename);
+    QString imageFileName(ViewLayer::ViewIdentifier);
+    bool anySticky(ViewLayer::ViewIdentifier);
+    bool hasMultipleLayers(ViewLayer::ViewIdentifier);
+    bool canFlipHorizontal(ViewLayer::ViewIdentifier);
+    bool canFlipVertical(ViewLayer::ViewIdentifier);
+    bool hasViewIdentifier(ViewLayer::ViewIdentifier viewIdentifier);
+    LayerList viewLayers(ViewLayer::ViewIdentifier viewIdentifier);
+    LayerList viewLayersFlipped(ViewLayer::ViewIdentifier viewIdentifier);
 
 	const QString & path();
 	void setPath(QString path);
@@ -82,10 +106,11 @@ public:
 
 	const QList< QPointer<class ConnectorShared> > connectorsShared();
 	void setConnectorsShared(QList< QPointer<class ConnectorShared> > connectors);
-	void connectorIDs(ViewIdentifierClass::ViewIdentifier viewId, ViewLayer::ViewLayerID viewLayerID, QStringList & connectorIDs, QStringList & terminalIDs, QStringList & legIDs);
+	void connectorIDs(ViewLayer::ViewIdentifier viewId, ViewLayer::ViewLayerID viewLayerID, QStringList & connectorIDs, QStringList & terminalIDs, QStringList & legIDs);
 
 	const QStringList &tags();
 	void setTags(const QStringList &tags);
+	void setTag(const QString &tag);
 
 	QString family();
 	void setFamily(const QString &family);
@@ -97,7 +122,7 @@ public:
 
 
 	void initConnectors();
-	void resetConnectorsInitialization();
+    void setConnectorsInitialized(bool); 
 	ConnectorShared * getConnectorShared(const QString & id);
 	bool ignoreTerminalPoints();
 
@@ -109,11 +134,15 @@ public:
 	void setFlippedSMD(bool);
 	bool flippedSMD();	
 	bool needsCopper1();
-	bool hasViewFor(ViewIdentifierClass::ViewIdentifier);
-	bool hasViewFor(ViewIdentifierClass::ViewIdentifier, ViewLayer::ViewLayerID);
-	void setHasViewFor(ViewIdentifierClass::ViewIdentifier, ViewLayer::ViewLayerID);
-	QString hasBaseNameFor(ViewIdentifierClass::ViewIdentifier);
-	void setHasBaseNameFor(ViewIdentifierClass::ViewIdentifier, const QString &);
+	bool hasViewFor(ViewLayer::ViewIdentifier);
+	bool hasViewFor(ViewLayer::ViewIdentifier, ViewLayer::ViewLayerID);
+	QString hasBaseNameFor(ViewLayer::ViewIdentifier);
+    void setViewImage(ViewImage *);
+    void addConnector(ConnectorShared *);
+    void insertBus(class BusShared *);
+    void lookForZeroConnector();
+    bool hasZeroConnector();
+    void addOwner(QObject *);
 
 protected:
 	void loadTagText(QDomElement parent, QString tagName, QString &field);
@@ -121,19 +150,23 @@ protected:
 	void populateTags(QDomElement parent, QStringList &list);
 	void populateProperties(QDomElement parent, QHash<QString,QString> &hash, QStringList & displayKeys);
 	void commonInit();
-	void loadDocument();
-	bool checkNeedsCopper1(QDomElement & copper0, QDomElement & copper1);
 	void ensurePartNumberProperty();
+    void copyPins(ViewLayer::ViewLayerID from, ViewLayer::ViewLayerID to);
+    LayerList viewLayersAux(ViewLayer::ViewIdentifier viewIdentifier, qulonglong (*accessor)(ViewImage *));
+
+protected slots:
+    void removeOwner();
 
 public:
 	static const QString PartNumberPropertyName;
 
 protected:
 
-	QDomDocument* m_domDocument;
+	//QDomDocument* m_domDocument;
 
 	QString m_uri;
 	QString m_moduleID;
+    QString m_fritzingVersion;
 	QString m_version;
 	QString m_author;
 	QString m_title;
@@ -152,16 +185,16 @@ protected:
 
 	QHash<QString, QPointer<class ConnectorShared> > m_connectorSharedHash;
 	QHash<QString, class BusShared *> m_buses;
-	QMultiHash<ViewIdentifierClass::ViewIdentifier, ViewLayer::ViewLayerID> m_hasViewFor;
-	QHash<ViewIdentifierClass::ViewIdentifier, QString> m_hasBaseNameFor;
-	QList<class ConnectorShared *> m_deletedList;
+    QHash<ViewLayer::ViewIdentifier, ViewImage *> m_viewImages;
 
 	bool m_connectorsInitialized;
 	bool m_ignoreTerminalPoints;
 
 	bool m_flippedSMD;
-	bool m_partlyLoaded;
 	bool m_needsCopper1;				// for converting pre-two-layer parts
+    qulonglong m_dbid;
+    bool m_hasZeroConnector;
+    int m_ownerCount;
 };
 
 class ModelPartSharedRoot : public ModelPartShared
