@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5759 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-16 07:45:36 +0100 (Mon, 16 Jan 2012) $
+$Revision: 6565 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-15 12:10:48 +0200 (Mon, 15 Oct 2012) $
 
 ********************************************************************/
 
@@ -41,15 +41,15 @@ class PaletteModel : public ModelBase
 Q_OBJECT
 public:
 	PaletteModel();
-	PaletteModel(bool makeRoot, bool doInit, bool fastLoad);
+	PaletteModel(bool makeRoot, bool doInit);
+    ~PaletteModel();
 	ModelPart * retrieveModelPart(const QString & moduleID);
-	void updateOrAddModelPart(const QString & moduleID, ModelPart *modelPart);
 	virtual bool containsModelPart(const QString & moduleID);
-	virtual ModelPart * loadPart(const QString & path, bool update, bool fastLoad);
+	virtual ModelPart * loadPart(const QString & path, bool update);
 	void clear();
 	bool loadedFromFile();
 	QString loadedFrom();
-	bool load(const QString & fileName, ModelBase* refModel);
+	bool loadFromFile(const QString & fileName, ModelBase* referenceModel, bool checkViews);
 	ModelPart * addPart(QString newPartPath, bool addToReference, bool updateIdAlreadyExists);
 	void removePart(const QString &moduleID);
     void removeParts();
@@ -63,16 +63,18 @@ protected:
 	bool m_loadedFromFile;
 	QString m_loadedFrom; // The file this was loaded from, only if m_loadedFromFile == true
 
-	bool m_loadingCore;
 	bool m_loadingContrib;
+    bool m_fullLoad;
 
 signals:
 	void loadedPart(int i, int total);
+    void incSearch();
+    void addSearchMaximum(int);
 
 protected:
-	virtual void initParts(bool fastLoad);
-	void loadParts(bool fastLoad);
-	void loadPartsAux(QDir & dir, QStringList & nameFilters, int & loadedPart, int totalParts, bool fastLoad);
+	virtual void initParts();
+	void loadParts();
+	void loadPartsAux(QDir & dir, QStringList & nameFilters, int & loadedPart, int totalParts);
 	void countParts(QDir & dir, QStringList & nameFilters, int & partCount);
     void search(ModelPart * modelPart, const QStringList & searchStrings, QList<ModelPart *> & modelParts, bool allowObsolete);
 
