@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5944 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-06 16:06:09 +0200 (Fri, 06 Apr 2012) $
+$Revision: 6569 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-16 05:51:14 +0200 (Tue, 16 Oct 2012) $
 
 ********************************************************************/
 
@@ -31,21 +31,23 @@ $Date: 2012-04-06 16:06:09 +0200 (Fri, 06 Apr 2012) $
 #include <QSettings>
 #include <QtDebug>
 #include <QInputDialog>
+#include <QDropEvent>
+#include <QMimeData>
 
 #include "binmanager.h"
 #include "stacktabwidget.h"
 #include "stacktabbar.h"
 
 #include "../../model/modelpart.h"
-#include "../../mainwindow.h"
+#include "../../mainwindow/mainwindow.h"
 #include "../../model/palettemodel.h"
 #include "../../waitpushundostack.h"
 #include "../../debugdialog.h"
-#include "../../partseditor/partseditormainwindow.h"
 #include "../../utils/folderutils.h"
 #include "../../utils/fileprogressdialog.h"
 #include "../../referencemodel/referencemodel.h"
 #include "../partsbinpalettewidget.h"
+#include "../partsbinview.h"
 
 ///////////////////////////////////////////////////////////
 
@@ -94,7 +96,6 @@ QString BinManager::SearchBinLocation;
 QString BinManager::SearchBinTemplateLocation;
 QString BinManager::ContribPartsBinLocation;
 QString BinManager::ContribPartsBinTemplateLocation;
-QString BinManager::TempPartsBinLocation;
 QString BinManager::TempPartsBinTemplateLocation;
 QString BinManager::CorePartsBinLocation;
 
@@ -103,13 +104,15 @@ QString BinManager::CurrentBinStyle = "background-color: black;";
 
 QHash<QString, QString> BinManager::StandardBinIcons;
 
-BinManager::BinManager(class ReferenceModel *refModel, class HtmlInfoView *infoView, WaitPushUndoStack *undoStack, MainWindow* parent)
+BinManager::BinManager(class ReferenceModel *referenceModel, class HtmlInfoView *infoView, WaitPushUndoStack *undoStack, MainWindow* parent)
 	: QFrame(parent)
 {
 	BinManager::Title = tr("Parts");
 
-	m_refModel = refModel;
-	m_paletteModel = NULL;
+    m_combinedMenu = NULL;
+    m_showListViewAction = m_showIconViewAction = NULL;
+
+	m_referenceModel = referenceModel;
 	m_infoView = infoView;
 	m_undoStack = undoStack;
 	m_defaultSaveFolder = FolderUtils::getUserDataStorePath("bins");
@@ -129,11 +132,17 @@ BinManager::BinManager(class ReferenceModel *refModel, class HtmlInfoView *infoV
 	lo->setMargin(0);
 	lo->setSpacing(0);
 	setMaximumHeight(500);
+}
 
+BinManager::~BinManager() {
+}
+
+void BinManager::initStandardBins()
+{
 	createCombinedMenu();
 	createContextMenus();
 
-	DebugDialog::debug("init bin manager");
+	//DebugDialog::debug("init bin manager");
 	QList<BinLocation *> actualLocations;
 	findAllBins(actualLocations);
 	restoreStateAndGeometry(actualLocations);
@@ -145,18 +154,14 @@ BinManager::BinManager(class ReferenceModel *refModel, class HtmlInfoView *infoV
 		registerBin(bin);
 		delete location;
 	}
-	DebugDialog::debug("open core bin");
+	//DebugDialog::debug("open core bin");
 	openCoreBinIn();
 		
-	DebugDialog::debug("after core bin");
+	//DebugDialog::debug("after core bin");
 
 	connectTabWidget();
 }
 
-BinManager::~BinManager() {
-
-}
-
 void BinManager::addBin(PartsBinPaletteWidget* bin) {
 	m_stackTabWidget->addTab(bin, bin->icon(), bin->title());
 	registerBin(bin);
@@ -165,25 +170,25 @@ void BinManager::addBin(PartsBinPaletteWidget* bin) {
 
 void BinManager::registerBin(PartsBinPaletteWidget* bin) {
 
-	if(bin->fileName() != ___emptyString___) {
+	if (!bin->fileName().isEmpty()) {
 		m_openedBins[bin->fileName()] = bin;
-	}
 
-	if (bin->fileName().compare(CorePartsBinLocation) == 0) {
-		bin->setAllowsChanges(false);
-	}
-	else if (bin->fileName().compare(SearchBinLocation) == 0) {
-		bin->setAllowsChanges(false);
-	}
-	else if (bin->fileName().compare(ContribPartsBinLocation) == 0) {
-		bin->setAllowsChanges(false);
-	}
-	else if (bin->fileName().compare(TempPartsBinLocation) == 0) {
-		bin->setAllowsChanges(false);
-	}
-	else if (bin->fileName().contains(FolderUtils::getApplicationSubFolderPath("bins"))) {
-		bin->setAllowsChanges(false);
-	}
+	    if (bin->fileName().compare(CorePartsBinLocation) == 0) {
+		    bin->setAllowsChanges(false);
+	    }
+	    else if (bin->fileName().compare(SearchBinLocation) == 0) {
+		    bin->setAllowsChanges(false);
+	    }
+	    else if (bin->fileName().compare(ContribPartsBinLocation) == 0) {
+		    bin->setAllowsChanges(false);
+	    }
+	    else if (bin->fileName().compare(m_tempPartsBinLocation) == 0) {
+		    bin->setAllowsChanges(false);
+	    }
+	    else if (bin->fileName().contains(FolderUtils::getApplicationSubFolderPath("bins"))) {
+		    bin->setAllowsChanges(false);
+	    }
+    }
 }
 
 void BinManager::connectTabWidget() {
@@ -203,22 +208,10 @@ void BinManager::insertBin(PartsBinPaletteWidget* bin, int index) {
 	m_stackTabWidget->setCurrentIndex(index);
 }
 
-void BinManager::loadFromModel(PaletteModel *model) {
-	Q_UNUSED(model);
-	/*PartsBinPaletteWidget* bin = newBin();
-	m_paletteModel=model;
-	bin->loadFromModel(model);
-	addBin(bin);*/
-}
-
-void BinManager::setPaletteModel(PaletteModel *model) {
-	m_paletteModel = model;
-}
-
 bool BinManager::beforeClosing() {
 	bool retval = true;
 
-	for(int j=0; j < m_stackTabWidget->count(); j++) {
+	for(int j = 0; j < m_stackTabWidget->count(); j++) {
 		PartsBinPaletteWidget *bin = qobject_cast<PartsBinPaletteWidget*>(m_stackTabWidget->widget(j));
 		if (bin && !bin->fastLoaded()) {
 			setAsCurrentTab(bin);
@@ -309,15 +302,15 @@ QString BinManager::createIfBinNotExists(const QString & dest, const QString & s
 	return binPath;
 }
 
-void BinManager::addPart(ModelPart *modelPart, int position) {
+void BinManager::addPartToBin(ModelPart *modelPart, int position) {
 	PartsBinPaletteWidget *bin = m_currentBin? m_currentBin: getOrOpenMyPartsBin();
-	addPartAux(bin,modelPart,position);
+	addPartToBinAux(bin,modelPart,position);
 }
 
-void BinManager::addToMyPart(ModelPart *modelPart) {
+void BinManager::addToMyParts(ModelPart *modelPart) {
 	PartsBinPaletteWidget *bin = getOrOpenMyPartsBin();
 	if (bin) {
-		addPartAux(bin,modelPart);
+		addPartToBinAux(bin,modelPart);
 		setAsCurrentTab(bin);
 	}
 }
@@ -325,31 +318,31 @@ void BinManager::addToMyPart(ModelPart *modelPart) {
 void BinManager::addToContrib(ModelPart *modelPart) {
 	PartsBinPaletteWidget *bin = getOrOpenBin(ContribPartsBinLocation, ContribPartsBinTemplateLocation);
 	if (bin) {
-		addPartAux(bin,modelPart);
+		addPartToBinAux(bin,modelPart);
 		setAsCurrentTab(bin);
 	}
 }
 
-void BinManager::addToTemp(ModelPart *modelPart) {
-	PartsBinPaletteWidget *bin = getOrOpenBin(TempPartsBinLocation, TempPartsBinTemplateLocation);
+void BinManager::addToTempPartsBin(ModelPart *modelPart) {
+	PartsBinPaletteWidget *bin = getOrOpenBin(m_tempPartsBinLocation, TempPartsBinTemplateLocation);
 	if (bin) {
-		addPartAux(bin,modelPart);
+		addPartToBinAux(bin,modelPart);
 		setAsCurrentTab(bin);
 		bin->setDirty(false);
 	}
 }
 
-void BinManager::hideTemp() {
+void BinManager::hideTempPartsBin() {
 	for (int i = 0; i < m_stackTabWidget->count(); i++) {
 		PartsBinPaletteWidget* bin = (PartsBinPaletteWidget *) m_stackTabWidget->widget(i);
-        if (bin->fileName() == TempPartsBinLocation) {
+        if (bin->fileName().compare(m_tempPartsBinLocation) == 0) {
             m_stackTabWidget->removeTab(i);
 			break;
 		}
 	}
 }
 
-void BinManager::addPartAux(PartsBinPaletteWidget *bin, ModelPart *modelPart, int position) {
+void BinManager::addPartToBinAux(PartsBinPaletteWidget *bin, ModelPart *modelPart, int position) {
 	if(bin) {
 		if (bin->fastLoaded()) {
 			bin->load(bin->fileName(), bin, false);
@@ -395,9 +388,10 @@ void BinManager::updateTitle(PartsBinPaletteWidget* w, const QString& newTitle)
 
 PartsBinPaletteWidget* BinManager::newBinIn() {
 	PartsBinPaletteWidget* bin = newBin();
-	bin->setPaletteModel(new PaletteModel(true, false, false),true);
+	bin->setPaletteModel(new PaletteModel(true, false), true);
 	bin->setTitle(tr("New bin (%1)").arg(++m_unsavedBinsCount));
 	insertBin(bin, m_stackTabWidget->count());
+    bin->setReadOnly(false);
 	renameBin();
 	return bin;
 }
@@ -436,9 +430,7 @@ PartsBinPaletteWidget* BinManager::openBinIn(QString fileName, bool fastLoad) {
 			// to force the user to take a decision of what to do with the imported parts
 			if(fileName.endsWith(FritzingBundledBinExtension)) {
 				setDirtyTab(bin);
-			} else {
-				bin->saveAsLastBin();
-			}
+			} 
 		}
 	}
 	if (!fastLoad) {
@@ -463,7 +455,7 @@ PartsBinPaletteWidget* BinManager::openCoreBinIn() {
 }
 
 PartsBinPaletteWidget* BinManager::newBin() {
-	PartsBinPaletteWidget* bin = new PartsBinPaletteWidget(m_refModel,m_infoView,m_undoStack,this);
+	PartsBinPaletteWidget* bin = new PartsBinPaletteWidget(m_referenceModel, m_infoView, m_undoStack,this);
 	connect(
 		bin, SIGNAL(fileNameUpdated(PartsBinPaletteWidget*, const QString&, const QString&)),
 		this, SLOT(updateFileName(PartsBinPaletteWidget*, const QString&, const QString&))
@@ -500,16 +492,15 @@ void BinManager::setAsCurrentBin(PartsBinPaletteWidget* bin) {
 	}
 
 	QString style = m_mainWindow->styleSheet();
-	StackTabBar *currTabBar = NULL;
 	if(m_currentBin && m_stackTabWidget) {
-		currTabBar = m_stackTabWidget->stackTabBar();
+		StackTabBar *currTabBar = m_stackTabWidget->stackTabBar();
 		currTabBar->setProperty("current","false");
 		currTabBar->setStyleSheet("");
 		currTabBar->setStyleSheet(style);
 	}
 	if(m_stackTabWidget) {
 		m_currentBin = bin;
-		currTabBar = m_stackTabWidget->stackTabBar();
+		StackTabBar *currTabBar = m_stackTabWidget->stackTabBar();
 		currTabBar->setProperty("current","true");
 		currTabBar->setStyleSheet("");
 		currTabBar->setStyleSheet(style);
@@ -729,50 +720,19 @@ void BinManager::tabCloseRequested(int index) {
 	closeBinIn(index);
 }
 
-void BinManager::addPartTo(PartsBinPaletteWidget* bin, ModelPart* mp) {
+void BinManager::addPartTo(PartsBinPaletteWidget* bin, ModelPart* mp, bool setDirty) {
 	if(mp) {
 		bool alreadyIn = bin->contains(mp->moduleID());
 		bin->addPart(mp);
-		if(!alreadyIn) {
+		if(!alreadyIn && setDirty) {
 			setDirtyTab(bin,true);
 		}
 	}
 }
 
-void BinManager::newPartTo(PartsBinPaletteWidget* bin) {
-	PartsEditorMainWindow *partsEditor = m_mainWindow->getPartsEditor(NULL, -1, NULL, bin);
-	if (partsEditor == NULL) return;
-
-	partsEditor->show();
-	partsEditor->raise();
-}
-
-void BinManager::importPartTo(PartsBinPaletteWidget* bin) {
-	QString newPartPath = QFileDialog::getOpenFileName(
-		this,
-		tr("Select a part to import"),
-		"",
-		tr("External Part (*%1)").arg(FritzingBundledPartExtension)
-	);
-	if(!newPartPath.isEmpty() && !newPartPath.isNull()) {
-		ModelPart *mp = m_mainWindow->loadBundledPart(newPartPath,!bin->allowsChanges());
-		if (bin->allowsChanges()) {
-			addPartTo(bin,mp);
-		}
-	}
-}
-
-void BinManager::editSelectedPartFrom(PartsBinPaletteWidget* bin) {
-	ModelPart *selectedMP = bin->selected();
-	PartsEditorMainWindow *partsEditor = m_mainWindow->getPartsEditor(selectedMP, -1, NULL, bin);
-	if (partsEditor == NULL) return;
-
-	partsEditor->show();
-	partsEditor->raise();
-}
-
-void BinManager::dockedInto(FDockWidget* dock) {
-	Q_UNUSED(dock);
+void BinManager::editSelectedPartNewFrom(PartsBinPaletteWidget* bin) {
+	ItemBase * itemBase = bin->selectedItemBase();
+	m_mainWindow->getPartsEditorNewAnd(itemBase);
 }
 
 bool BinManager::isTabReorderingEvent(QDropEvent* event) {
@@ -790,6 +750,8 @@ QList<QAction*> BinManager::openedBinsActions(const QString &moduleId) {
 
 	for (int i = 0; i < m_stackTabWidget->count(); i++) {
 		PartsBinPaletteWidget* pppw = (PartsBinPaletteWidget *) m_stackTabWidget->widget(i);
+        if (pppw->readOnly()) continue;
+
 		QAction *act = pppw->addPartToMeAction();
 		act->setEnabled(!pppw->contains(moduleId));
 		titlesAndActions[pppw->title()] = act;
@@ -812,28 +774,34 @@ void BinManager::initNames() {
     BinManager::SearchBinLocation = FolderUtils::getUserDataStorePath("bins")+"/search.fzb";
     BinManager::SearchBinTemplateLocation =":/resources/bins/search.fzb";
 	BinManager::ContribPartsBinLocation = FolderUtils::getUserDataStorePath("bins")+"/contribParts.fzb";
-	BinManager::TempPartsBinLocation = FolderUtils::getUserDataStorePath("bins")+"/tempParts.fzb";
     BinManager::CorePartsBinLocation = FolderUtils::getApplicationSubFolderPath("bins")+"/core.fzb";
+    BinManager::TempPartsBinTemplateLocation =":/resources/bins/temp.fzb";
 
 	StandardBinIcons.insert(BinManager::MyPartsBinLocation, "Mine.png");
 	StandardBinIcons.insert(BinManager::SearchBinLocation, "Search.png");
 	StandardBinIcons.insert(BinManager::ContribPartsBinLocation, "Contrib.png");
 	StandardBinIcons.insert(BinManager::CorePartsBinLocation, "Core.png");
-	StandardBinIcons.insert(BinManager::TempPartsBinLocation, "Temp.png");
 }
 
 void BinManager::search(const QString & searchText) {
     PartsBinPaletteWidget * searchBin = getOrOpenSearchBin();
     if (searchBin == NULL) return;
 
-    QList<ModelPart *> modelParts = m_refModel->search(searchText, false);
+    FileProgressDialog progress(tr("Searching..."), 0, this);
+    progress.setIncValueMod(10);
+    connect(m_referenceModel, SIGNAL(addSearchMaximum(int)), &progress, SLOT(addMaximum(int)));
+    connect(m_referenceModel, SIGNAL(incSearch()), &progress, SLOT(incValue()));
 
+    QList<ModelPart *> modelParts = m_referenceModel->search(searchText, false);
+
+    progress.setIncValueMod(1);
     searchBin->removeParts();
     foreach (ModelPart * modelPart, modelParts) {
         //DebugDialog::debug(modelPart->title());
-        this->addPartTo(searchBin, modelPart);
+        this->addPartTo(searchBin, modelPart, false);
+        progress.incValue();
     }
-
+ 
     setDirtyTab(searchBin);
 }
 
@@ -866,67 +834,69 @@ void BinManager::updateBinCombinedMenuCurrent() {
 }
 
 void BinManager::updateBinCombinedMenu(PartsBinPaletteWidget * bin) {
+    if (m_combinedMenu == NULL) return;
+
 	m_saveBinAction->setEnabled(bin->allowsChanges());
 	m_renameBinAction->setEnabled(bin->canClose());
 	m_closeBinAction->setEnabled(bin->canClose());
 	m_deleteBinAction->setEnabled(bin->canClose());
-	ModelPart *mp = bin->selected();
-	bool enabled = (mp != NULL);
-	m_editPartAction->setEnabled(enabled);
-	m_exportPartAction->setEnabled(enabled && !mp->isCore());
+	ItemBase *itemBase = bin->selectedItemBase();
+	bool enabled = (itemBase != NULL);
+	m_editPartNewAction->setEnabled(enabled && itemBase->canEditPart());
+	m_exportPartAction->setEnabled(enabled && !itemBase->modelPart()->isCore());
 	m_removePartAction->setEnabled(enabled && bin->allowsChanges());
-	m_importPartAction->setEnabled(true);
 }
 
 void BinManager::createCombinedMenu() 
 {
 	m_combinedMenu = new QMenu(tr("Bin"), this);
 
+    m_openAction = new QAction(tr("Import..."), this);
+	m_openAction->setStatusTip(tr("Load a Fritzing part (.fzpz), or a Fritzing parts bin (.fzb, .fzbz)"));
+	connect(m_openAction, SIGNAL(triggered()), this, SLOT(mainLoad()));
+
 	m_newBinAction = new QAction(tr("New Bin..."), this);
-	m_newBinAction->setToolTip(tr("Create a new parts bin"));
+	m_newBinAction->setStatusTip(tr("Create a new parts bin"));
 	connect(m_newBinAction, SIGNAL(triggered()),this, SLOT(newBinIn()));
 
-	m_openBinAction = new QAction(tr("Open Bin..."), this);
-	m_openBinAction->setToolTip(tr("Open a parts bin from a file"));
-	connect(m_openBinAction, SIGNAL(triggered()),this, SLOT(openNewBin()));
-
 	m_closeBinAction = new QAction(tr("Close Bin"), this);
-	m_closeBinAction->setToolTip(tr("Close parts bin"));
+	m_closeBinAction->setStatusTip(tr("Close parts bin"));
 	connect(m_closeBinAction, SIGNAL(triggered()),this, SLOT(closeBin()));
 
 	m_deleteBinAction = new QAction(tr("Delete Bin"), this);
-	m_deleteBinAction->setToolTip(tr("Delete parts bin"));
+	m_deleteBinAction->setStatusTip(tr("Delete parts bin"));
 	connect(m_deleteBinAction, SIGNAL(triggered()),this, SLOT(deleteBin()));
 
 	m_saveBinAction = new QAction(tr("Save Bin"), this);
-	m_saveBinAction->setToolTip(tr("Save parts bin"));
+	m_saveBinAction->setStatusTip(tr("Save parts bin"));
 	connect(m_saveBinAction, SIGNAL(triggered()),this, SLOT(saveBin()));
 
 	m_saveBinAsAction = new QAction(tr("Save Bin As..."), this);
-	m_saveBinAsAction->setToolTip(tr("Save parts bin as..."));
+	m_saveBinAsAction->setStatusTip(tr("Save parts bin as..."));
 	connect(m_saveBinAsAction, SIGNAL(triggered()),this, SLOT(saveBinAs()));
 
 	m_saveBinAsBundledAction = new QAction(tr("Export Bin..."), this);
-	m_saveBinAsBundledAction->setToolTip(tr("Save parts bin in compressed format..."));
+	m_saveBinAsBundledAction->setStatusTip(tr("Save parts bin in compressed format..."));
 	connect(m_saveBinAsBundledAction, SIGNAL(triggered()),this, SLOT(saveBundledBin()));
 
 	m_renameBinAction = new QAction(tr("Rename Bin..."), this);
-	m_renameBinAction->setToolTip(tr("Rename parts bin..."));
+	m_renameBinAction->setStatusTip(tr("Rename parts bin..."));
 	connect(m_renameBinAction, SIGNAL(triggered()),this, SLOT(renameBin()));
 
 	m_showListViewAction = new QAction(tr("Show Bin in List View"), this);
 	m_showListViewAction->setCheckable(true);
-	m_showListViewAction->setToolTip(tr("Display parts as a list"));
+	m_showListViewAction->setStatusTip(tr("Display parts as a list"));
 	connect(m_showListViewAction, SIGNAL(triggered()),this, SLOT(toListView()));
 
 	m_showIconViewAction = new QAction(tr("Show Bin in Icon View"), this);
 	m_showIconViewAction->setCheckable(true);
-	m_showIconViewAction->setToolTip(tr("Display parts as icons"));
+	m_showIconViewAction->setStatusTip(tr("Display parts as icons"));
 	connect(m_showIconViewAction, SIGNAL(triggered()),this, SLOT(toIconView()));
 
-	m_combinedMenu->addAction(m_newBinAction);
-	m_combinedMenu->addAction(m_openBinAction);
+    m_combinedMenu->addAction(m_openAction);
 	m_combinedMenu->addSeparator();
+
+	m_combinedMenu->addAction(m_newBinAction);
 	m_combinedMenu->addAction(m_closeBinAction);
 	m_combinedMenu->addAction(m_deleteBinAction);
 	m_combinedMenu->addAction(m_saveBinAction);
@@ -937,25 +907,18 @@ void BinManager::createCombinedMenu()
 	m_combinedMenu->addAction(m_showIconViewAction);
 	m_combinedMenu->addAction(m_showListViewAction);
 
-	m_newPartAction = new QAction(tr("New Part..."), this);
-	m_importPartAction = new QAction(tr("Import Part..."),this);
-	m_editPartAction = new QAction(tr("Edit Part..."),this);
+	m_editPartNewAction = new QAction(tr("Edit Part (new parts editor)..."),this);
 	m_exportPartAction = new QAction(tr("Export Part..."),this);
 	m_removePartAction = new QAction(tr("Remove Part"),this);
 
-	connect(m_newPartAction, SIGNAL(triggered()),this, SLOT(newPart()));
-	connect(m_importPartAction, SIGNAL(triggered()),this, SLOT(importPart()));
-	connect(m_editPartAction, SIGNAL(triggered()),this, SLOT(editSelected()));
+	connect(m_editPartNewAction, SIGNAL(triggered()),this, SLOT(editSelectedNew()));
 	connect(m_exportPartAction, SIGNAL(triggered()),this, SLOT(exportSelected()));
 	connect(m_removePartAction, SIGNAL(triggered()),this, SLOT(removeSelected()));
 
 	connect(m_combinedMenu, SIGNAL(aboutToShow()), this, SLOT(updateBinCombinedMenuCurrent()));
 
 	m_combinedMenu->addSeparator();
-	m_combinedMenu->addAction(m_newPartAction);
-	m_combinedMenu->addAction(m_importPartAction);
-	m_combinedMenu->addSeparator();
-	m_combinedMenu->addAction(m_editPartAction);
+	m_combinedMenu->addAction(m_editPartNewAction);
 	m_combinedMenu->addAction(m_exportPartAction);
 	m_combinedMenu->addAction(m_removePartAction);
 
@@ -971,15 +934,11 @@ void BinManager::createContextMenus() {
 	m_binContextMenu->addAction(m_renameBinAction);
 
 	m_partContextMenu = new QMenu(this);
-	m_partContextMenu->addAction(m_editPartAction);
+	m_partContextMenu->addAction(m_editPartNewAction);
 	m_partContextMenu->addAction(m_exportPartAction);
 	m_partContextMenu->addAction(m_removePartAction);
 }
 
-void BinManager::openNewBin() {
-	openBinIn("", false);
-}
-
 void BinManager::closeBin() {
 	closeBinIn(-1);
 }
@@ -1003,16 +962,35 @@ void BinManager::deleteBin() {
 	QFile::remove(filename);
 }
 
-void BinManager::newPart() {
-	newPartTo(currentBin());
+void BinManager::importPartToContribBin(const QString & filename) {
+
+	if (!filename.isEmpty() && !filename.isNull()) {
+        PartsBinPaletteWidget * bin = getOrOpenBin(ContribPartsBinLocation, ContribPartsBinTemplateLocation);
+        if (bin == NULL) return;
+
+        importPart(filename, bin);
+    }
 }
 
-void BinManager::importPart() {
-	importPartTo(currentBin());
+void BinManager::importPartToCurrentBin(const QString & filename) {
+
+	if (!filename.isEmpty() && !filename.isNull()) {
+        PartsBinPaletteWidget * bin = currentBin();
+        if (bin == NULL) return;
+
+        importPart(filename, bin);
+	}
 }
 
-void BinManager::editSelected() {
-	editSelectedPartFrom(currentBin());
+void BinManager::importPart(const QString & filename, PartsBinPaletteWidget * bin) {
+	ModelPart *mp = m_mainWindow->loadBundledPart(filename, !bin->allowsChanges());
+	if (bin->allowsChanges()) {
+		addPartTo(bin, mp, true);
+	}
+}
+
+void BinManager::editSelectedNew() {
+	editSelectedPartNewFrom(currentBin());
 }
 
 void BinManager::renameBin() {
@@ -1021,7 +999,7 @@ void BinManager::renameBin() {
 
 	if (!currentBin()->allowsChanges()) {
 		// TODO: disable menu item instead
-		QMessageBox::warning(NULL, tr("Read-only bin"), tr("This bin cannot be renamed."));
+		QMessageBox::warning(this, tr("Read-only bin"), tr("This bin cannot be renamed."));
 		return;
 	}
 
@@ -1059,6 +1037,9 @@ void BinManager::saveBinAs() {
 
 
 void BinManager::updateViewChecks(bool iconView) {
+    if (m_showListViewAction == NULL) return;
+    if (m_showIconViewAction == NULL) return;
+
 	if (iconView) {
 		m_showListViewAction->setChecked(false);
 		m_showIconViewAction->setChecked(true);
@@ -1092,7 +1073,7 @@ bool BinManager::removeSelected() {
 	PartsBinPaletteWidget * bin = currentBin();
 	if (bin == NULL) return false;
 
-	ModelPart * mp = bin->selected();
+	ModelPart * mp = bin->selectedModelPart();
 	if (mp == NULL) return false;
 
 	QMessageBox::StandardButton answer = QMessageBox::question(
@@ -1117,7 +1098,7 @@ void BinManager::exportSelected() {
 	PartsBinPaletteWidget * bin = currentBin();
 	if (bin == NULL) return;
 
-	ModelPart * mp = bin->selected();
+	ModelPart * mp = bin->selectedModelPart();
 	if (mp == NULL) return;
 
 	emit savePartAsBundled(mp->moduleID());
@@ -1138,12 +1119,11 @@ void BinManager::setTabIcon(PartsBinPaletteWidget* w, QIcon * icon)
 	}
 }
 
-
 void BinManager::copyFilesToContrib(ModelPart * mp, QWidget * originator) {
 	PartsBinPaletteWidget * bin = qobject_cast<PartsBinPaletteWidget *>(originator);
 	if (bin == NULL) return;
 
-	if (bin->fileName().compare(TempPartsBinLocation) != 0) return;				// only copy from temp bin
+	if (bin->fileName().compare(m_tempPartsBinLocation) != 0) return;				// only copy from temp bin
 
 	QString path = mp->path();
 	if (path.isEmpty()) return;
@@ -1160,9 +1140,9 @@ void BinManager::copyFilesToContrib(ModelPart * mp, QWidget * originator) {
 	dir.cd("svg");
 	dir.cd("contrib");
 
-	QList<ViewIdentifierClass::ViewIdentifier> viewIdentifiers;
-	viewIdentifiers << ViewIdentifierClass::IconView << ViewIdentifierClass::BreadboardView << ViewIdentifierClass::SchematicView << ViewIdentifierClass::PCBView;
-	foreach (ViewIdentifierClass::ViewIdentifier viewIdentifier, viewIdentifiers) {
+	QList<ViewLayer::ViewIdentifier> viewIdentifiers;
+	viewIdentifiers << ViewLayer::IconView << ViewLayer::BreadboardView << ViewLayer::SchematicView << ViewLayer::PCBView;
+	foreach (ViewLayer::ViewIdentifier viewIdentifier, viewIdentifiers) {
 		QString fn = mp->hasBaseNameFor(viewIdentifier);
 		if (!fn.isEmpty()) {
 			QFile svg(dir.absoluteFilePath(fn));
@@ -1170,3 +1150,52 @@ void BinManager::copyFilesToContrib(ModelPart * mp, QWidget * originator) {
 		}
 	}
 }
+
+bool BinManager::isTempPartsBin(PartsBinPaletteWidget * bin) {
+    return bin->fileName().compare(m_tempPartsBinLocation) == 0;
+}
+
+void BinManager::setTempPartsBinLocation(const QString & name) {
+    m_tempPartsBinLocation = name;
+    //StandardBinIcons.insert(m_tempPartsBinLocation, "Temp.png");
+}
+
+void BinManager::mainLoad() {
+	QString path = m_defaultSaveFolder;
+
+	QString fileName = FolderUtils::getOpenFileName(
+			this,
+			tr("Select a Fritzing File to Open"),
+			path,
+			tr("Fritzing Files (*%1 *%2 *%3);;Fritzing Part (*%1);;Fritzing Bin (*%2);;Fritzing Shareable Bin (*%3)")
+                .arg(FritzingBundledPartExtension)
+                .arg(FritzingBinExtension)
+                .arg(FritzingBundledBinExtension)
+		);
+
+    if (fileName.isEmpty()) return;
+
+    if (fileName.endsWith(FritzingBundledPartExtension)) {
+        importPartToCurrentBin(fileName);
+        return;
+    }
+
+    if (fileName.endsWith(FritzingBinExtension) || fileName.endsWith(FritzingBundledBinExtension)) {
+        openBinIn(fileName, false);
+    }
+}
+
+void BinManager::hideTabBar()
+{
+    m_stackTabWidget->stackTabBar()->hide();
+}
+
+void BinManager::reloadPart(const QString & moduleID) {
+	PartsBinView::removePartReference(moduleID);
+	for(int j = 0; j < m_stackTabWidget->count(); j++) {
+		PartsBinPaletteWidget *bin = qobject_cast<PartsBinPaletteWidget*>(m_stackTabWidget->widget(j));
+		if (bin == NULL) continue;
+
+		bin->reloadPart(moduleID);
+	}
+}
