@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5797 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-29 22:24:16 +0100 (Sun, 29 Jan 2012) $
+$Revision: 6494 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-29 17:40:27 +0200 (Sat, 29 Sep 2012) $
 
 ********************************************************************/
 
@@ -61,19 +61,17 @@ struct BinLocation {
 class BinManager : public QFrame {
 	Q_OBJECT
 	public:
-		BinManager(class ReferenceModel *refModel, class HtmlInfoView *infoView, class WaitPushUndoStack *undoStack, MainWindow* parent);
+		BinManager(class ReferenceModel *referenceModel, class HtmlInfoView *infoView, class WaitPushUndoStack *undoStack, MainWindow* parent);
 		virtual ~BinManager();
 
-		void loadFromModel(PaletteModel *model);
-		void setPaletteModel(PaletteModel *model);
-
-		void addBin(PartsBinPaletteWidget* bin);
+        void initStandardBins();
+        void addBin(PartsBinPaletteWidget* bin);
 		void insertBin(PartsBinPaletteWidget* bin, int index);
-		void addPart(ModelPart *modelPart, int position = -1);
-		void addToMyPart(ModelPart *modelPart);
+		void addPartToBin(ModelPart *modelPart, int position = -1);
+		void addToMyParts(ModelPart *modelPart);
 		void addToContrib(ModelPart *modelPart);
-		void addToTemp(ModelPart *modelPart);
-		void hideTemp();
+		void addToTempPartsBin(ModelPart *modelPart);
+		void hideTempPartsBin();
 
 		void addNewPart(ModelPart *modelPart);
 
@@ -95,12 +93,8 @@ class BinManager : public QFrame {
 		PartsBinPaletteWidget* openCoreBinIn();
 		void closeBinIn(int index);
 
-		void addPartTo(PartsBinPaletteWidget* bin, ModelPart* mp);
-		void newPartTo(PartsBinPaletteWidget* bin);
-		void importPartTo(PartsBinPaletteWidget* bin);
-		void editSelectedPartFrom(PartsBinPaletteWidget* bin);
-
-		void dockedInto(class FDockWidget* dock);
+		void addPartTo(PartsBinPaletteWidget* bin, ModelPart* mp, bool setDirty);
+		void editSelectedPartNewFrom(PartsBinPaletteWidget* bin);
 
 		const QString &getSelectedModuleIDFromSketch();
 		QList<QAction*> openedBinsActions(const QString &moduleId);
@@ -115,6 +109,12 @@ class BinManager : public QFrame {
 		QMenu * combinedMenu();
 		void setTabIcon(PartsBinPaletteWidget* w, QIcon *);
 		void copyFilesToContrib(ModelPart *, QWidget * originator);
+		void importPartToCurrentBin(const QString & filename);
+		void importPartToContribBin(const QString & filename);
+        bool isTempPartsBin(PartsBinPaletteWidget * bin);
+        void setTempPartsBinLocation(const QString & filename);
+        void hideTabBar();
+		void reloadPart(const QString & moduleID);
 
 	signals:
 		void savePartAsBundled(const QString &moduleId);
@@ -124,25 +124,23 @@ class BinManager : public QFrame {
 		void updateBinCombinedMenuCurrent();					
 		void toIconView();
 		void toListView();
+		void setAsCurrentBin(PartsBinPaletteWidget* bin);
 
 	protected slots:
 		void updateFileName(PartsBinPaletteWidget* bin, const QString &newFileName, const QString &oldFilename);
-		void setAsCurrentBin(PartsBinPaletteWidget* bin);
 		void currentChanged(int);
 		void tabCloseRequested(int);
 		PartsBinPaletteWidget* newBinIn();
-		void openNewBin();
 		void closeBin();
 		void deleteBin();
-		void newPart();
-		void importPart();
-		void editSelected();
+		void editSelectedNew();
 		void saveBin();
 		void saveBinAs();
 		void renameBin();
 		void exportSelected();
 		bool removeSelected();
 		void saveBundledBin();
+        void mainLoad();
 
 	protected:
 		void createMenu();
@@ -155,7 +153,7 @@ class BinManager : public QFrame {
         PartsBinPaletteWidget* getOrOpenSearchBin();
         PartsBinPaletteWidget* getOrOpenBin(const QString & dest, const QString & source);
         void connectTabWidget();
-		void addPartAux(PartsBinPaletteWidget *bin, ModelPart *modelPart, int position = -1);
+		void addPartToBinAux(PartsBinPaletteWidget *bin, ModelPart *modelPart, int position = -1);
 		PartsBinPaletteWidget* findBin(const QString & binLocation);
 		void createCombinedMenu();
 		void createContextMenus();
@@ -165,10 +163,11 @@ class BinManager : public QFrame {
 		void findBins(QDir &, QList<BinLocation *> & actualLocations, BinLocation::Location);
 		void readTheoreticalLocations(QList<BinLocation *> & theoreticalLocations);
 		void updateBinCombinedMenu(PartsBinPaletteWidget * bin);
+        void importPart(const QString & filename, PartsBinPaletteWidget * bin);
+
 
 protected:
-		ReferenceModel *m_refModel;
-		PaletteModel *m_paletteModel;
+		ReferenceModel *m_referenceModel;
 
 		HtmlInfoView *m_infoView;
 		WaitPushUndoStack *m_undoStack;
@@ -184,8 +183,8 @@ protected:
 		QMenu *m_binContextMenu;
 		QMenu *m_combinedMenu;		
 
+		QAction *m_openAction;
 		QAction *m_newBinAction;
-		QAction *m_openBinAction;
 		QAction *m_closeBinAction;
 		QAction *m_deleteBinAction;
 		QAction *m_saveBinAction;
@@ -198,12 +197,12 @@ protected:
 
 		QMenu *m_partContextMenu;
 		QMenu *m_partMenu;	
-		QAction *m_newPartAction;
-		QAction *m_importPartAction;
-		QAction *m_editPartAction;
+		QAction *m_editPartNewAction;
 		QAction *m_exportPartAction;
 		QAction *m_removePartAction;
 
+        QString m_tempPartsBinLocation;
+
 	protected:
 		static QString StandardBinStyle;
 		static QString CurrentBinStyle;
@@ -217,7 +216,6 @@ protected:
         static QString SearchBinTemplateLocation;
 		static QString ContribPartsBinLocation;
 		static QString ContribPartsBinTemplateLocation;
-		static QString TempPartsBinLocation;
 		static QString TempPartsBinTemplateLocation;
 		static QHash<QString, QString> StandardBinIcons;
 
