@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5797 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-29 22:24:16 +0100 (Sun, 29 Jan 2012) $
+$Revision: 6549 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-11 06:54:26 +0200 (Thu, 11 Oct 2012) $
 
 ********************************************************************/
 
@@ -40,7 +40,7 @@ $Date: 2012-01-29 22:24:16 +0100 (Sun, 29 Jan 2012) $
 
 StackTabBar::StackTabBar(StackTabWidget *parent) : QTabBar(parent) {
 	setAcceptDrops(true);
-	this->setUsesScrollButtons(false);
+	this->setUsesScrollButtons(true);
     //this->setContentsMargins(0,0,0,0);
     //this->setTabsClosable(true);
     setMovable(true);
@@ -90,6 +90,7 @@ void StackTabBar::dragMoveEvent(QDragMoveEvent* event) {
 			event->acceptProposedAction();
 			m_dragMoveTimer.setProperty("index", index);
 			if (!m_dragMoveTimer.isActive()) {
+                DebugDialog::debug("starting drag move timer");
 				m_dragMoveTimer.start();
 			}
 			//DebugDialog::debug(QString("setting index %1").arg(index));
