@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5721 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-03 16:53:58 +0100 (Tue, 03 Jan 2012) $
+$Revision: 6494 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-29 17:40:27 +0200 (Sat, 29 Sep 2012) $
 
 ********************************************************************/
 
@@ -41,8 +41,8 @@ $Date: 2012-01-03 16:53:58 +0100 (Tue, 03 Jan 2012) $
 
 #define ICON_SPACING 2
 
-PartsBinIconView::PartsBinIconView(ReferenceModel* refModel, PartsBinPaletteWidget *parent)
-    : InfoGraphicsView((QWidget*)parent), PartsBinView(refModel, parent)
+PartsBinIconView::PartsBinIconView(ReferenceModel* referenceModel, PartsBinPaletteWidget *parent)
+    : InfoGraphicsView((QWidget*)parent), PartsBinView(referenceModel, parent)
 {
 	setAcceptWheelEvents(false);
     setFrameStyle(QFrame::Raised | QFrame::StyledPanel);
@@ -160,7 +160,7 @@ void PartsBinIconView::removePart(const QString &moduleID) {
         }
     }
     if(itemToRemove) {
-        m_partHash.remove(moduleID);
+        m_itemBaseHash.remove(moduleID);
         itemToRemove->setParentItem(NULL);
         m_noSelectionChangeEmition = true;
         m_layout->removeItem(itemToRemove);
@@ -179,8 +179,7 @@ void PartsBinIconView::removeParts() {
             itemsToRemove.append(it);
         }
     }
-    m_partHash.clear();
-
+    m_itemBaseHash.clear();
 
     foreach (SvgIconWidget * itemToRemove, itemsToRemove) {
         m_noSelectionChangeEmition = true;
@@ -200,31 +199,18 @@ int PartsBinIconView::setItemAux(ModelPart * modelPart, int position) {
 
 	emit settingItem();
 	QString moduleID = modelPart->moduleID();
-	if(contains(moduleID)) {
-		m_partHash[moduleID]->copy(modelPart);
+	if (contains(moduleID)) {
 		return position;
 	}
 	
 	SvgIconWidget* svgicon = NULL;
 	if (modelPart->itemType() != ModelPart::Space) {
-		ItemBase * itemBase = PartFactory::createPart(modelPart, ViewLayer::ThroughHoleThroughTop_OneLayer, ViewIdentifierClass::IconView, ViewGeometry(), ItemBase::getNextID(), NULL, NULL, false);
-		ItemBase::PluralType plural = itemBase->isPlural();
-		if (plural == ItemBase::NotSure) {
-			QHash<QString,QString> properties = modelPart->properties();
-			QString family = properties.value("family", "").toLower();
-			foreach (QString key, properties.keys()) {
-				QStringList values = m_refModel->values(family, key);
-				if (values.length() > 1) {
-					plural = ItemBase::Plural;
-					break;
-				}
-			}
-		}
-		svgicon = new SvgIconWidget(modelPart, ViewIdentifierClass::IconView, itemBase, plural == ItemBase::Plural);
-		m_partHash[moduleID] = modelPart;
+		ItemBase::PluralType plural;
+		ItemBase * itemBase = loadItemBase(moduleID, plural);
+        svgicon = new SvgIconWidget(modelPart, ViewLayer::IconView, itemBase, plural == ItemBase::Plural);
 	}
 	else {
-		svgicon = new SvgIconWidget(modelPart, ViewIdentifierClass::IconView, NULL, false);
+		svgicon = new SvgIconWidget(modelPart, ViewLayer::IconView, NULL, false);
 	}
 
 
@@ -257,7 +243,7 @@ void PartsBinIconView::loadFromModel(PaletteModel * model) {
 		QDomElement views = instance.firstChildElement("views");
 		if (views.isNull()) continue;
 
-		QString name = ViewIdentifierClass::viewIdentifierXmlName(ViewIdentifierClass::IconView);
+		QString name = ViewLayer::viewIdentifierXmlName(ViewLayer::IconView);
 		QDomElement view = views.firstChildElement(name);
 		if (view.isNull()) continue;
 
@@ -268,7 +254,7 @@ void PartsBinIconView::loadFromModel(PaletteModel * model) {
 	}
 }
 
-ModelPart *PartsBinIconView::selected() {
+ModelPart *PartsBinIconView::selectedModelPart() {
 	SvgIconWidget *icon = dynamic_cast<SvgIconWidget *>(selectedAux());
 	if(icon) {
 		return icon->modelPart();
@@ -277,6 +263,15 @@ ModelPart *PartsBinIconView::selected() {
 	}
 }
 
+ItemBase *PartsBinIconView::selectedItemBase() {
+	SvgIconWidget *icon = dynamic_cast<SvgIconWidget *>(selectedAux());
+	if(icon) {
+		return icon->itemBase();
+	} else {
+		return NULL;
+	}
+}
+
 void PartsBinIconView::setSelected(int position, bool doEmit) {
 	QGraphicsLayoutItem *glIt = m_layout->itemAt(position);
 	if(SvgIconWidget *item = dynamic_cast<SvgIconWidget*>(glIt)) {
@@ -362,13 +357,13 @@ int PartsBinIconView::itemIndexAt(const QPoint& pos, bool &trustIt) {
 }
 
 bool PartsBinIconView::inEmptyArea(const QPoint& pos) {
+    // used only by internal drag and drop
 	if(m_layout->count() == 0) {
 		return true;
 	} else {
 		QGraphicsLayoutItem *lastItem = m_layout->itemAt(m_layout->count()-1);
 		QPointF itemBottomRightPoint =
 			lastItem->graphicsItem()->mapToScene(lastItem->contentsRect().bottomRight());
-		QPointF posF = mapToScene(pos);
 
 		return itemBottomRightPoint.y() < pos.y()
 			|| ( itemBottomRightPoint.y() >= pos.y()
@@ -437,3 +432,45 @@ SvgIconWidget * PartsBinIconView::svgIconWidgetAt(const QPoint & pos) {
 
 	return NULL;
 }
+
+void PartsBinIconView::reloadPart(const QString & moduleID) {
+	if (!contains(moduleID)) return;
+
+	for (int i = 0; i < m_layout->count(); i++) {
+		SvgIconWidget *it = dynamic_cast<SvgIconWidget*>(m_layout->itemAt(i));
+		if (it == NULL) continue;
+
+		if (it->itemBase()->moduleID().compare(moduleID) != 0) continue;
+
+		ItemBase::PluralType plural;
+		ItemBase * itemBase = loadItemBase(moduleID, plural);
+
+		it->setItemBase(itemBase, plural);
+		return;
+	}
+}
+
+ItemBase * PartsBinIconView::loadItemBase(const QString & moduleID, ItemBase::PluralType & plural) {
+	ItemBase * itemBase = ItemBaseHash.value(moduleID);
+	ModelPart * modelPart = m_referenceModel->retrieveModelPart(moduleID);
+    if (itemBase == NULL) {
+		itemBase = PartFactory::createPart(modelPart, ViewLayer::ThroughHoleThroughTop_OneLayer, ViewLayer::IconView, ViewGeometry(), ItemBase::getNextID(), NULL, NULL, false);
+		ItemBaseHash.insert(moduleID, itemBase);
+	}
+	m_itemBaseHash.insert(moduleID, itemBase);
+
+    plural = itemBase->isPlural();
+	if (plural == ItemBase::NotSure) {
+		QHash<QString,QString> properties = modelPart->properties();
+		QString family = properties.value("family", "").toLower();
+		foreach (QString key, properties.keys()) {
+			QStringList values = m_referenceModel->propValues(family, key, true);
+			if (values.length() > 1) {
+				plural = ItemBase::Plural;
+				break;
+			}
+		}
+	}
+
+	return itemBase;
+}
