@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5721 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-03 16:53:58 +0100 (Tue, 03 Jan 2012) $
+$Revision: 6494 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-29 17:40:27 +0200 (Sat, 29 Sep 2012) $
 
 ********************************************************************/
 
@@ -43,7 +43,7 @@ class PartsBinIconView : public InfoGraphicsView, public PartsBinView
 {
 	Q_OBJECT
 	public:
-		PartsBinIconView(ReferenceModel* refModel, PartsBinPaletteWidget *parent);
+		PartsBinIconView(ReferenceModel* referenceModel, PartsBinPaletteWidget *parent);
 		void loadFromModel(class PaletteModel *);
 		void setPaletteModel(class PaletteModel *model, bool clear=false);
 		void addPart(ModelPart * model, int position = -1);
@@ -52,10 +52,12 @@ class PartsBinIconView : public InfoGraphicsView, public PartsBinView
 
 		bool swappingEnabled(ItemBase *);
 
-		ModelPart *selected();
+		ModelPart *selectedModelPart();
+		ItemBase *selectedItemBase();
 		int selectedIndex();
 
 		QList<QObject*> orderedChildren();
+		void reloadPart(const QString & moduleID);
 
 	protected:
 		void doClear();
@@ -78,6 +80,7 @@ class PartsBinIconView : public InfoGraphicsView, public PartsBinView
 		QGraphicsWidget* closestItemTo(const QPoint& pos);
 		class SvgIconWidget * svgIconWidgetAt(const QPoint & pos);
 		class SvgIconWidget * svgIconWidgetAt(int x, int y);
+		ItemBase * loadItemBase(const QString & moduleID, ItemBase::PluralType &);
 
 	public slots:
 		void setSelected(int position, bool doEmit=false);
