@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5783 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-26 07:31:21 +0100 (Thu, 26 Jan 2012) $
+$Revision: 6494 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-29 17:40:27 +0200 (Sat, 29 Sep 2012) $
 
 ********************************************************************/
 
@@ -41,8 +41,8 @@ $Date: 2012-01-26 07:31:21 +0100 (Thu, 26 Jan 2012) $
 static const QColor SectionHeaderBackgroundColor(128, 128, 128);
 static const QColor SectionHeaderForegroundColor(32, 32, 32);
 
-PartsBinListView::PartsBinListView(ReferenceModel* refModel, PartsBinPaletteWidget *parent)
-	: QListWidget((QWidget *) parent), PartsBinView(refModel, parent)
+PartsBinListView::PartsBinListView(ReferenceModel* referenceModel, PartsBinPaletteWidget *parent)
+	: QListWidget((QWidget *) parent), PartsBinView(referenceModel, parent)
 {
 	m_infoView = NULL;
 	m_hoverItem = NULL;
@@ -66,10 +66,6 @@ PartsBinListView::PartsBinListView(ReferenceModel* refModel, PartsBinPaletteWidg
 }
 
 PartsBinListView::~PartsBinListView() {
-	for (int i = 0; i < this->count(); i++) {
-		QListWidgetItem * item = this->item(i);
-		delete item->data(Qt::UserRole).value<ItemBase *>();
-	}
 }
 
 void PartsBinListView::doClear() {
@@ -87,8 +83,7 @@ int PartsBinListView::setItemAux(ModelPart * modelPart, int position) {
 
 	emit settingItem();
 	QString moduleID = modelPart->moduleID();
-	if(contains(moduleID)) {
-		m_partHash[moduleID]->copy(modelPart);
+	if (contains(moduleID)) {
 		return position;
 	}
 
@@ -101,23 +96,7 @@ int PartsBinListView::setItemAux(ModelPart * modelPart, int position) {
 		lwi->setText("        " + TranslatedCategoryNames.value(modelPart->instanceText(), modelPart->instanceText()));
 	}
 	else {
-		ItemBase * itemBase = PartFactory::createPart(modelPart, ViewLayer::ThroughHoleThroughTop_OneLayer, ViewIdentifierClass::IconView, ViewGeometry(), ItemBase::getNextID(), NULL, NULL, false);
-		lwi->setData(Qt::UserRole, qVariantFromValue( itemBase ) );
-		QString error;
-		LayerAttributes layerAttributes;
-		FSvgRenderer * renderer = ItemBase::setUpImage(modelPart, ViewIdentifierClass::IconView, ViewLayer::Icon, itemBase->viewLayerSpec(), layerAttributes, error);
-		if (renderer != NULL) {
-			if (itemBase) {
-				itemBase->setFilename(renderer->filename());
-			}
-			QSize size(HtmlInfoView::STANDARD_ICON_IMG_WIDTH, HtmlInfoView::STANDARD_ICON_IMG_HEIGHT);
-			QPixmap * pixmap = FSvgRenderer::getPixmap(modelPart->moduleID(), ViewLayer::Icon, size);
-			lwi->setIcon(QIcon(*pixmap));
-			delete pixmap;
-			lwi->setData(Qt::UserRole + 1, renderer->defaultSize());
-		}
-
-		m_partHash[moduleID] = modelPart;
+		loadImage(lwi, moduleID);
 	}
 
 	if(position > -1 && position < count()) {
@@ -132,8 +111,6 @@ int PartsBinListView::setItemAux(ModelPart * modelPart, int position) {
 }
 
 void PartsBinListView::mouseMoveEvent(QMouseEvent *event) {
-	if (m_infoView == NULL) return;
-
 	if(m_infoViewOnHover) {
 		QListWidgetItem * item = itemAt(event->pos());
 		if (item != NULL) {
@@ -153,8 +130,8 @@ void PartsBinListView::showInfo(QListWidgetItem * item) {
 		return;
 	}
 
-	if (m_hoverItem != NULL) {
-		ItemBase * itemBase = m_hoverItem->data(Qt::UserRole).value<ItemBase *>();
+	if (m_hoverItem != NULL && m_infoView != NULL) {
+		ItemBase * itemBase = itemItemBase(m_hoverItem);
 		if (itemBase != NULL) {
 			m_infoView->hoverLeaveItem(NULL, NULL, itemBase);
 		}
@@ -165,11 +142,12 @@ void PartsBinListView::showInfo(QListWidgetItem * item) {
 	}
 
 	m_hoverItem = item;
-
-	ItemBase * itemBase = item->data(Qt::UserRole).value<ItemBase *>();
-	if (itemBase == NULL) return;
-
-	m_infoView->hoverEnterItem(NULL, NULL, itemBase, swappingEnabled());
+    if (m_infoView != NULL) {
+	    ItemBase * itemBase = itemItemBase(item);
+	    if (itemBase != NULL) {
+	        m_infoView->hoverEnterItem(NULL, NULL, itemBase, swappingEnabled());
+        }
+    }
 }
 
 
@@ -180,12 +158,12 @@ void PartsBinListView::mousePressEvent(QMouseEvent *event) {
 	QListWidgetItem * current = currentItem();
 	if (current == NULL) {
 		m_hoverItem = NULL;
-		m_infoView->viewItemInfo(NULL, NULL, false);
+        if (m_infoView != NULL) m_infoView->viewItemInfo(NULL, NULL, false);
 		return;
 	}
 
 	showInfo(current);
-	m_infoView->viewItemInfo(NULL, current->data(Qt::UserRole).value<ItemBase *>(), false);
+	if (m_infoView != NULL) m_infoView->viewItemInfo(NULL, itemItemBase(current), false);
 }
 
 void PartsBinListView::setInfoView(HtmlInfoView * infoView) {
@@ -196,14 +174,14 @@ void PartsBinListView::removePart(const QString &moduleID) {
 	m_hoverItem = NULL;
 	int idxToRemove = position(moduleID);
 	if(idxToRemove > -1) {
-		m_partHash.remove(moduleID);
+		m_itemBaseHash.remove(moduleID);
 		delete takeItem(idxToRemove);
 	}
 }
 
 void PartsBinListView::removeParts() {
 	m_hoverItem = NULL;
-    m_partHash.clear();
+    m_itemBaseHash.clear();
     while (count() > 0) {
         delete takeItem(0);
     }
@@ -218,18 +196,35 @@ int PartsBinListView::position(const QString &moduleID) {
 	return -1;
 }
 
+ItemBase * PartsBinListView::itemItemBase(const QListWidgetItem *item) const {
+    return item->data(Qt::UserRole).value<ItemBase *>();
+}
+
 ModelPart *PartsBinListView::itemModelPart(const QListWidgetItem *item) const {
-	ItemBase * itemBase = item->data(Qt::UserRole).value<ItemBase *>();
+	ItemBase * itemBase = itemItemBase(item);
 	if (itemBase == NULL) return NULL;
 
 	return itemBase->modelPart();
 }
 
 const QString &PartsBinListView::itemModuleID(const QListWidgetItem *item) {
-	return itemModelPart(item)->moduleID();
+    ModelPart *modelPart = itemModelPart(item);
+    if (modelPart == NULL) {
+        // this shouldn't happen?
+        return ___emptyString___;
+    }
+
+	return modelPart->moduleID();
 }
 
-ModelPart *PartsBinListView::selected() {
+ItemBase *PartsBinListView::selectedItemBase() {
+	if(selectedItems().size()==1) {
+		return itemItemBase(selectedItems()[0]);
+	}
+	return NULL;
+}
+
+ModelPart *PartsBinListView::selectedModelPart() {
 	if(selectedItems().size()==1) {
 		return itemModelPart(selectedItems()[0]);
 	}
@@ -364,3 +359,46 @@ void PartsBinListView::showContextMenu(const QPoint& pos) {
 	}
     menu->exec(mapToGlobal(pos));
 }
+
+void PartsBinListView::reloadPart(const QString & moduleID) {
+	if (!contains(moduleID)) return;
+
+	for(int i = 0; i < count(); i++) {
+		QListWidgetItem * lwi = item(i);
+		ItemBase * itemBase = itemItemBase(lwi);
+		if (itemBase == NULL) continue;
+
+		if (itemBase->moduleID().compare(moduleID) == 0) {
+			lwi->setText(itemBase->title());
+			loadImage(lwi, moduleID);
+			return;
+		}
+	}
+}
+
+void PartsBinListView::loadImage(QListWidgetItem * lwi, const QString & moduleID) 
+{
+    ItemBase * itemBase = ItemBaseHash.value(moduleID);
+    if (itemBase == NULL) {
+		ModelPart * modelPart = itemBase->modelPart();
+		itemBase = PartFactory::createPart(modelPart, ViewLayer::ThroughHoleThroughTop_OneLayer, ViewLayer::IconView, ViewGeometry(), ItemBase::getNextID(), NULL, NULL, false);
+		ItemBaseHash.insert(moduleID, itemBase);
+        QString error;
+		LayerAttributes layerAttributes;
+		FSvgRenderer * renderer = itemBase->setUpImage(modelPart, ViewLayer::IconView, ViewLayer::Icon, itemBase->viewLayerSpec(), layerAttributes, error);
+		if (renderer != NULL) {
+			if (itemBase) {
+				itemBase->setFilename(renderer->filename());
+			}
+            itemBase->setSharedRendererEx(renderer);
+        }
+    }
+	lwi->setData(Qt::UserRole, qVariantFromValue( itemBase ) );
+	QSize size(HtmlInfoView::STANDARD_ICON_IMG_WIDTH, HtmlInfoView::STANDARD_ICON_IMG_HEIGHT);
+	QPixmap * pixmap = FSvgRenderer::getPixmap(itemBase->renderer(), size);
+	lwi->setIcon(QIcon(*pixmap));
+	delete pixmap;
+	lwi->setData(Qt::UserRole + 1, itemBase->renderer()->defaultSize());
+
+	m_itemBaseHash.insert(moduleID, itemBase);
+}
\ No newline at end of file
