@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5944 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-06 16:06:09 +0200 (Fri, 06 Apr 2012) $
+$Revision: 6569 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-16 05:51:14 +0200 (Tue, 16 Oct 2012) $
 
 ********************************************************************/
 
@@ -40,15 +40,14 @@ $Date: 2012-04-06 16:06:09 +0200 (Fri, 06 Apr 2012) $
 #include "partsbincommands.h"
 #include "partsbiniconview.h"
 #include "partsbinlistview.h"
-#include "simpleeditablelabelwidget.h"
 #include "searchlineedit.h"
 #include "../utils/misc.h"
 #include "../debugdialog.h"
-#include "../dockmanager.h"
 #include "../infoview/htmlinfoview.h"
 #include "../utils/fileprogressdialog.h"
 #include "../utils/folderutils.h"
 #include "../utils/textutils.h"
+#include "../mainwindow/mainwindow.h"          // TODO: PartsBinPaletteWidget should not call MainWindow functions
 
 
 static QString CustomIconName = "Custom1.png";
@@ -58,11 +57,14 @@ inline bool isCustomSvg(const QString & string) {
 	return string.startsWith("<?xml") && string.contains(CustomIconTitle);
 }
 
+static QHash<QString, PaletteModel *> PaletteBinModels;
+
 //////////////////////////////////////////////
 
-PartsBinPaletteWidget::PartsBinPaletteWidget(ReferenceModel *refModel, HtmlInfoView *infoView, WaitPushUndoStack *undoStack, BinManager* manager) :
+PartsBinPaletteWidget::PartsBinPaletteWidget(ReferenceModel *referenceModel, HtmlInfoView *infoView, WaitPushUndoStack *undoStack, BinManager* manager) :
 	QFrame(manager)
 {
+    m_binLabel = NULL;
 	m_icon = NULL;
 	m_searchLineEdit = NULL;
 	m_saveQuietly = false;
@@ -76,7 +78,7 @@ PartsBinPaletteWidget::PartsBinPaletteWidget(ReferenceModel *refModel, HtmlInfoV
 
 	m_manager = manager;
 
-	m_refModel = refModel;
+	m_referenceModel = referenceModel;
 	m_canDeleteModel = false;
 	m_orderHasChanged = false;
 
@@ -85,12 +87,10 @@ PartsBinPaletteWidget::PartsBinPaletteWidget(ReferenceModel *refModel, HtmlInfoV
 	m_undoStack = new WaitPushUndoStack(this);
 	connect(m_undoStack, SIGNAL(cleanChanged(bool)), this, SLOT(undoStackCleanChanged(bool)) );
 
-	setupHeader();
-
-	m_iconView = new PartsBinIconView(m_refModel, this);
+	m_iconView = new PartsBinIconView(m_referenceModel, this);
 	m_iconView->setInfoView(infoView);
 
-	m_listView = new PartsBinListView(m_refModel, this);
+	m_listView = new PartsBinListView(m_referenceModel, this);
 	m_listView->setInfoView(infoView);
 
 	m_stackedWidget = new QStackedWidget(this);
@@ -100,14 +100,19 @@ PartsBinPaletteWidget::PartsBinPaletteWidget(ReferenceModel *refModel, HtmlInfoV
 	QVBoxLayout * vbl = new QVBoxLayout(this);
     vbl->setMargin(3);
     vbl->setSpacing(0);
-	vbl->addWidget(m_header);
 
-	QFrame * separator = new QFrame();
-	separator->setMaximumHeight(1);
-	separator->setObjectName("partsBinHeaderSeparator");
-    separator->setFrameShape(QFrame::HLine);
-    separator->setFrameShadow(QFrame::Plain);
-	vbl->addWidget(separator);
+    m_header = NULL;
+    setupHeader();
+    if (m_header) {
+	    vbl->addWidget(m_header);
+
+	    QFrame * separator = new QFrame();
+	    separator->setMaximumHeight(1);
+	    separator->setObjectName("partsBinHeaderSeparator");
+        separator->setFrameShape(QFrame::HLine);
+        separator->setFrameShadow(QFrame::Plain);
+	    vbl->addWidget(separator);
+    }
 
 	vbl->addWidget(m_stackedWidget);
 	this->setLayout(vbl);
@@ -129,7 +134,7 @@ PartsBinPaletteWidget::PartsBinPaletteWidget(ReferenceModel *refModel, HtmlInfoV
 	connect(m_listView, SIGNAL(informItemMoved(int,int)), this, SLOT(itemMoved()));
 	connect(m_iconView, SIGNAL(informItemMoved(int,int)), this, SLOT(itemMoved()));
 
-	m_binLabel->setText(m_title);
+	if (m_binLabel) m_binLabel->setText(m_title);
 
 	m_addPartToMeAction = new QAction(m_title,this);
 	connect(m_addPartToMeAction, SIGNAL(triggered()),this, SLOT(addSketchPartToMe()));
@@ -142,10 +147,20 @@ PartsBinPaletteWidget::~PartsBinPaletteWidget() {
 		delete m_model;
 		m_model = NULL;
 	}
+   
+    if (m_icon) delete m_icon;
 }
 
+void PartsBinPaletteWidget::cleanup() {
+    foreach (PaletteModel * paletteModel, PaletteBinModels) {
+        delete paletteModel;
+    }
+    PaletteBinModels.clear();
+}
+
+
 QSize PartsBinPaletteWidget::sizeHint() const {
-	return QSize(DockManager::DockDefaultWidth, DockManager::PartsBinDefaultHeight);
+	return QSize(DockWidthDefault, PartsBinHeightDefault);
 }
 
 QString PartsBinPaletteWidget::title() const {
@@ -155,14 +170,17 @@ QString PartsBinPaletteWidget::title() const {
 void PartsBinPaletteWidget::setTitle(const QString &title) {
 	if(m_title != title) {
 		m_title = title;
-		m_binLabel->setText(title);
+		if (m_binLabel) m_binLabel->setText(title);
 	}
 }
 
 void PartsBinPaletteWidget::setupHeader()
 {
-	m_combinedBinMenuButton = newToolButton("partsBinCombinedMenuButton");
-	m_combinedBinMenuButton->setMenu(m_manager->combinedMenu());
+    QMenu * combinedMenu = m_manager->combinedMenu();
+    if (combinedMenu == NULL) return;
+
+	m_combinedBinMenuButton = newToolButton("partsBinCombinedMenuButton", ___emptyString___, ___emptyString___);
+	m_combinedBinMenuButton->setMenu(combinedMenu);
 
 	m_binLabel = new QLabel(this);
 	m_binLabel->setObjectName("partsBinLabel");
@@ -237,7 +255,6 @@ bool PartsBinPaletteWidget::saveAsAux(const QString &filename) {
 
 	m_location = BinLocation::findLocation(filename);
 
-	saveAsLastBin();
 	if(oldFilename != m_fileName) {
 		emit fileNameUpdated(this,m_fileName,oldFilename);
 	}
@@ -275,14 +292,14 @@ void PartsBinPaletteWidget::grabTitle(PaletteModel *model) {
 	grabTitle(root->title(), iconFilename);
 	root->setIcon(iconFilename);
 
-	m_searchLineEdit->setText(root->searchTerm());
+	if (m_searchLineEdit) m_searchLineEdit->setText(root->searchTerm());
 }
 
 void PartsBinPaletteWidget::grabTitle(const QString & title, QString & iconFilename)
 {
 	m_title = title;
 	m_addPartToMeAction->setText(m_title);
-	m_binLabel->setText(m_title);
+	if (m_binLabel) m_binLabel->setText(m_title);
 
 	QString temp = BinManager::StandardBinIcons.value(m_fileName, "");
 	if (!temp.isEmpty()) {
@@ -304,7 +321,7 @@ void PartsBinPaletteWidget::grabTitle(const QString & title, QString & iconFilen
 		painter.begin(&image);
 		renderer.render(&painter, target);
 		painter.end();	
-		image.save("test icon.png");
+		//image.save(FolderUtils::getUserDataStorePath("") + "/test icon.png");
 		m_icon = new QIcon(QPixmap::fromImage(image));
 	}
 	else {
@@ -317,6 +334,10 @@ void PartsBinPaletteWidget::grabTitle(const QString & title, QString & iconFilen
 }
 
 void PartsBinPaletteWidget::addPart(ModelPart *modelPart, int position) {
+    if (m_model == NULL) {
+        return;
+    }
+
 	ModelPart *mp = m_model->addModelPart(m_model->root(),modelPart);
 
 	m_iconView->addPart(mp, position);
@@ -332,12 +353,12 @@ QToolButton* PartsBinPaletteWidget::newToolButton(const QString& btnObjName, con
 	toolBtn->setObjectName(btnObjName);
 	toolBtn->setToolButtonStyle(Qt::ToolButtonIconOnly);
 	toolBtn->setArrowType(Qt::NoArrow);
-	if (text != ___emptyString___) {
+	if (!text.isEmpty()) {
 		toolBtn->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
 		toolBtn->setText(text);
 	}
 	toolBtn->setPopupMode(QToolButton::InstantPopup);
-	if (imgPath != ___emptyString___) {
+	if (!imgPath.isEmpty()) {
 		toolBtn->setIcon(QIcon(imgPath));
 	}
 	toolBtn->setArrowType(Qt::NoArrow);
@@ -382,7 +403,6 @@ void PartsBinPaletteWidget::saveBundledBin() {
 		m_model->root()->getAllNonCoreParts(), true, "", true, false
 	);
 	setDirty(wasModified);
-	saveAsLastBin();
 }
 
 bool PartsBinPaletteWidget::loadBundledAux(QDir &unzipDir, QList<ModelPart*> mps) {
@@ -422,7 +442,6 @@ bool PartsBinPaletteWidget::open(QString fileName, QWidget * progressTarget, boo
 
     if(fileName.endsWith(FritzingBinExtension)) {
     	load(fileName, progressTarget, fastLoad);
-    	saveAsLastBin();
     	m_isDirty = false;
     } else if(fileName.endsWith(FritzingBundledBinExtension)) {
     	m_manager->mainWindow()->loadBundledNonAtomicEntity(fileName,this,false, false);
@@ -437,7 +456,7 @@ void PartsBinPaletteWidget::load(const QString &filename, QWidget * progressTarg
 
 	m_location = BinLocation::findLocation(filename);
 
-	DebugDialog::debug("loading bin");
+	//DebugDialog::debug("loading bin");
 
 	if (fastLoad) {
 		QString binName, iconName;
@@ -450,62 +469,64 @@ void PartsBinPaletteWidget::load(const QString &filename, QWidget * progressTarg
 	}
 
 	m_fastLoaded = false;
-	PaletteModel * oldModel = (m_canDeleteModel) ? m_model : NULL;
-	PaletteModel * paletteBinModel = new PaletteModel(true, false, false);
+    PaletteModel * paletteBinModel = PaletteBinModels.value(filename);
+    if (paletteBinModel == NULL) {
+	    paletteBinModel = new PaletteModel(true, false);
+	    //DebugDialog::debug("after palette model");
 
+	    QString name = m_title;
+	    if (name.isEmpty()) name = QFileInfo(filename).baseName();
 
-	DebugDialog::debug("after palette model");
-
-	QString name = m_title;
-	if (name.isEmpty()) name = QFileInfo(filename).baseName();
-
-	bool deleteWhenDone = false;
-    if (progressTarget != NULL) {
-        DebugDialog::debug("open progress " + filename);
-		deleteWhenDone = true;
-        progressTarget = m_loadingProgressDialog = new FileProgressDialog(tr("Loading..."), 200, progressTarget);
-		m_loadingProgressDialog->setBinLoadingChunk(200);
-		m_loadingProgressDialog->setBinLoadingCount(1);
-		m_loadingProgressDialog->setMessage(tr("loading bin '%1'").arg(name));
-		m_loadingProgressDialog->show();
-	}
+	    bool deleteWhenDone = false;
+        if (progressTarget != NULL) {
+            //DebugDialog::debug("open progress " + filename);
+		    deleteWhenDone = true;
+            progressTarget = m_loadingProgressDialog = new FileProgressDialog(tr("Loading..."), 200, progressTarget);
+		    m_loadingProgressDialog->setBinLoadingChunk(200);
+		    m_loadingProgressDialog->setBinLoadingCount(1);
+		    m_loadingProgressDialog->setMessage(tr("loading bin '%1'").arg(name));
+		    m_loadingProgressDialog->show();
+	    }
 	
-	if (progressTarget) {
-		connect(paletteBinModel, SIGNAL(loadingInstances(ModelBase *, QDomElement &)), progressTarget, SLOT(loadingInstancesSlot(ModelBase *, QDomElement &)));
-		connect(paletteBinModel, SIGNAL(loadingInstance(ModelBase *, QDomElement &)), progressTarget, SLOT(loadingInstanceSlot(ModelBase *, QDomElement &)));
-		connect(m_iconView, SIGNAL(settingItem()), progressTarget, SLOT(settingItemSlot()));
-		connect(m_listView, SIGNAL(settingItem()), progressTarget, SLOT(settingItemSlot()));
-	}
-	DebugDialog::debug(QString("loading bin '%1'").arg(name));
-	bool result = paletteBinModel->load(filename, m_refModel);
-	DebugDialog::debug(QString("done loading bin '%1'").arg(name));
+	    if (progressTarget) {
+		    connect(paletteBinModel, SIGNAL(loadingInstances(ModelBase *, QDomElement &)), progressTarget, SLOT(loadingInstancesSlot(ModelBase *, QDomElement &)));
+		    connect(paletteBinModel, SIGNAL(loadingInstance(ModelBase *, QDomElement &)), progressTarget, SLOT(loadingInstanceSlot(ModelBase *, QDomElement &)));
+		    connect(m_iconView, SIGNAL(settingItem()), progressTarget, SLOT(settingItemSlot()));
+		    connect(m_listView, SIGNAL(settingItem()), progressTarget, SLOT(settingItemSlot()));
+	    }
+	    DebugDialog::debug(QString("loading bin '%1'").arg(name));
+	    bool result = paletteBinModel->loadFromFile(filename, m_referenceModel, false);
+	    //DebugDialog::debug(QString("done loading bin '%1'").arg(name));
 
-	if (!result) {
-		QMessageBox::warning(NULL, QObject::tr("Fritzing"), QObject::tr("Friting cannot load the parts bin"));
-	}
-	else {
+	    if (!result) {
+		    QMessageBox::warning(NULL, QObject::tr("Fritzing"), QObject::tr("Fritzing cannot load the parts bin"));
+	    }
+	    else {
+		    m_fileName = filename;
+		    setPaletteModel(paletteBinModel,true);
+            PaletteBinModels.insert(filename, paletteBinModel);
+	    }
+
+	    if (progressTarget) {
+            //DebugDialog::debug("close progress " + filename);
+		    disconnect(paletteBinModel, SIGNAL(loadingInstances(ModelBase *, QDomElement &)), progressTarget, SLOT(loadingInstancesSlot(ModelBase *, QDomElement &)));
+		    disconnect(paletteBinModel, SIGNAL(loadingInstance(ModelBase *, QDomElement &)), progressTarget, SLOT(loadingInstanceSlot(ModelBase *, QDomElement &)));
+		    disconnect(m_iconView, SIGNAL(settingItem()), progressTarget, SLOT(settingItemSlot()));
+		    disconnect(m_listView, SIGNAL(settingItem()), progressTarget, SLOT(settingItemSlot()));
+		    if (deleteWhenDone) {
+			    m_loadingProgressDialog->close();
+			    delete m_loadingProgressDialog;
+		    }
+		    m_loadingProgressDialog = NULL;
+	    }
+    }
+    else {
 		m_fileName = filename;
 		setPaletteModel(paletteBinModel,true);
-		m_canDeleteModel = true;					// since we just created this model, we can delete it later
-		if (oldModel) {
-			delete oldModel;
-		}
-	}
+    }
 
-	if (progressTarget) {
-        DebugDialog::debug("close progress " + filename);
-		disconnect(paletteBinModel, SIGNAL(loadingInstances(ModelBase *, QDomElement &)), progressTarget, SLOT(loadingInstancesSlot(ModelBase *, QDomElement &)));
-		disconnect(paletteBinModel, SIGNAL(loadingInstance(ModelBase *, QDomElement &)), progressTarget, SLOT(loadingInstanceSlot(ModelBase *, QDomElement &)));
-		disconnect(m_iconView, SIGNAL(settingItem()), progressTarget, SLOT(settingItemSlot()));
-		disconnect(m_listView, SIGNAL(settingItem()), progressTarget, SLOT(settingItemSlot()));
-		if (deleteWhenDone) {
-			m_loadingProgressDialog->close();
-			delete m_loadingProgressDialog;
-		}
-		m_loadingProgressDialog = NULL;
-	}
 
-	DebugDialog::debug("done loading bin");
+	//DebugDialog::debug("done loading bin");
 	//delete paletteReferenceModel;
 }
 
@@ -558,13 +579,7 @@ bool PartsBinPaletteWidget::beforeClosing() {
 	return retval;
 }
 
-void PartsBinPaletteWidget::saveAsLastBin() {
-	QSettings settings;
-	settings.setValue("lastBin",m_fileName);
-}
-
 void PartsBinPaletteWidget::closeEvent(QCloseEvent* event) {
-	saveAsLastBin();
 	QFrame::closeEvent(event);
 }
 
@@ -573,8 +588,12 @@ void PartsBinPaletteWidget::mousePressEvent(QMouseEvent* event) {
 	QFrame::mousePressEvent(event);
 }
 
-ModelPart * PartsBinPaletteWidget::selected() {
-	return m_currentView->selected();
+ModelPart * PartsBinPaletteWidget::selectedModelPart() {
+	return m_currentView->selectedModelPart();
+}
+
+ItemBase * PartsBinPaletteWidget::selectedItemBase() {
+	return m_currentView->selectedItemBase();
 }
 
 bool PartsBinPaletteWidget::contains(const QString &moduleID) {
@@ -586,7 +605,7 @@ bool PartsBinPaletteWidget::hasAlienParts() {
 }
 
 void PartsBinPaletteWidget::addPart(const QString& moduleID, int position) {
-	ModelPart *modelPart = m_refModel->retrieveModelPart(moduleID);
+	ModelPart *modelPart = m_referenceModel->retrieveModelPart(moduleID);
 	addPart(modelPart, position);
 }
 
@@ -625,8 +644,8 @@ void PartsBinPaletteWidget::setInfoViewOnHover(bool infoViewOnHover) {
 void PartsBinPaletteWidget::addPartCommand(const QString& moduleID) {
 	/*bool updating = alreadyIn(moduleID);
 
-	QString partTitle = m_refModel->partTitle(moduleID);
-	if(partTitle == ___emptyString___) partTitle = moduleID;
+	QString partTitle = m_referenceModel->partTitle(moduleID);
+	if(partTitle.isEmpty()) partTitle = moduleID;
 
 	QString undoStackMsg;
 
@@ -709,9 +728,10 @@ QAction *PartsBinPaletteWidget::addPartToMeAction() {
 }
 
 void PartsBinPaletteWidget::addSketchPartToMe() {
+    m_manager->openBinIn(this->m_fileName, false);
 	QString moduleID = m_manager->getSelectedModuleIDFromSketch();
 	bool wasAlreadyIn = contains(moduleID);
-	addPart(moduleID);
+	addPart(moduleID, -1);
 	if(!wasAlreadyIn) {
 		setDirty();
 	}
@@ -747,10 +767,18 @@ bool PartsBinPaletteWidget::allowsChanges() {
 	return m_allowsChanges;
 }
 
+bool PartsBinPaletteWidget::readOnly() {
+	return !allowsChanges();
+}
+
 void PartsBinPaletteWidget::setAllowsChanges(bool allowsChanges) {
 	m_allowsChanges = allowsChanges;
 }
 
+void PartsBinPaletteWidget::setReadOnly(bool readOnly) {
+	setAllowsChanges(!readOnly);
+}
+
 void PartsBinPaletteWidget::focusSearch() {
 	if (m_searchLineEdit) {
 		QTimer::singleShot(20, this, SLOT(focusSearchAfter()));
@@ -872,7 +900,7 @@ bool PartsBinPaletteWidget::canClose() {
 		if (m_fileName.compare(BinManager::SearchBinLocation) == 0) return false;
 		if (m_fileName.compare(BinManager::ContribPartsBinLocation) == 0) return false;
 		if (m_fileName.compare(BinManager::MyPartsBinLocation) == 0) return false;	
-		if (m_fileName.compare(BinManager::TempPartsBinLocation) == 0) return false;	
+		if (m_manager->isTempPartsBin(this)) return false;	
 		return true;
 	case BinLocation::More:
 		return false;
@@ -887,3 +915,18 @@ bool PartsBinPaletteWidget::canClose() {
 void PartsBinPaletteWidget::copyFilesToContrib(ModelPart * mp, QWidget * originator) {
 	m_manager->copyFilesToContrib(mp, originator);
 }
+
+ModelPart * PartsBinPaletteWidget::root() {
+    if (m_model == NULL) return NULL;
+
+    return m_model->root();
+}
+
+bool PartsBinPaletteWidget::isTempPartsBin() {
+    return m_manager->isTempPartsBin(this);
+}
+
+void PartsBinPaletteWidget::reloadPart(const QString & moduleID) {
+	m_iconView->reloadPart(moduleID);
+	m_listView->reloadPart(moduleID);
+}
