@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 *********************************************** *********************
 
-$Revision: 5783 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-26 07:31:21 +0100 (Thu, 26 Jan 2012) $
+$Revision: 6494 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-29 17:40:27 +0200 (Sat, 29 Sep 2012) $
 
 ********************************************************************/
 
@@ -36,7 +36,6 @@ $Date: 2012-01-26 07:31:21 +0100 (Thu, 26 Jan 2012) $
 #include "../model/palettemodel.h"
 #include "../model/modelpart.h"
 #include "../waitpushundostack.h"
-#include "../utils/abstractimagebutton.h"
 #include "../utils/fileprogressdialog.h"
 #include "../utils/bundler.h"
 #include "binmanager/binmanager.h"
@@ -45,7 +44,7 @@ class PartsBinPaletteWidget : public QFrame, public Bundler {
 	Q_OBJECT
 
 	public:
-		PartsBinPaletteWidget(class ReferenceModel *refModel, class HtmlInfoView *infoView, WaitPushUndoStack *undoStack, class BinManager* manager);
+		PartsBinPaletteWidget(class ReferenceModel *referenceModel, class HtmlInfoView *infoView, WaitPushUndoStack *undoStack, class BinManager* manager);
 		~PartsBinPaletteWidget();
 
 		QSize sizeHint() const;
@@ -61,11 +60,12 @@ class PartsBinPaletteWidget : public QFrame, public Bundler {
 		bool beforeClosing();
 		bool canClose();
 
-		ModelPart * selected();
+		ModelPart * selectedModelPart();
+		ItemBase * selectedItemBase();
 		bool hasAlienParts();
 
 		void setInfoViewOnHover(bool infoViewOnHover);
-		void addPart(const QString& moduleID, int position = -1);
+		void addPart(const QString& moduleID, int position);
 		void addNewPart(ModelPart *modelPart);
         void removePart(const QString& moduleID);
         void removeParts();
@@ -79,7 +79,9 @@ class PartsBinPaletteWidget : public QFrame, public Bundler {
 		class PartsBinView *currentView();
 		QAction *addPartToMeAction();
 		bool allowsChanges();
+		bool readOnly();
 		void setAllowsChanges(bool);
+		void setReadOnly(bool);
 		void focusSearch();
 		void setSaveQuietly(bool);
         bool open(QString fileName, QWidget * progressTarget, bool fastLoad);
@@ -93,12 +95,14 @@ class PartsBinPaletteWidget : public QFrame, public Bundler {
 		bool fastLoaded();
 		BinLocation::Location location();
 		void copyFilesToContrib(ModelPart *, QWidget * originator);
+        ModelPart * root();
+        bool isTempPartsBin();
+		void reloadPart(const QString & moduleID);
 
 	public slots:
 		void addPartCommand(const QString& moduleID);
 		void removeAlienParts();
 		void itemMoved();
-		void saveAsLastBin();
 		void toIconView();
 		void toListView();
 		bool save();
@@ -135,7 +139,7 @@ class PartsBinPaletteWidget : public QFrame, public Bundler {
 
 		void afterModelSetted(PaletteModel *model);
 
-		QToolButton* newToolButton(const QString& btnObjName, const QString& imgPath = ___emptyString___, const QString &text = ___emptyString___);
+		QToolButton* newToolButton(const QString& btnObjName, const QString& imgPath, const QString &text);
 
 		bool loadBundledAux(QDir &unzipDir, QList<ModelPart*> mps);
 
@@ -143,7 +147,7 @@ class PartsBinPaletteWidget : public QFrame, public Bundler {
 
 	protected:
 		PaletteModel *m_model;
-		ReferenceModel *m_refModel;
+		ReferenceModel *m_referenceModel;
 		bool m_canDeleteModel;
 		bool m_orderHasChanged;
 
@@ -151,7 +155,6 @@ class PartsBinPaletteWidget : public QFrame, public Bundler {
 		QString m_defaultSaveFolder;
 		QString m_untitledFileName;
 
-		//class SimpleEditableLabelWidget *m_binTitle;
 		QString m_title;
 		bool m_isDirty;
 
@@ -181,6 +184,9 @@ class PartsBinPaletteWidget : public QFrame, public Bundler {
 		bool m_fastLoaded;
 		BinLocation::Location m_location;
 
+    public:
+        static void cleanup();
+
 	public:
 		static QString Title;
 };
