@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5783 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-26 07:31:21 +0100 (Thu, 26 Jan 2012) $
+$Revision: 6494 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-29 17:40:27 +0200 (Sat, 29 Sep 2012) $
 
 ********************************************************************/
 
@@ -36,8 +36,9 @@ $Date: 2012-01-26 07:31:21 +0100 (Thu, 26 Jan 2012) $
 #include "../utils/misc.h"
 
 QHash<QString, QString> PartsBinView::TranslatedCategoryNames;
+QHash<QString, ItemBase *> PartsBinView::ItemBaseHash;
 
-PartsBinView::PartsBinView(ReferenceModel *refModel, PartsBinPaletteWidget *parent) {
+PartsBinView::PartsBinView(ReferenceModel *referenceModel, PartsBinPaletteWidget *parent) {
 	if (TranslatedCategoryNames.count() == 0) {
 		TranslatedCategoryNames.insert("Basic", QObject::tr("Basic"));
 		TranslatedCategoryNames.insert("Input", QObject::tr("Input"));
@@ -56,10 +57,19 @@ PartsBinView::PartsBinView(ReferenceModel *refModel, PartsBinPaletteWidget *pare
 		TranslatedCategoryNames.insert("Sensors",  QObject::tr("Sensors"));
 	}
 
-	m_refModel = refModel;
+	m_referenceModel = referenceModel;
 	m_parent = parent;
 }
 
+PartsBinView::~PartsBinView() {
+}	
+
+void PartsBinView::cleanup() {
+    foreach (ItemBase * itemBase, ItemBaseHash.values()) {
+        delete itemBase;
+    }
+}
+
 void PartsBinView::setPaletteModel(PaletteModel * model, bool clear) {
 	if (clear) {
 		doClear();
@@ -76,7 +86,15 @@ void PartsBinView::reloadParts(PaletteModel * model) {
 }
 
 void PartsBinView::doClear() {
-	m_partHash.clear();
+	m_itemBaseHash.clear();
+}
+
+void PartsBinView::removePartReference(const QString & moduleID) {
+	ItemBase * itemBase = ItemBaseHash.value(moduleID);
+	if (itemBase) {
+		ItemBaseHash.remove(moduleID);
+		itemBase->deleteLater();
+	}
 }
 
 void PartsBinView::setItem(ModelPart * modelPart) {
@@ -109,6 +127,7 @@ void PartsBinView::mousePressOnItem(const QPoint &dragStartPos, const QString &m
 	mimeData->setData("action", "part-reordering");
 
 	ItemDrag::setOriginator(this->m_parent);
+    ItemDrag::setOriginatorIsTempBin(m_parent->isTempPartsBin());
 
 	QDrag * drag = new QDrag(dynamic_cast<QWidget*>(this));
 
@@ -197,7 +216,7 @@ void PartsBinView::dropEventAux(QDropEvent* event, bool justAppend) {
 		QPointF offset;
 		dataStream >> moduleID >> offset;
 
-		ModelPart * mp = m_refModel->retrieveModelPart(moduleID);
+		ModelPart * mp = m_referenceModel->retrieveModelPart(moduleID);
 		m_parent->copyFilesToContrib(mp, ItemDrag::originator());
 		if(mp) {
 			if(m_parent->contains(moduleID)) {
@@ -212,7 +231,7 @@ void PartsBinView::dropEventAux(QDropEvent* event, bool justAppend) {
 }
 
 bool PartsBinView::contains(const QString &moduleID) {
-	return m_partHash.contains(moduleID);
+	return m_itemBaseHash.contains(moduleID);
 }
 
 void PartsBinView::setInfoViewOnHover(bool infoViewOnHover) {
