@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5619 $:
-$Author: cohen@irascible.com $:
-$Date: 2011-11-16 16:16:04 +0100 (Wed, 16 Nov 2011) $
+$Revision: 6494 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-29 17:40:27 +0200 (Sat, 29 Sep 2012) $
 
 ********************************************************************/
 
@@ -38,8 +38,8 @@ class PartsBinPaletteWidget;
 class PartsBinView {
 
 	public:
-		PartsBinView(ReferenceModel *refModel, PartsBinPaletteWidget *parent);
-		virtual ~PartsBinView() {};				// removes compiler warnings
+		PartsBinView(ReferenceModel *referenceModel, PartsBinPaletteWidget *parent);
+		virtual ~PartsBinView();				// removes compiler warnings
 
 		virtual void setPaletteModel(PaletteModel * model, bool clear = false);
 		void reloadParts(PaletteModel * model);
@@ -47,12 +47,14 @@ class PartsBinView {
 		virtual void removePart(const QString &moduleID) = 0;
         virtual void removeParts() = 0;
 
-		virtual ModelPart *selected() = 0;
+		virtual ModelPart *selectedModelPart() = 0;
+		virtual ItemBase *selectedItemBase() = 0;
 
 		bool contains(const QString &moduleID);
 		void setInfoViewOnHover(bool infoViewOnHover);
 
 		virtual QList<QObject*> orderedChildren() = 0;
+		virtual void reloadPart(const QString & moduleID) = 0;
 		void dropEventAux(QDropEvent* event, bool justAppend = false);
 
 	protected:
@@ -71,18 +73,23 @@ class PartsBinView {
 
 		virtual int setItemAux(ModelPart * modelPart, int position = -1) = 0;
 
+    public:
+        static void cleanup();
+		static void removePartReference(const QString & moduleID);
+
 	public:
 		static QHash<QString, QString> TranslatedCategoryNames;
 
 	protected:
-
-		ReferenceModel *m_refModel;
+		ReferenceModel *m_referenceModel;
 		PartsBinPaletteWidget *m_parent;
 
-		QHash<QString /*moduleId*/,ModelPart*> m_partHash;
 		bool m_infoViewOnHover;
 
 		QPoint m_dragStartPos;
+        
+		QHash<QString, class ItemBase *> m_itemBaseHash;
+        static QHash<QString, class ItemBase *> ItemBaseHash;
 };
 
 #endif /* PARTSBINVIEW_H_ */
