@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5759 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-16 07:45:36 +0100 (Mon, 16 Jan 2012) $
+$Revision: 6469 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-23 00:54:30 +0200 (Sun, 23 Sep 2012) $
 
 ********************************************************************/
 
@@ -580,7 +580,7 @@ void ProgramTab::sendProgram() {
 	if (m_programmerPath.isEmpty()) return;
 
 	if (isModified()) {
-		QMessageBox::information(NULL, QObject::tr("Fritzing"), tr("The file '%1' must be saved before it can be sent to the programmer.").arg(m_filename));
+		QMessageBox::information(this, QObject::tr("Fritzing"), tr("The file '%1' must be saved before it can be sent to the programmer.").arg(m_filename));
 		return;
 	}
 
