@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5787 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-27 01:48:06 +0100 (Fri, 27 Jan 2012) $
+$Revision: 6496 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-30 02:00:34 +0200 (Sun, 30 Sep 2012) $
 
 ********************************************************************/
 
@@ -161,7 +161,7 @@ void ProgramWindow::initLanguages() {
 		}
 		else {
 			QString name = Syntaxer::parseForName(fileInfo.absoluteFilePath());
-			if (!name.isEmpty()) {		// Arduino is not really available      && !name.contains("arduino", Qt::CaseInsensitive)
+			if (!name.isEmpty() && !name.contains("arduino", Qt::CaseInsensitive)) {		// Arduino is not really available      
 				m_languages.insert(name, fileInfo.absoluteFilePath());
 			}
 		}
@@ -465,7 +465,8 @@ bool ProgramWindow::eventFilter(QObject * object, QEvent * event) {
  * Reimplement closeEvent to save any modified documents before closing.
  */
 void ProgramWindow::closeEvent(QCloseEvent *event) {
-	if(beforeClosing()) {
+	bool discard;
+	if(beforeClosing(true, discard)) {
 		cleanUp();
 		QMainWindow::closeEvent(event);
 		emit closed();
@@ -626,7 +627,8 @@ void ProgramWindow::setProgrammer(QAction* action) {
     currentWidget()->chooseProgrammer(action->data().toString());
 }
 
-bool ProgramWindow::beforeClosing(bool showCancel) {
+bool ProgramWindow::beforeClosing(bool showCancel, bool & discard) {
+	discard = false;
 	for (int i = 0; i < m_tabWidget->count(); i++) {
 		if (!beforeClosingTab(i, showCancel)) {
 			return false;
