@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2010 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by\
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5760 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-18 10:54:44 +0100 (Wed, 18 Jan 2012) $
+$Revision: 6496 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-30 02:00:34 +0200 (Sun, 30 Sep 2012) $
 
 ********************************************************************/
 
@@ -40,7 +40,7 @@ $Date: 2012-01-18 10:54:44 +0100 (Wed, 18 Jan 2012) $
 
 #include "syntaxer.h"
 
-#include "../fritzingwindow.h"
+#include "../mainwindow/fritzingwindow.h"
 
 struct LinkedFile {
 	enum FileFlag {
@@ -154,7 +154,7 @@ protected:
 	void initProgrammerNames();
 	QString getExtensionString();
 	QStringList getExtensions();
-	bool beforeClosing(bool showCancel=true); // returns true if close, false if cancel
+	bool beforeClosing(bool showCancel, bool & discard); // returns true if close, false if cancel
 	QStringList getSerialPortsAux();
 
 protected:
