@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,15 +18,16 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5909 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-03-10 14:48:44 +0100 (Sat, 10 Mar 2012) $
+$Revision: 6497 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-30 08:56:08 +0200 (Sun, 30 Sep 2012) $
 
 ********************************************************************/
 
 #include "breadboardsketchwidget.h"
 #include "../debugdialog.h"
 #include "../items/virtualwire.h"
+#include "../items/resizableboard.h"
 #include "../connectors/connectoritem.h"
 #include "../items/moduleidnames.h"
 #include "../waitpushundostack.h"
@@ -36,7 +37,7 @@ $Date: 2012-03-10 14:48:44 +0100 (Sat, 10 Mar 2012) $
 
 static const double WireHoverStrokeFactor = 4.0;
 
-BreadboardSketchWidget::BreadboardSketchWidget(ViewIdentifierClass::ViewIdentifier viewIdentifier, QWidget *parent)
+BreadboardSketchWidget::BreadboardSketchWidget(ViewLayer::ViewIdentifier viewIdentifier, QWidget *parent)
     : SketchWidget(viewIdentifier, parent)
 {
 	m_shortName = QObject::tr("bb");
@@ -109,10 +110,13 @@ BaseCommand::CrossViewType BreadboardSketchWidget::wireSplitCrossView()
 }
 
 bool BreadboardSketchWidget::canDropModelPart(ModelPart * modelPart) {	
+	if (!SketchWidget::canDropModelPart(modelPart)) return false;
+
+    if (Board::isBoard(modelPart)) {
+        return matchesLayer(modelPart);
+    }
+
 	switch (modelPart->itemType()) {
-		case ModelPart::Board:
-		case ModelPart::ResizableBoard:
-			return matchesLayer(modelPart);
 		case ModelPart::Logo:
 		case ModelPart::Symbol:
 		case ModelPart::Jumper:
@@ -123,6 +127,7 @@ bool BreadboardSketchWidget::canDropModelPart(ModelPart * modelPart) {
 		default:
 			if (modelPart->moduleID().endsWith(ModuleIDNames::SchematicFrameModuleIDName)) return false;
 			if (modelPart->moduleID().endsWith(ModuleIDNames::PadModuleIDName)) return false;
+			if (modelPart->moduleID().endsWith(ModuleIDNames::CopperBlockerModuleIDName)) return false;
 			return true;
 	}
 }
@@ -200,7 +205,7 @@ void BreadboardSketchWidget::addDefaultParts() {
 	long newID = ItemBase::getNextID();
 	ViewGeometry viewGeometry;
 	viewGeometry.setLoc(QPointF(0, 0));
-	m_addedDefaultPart = addItem(paletteModel()->retrieveModelPart(ModuleIDNames::BreadboardModuleIDName), defaultViewLayerSpec(), BaseCommand::CrossView, viewGeometry, newID, -1, NULL, NULL);
+	m_addedDefaultPart = addItem(referenceModel()->retrieveModelPart(ModuleIDNames::FullPlusBreadboardModuleIDName), defaultViewLayerSpec(), BaseCommand::CrossView, viewGeometry, newID, -1, NULL);
 	m_addDefaultParts = true;
 	// have to put this off until later, because positioning the item doesn't work correctly until the view is visible
 }
@@ -223,9 +228,10 @@ void BreadboardSketchWidget::showEvent(QShowEvent * event) {
 
 			// add a board to the empty sketch, and place it below the help area.
 
-			p += QPointF(0, 50);
+            p += QPointF(4, 50);
 			QPointF q = mapToScene(p.toPoint());
 			m_addedDefaultPart->setPos(q);
+			alignOneToGrid(m_addedDefaultPart);
 			QTimer::singleShot(10, this, SLOT(vScrollToZero()));
 		}
 	}
