@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5881 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-02-27 07:27:45 +0100 (Mon, 27 Feb 2012) $
+$Revision: 6460 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-20 17:37:06 +0200 (Thu, 20 Sep 2012) $
 
 ********************************************************************/
 
@@ -49,7 +49,7 @@ void InfoGraphicsView::viewItemInfo(ItemBase * item) {
 void InfoGraphicsView::hoverEnterItem(QGraphicsSceneHoverEvent * event, ItemBase * itemBase) {
 	if (m_infoView == NULL) return;
 
-	if (event->modifiers() & Qt::ShiftModifier || itemBase->viewIdentifier() == ViewIdentifierClass::IconView) {
+	if (event->modifiers() & Qt::ShiftModifier || itemBase->viewIdentifier() == ViewLayer::IconView) {
 		m_hoverEnterMode = true;
 		m_infoView->hoverEnterItem(this, event, itemBase ? itemBase->layerKinChief() : itemBase, swappingEnabled(itemBase));
 	}
@@ -242,9 +242,10 @@ void InfoGraphicsView::swap(const QString & family, const QString & prop, QMap<Q
 	emit swapSignal(family, prop, propsMap, itemBase);
 }
 
-void InfoGraphicsView::setInstanceTitle(long id, const QString & title, bool isUndoable, bool doEmit) {
+void InfoGraphicsView::setInstanceTitle(long id, const QString & oldTitle, const QString & newTitle, bool isUndoable, bool doEmit) {
 	Q_UNUSED(id);
-	Q_UNUSED(title);
+	Q_UNUSED(newTitle);
+	Q_UNUSED(oldTitle);
 	Q_UNUSED(isUndoable);
 	Q_UNUSED(doEmit);
 }
@@ -253,8 +254,7 @@ LayerHash & InfoGraphicsView::viewLayers() {
 	return ViewLayers;
 }
 
-void InfoGraphicsView::loadLogoImage(long itemID, const QString & oldSvg, const QSizeF oldAspectRatio, const QString & oldFilename, const QString & newFilename, bool addName) {
-	Q_UNUSED(itemID);
+void InfoGraphicsView::loadLogoImage(ItemBase *, const QString & oldSvg, const QSizeF oldAspectRatio, const QString & oldFilename, const QString & newFilename, bool addName) {
 	Q_UNUSED(oldSvg);
 	Q_UNUSED(oldAspectRatio);
 	Q_UNUSED(oldFilename);
@@ -276,11 +276,12 @@ int InfoGraphicsView::boardLayers() {
 	return m_boardLayers;
 }
 
-VirtualWire * InfoGraphicsView::makeOneRatsnestWire(ConnectorItem * source, ConnectorItem * dest, bool routed, QColor color) {
+VirtualWire * InfoGraphicsView::makeOneRatsnestWire(ConnectorItem * source, ConnectorItem * dest, bool routed, QColor color, bool force) {
 	Q_UNUSED(source);
 	Q_UNUSED(dest);
 	Q_UNUSED(routed);
 	Q_UNUSED(color);
+	Q_UNUSED(force);
 	return NULL;
 }
 
@@ -384,3 +385,26 @@ void InfoGraphicsView::setActiveConnectorItem(ConnectorItem * connectorItem)
 {
 	emit setActiveConnectorItemSignal(connectorItem);
 }
+
+void InfoGraphicsView::resolveTemporary(bool, ItemBase *)
+{
+}
+void InfoGraphicsView::newWire(Wire * wire) 
+{
+	bool succeeded = connect(wire, SIGNAL(wireChangedSignal(Wire*, const QLineF & , const QLineF & , QPointF, QPointF, ConnectorItem *, ConnectorItem *)	),
+			this, SLOT(wireChangedSlot(Wire*, const QLineF & , const QLineF & , QPointF, QPointF, ConnectorItem *, ConnectorItem *)),
+			Qt::DirectConnection);		// DirectConnection means call the slot directly like a subroutine, without waiting for a thread or queue
+	succeeded = connect(wire, SIGNAL(wireChangedCurveSignal(Wire*, const Bezier *, const Bezier *, bool)),
+			this, SLOT(wireChangedCurveSlot(Wire*, const Bezier *, const Bezier *, bool)),
+			Qt::DirectConnection);		// DirectConnection means call the slot directly like a subroutine, without waiting for a thread or queue
+	succeeded = succeeded && connect(wire, SIGNAL(wireSplitSignal(Wire*, QPointF, QPointF, const QLineF & )),
+			this, SLOT(wireSplitSlot(Wire*, QPointF, QPointF, const QLineF & )));
+	succeeded = succeeded && connect(wire, SIGNAL(wireJoinSignal(Wire*, ConnectorItem *)),
+			this, SLOT(wireJoinSlot(Wire*, ConnectorItem*)));
+	if (!succeeded) {
+		DebugDialog::debug("wire signal connect failed");
+	}
+
+	emit newWireSignal(wire);
+}
+
