@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5881 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-02-27 07:27:45 +0100 (Mon, 27 Feb 2012) $
+$Revision: 6460 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-20 17:37:06 +0200 (Thu, 20 Sep 2012) $
 
 ********************************************************************/
 
@@ -75,13 +75,13 @@ public:
 	virtual bool hasBigDots();
 
 	virtual LayerHash & viewLayers();
-	virtual void loadLogoImage(long itemID, const QString & oldSvg, const QSizeF oldAspectRatio, const QString & oldFilename, const QString & newFilename, bool addName);
+	virtual void loadLogoImage(ItemBase *, const QString & oldSvg, const QSizeF oldAspectRatio, const QString & oldFilename, const QString & newFilename, bool addName);
 
 	virtual void setNoteFocus(QGraphicsItem *, bool inFocus);
 
 	int boardLayers();
 	virtual void setBoardLayers(int, bool redraw);
-	virtual class VirtualWire * makeOneRatsnestWire(ConnectorItem * source, ConnectorItem * dest, bool routed, QColor);
+	virtual class VirtualWire * makeOneRatsnestWire(ConnectorItem * source, ConnectorItem * dest, bool routed, QColor, bool force);
 	virtual void getRatsnestColor(QColor &);
 
 	virtual void changeBus(ItemBase *, bool connec, const QString & oldBust, const QString & newBus, QList<ConnectorItem *> &, const QString & message);
@@ -107,6 +107,9 @@ public:
 	virtual void changeWireWidthMils(const QString newWidth);
 	virtual void changeWireColor(const QString newColor);
 	virtual void swap(const QString & family, const QString & prop, QMap<QString, QString> & propsMap, ItemBase *);
+    virtual void resolveTemporary(bool, ItemBase *);
+	virtual void newWire(Wire *);
+
 	void setActiveWire(Wire *);
 	void setActiveConnectorItem(ConnectorItem *);
 
@@ -114,7 +117,7 @@ public:
 public slots:
 	virtual void setVoltage(double, bool doEmit);
 	virtual void resizeBoard(double w, double h, bool doEmit);
-	virtual void setInstanceTitle(long id, const QString & title, bool isUndoable, bool doEmit);
+	virtual void setInstanceTitle(long id, const QString & oldTitle, const QString & newTitle, bool isUndoable, bool doEmit);
 
 signals:
 	void setVoltageSignal(double, bool doEmit);
@@ -122,6 +125,7 @@ signals:
 	void changePinLabelsSignal(ItemBase *, bool singleRow);
 	void setActiveWireSignal(Wire *);
 	void setActiveConnectorItemSignal(ConnectorItem *);
+	void newWireSignal(Wire *);
 
 public:
 	static InfoGraphicsView * getInfoGraphicsView(QGraphicsItem *);
