@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5944 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-06 16:06:09 +0200 (Fri, 06 Apr 2012) $
+$Revision: 6560 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-12 21:45:55 +0200 (Fri, 12 Oct 2012) $
 
 ********************************************************************/
 
@@ -35,7 +35,7 @@ class PCBSketchWidget : public SketchWidget
 	Q_OBJECT
 
 public:
-    PCBSketchWidget(ViewIdentifierClass::ViewIdentifier, QWidget *parent=0);
+    PCBSketchWidget(ViewLayer::ViewIdentifier, QWidget *parent=0);
 
 	void addViewLayers();
 	bool canDeleteItem(QGraphicsItem * item, int count);
@@ -43,6 +43,7 @@ public:
 	void createTrace(Wire *);
 	void excludeFromAutoroute(bool exclude);
 	void selectAllExcludedTraces();
+	void selectAllIncludedTraces();
 	bool hasAnyNets();
 	void forwardRoutingStatus(const RoutingStatus &);
 	void addDefaultParts();
@@ -65,17 +66,19 @@ public:
 	virtual double getLabelFontSizeLarge();
 	ViewLayer::ViewLayerID getWireViewLayerID(const ViewGeometry & viewGeometry, ViewLayer::ViewLayerSpec);
 	QList<ItemBase *> findBoard();
+    ItemBase * findSelectedBoard(int & boardCount);
+    ItemBase * findBoardBeneath(ItemBase *);
 	double getRatsnestOpacity();
 	double getRatsnestWidth();
 
 	void setBoardLayers(int, bool redraw);
-	long setUpSwap(ItemBase *, long newModelIndex, const QString & newModuleID, ViewLayer::ViewLayerSpec, bool doEmit, bool noFinalChangeWiresCommand, QList<Wire *> & wiresToDelete, QUndoCommand * parentCommand);
+    void swapLayers(ItemBase * itemBase, int newLayers, QUndoCommand * parentCommand);
 	void loadFromModelParts(QList<ModelPart *> & modelParts, BaseCommand::CrossViewType, QUndoCommand * parentCommand, 
 							bool offsetPaste, const QRectF * boundingRect, bool seekOutsideConnections, QList<long> & newIDs);
 	virtual bool isInLayers(ConnectorItem *, ViewLayer::ViewLayerSpec);
 	bool routeBothSides();
-	virtual bool sameElectricalLayer2(ViewLayer::ViewLayerID, ViewLayer::ViewLayerID);
-	void changeTraceLayer();
+	bool sameElectricalLayer2(ViewLayer::ViewLayerID, ViewLayer::ViewLayerID);
+	void changeTraceLayer(bool force, QUndoCommand * parentCommand);
 	void changeLayer(long id, double z, ViewLayer::ViewLayerID viewLayerID);
 	void updateNet(Wire*);
 	bool acceptsTrace(const ViewGeometry & viewGeometry);
@@ -87,17 +90,25 @@ public:
 	virtual double getAutorouterTraceWidth();
 	void getBendpointWidths(class Wire *, double w, double & w1, double & w2, bool & negativeOffsetRect);
 	double getSmallerTraceWidth(double minDim);
-	bool groundFill(bool fillGroundTraces, QUndoCommand * parentCommand);
+	bool groundFill(bool fillGroundTraces, ViewLayer::ViewLayerID, QUndoCommand * parentCommand);
 	void setGroundFillSeeds();
 	void clearGroundFillSeeds();
 	QString generateCopperFillUnit(ItemBase * itemBase, QPointF whereToStart);
 	double getWireStrokeWidth(Wire *, double wireWidth);
 	bool curvyWiresIndicated(Qt::KeyboardModifiers);
 	ItemBase * addCopperLogoItem(ViewLayer::ViewLayerSpec viewLayerSpec);
-	QString characterizeGroundFill();
+	QString characterizeGroundFill(ViewLayer::ViewLayerID);
 	ViewGeometry::WireFlag getTraceFlag();
-	void hideCopperLogoItems(QList<ItemBase *> & copperLogoItems);
-	void restoreCopperLogoItems(QList<ItemBase *> & copperLogoItems);
+	void hideCopperLogoItems(QList<ItemBase *> &);
+	void restoreCopperLogoItems(QList<ItemBase *> &);
+	void hideHoles(QList<ItemBase *> &);
+    QString makePasteMask(const QString & svgMask, ItemBase * board, double dpi, const LayerList & maskLayerIDs);
+	int selectAllItemType(ModelPart::ItemType, const QString & typeName);
+	bool isBoardLayerChange(ItemBase * itemBase, const QString & newModuleID, int & newLayers);
+	void convertToVia(ConnectorItem * lastHoverEnterConnectorItem);
+	void convertToBendpoint();
+    int checkLoadedTraces();
+	bool hasCustomBoardShape();
 
 public:
 	static QSizeF jumperItemSize();
@@ -120,7 +131,7 @@ public:
 protected:
 	void setWireVisible(Wire * wire);
 	// void checkAutorouted();
-	ViewLayer::ViewLayerID multiLayerGetViewLayerID(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier, ViewLayer::ViewLayerSpec, QDomElement & layers, QString & layerName);
+	ViewLayer::ViewLayerID multiLayerGetViewLayerID(ModelPart * modelPart, ViewLayer::ViewIdentifier, ViewLayer::ViewLayerSpec, LayerList &);
 	bool canChainWire(Wire *);
 	bool canDragWire(Wire * wire);
 	const QString & hoverEnterPartConnectorMessage(QGraphicsSceneHoverEvent * event, ConnectorItem * item);
@@ -136,7 +147,6 @@ protected:
 	double defaultGridSizeInches();
 	ViewLayer::ViewLayerID getLabelViewLayerID(ViewLayer::ViewLayerSpec);
 	ViewLayer::ViewLayerSpec wireViewLayerSpec(ConnectorItem *);
-	int isBoardLayerChange(ItemBase * itemBase, const QString & newModuleID, bool master);
 	bool resizingJumperItemPress(QGraphicsItem * item);
 	bool resizingJumperItemRelease();
 	bool resizingBoardPress(QGraphicsItem * item);
@@ -145,8 +155,6 @@ protected:
 	void resizeJumperItem();
 	QPoint calcFixedToCenterItemOffset(const QRect & viewPortRect, const QSizeF & helpSize);
 	void dealWithDefaultParts();
-	void changeTrace(Wire * wire, ConnectorItem * from, ConnectorItem * to, QUndoCommand * parentCommand);
-	void clearSmdTraces(QList<ItemBase *> & smds, 	QList<Wire *> & already, QUndoCommand * parentCommand);
 	bool connectorItemHasSpec(ConnectorItem * connectorItem, ViewLayer::ViewLayerSpec spec);
 	ViewLayer::ViewLayerSpec createWireViewLayerSpec(ConnectorItem * from, ConnectorItem * to);
 	Wire * createTempWireForDragging(Wire * fromWire, ModelPart * wireModel, ConnectorItem * connectorItem, ViewGeometry & viewGeometry, ViewLayer::ViewLayerSpec);
@@ -156,10 +164,16 @@ protected:
 	void setGroundFillSeeds(const QString & intro);
 	bool collectGroundFillSeeds(QList<ConnectorItem *> & seeds, bool includePotential);
 	void shiftHoles();
+	void selectAllXTraces(bool autoroutable, const QString & cmdText, bool forPCB);
+	bool canAlignToCenter(ItemBase *);
+    void selectAllWires(ViewGeometry::WireFlag flag);
+    QString checkDroppedModuleID(const QString & moduleID);
+    bool canConnect(Wire * from, ItemBase * to);
+	void collectThroughHole(QList<ConnectorItem *> & th, QList<ConnectorItem *> & pads, const LayerList &);
+	ViewLayer::ViewLayerSpec getViewLayerSpec(ModelPart * modelPart, QDomElement & instance, QDomElement & view, ViewGeometry &);
 
 signals:
-	void subSwapSignal(SketchWidget *, ItemBase *, ViewLayer::ViewLayerSpec, QUndoCommand * parentCommand);
-	void updateLayerMenuSignal();
+	void subSwapSignal(SketchWidget *, ItemBase *, const QString & newModuleID, ViewLayer::ViewLayerSpec, long & newID, QUndoCommand * parentCommand);
 	void boardDeletedSignal();
 	void groundFillSignal();
 	void copperFillSignal();
