@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5944 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-06 16:06:09 +0200 (Fri, 06 Apr 2012) $
+$Revision: 6546 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-10 20:47:53 +0200 (Wed, 10 Oct 2012) $
 
 ********************************************************************/
 
@@ -50,7 +50,7 @@ bool sameGround(ConnectorItem * c1, ConnectorItem * c2)
 	return (c1Grounded == c2Grounded);
 }
 
-SchematicSketchWidget::SchematicSketchWidget(ViewIdentifierClass::ViewIdentifier viewIdentifier, QWidget *parent)
+SchematicSketchWidget::SchematicSketchWidget(ViewLayer::ViewIdentifier viewIdentifier, QWidget *parent)
     : PCBSketchWidget(viewIdentifier, parent)
 {
 	m_shortName = QObject::tr("schem");
@@ -152,10 +152,11 @@ void SchematicSketchWidget::getLabelFont(QFont & font, QColor & color, ViewLayer
 
 void SchematicSketchWidget::setNewPartVisible(ItemBase * itemBase) {
 	switch (itemBase->itemType()) {
+		case ModelPart::Logo:
+            if (itemBase->moduleID().contains("schematic", Qt::CaseInsensitive)) break;
 		case ModelPart::Breadboard:
 		case ModelPart::Jumper:
 		case ModelPart::CopperFill:
-		case ModelPart::Logo:
 		case ModelPart::Via:
 		case ModelPart::Hole:
 			// don't need to see the breadboard in the other views
@@ -164,7 +165,7 @@ void SchematicSketchWidget::setNewPartVisible(ItemBase * itemBase) {
 			itemBase->setEverVisible(false);
 			return;
 		default:
-		if (itemBase->moduleID().endsWith(ModuleIDNames::PadModuleIDName)) {
+		    if (itemBase->moduleID().endsWith(ModuleIDNames::PadModuleIDName)) {
 				itemBase->setVisible(false);
 				itemBase->setEverVisible(false);
 				return;
@@ -174,10 +175,13 @@ void SchematicSketchWidget::setNewPartVisible(ItemBase * itemBase) {
 }
 
 bool SchematicSketchWidget::canDropModelPart(ModelPart * modelPart) {
+	if (!SketchWidget::canDropModelPart(modelPart)) return false;
+
 	switch (modelPart->itemType()) {
+		case ModelPart::Logo:
+            if (modelPart->moduleID().contains("schematic", Qt::CaseInsensitive)) return true;
 		case ModelPart::Jumper:
 		case ModelPart::CopperFill:
-		case ModelPart::Logo:
 		case ModelPart::Board:
 		case ModelPart::ResizableBoard:
 		case ModelPart::Breadboard:
@@ -192,6 +196,7 @@ bool SchematicSketchWidget::canDropModelPart(ModelPart * modelPart) {
 
 	if (modelPart->moduleID().endsWith(ModuleIDNames::SchematicFrameModuleIDName)) return true;
 	if (modelPart->moduleID().endsWith(ModuleIDNames::PadModuleIDName)) return false;
+	if (modelPart->moduleID().endsWith(ModuleIDNames::CopperBlockerModuleIDName)) return false;
 
 	return PCBSketchWidget::canDropModelPart(modelPart);
 }
@@ -238,6 +243,57 @@ void SchematicSketchWidget::changeConnection(long fromID, const QString & fromCo
 	m_updateDotsTimer.start();
 }
 
+void SchematicSketchWidget::setInstanceTitle(long itemID, const QString & oldText, const QString & newText, bool isUndoable, bool doEmit) {
+	// isUndoable is true when setInstanceTitle is called from the infoview 
+
+    if (isUndoable) {
+	    SymbolPaletteItem * sitem = qobject_cast<SymbolPaletteItem *>(findItem(itemID));
+	    if (sitem && sitem->isNetLabel()) {
+            setProp(sitem, "label", ItemBase::TranslatedPropertyNames.value("label"), oldText, newText, true);
+            return;
+        }
+    }
+
+    SketchWidget::setInstanceTitle(itemID, oldText, newText, isUndoable, doEmit);
+}
+
+void SchematicSketchWidget::setProp(ItemBase * itemBase, const QString & prop, const QString & trProp, const QString & oldValue, const QString & newValue, bool redraw)
+{
+    if (prop =="label") {
+        SymbolPaletteItem * sitem = qobject_cast<SymbolPaletteItem *>(itemBase);
+        if (sitem != NULL && sitem->isNetLabel()) {
+            if (sitem->getLabel() == newValue) {
+                return;
+            }
+
+            QUndoCommand * parentCommand =  new QUndoCommand();
+	        parentCommand->setText(tr("Change label from %1 to %2").arg(oldValue).arg(newValue));
+
+	        new CleanUpWiresCommand(this, CleanUpWiresCommand::UndoOnly, parentCommand);
+
+	        QList<Wire *> done;
+	        foreach (ConnectorItem * toConnectorItem, sitem->connector0()->connectedToItems()) {
+		        Wire * w = qobject_cast<Wire *>(toConnectorItem->attachedTo());
+		        if (w == NULL) continue;
+		        if (done.contains(w)) continue;
+
+		        QList<ConnectorItem *> ends;
+		        removeWire(w, ends, done, parentCommand);
+	        }
+
+	        new SetPropCommand(this, itemBase->id(), "label", oldValue, newValue, true, parentCommand);
+            new ChangeLabelTextCommand(this, itemBase->id(), oldValue, newValue, parentCommand);
+
+	        new CleanUpWiresCommand(this, CleanUpWiresCommand::RedoOnly, parentCommand);
+
+	        m_undoStack->waitPush(parentCommand, PropChangeDelay);
+            return;
+        }
+    }
+
+    SketchWidget::setProp(itemBase, prop, trProp, oldValue, newValue, redraw);
+}
+
 void SchematicSketchWidget::setVoltage(double v, bool doEmit)
 {
 	Q_UNUSED(doEmit);
@@ -293,12 +349,6 @@ const QString & SchematicSketchWidget::traceColor(ViewLayer::ViewLayerSpec) {
 	return SchematicTraceColor;
 }
 
-long SchematicSketchWidget::setUpSwap(ItemBase * itemBase, long newModelIndex, const QString & newModuleID, ViewLayer::ViewLayerSpec viewLayerSpec, bool master, bool noFinalChangeWiresCommand, QList<Wire *> & wiresToDelete, QUndoCommand * parentCommand)
-{
-	return SketchWidget::setUpSwap(itemBase, newModelIndex, newModuleID, viewLayerSpec, master, noFinalChangeWiresCommand, wiresToDelete, parentCommand);
-}
-
-
 bool SchematicSketchWidget::isInLayers(ConnectorItem * connectorItem, ViewLayer::ViewLayerSpec viewLayerSpec) {
 	Q_UNUSED(connectorItem);
 	Q_UNUSED(viewLayerSpec);
@@ -323,7 +373,7 @@ bool SchematicSketchWidget::sameElectricalLayer2(ViewLayer::ViewLayerID, ViewLay
 }
 
 double SchematicSketchWidget::getKeepout() {
-	return 0.1 * FSvgRenderer::printerScale();
+	return 0.1 * GraphicsUtils::SVGDPI;
 }
 
 bool SchematicSketchWidget::acceptsTrace(const ViewGeometry & viewGeometry) {
@@ -335,7 +385,7 @@ ViewGeometry::WireFlag SchematicSketchWidget::getTraceFlag() {
 }
 
 double SchematicSketchWidget::getTraceWidth() {
-	return FSvgRenderer::printerScale() * TraceWidthMils / 1000;
+	return GraphicsUtils::SVGDPI * TraceWidthMils / 1000;
 }
 
 double SchematicSketchWidget::getAutorouterTraceWidth() {
@@ -411,3 +461,16 @@ void SchematicSketchWidget::loadFromModelParts(QList<ModelPart *> & modelParts,
 {
 	SketchWidget::loadFromModelParts(modelParts, crossViewType, parentCommand, offsetPaste, boundingRect, seekOutsideConnections, newIDs);
 }
+
+void SchematicSketchWidget::selectAllWires(ViewGeometry::WireFlag flag) 
+{
+   SketchWidget::selectAllWires(flag);
+}
+
+bool SchematicSketchWidget::canConnect(Wire *, ItemBase *) {
+    return true;
+}
+
+QString SchematicSketchWidget::checkDroppedModuleID(const QString & moduleID) {
+    return moduleID;
+}
