@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5945 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-07 00:49:26 +0200 (Sat, 07 Apr 2012) $
+$Revision: 6546 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-10 20:47:53 +0200 (Wed, 10 Oct 2012) $
 
 ********************************************************************/
 
@@ -35,7 +35,7 @@ class SchematicSketchWidget : public PCBSketchWidget
 	Q_OBJECT
 
 public:
-    SchematicSketchWidget(ViewIdentifierClass::ViewIdentifier, QWidget *parent=0);
+    SchematicSketchWidget(ViewLayer::ViewIdentifier, QWidget *parent=0);
 
 	void addViewLayers();
 	ViewLayer::ViewLayerID getWireViewLayerID(const ViewGeometry & viewGeometry, ViewLayer::ViewLayerSpec);
@@ -63,7 +63,6 @@ public:
 	double defaultGridSizeInches();
 	const QString & traceColor(ConnectorItem * forColor);
 	const QString & traceColor(ViewLayer::ViewLayerSpec);
-	long setUpSwap(ItemBase *, long newModelIndex, const QString & newModuleID,  ViewLayer::ViewLayerSpec, bool doEmit, bool noFinalChangeWiresCommand, QList<Wire *> & wiresToDelete, QUndoCommand * parentCommand);
 	bool isInLayers(ConnectorItem *, ViewLayer::ViewLayerSpec);
 	bool routeBothSides();
 	void addDefaultParts();
@@ -81,6 +80,8 @@ public:
 
 public slots:
 	void setVoltage(double voltage, bool doEmit);
+	void setProp(ItemBase *, const QString & propName, const QString & translatedPropName, const QString & oldValue, const QString & newValue, bool redraw);
+	void setInstanceTitle(long id, const QString & oldTitle, const QString & newTitle, bool isUndoable, bool doEmit);
 
 protected slots:
 	void updateBigDots();
@@ -93,7 +94,9 @@ protected:
 	void extraRenderSvgStep(ItemBase *, QPointF offset, double dpi, double printerScale, QString & outputSvg);
 	QString makeCircleSVG(QPointF p, double r, QPointF offset, double dpi, double printerScale);
 	ViewLayer::ViewLayerSpec createWireViewLayerSpec(ConnectorItem * from, ConnectorItem * to);
-
+    void selectAllWires(ViewGeometry::WireFlag flag);
+    bool canConnect(Wire * from, ItemBase * to);
+    QString checkDroppedModuleID(const QString & moduleID);
 
 protected:
 	QTimer m_updateDotsTimer;
