@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5961 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-09 02:13:59 +0200 (Mon, 09 Apr 2012) $
+$Revision: 6572 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-16 13:08:45 +0200 (Tue, 16 Oct 2012) $
 
 ********************************************************************/
 
@@ -38,7 +38,7 @@ $Date: 2012-04-09 02:13:59 +0200 (Mon, 09 Apr 2012) $
 #include <QTimer>
 
 #include "../items/paletteitem.h"
-#include "../model/palettemodel.h"
+#include "../referencemodel/referencemodel.h"
 #include "../model/sketchmodel.h"
 #include "../viewgeometry.h"
 #include "infographicsview.h"
@@ -60,6 +60,17 @@ struct ItemCount {
 	int wireCount;
 };
 
+struct SwapThing {
+    bool firstTime;
+    long newID;
+    ItemBase * itemBase;
+    long newModelIndex;
+    QString newModuleID;
+    ViewLayer::ViewLayerSpec viewLayerSpec;
+    QList<Wire *> wiresToDelete;
+    QUndoCommand * parentCommand;
+};
+
 class SizeItem : public QObject, public QGraphicsLineItem
 {
 	Q_OBJECT
@@ -74,12 +85,12 @@ class SketchWidget : public InfoGraphicsView
 	Q_OBJECT
 
 public:
-    SketchWidget(ViewIdentifierClass::ViewIdentifier, QWidget *parent=0, int size=400, int minSize=300);
+    SketchWidget(ViewLayer::ViewIdentifier, QWidget *parent=0, int size=400, int minSize=300);
 	~SketchWidget();
 
 	void pushCommand(QUndoCommand *);
     class WaitPushUndoStack * undoStack();
-    ItemBase * addItem(ModelPart *, ViewLayer::ViewLayerSpec, BaseCommand::CrossViewType, const ViewGeometry &, long id, long modelIndex, AddDeleteItemCommand * originatingCommand, PaletteItem* item);
+    ItemBase * addItem(ModelPart *, ViewLayer::ViewLayerSpec, BaseCommand::CrossViewType, const ViewGeometry &, long id, long modelIndex, AddDeleteItemCommand * originatingCommand);
 	ItemBase * addItem(const QString & moduleID, ViewLayer::ViewLayerSpec, BaseCommand::CrossViewType, const ViewGeometry &, long id, long modelIndex, AddDeleteItemCommand * originatingCommand);
     void deleteItem(long id, bool deleteModelPart, bool doEmit, bool later);
     virtual void deleteItem(ItemBase *, bool deleteModelPart, bool doEmit, bool later);
@@ -92,6 +103,8 @@ public:
     void transformItem(long id, const QMatrix &);
     void flipItem(long id, Qt::Orientations orientation);
     void selectItem(long id, bool state, bool updateInfoView, bool doEmit);
+    void selectItem(ItemBase * itemBase);
+    void selectItems(QList<ItemBase *>);
     void selectDeselectAllCommand(bool state);
     void changeWire(long fromID, QLineF line, QPointF pos, bool updateConnections, bool updateRatsnest);   
     void changeLeg(long fromID, const QString & connectorID, const QPolygonF &, bool relative, const QString & why);   
@@ -99,8 +112,8 @@ public:
     void rotateLeg(long fromID, const QString & connectorID, const QPolygonF &, bool active);   
     void cut();
     void copy();
-    void setPaletteModel(PaletteModel *);
-    void setRefModel(class ReferenceModel *refModel);
+    void setReferenceModel(class ReferenceModel *referenceModel);
+    class ReferenceModel * referenceModel();
     void setSketchModel(SketchModel *);
     void setUndoStack(class WaitPushUndoStack *);
     void clearSelection();
@@ -117,7 +130,7 @@ public:
 	void addBendpoint(ItemBase * lastHoverEnterItem, ConnectorItem * lastHoverEnterConnectorItem, QPointF lastLocation);
 	void flattenCurve(ItemBase * lastHoverEnterItem, ConnectorItem * lastHoverEnterConnectorItem, QPointF lastLocation);
 
-	void deleteSelected(Wire *);
+	void deleteSelected(Wire *, bool plus);
 	PaletteItem *getSelectedPart();
 
     void addViewLayer(ViewLayer *);
@@ -132,6 +145,7 @@ public:
 	void sortAnyByZ(const QList<QGraphicsItem *> & items, QList<ItemBase *> & bases);
  	void mousePressConnectorEvent(ConnectorItem *, QGraphicsSceneMouseEvent *);
  	void setBackground(QColor);
+    void setBackgroundColor(QColor, bool setPref);
  	const QColor& background();
 	QColor standardBackground();
  	void setItemMenu(QMenu*);
@@ -145,7 +159,7 @@ public:
 
  	ItemCount calcItemCount();
 
-	ViewIdentifierClass::ViewIdentifier viewIdentifier();
+	ViewLayer::ViewIdentifier viewIdentifier();
 	void setViewLayerIDs(ViewLayer::ViewLayerID part, ViewLayer::ViewLayerID wire, ViewLayer::ViewLayerID connector, ViewLayer::ViewLayerID ruler, ViewLayer::ViewLayerID note);
 	void stickem(long stickTargetID, long stickSourceID, bool stick);
 	void stickyScoop(ItemBase * stickyOne, bool checkCurrent, CheckStickyCommand *);
@@ -160,9 +174,8 @@ public:
 	void noteChanged(ItemBase *, const QString & oldText, const QString &newtext, QSizeF oldSize, QSizeF newSize);
 
 	void setInfoViewOnHover(bool infoViewOnHover);
-	PaletteModel * paletteModel();
-	virtual ItemBase * addItemAux(ModelPart *, ViewLayer::ViewLayerSpec, const ViewGeometry &, long id, PaletteItem * paletteItem, bool doConnectors, ViewIdentifierClass::ViewIdentifier, bool temporary);
-	ItemBase * addItemAuxTemp(ModelPart *, ViewLayer::ViewLayerSpec, const ViewGeometry &, long id, PaletteItem * paletteItem, bool doConnectors, ViewIdentifierClass::ViewIdentifier, bool temporary);
+	virtual ItemBase * addItemAux(ModelPart *, ViewLayer::ViewLayerSpec, const ViewGeometry &, long id, bool doConnectors, ViewLayer::ViewIdentifier, bool temporary);
+	ItemBase * addItemAuxTemp(ModelPart *, ViewLayer::ViewLayerSpec, const ViewGeometry &, long id, bool doConnectors, ViewLayer::ViewIdentifier, bool temporary);
 
     bool swappingEnabled(ItemBase *);
 
@@ -170,6 +183,7 @@ public:
 	void addPcbViewLayers();
 	void addSchematicViewLayers();
 	void addBreadboardViewLayers();
+	void addIconViewLayers();
 
 	void changeWireColor(long wireId, const QString& color, double opacity);
 	void changeWireWidth(long wireId, double width);
@@ -205,23 +219,23 @@ public:
 	void resizeNote(long itemID, const QSizeF & );
 	class SelectItemCommand* stackSelectionState(bool pushIt, QUndoCommand * parentCommand);
 	QString renderToSVG(double printerScale, const LayerList &, 
-						bool blackOnly, QSizeF & imageSize, ItemBase * board, double dpi, 
-						bool selectedItems, bool flatten, bool fillHoles, bool & empty);
+						bool blackOnly, QRectF & imageRect, ItemBase * board, double dpi, 
+						bool selectedItems, bool renderBlocker, bool & empty);
 	QString renderToSVG(double printerScale, const LayerList &, 
-						bool blackOnly, QSizeF & imageSize, QRectF & offsetRect, double dpi, 
-						bool selectedItems, bool flatten, bool fillHoles, bool & empty);
-	QString renderToSVG(double printerScale, bool blackOnly, QSizeF & imageSize, QRectF & offsetRect, double dpi, 
-								  bool flatten, bool fillHoles, 
+						bool blackOnly, QRectF & imageRect, ItemBase * board, QRectF & offsetRect, double dpi, 
+						bool selectedItems, bool renderBlocker, bool & empty);
+	QString renderToSVG(double printerScale, bool blackOnly, QRectF & imageRect, QRectF & offsetRect, double dpi, 
+								  bool renderBlocker, 
 								  QList<QGraphicsItem *> & itemsAndLabels, QRectF itemsBoundingRect, bool & empty);
 
 	bool spaceBarIsPressed();
-	virtual long setUpSwap(ItemBase *, long newModelIndex, const QString & newModuleID, ViewLayer::ViewLayerSpec, bool doEmit, bool noFinalChangeWiresCommand, QList<Wire *> & wiresToDelete, QUndoCommand * parentCommand);
+	virtual long setUpSwap(SwapThing &, bool master);
 	ConnectorItem * lastHoverEnterConnectorItem();
 	ItemBase * lastHoverEnterItem();
 	LayerHash & viewLayers();
 	virtual void createTrace(Wire*);
 	virtual void updateNet(Wire*);
-	void selectAllWires(ViewGeometry::WireFlag);
+	virtual void selectAllWires(ViewGeometry::WireFlag);
 	virtual void tidyWires();
 	const QString & getShortName();
 	virtual void setClipEnds(class ClipableWire *, bool);
@@ -236,10 +250,9 @@ public:
 	int selectAllObsolete();
 	int selectAllMoveLock();
 	void setMoveLock(long id, bool lock);
-	int selectAllItemType(ModelPart::ItemType);
 	bool partLabelsVisible();
 	void restorePartLabel(long itemID, QDomElement & element);
-	void loadLogoImage(long itemID, const QString & oldSvg, const QSizeF oldAspectRatio, const QString & oldFilename, const QString & newFilename, bool addName);
+	void loadLogoImage(ItemBase *, const QString & oldSvg, const QSizeF oldAspectRatio, const QString & oldFilename, const QString & newFilename, bool addName);
 	void loadLogoImage(long itemID, const QString & oldSvg, const QSizeF oldAspectRatio, const QString & oldFilename);
 	void loadLogoImage(long itemID, const QString & newFilename, bool addName);
 	void setNoteFocus(QGraphicsItem *, bool inFocus);
@@ -248,6 +261,8 @@ public:
 	bool alignedToGrid();
 	void showGrid(bool);
 	bool showingGrid();
+	void setGridSize(const QString &);
+    QString gridSizeText();
 	void saveZoom(double);
 	double retrieveZoom();
 	void initGrid();
@@ -287,13 +302,21 @@ public:
 	void renamePins(ItemBase *, const QStringList & oldLabels, const QStringList & newLabels, bool singleRow);
 	void renamePins(long itemID, const QStringList & labels, bool singleRow);
 	void getRatsnestColor(QColor &);
-	VirtualWire * makeOneRatsnestWire(ConnectorItem * source, ConnectorItem * dest, bool routed, QColor color);
+	VirtualWire * makeOneRatsnestWire(ConnectorItem * source, ConnectorItem * dest, bool routed, QColor color, bool force);
 	virtual double getRatsnestOpacity();
 	virtual double getRatsnestWidth();
 	void setAnyInRotation();
 	ConnectorItem * findConnectorItem(ConnectorItem * foreignConnectorItem);
 	void setGroundFillSeed(long id, const QString & connectorID, bool seed);
 	void setWireExtras(long id, const QDomElement &);
+    void resolveTemporary(bool, ItemBase *);
+	virtual bool sameElectricalLayer2(ViewLayer::ViewLayerID, ViewLayer::ViewLayerID);
+	void deleteMiddle(QSet<ItemBase *> & deletedItems, QUndoCommand * parentCommand);
+    void setPasting(bool);
+    void showUnrouted();
+	QPointF alignOneToGrid(ItemBase * itemBase);
+	void showEvent(QShowEvent * event);
+
 
 protected:
     void dragEnterEvent(QDragEnterEvent *event);
@@ -307,7 +330,7 @@ protected:
 	void mouseMoveEvent(QMouseEvent *event);
 	void mouseReleaseEvent(QMouseEvent *event);
     void paintEvent(QPaintEvent *);
-    PaletteItem* addPartItem(ModelPart * modelPart, ViewLayer::ViewLayerSpec, PaletteItem * paletteItem, bool doConnectors, bool & ok, ViewIdentifierClass::ViewIdentifier, bool temporary);
+    PaletteItem* addPartItem(ModelPart * modelPart, ViewLayer::ViewLayerSpec, PaletteItem * paletteItem, bool doConnectors, bool & ok, ViewLayer::ViewIdentifier, bool temporary);
 	void clearHoldingSelectItem();
 	bool startZChange(QList<ItemBase *> & bases);
 	void continueZChange(QList<ItemBase *> & bases, int start, int end, bool (*test)(int current, int start), int inc, const QString & text);
@@ -331,9 +354,8 @@ protected:
 						  bool connect, bool updateConnections);
 
 
-	void cutDeleteAux(QString undoStackMessage);
+	void cutDeleteAux(QString undoStackMessage, bool plus, Wire * wire);
 	void deleteAux(QSet<ItemBase *> & deletedItems, QUndoCommand * parentCommand, bool doPush);
-	void deleteMiddle(QHash<ItemBase *, SketchWidget *> & otherDeletedItems, QUndoCommand * parentCommand);
 
 	ChangeConnectionCommand * extendChangeConnectionCommand(BaseCommand::CrossViewType, long fromID, const QString & fromConnectorID,
 									   long toID, const QString & toConnectorID,
@@ -350,7 +372,7 @@ protected:
 	void dragWireChanged(class Wire* wire, ConnectorItem * from, ConnectorItem * to);
 	void dragRatsnestChanged();
 	void killDroppingItem();
-	ViewLayer::ViewLayerID getViewLayerID(ModelPart *, ViewIdentifierClass::ViewIdentifier, ViewLayer::ViewLayerSpec);
+	ViewLayer::ViewLayerID getViewLayerID(ModelPart *, ViewLayer::ViewIdentifier, ViewLayer::ViewLayerSpec);
 	ItemBase * overSticky(ItemBase *);
 	virtual void setNewPartVisible(ItemBase *);
 	virtual bool collectFemaleConnectees(ItemBase *, QSet<ItemBase *> &);
@@ -365,7 +387,7 @@ protected:
 	void clearDragWireTempCommand();
 	bool draggingWireEnd();
 	void moveItems(QPoint globalPos, bool checkAutoScroll, bool rubberBandLegEnabled);
-	virtual ViewLayer::ViewLayerID multiLayerGetViewLayerID(ModelPart * modelPart, ViewIdentifierClass::ViewIdentifier, ViewLayer::ViewLayerSpec, QDomElement & layers, QString & layerName);
+	virtual ViewLayer::ViewLayerID multiLayerGetViewLayerID(ModelPart * modelPart, ViewLayer::ViewIdentifier, ViewLayer::ViewLayerSpec, LayerList &);
 	virtual BaseCommand::CrossViewType wireSplitCrossView();
 	virtual bool canChainMultiple();
 	virtual bool canChainWire(Wire *);
@@ -387,7 +409,7 @@ protected:
 	void drawBackground( QPainter * painter, const QRectF & rect );
 	void handleConnect(QDomElement & connect, ModelPart *, const QString & fromConnectorID, ViewLayer::ViewLayerID, QStringList & alreadyConnected, 
 						QHash<long, ItemBase *> & newItems, QUndoCommand * parentCommand, bool seekOutsideConnections);
-	void setUpSwapReconnect(ItemBase* itemBase, long newID, const QString & newModuleID, bool master, QList<Wire *> & wiresToDelete, QUndoCommand * parentCommand);
+	void setUpSwapReconnect(SwapThing &, ItemBase * itemBase, long newID, bool master);
 	bool swappedGender(ConnectorItem * originalConnectorItem, Connector * newConnector);
 	void setLastPaletteItemSelected(PaletteItem * paletteItem);
 	void setLastPaletteItemSelectedIf(ItemBase * itemBase);
@@ -407,18 +429,20 @@ protected:
 	bool moveByArrow(int dx, int dy, QKeyEvent * );
 	double gridSizeInches();
 	virtual bool canAlignToTopLeft(ItemBase *);
+	virtual bool canAlignToCenter(ItemBase *);
 	virtual void findAlignmentAnchor(ItemBase * originatingItem, QHash<long, ItemBase *> & savedItems, QHash<Wire *, ConnectorItem *> & savedWires);
 	void alignLoc(QPointF & loc, const QPointF startPoint, const QPointF newLoc, const QPointF originalLoc);
 	void copyAux(QList<ItemBase *> & bases, bool saveBoundingRects);
 	void copyDrop();
 	void dropItemEvent(QDropEvent *event);
+    virtual QString checkDroppedModuleID(const QString & moduleID);
 	QString makeWireSVG(Wire * wire, QPointF offset, double dpi, double printerscale, bool blackOnly);
 	QString makeWireSVGAux(Wire * wire, double width, const QString & color, QPointF offset, double dpi, double printerScale, bool blackOnly);
 
 	QString makeMoveSVG(double printerScale, double dpi, QPointF & offset); 
 	void prepDeleteProps(ItemBase * itemBase, long id, const QString & newModuleID, QUndoCommand * parentCommand);
 	void prepDeleteOtherProps(ItemBase * itemBase, long id, const QString & newModuleID, QUndoCommand * parentCommand);
-	ViewLayer::ViewLayerSpec getViewLayerSpec(ModelPart * modelPart, QDomElement & instance, QDomElement & view, ViewGeometry &);
+	virtual ViewLayer::ViewLayerSpec getViewLayerSpec(ModelPart * modelPart, QDomElement & instance, QDomElement & view, ViewGeometry &);
 	virtual ViewLayer::ViewLayerSpec wireViewLayerSpec(ConnectorItem *);
 
 	virtual bool resizingJumperItemPress(QGraphicsItem * item);
@@ -428,9 +452,7 @@ protected:
 	virtual QPoint calcFixedToCenterItemOffset(const QRect & viewPortRect, const QSizeF & helpSize);
 	virtual bool acceptsTrace(const ViewGeometry &);
 	virtual ItemBase * placePartDroppedInOtherView(ModelPart *, ViewLayer::ViewLayerSpec, const ViewGeometry & viewGeometry, long id, SketchWidget * dropOrigin);
-	void alignOneToGrid(ItemBase * itemBase);
 	void showPartLabelsAux(bool show, QList<ItemBase *> & itemBases);
-	virtual void changeTrace(Wire * wire, ConnectorItem * from, ConnectorItem * to, QUndoCommand * parentCommand);
 	virtual void extraRenderSvgStep(ItemBase *, QPointF offset, double dpi, double printerScale, QString & outputSvg);
 	virtual ViewLayer::ViewLayerSpec createWireViewLayerSpec(ConnectorItem * from, ConnectorItem * to);
 	virtual Wire * createTempWireForDragging(Wire * fromWire, ModelPart * wireModel, ConnectorItem * connectorItem, ViewGeometry & viewGeometry, ViewLayer::ViewLayerSpec);
@@ -454,6 +476,10 @@ protected:
 	void createTrace(Wire * fromWire, const QString & commandString, ViewGeometry::WireFlag);
 	bool createOneTrace(Wire * wire, ViewGeometry::WireFlag flag, bool allowAny, QList<Wire *> & done, QUndoCommand * parentCommand);
 	void removeWire(Wire * w, QList<ConnectorItem *> & ends, QList<Wire *> & done, QUndoCommand * parentCommand);
+    void selectAllWiresFrom(ViewGeometry::WireFlag flag, QList<QGraphicsItem *> & items);
+    bool canConnect(ItemBase * from, ItemBase * to);
+    virtual bool canConnect(Wire * from, ItemBase * to);
+    void removeDragWire();
 
 protected:
 	static bool lessThan(int a, int b);
@@ -475,8 +501,7 @@ signals:
 	void selectionChangedSignal();
 
 	void resizeSignal();
-	void dropSignal(const QPoint &pos, ModelPart *);
-	void dropTempSignal(ModelPart *, QWidget *);
+	void dropSignal(const QPoint &pos);
 	void routingStatusSignal(SketchWidget *, const RoutingStatus &);
 	void movingSignal(SketchWidget *, QUndoCommand * parentCommand);
 	void selectAllItemsSignal(bool state, bool doEmit);
@@ -484,7 +509,7 @@ signals:
 	void disconnectAllSignal(QList<ConnectorItem *>, QHash<ItemBase *, SketchWidget *> & itemsToDelete, QUndoCommand * parentCommand);
 	void setResistanceSignal(long itemID, QString resistance, QString pinSpacing, bool doEmit);
 	void setPropSignal(long itemID, const QString & prop, const QString & value, bool doRedraw, bool doEmit);
-	void setInstanceTitleSignal(long id, const QString & title, bool isUndoable, bool doEmit);
+	void setInstanceTitleSignal(long id, const QString & oldTitle, const QString & newTitle, bool isUndoable, bool doEmit);
 	void statusMessageSignal(QString, int timeout);
 	void showLabelFirstTimeSignal(long itemID, bool show, bool doEmit);
 	void dropPasteSignal(SketchWidget *);
@@ -493,13 +518,17 @@ signals:
 	void deleteTracesSignal(QSet<ItemBase *> & deletedItems, QHash<ItemBase *, SketchWidget *> & otherDeletedItems, QList<long> & deletedIDs, bool isForeign, QUndoCommand * parentCommand);
 	void makeDeleteItemCommandPrepSignal(ItemBase * itemBase, bool foreign, QUndoCommand * parentCommand);
 	void makeDeleteItemCommandFinalSignal(ItemBase * itemBase, bool foreign, QUndoCommand * parentCommand);
-	void warnSMDSignal(const QString &);
 	void cursorLocationSignal(double xinches, double yinches);
 	void ratsnestConnectSignal(long id, const QString & connectorID, bool connect, bool doEmit);
 	void updatePartLabelInstanceTitleSignal(long itemID);
 	void filenameIfSignal(QString & filename);
 	void collectRatsnestSignal(QList<SketchWidget *> & foreignSketchWidgets);
 	void removeRatsnestSignal(QList<struct ConnectorEdge *> & cutSet, QUndoCommand * parentCommand); 
+	void updateLayerMenuSignal();
+    void swapBoardImageSignal(SketchWidget * sketchWidget, ItemBase * itemBase, const QString & filename, const QString & moduleID, bool addName);
+    void canConnectSignal(Wire * from, ItemBase * to, bool & connect);
+    void swapStartSignal(SwapThing & swapThing, bool master);
+	void showing(SketchWidget *);
 
 protected slots:
 	void itemAddedSlot(ModelPart *, ViewLayer::ViewLayerSpec, const ViewGeometry &, long id, SketchWidget * dropOrigin);
@@ -539,13 +568,16 @@ protected slots:
 	void changePinLabels(ItemBase *, bool singleRow);
 	void collectRatsnestSlot(QList<SketchWidget *> & foreignSketchWidgets);
 	void removeRatsnestSlot(QList<struct ConnectorEdge *> & cutSet, QUndoCommand * parentCommand);
+    void deleteTemporary();
+    void canConnect(Wire * from, ItemBase * to, bool & connect);
+    long swapStart(SwapThing & swapThing, bool master);
 
 public slots:
 	void changeWireColor(const QString newColor);
 	void changeWireWidthMils(const QString newWidth);
  	void selectAllItems(bool state, bool doEmit);
 	void setNoteText(long itemID, const QString & newText);
-	void setInstanceTitle(long id, const QString & title, bool isUndoable, bool doEmit);
+	void setInstanceTitle(long id, const QString & oldTitle, const QString & newTitle, bool isUndoable, bool doEmit);
 	void incInstanceTitle(long id);
 	void showPartLabel(long id, bool showIt);
 	void checkSticky(long id, bool doEmit, bool checkCurrent, CheckStickyCommand *);
@@ -555,10 +587,8 @@ public slots:
 	void setResistance(long itemID, QString resistance, QString pinSpacing, bool doEmit);
 	void setResistance(QString resistance, QString pinSpacing);
 	void setProp(long itemID, const QString & prop, const QString & value, bool redraw, bool doEmit);
-	void setProp(ItemBase *, const QString & propName, const QString & translatedPropName, const QString & oldValue, const QString & newValue, bool redraw);
+	virtual void setProp(ItemBase *, const QString & propName, const QString & translatedPropName, const QString & oldValue, const QString & newValue, bool redraw);
 	void setHoleSize(ItemBase *, const QString & propName, const QString & translatedPropName, const QString & oldValue, const QString & newValue, QRectF & oldRect, QRectF & newRect, bool redraw);
-	void setSpacing(const QString & spacing);
-	void setForm(const QString & form);
 	virtual void showLabelFirstTime(long itemID, bool show, bool doEmit);
 	void resizeBoard(double w, double h, bool doEmit);
 	virtual void changeBoardLayers(int layers, bool doEmit);
@@ -573,10 +603,9 @@ protected:
 	};
 
 protected:
-	QPointer<PaletteModel> m_paletteModel;
-	QPointer<class ReferenceModel> m_refModel;
+	QPointer<class ReferenceModel> m_referenceModel;
 	QPointer<SketchModel> m_sketchModel;
-	ViewIdentifierClass::ViewIdentifier m_viewIdentifier;
+	ViewLayer::ViewIdentifier m_viewIdentifier;
 	class WaitPushUndoStack * m_undoStack;
 	class SelectItemCommand * m_holdingSelectItemCommand;
 	class SelectItemCommand * m_tempDragWireCommand;
@@ -648,6 +677,7 @@ protected:
 	bool m_alignToGrid;
 	bool m_showGrid;
 	double m_gridSizeInches;
+    QString m_gridSizeText;
 	QPointer<ItemBase> m_alignmentItem;
 	QPointF m_alignmentStartPoint;
 	double m_zoom;
@@ -672,9 +702,10 @@ protected:
 	bool m_rubberBandLegWasEnabled;
 	RoutingStatus m_routingStatus;
 	bool m_anyInRotation;
+    bool m_pasting;
 
 public:
-	static ViewLayer::ViewLayerID defaultConnectorLayer(ViewIdentifierClass::ViewIdentifier viewId);
+	static ViewLayer::ViewLayerID defaultConnectorLayer(ViewLayer::ViewIdentifier viewId);
 	static const int PropChangeDelay;
 
 protected:
