@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5930 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-03-28 13:26:38 +0200 (Wed, 28 Mar 2012) $
+$Revision: 6549 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-11 06:54:26 +0200 (Thu, 11 Oct 2012) $
 
 ********************************************************************/
 
@@ -40,6 +40,7 @@ $Date: 2012-03-28 13:26:38 +0200 (Wed, 28 Mar 2012) $
 #include "../utils/folderutils.h"
 
 static QRegExp AaCc("[aAcCqQtTsS]");
+static QRegExp MultipleZs("z\\s*[^\\s]");
 
 const QString GerberGenerator::SilkTopSuffix = "_silkTop.gto";
 const QString GerberGenerator::SilkBottomSuffix = "_silkBottom.gbo";
@@ -47,6 +48,8 @@ const QString GerberGenerator::CopperTopSuffix = "_copperTop.gtl";
 const QString GerberGenerator::CopperBottomSuffix = "_copperBottom.gbl";
 const QString GerberGenerator::MaskTopSuffix = "_maskTop.gts";
 const QString GerberGenerator::MaskBottomSuffix = "_maskBottom.gbs";
+const QString GerberGenerator::PasteMaskTopSuffix = "_pasteMaskTop.gtp";
+const QString GerberGenerator::PasteMaskBottomSuffix = "_pasteMaskBottom.gbp";
 const QString GerberGenerator::DrillSuffix = "_drill.txt";
 const QString GerberGenerator::OutlineSuffix = "_contour.gm1";
 const QString GerberGenerator::MagicBoardOutlineID = "boardoutline";
@@ -75,75 +78,82 @@ bool pixelsCollide(QImage * image1, QImage * image2, int x1, int y1, int x2, int
 
 ////////////////////////////////////////////
 
-void GerberGenerator::exportToGerber(const QString & filename, const QString & exportDir, ItemBase * board, PCBSketchWidget * sketchWidget, bool displayMessageBoxes) 
+void GerberGenerator::exportToGerber(const QString & prefix, const QString & exportDir, ItemBase * board, PCBSketchWidget * sketchWidget, bool displayMessageBoxes) 
 {
 	if (board == NULL) {
-		QList<ItemBase *> boards = sketchWidget->findBoard();
-		if (boards.count() == 0) {
+        int boardCount;
+		board = sketchWidget->findSelectedBoard(boardCount);
+		if (boardCount == 0) {
 			DebugDialog::debug("board not found");
 			return;
 		}
-		if (boards.count() > 1) {
+		if (board == NULL) {
 			DebugDialog::debug("multiple boards found");
 			return;
 		}
-
-		board = boards.at(0);
 	}
 
 	LayerList viewLayerIDs = ViewLayer::copperLayers(ViewLayer::Bottom);
-	int copperInvalidCount = doCopper(board, sketchWidget, viewLayerIDs, "Copper0", CopperBottomSuffix, filename, exportDir, displayMessageBoxes);
-
-	if (sketchWidget->boardLayers() == 2) {
+	int copperInvalidCount = doCopper(board, sketchWidget, viewLayerIDs, "Copper0", CopperBottomSuffix, prefix, exportDir, displayMessageBoxes);
+ 
+    if (sketchWidget->boardLayers() == 2) {
 		viewLayerIDs = ViewLayer::copperLayers(ViewLayer::Top);
-		copperInvalidCount += doCopper(board, sketchWidget, viewLayerIDs, "Copper1", CopperTopSuffix, filename, exportDir, displayMessageBoxes);
+		copperInvalidCount += doCopper(board, sketchWidget, viewLayerIDs, "Copper1", CopperTopSuffix, prefix, exportDir, displayMessageBoxes);
 	}
 
 	LayerList maskLayerIDs = ViewLayer::maskLayers(ViewLayer::Bottom);
 	QString maskBottom, maskTop;
-	int maskInvalidCount = doMask(maskLayerIDs, "Mask0", MaskBottomSuffix, board, sketchWidget, filename, exportDir, displayMessageBoxes, maskBottom);
+	int maskInvalidCount = doMask(maskLayerIDs, "Mask0", MaskBottomSuffix, board, sketchWidget, prefix, exportDir, displayMessageBoxes, maskBottom);
 
 	if (sketchWidget->boardLayers() == 2) {
 		maskLayerIDs = ViewLayer::maskLayers(ViewLayer::Top);
-		maskInvalidCount += doMask(maskLayerIDs, "Mask1", MaskTopSuffix, board, sketchWidget, filename, exportDir, displayMessageBoxes, maskTop);
+		maskInvalidCount += doMask(maskLayerIDs, "Mask1", MaskTopSuffix, board, sketchWidget, prefix, exportDir, displayMessageBoxes, maskTop);
+	}
+
+	maskLayerIDs = ViewLayer::maskLayers(ViewLayer::Bottom);
+	int pasteMaskInvalidCount = doPasteMask(maskLayerIDs, "PasteMask0", PasteMaskBottomSuffix, board, sketchWidget, prefix, exportDir, displayMessageBoxes);
+
+	if (sketchWidget->boardLayers() == 2) {
+		maskLayerIDs = ViewLayer::maskLayers(ViewLayer::Top);
+		pasteMaskInvalidCount += doPasteMask(maskLayerIDs, "PasteMask1", PasteMaskTopSuffix, board, sketchWidget, prefix, exportDir, displayMessageBoxes);
 	}
 
     LayerList silkLayerIDs = ViewLayer::silkLayers(ViewLayer::Top);
-	int silkInvalidCount = doSilk(silkLayerIDs, "Silk1", SilkTopSuffix, board, sketchWidget, filename, exportDir, displayMessageBoxes, maskTop);
+	int silkInvalidCount = doSilk(silkLayerIDs, "Silk1", SilkTopSuffix, board, sketchWidget, prefix, exportDir, displayMessageBoxes, maskTop);
     silkLayerIDs = ViewLayer::silkLayers(ViewLayer::Bottom);
-	silkInvalidCount += doSilk(silkLayerIDs, "Silk0", SilkBottomSuffix, board, sketchWidget, filename, exportDir, displayMessageBoxes, maskBottom);
+	silkInvalidCount += doSilk(silkLayerIDs, "Silk0", SilkBottomSuffix, board, sketchWidget, prefix, exportDir, displayMessageBoxes, maskBottom);
 
     // now do it for the outline/contour
     LayerList outlineLayerIDs = ViewLayer::outlineLayers();
-	QSizeF imageSize;
+	QRectF imageRect;
 	bool empty;
-	QString svgOutline = sketchWidget->renderToSVG(FSvgRenderer::printerScale(), outlineLayerIDs, true, imageSize, board, GraphicsUtils::StandardFritzingDPI, false, false, false, empty);
+	QString svgOutline = sketchWidget->renderToSVG(GraphicsUtils::SVGDPI, outlineLayerIDs, true, imageRect, board, GraphicsUtils::StandardFritzingDPI, false, false, empty);
     if (svgOutline.isEmpty()) {
         displayMessage(QObject::tr("outline is empty"), displayMessageBoxes);
         return;
     }
 
 	svgOutline = cleanOutline(svgOutline);
+    // at this point svgOutline must be a single element; a path element may contain cutouts
 	svgOutline = clipToBoard(svgOutline, board, "board", SVG2gerber::ForOutline, "");
-
-	QXmlStreamReader streamReader(svgOutline);
-	QSizeF svgSize = FSvgRenderer::parseForWidthAndHeight(streamReader);
+	QSizeF svgSize = TextUtils::parseForWidthAndHeight(svgOutline);
 
     // create outline gerber from svg
     SVG2gerber outlineGerber;
 	int outlineInvalidCount = outlineGerber.convert(svgOutline, sketchWidget->boardLayers() == 2, "contour", SVG2gerber::ForOutline, svgSize * GraphicsUtils::StandardFritzingDPI);
 	
 	//DebugDialog::debug(QString("outline output: %1").arg(outlineGerber.getGerber()));
-	saveEnd("contour", exportDir, filename, OutlineSuffix, displayMessageBoxes, true, outlineGerber);
+	saveEnd("contour", exportDir, prefix, OutlineSuffix, displayMessageBoxes, outlineGerber);
 
-	doDrill(board, sketchWidget, filename, exportDir, displayMessageBoxes);
+	doDrill(board, sketchWidget, prefix, exportDir, displayMessageBoxes);
 
-	if (outlineInvalidCount > 0 || silkInvalidCount > 0 || copperInvalidCount > 0 || maskInvalidCount) {
+	if (outlineInvalidCount > 0 || silkInvalidCount > 0 || copperInvalidCount > 0 || maskInvalidCount || pasteMaskInvalidCount) {
 		QString s;
 		if (outlineInvalidCount > 0) s += QObject::tr("the board outline layer, ");
 		if (silkInvalidCount > 0) s += QObject::tr("silkscreen layer(s), ");
 		if (copperInvalidCount > 0) s += QObject::tr("copper layer(s), ");
 		if (maskInvalidCount > 0) s += QObject::tr("mask layer(s), ");
+		if (pasteMaskInvalidCount > 0) s += QObject::tr("paste mask layer(s), ");
 		s.chop(2);
 		displayMessage(QObject::tr("Unable to translate svg curves in %1").arg(s), displayMessageBoxes);
 	}
@@ -152,16 +162,15 @@ void GerberGenerator::exportToGerber(const QString & filename, const QString & e
 
 int GerberGenerator::doCopper(ItemBase * board, PCBSketchWidget * sketchWidget, LayerList & viewLayerIDs, const QString & copperName, const QString & copperSuffix, const QString & filename, const QString & exportDir, bool displayMessageBoxes) 
 {
-	QSizeF imageSize;
+	QRectF imageRect;
 	bool empty;
-	QString svg = sketchWidget->renderToSVG(FSvgRenderer::printerScale(), viewLayerIDs, true, imageSize, board, GraphicsUtils::StandardFritzingDPI, false, false, false, empty);
+	QString svg = sketchWidget->renderToSVG(GraphicsUtils::SVGDPI, viewLayerIDs, true, imageRect, board, GraphicsUtils::StandardFritzingDPI, false, false, empty);
 	if (svg.isEmpty()) {
 		displayMessage(QObject::tr("%1 file export failure (1)").arg(copperName), displayMessageBoxes);
 		return 0;
 	}
 
-	QXmlStreamReader streamReader(svg);
-	QSizeF svgSize = FSvgRenderer::parseForWidthAndHeight(streamReader);
+	QSizeF svgSize = TextUtils::parseForWidthAndHeight(svg);
 
 	svg = clipToBoard(svg, board, copperName, SVG2gerber::ForCopper, "");
 	if (svg.isEmpty()) {
@@ -169,15 +178,15 @@ int GerberGenerator::doCopper(ItemBase * board, PCBSketchWidget * sketchWidget,
 		return 0;
 	}
 
-	return doEnd(svg, sketchWidget->boardLayers(), copperName, SVG2gerber::ForCopper, svgSize * GraphicsUtils::StandardFritzingDPI, exportDir, filename, copperSuffix, displayMessageBoxes, true);
+	return doEnd(svg, sketchWidget->boardLayers(), copperName, SVG2gerber::ForCopper, svgSize * GraphicsUtils::StandardFritzingDPI, exportDir, filename, copperSuffix, displayMessageBoxes);
 }
 
 
 int GerberGenerator::doSilk(LayerList silkLayerIDs, const QString & silkName, const QString & gerberSuffix, ItemBase * board, PCBSketchWidget * sketchWidget, const QString & filename, const QString & exportDir, bool displayMessageBoxes, const QString & clipString) 
 {
-	QSizeF imageSize;
+	QRectF imageRect;
 	bool empty;
-	QString svgSilk = sketchWidget->renderToSVG(FSvgRenderer::printerScale(), silkLayerIDs, true, imageSize, board, GraphicsUtils::StandardFritzingDPI, false, false, false, empty);
+	QString svgSilk = sketchWidget->renderToSVG(GraphicsUtils::SVGDPI, silkLayerIDs, true, imageRect, board, GraphicsUtils::StandardFritzingDPI, false, false, empty);
     if (svgSilk.isEmpty()) {
 		displayMessage(QObject::tr("silk file export failure (1)"), displayMessageBoxes);
         return 0;
@@ -194,8 +203,7 @@ int GerberGenerator::doSilk(LayerList silkLayerIDs, const QString & silkName, co
 	//fs << svgSilk;
 	//f.close();
 
-	QXmlStreamReader streamReader(svgSilk);
-	QSizeF svgSize = FSvgRenderer::parseForWidthAndHeight(streamReader);
+	QSizeF svgSize = TextUtils::parseForWidthAndHeight(svgSilk);
 
 	svgSilk = clipToBoard(svgSilk, board, silkName, SVG2gerber::ForSilk, clipString);
 	if (svgSilk.isEmpty()) {
@@ -209,7 +217,7 @@ int GerberGenerator::doSilk(LayerList silkLayerIDs, const QString & silkName, co
 	//fs2 << svgSilk;
 	//f2.close();
 
-	return doEnd(svgSilk, sketchWidget->boardLayers(), silkName, SVG2gerber::ForSilk, svgSize * GraphicsUtils::StandardFritzingDPI, exportDir, filename, gerberSuffix, displayMessageBoxes, true);
+	return doEnd(svgSilk, sketchWidget->boardLayers(), silkName, SVG2gerber::ForSilk, svgSize * GraphicsUtils::StandardFritzingDPI, exportDir, filename, gerberSuffix, displayMessageBoxes);
 }
 
 
@@ -218,9 +226,9 @@ int GerberGenerator::doDrill(ItemBase * board, PCBSketchWidget * sketchWidget, c
     LayerList drillLayerIDs;
     drillLayerIDs << ViewLayer::drillLayers();
 
-	QSizeF imageSize;
+	QRectF imageRect;
 	bool empty;
-	QString svgDrill = sketchWidget->renderToSVG(FSvgRenderer::printerScale(), drillLayerIDs, true, imageSize, board, GraphicsUtils::StandardFritzingDPI, false, false, false, empty);
+	QString svgDrill = sketchWidget->renderToSVG(GraphicsUtils::SVGDPI, drillLayerIDs, true, imageRect, board, GraphicsUtils::StandardFritzingDPI, false, false, empty);
     if (svgDrill.isEmpty()) {
 		displayMessage(QObject::tr("drill file export failure (1)"), displayMessageBoxes);
         return 0;
@@ -231,8 +239,7 @@ int GerberGenerator::doDrill(ItemBase * board, PCBSketchWidget * sketchWidget, c
 		return 0;
 	}
 
-	QXmlStreamReader streamReader(svgDrill);
-	QSizeF svgSize = FSvgRenderer::parseForWidthAndHeight(streamReader);
+	QSizeF svgSize = TextUtils::parseForWidthAndHeight(svgDrill);
 
 	svgDrill = clipToBoard(svgDrill, board, "Copper0", SVG2gerber::ForDrill, "");
 	if (svgDrill.isEmpty()) {
@@ -240,7 +247,7 @@ int GerberGenerator::doDrill(ItemBase * board, PCBSketchWidget * sketchWidget, c
 		return 0;
 	}
 
-	return doEnd(svgDrill, sketchWidget->boardLayers(), "drill", SVG2gerber::ForDrill, svgSize * GraphicsUtils::StandardFritzingDPI, exportDir, filename, DrillSuffix, displayMessageBoxes, true);
+	return doEnd(svgDrill, sketchWidget->boardLayers(), "drill", SVG2gerber::ForDrill, svgSize * GraphicsUtils::StandardFritzingDPI, exportDir, filename, DrillSuffix, displayMessageBoxes);
 }
 
 int GerberGenerator::doMask(LayerList maskLayerIDs, const QString &maskName, const QString & gerberSuffix, ItemBase * board, PCBSketchWidget * sketchWidget, const QString & filename, const QString & exportDir, bool displayMessageBoxes, QString & clipString) 
@@ -249,9 +256,9 @@ int GerberGenerator::doMask(LayerList maskLayerIDs, const QString &maskName, con
 	QList<ItemBase *> copperLogoItems;
 	sketchWidget->hideCopperLogoItems(copperLogoItems);
 
-	QSizeF imageSize;
+	QRectF imageRect;
 	bool empty;
-	QString svgMask = sketchWidget->renderToSVG(FSvgRenderer::printerScale(), maskLayerIDs, true, imageSize, board, GraphicsUtils::StandardFritzingDPI, false, false, false, empty);
+	QString svgMask = sketchWidget->renderToSVG(GraphicsUtils::SVGDPI, maskLayerIDs, true, imageRect, board, GraphicsUtils::StandardFritzingDPI, false, false, empty);
     if (svgMask.isEmpty()) {
 		displayMessage(QObject::tr("mask file export failure (1)"), displayMessageBoxes);
         return 0;
@@ -270,8 +277,7 @@ int GerberGenerator::doMask(LayerList maskLayerIDs, const QString &maskName, con
 		return 0;
 	}
 
-	QXmlStreamReader streamReader(svgMask);
-	QSizeF svgSize = FSvgRenderer::parseForWidthAndHeight(streamReader);
+	QSizeF svgSize = TextUtils::parseForWidthAndHeight(svgMask);
 
 	svgMask = clipToBoard(svgMask, board, maskName, SVG2gerber::ForCopper, "");
 	if (svgMask.isEmpty()) {
@@ -281,29 +287,66 @@ int GerberGenerator::doMask(LayerList maskLayerIDs, const QString &maskName, con
 
 	clipString = svgMask;
 
-	return doEnd(svgMask, sketchWidget->boardLayers(), maskName, SVG2gerber::ForCopper, svgSize * GraphicsUtils::StandardFritzingDPI, exportDir, filename, gerberSuffix, displayMessageBoxes, true);
+	return doEnd(svgMask, sketchWidget->boardLayers(), maskName, SVG2gerber::ForCopper, svgSize * GraphicsUtils::StandardFritzingDPI, exportDir, filename, gerberSuffix, displayMessageBoxes);
+}
+
+int GerberGenerator::doPasteMask(LayerList maskLayerIDs, const QString &maskName, const QString & gerberSuffix, ItemBase * board, PCBSketchWidget * sketchWidget, const QString & filename, const QString & exportDir, bool displayMessageBoxes) 
+{
+	// don't want these in the mask laqyer
+	QList<ItemBase *> copperLogoItems;
+	sketchWidget->hideCopperLogoItems(copperLogoItems);
+	QList<ItemBase *> holes;
+	sketchWidget->hideHoles(holes);
+
+	QRectF imageRect;
+	bool empty;
+	QString svgMask = sketchWidget->renderToSVG(GraphicsUtils::SVGDPI, maskLayerIDs, true, imageRect, board, GraphicsUtils::StandardFritzingDPI, false, false, empty);
+    if (svgMask.isEmpty()) {
+		displayMessage(QObject::tr("mask file export failure (1)"), displayMessageBoxes);
+        return 0;
+    }
+
+	sketchWidget->restoreCopperLogoItems(copperLogoItems);
+	sketchWidget->restoreCopperLogoItems(holes);
+
+	if (empty) {
+		// don't bother with file
+		return 0;
+	}
+
+    svgMask = sketchWidget->makePasteMask(svgMask, board, GraphicsUtils::StandardFritzingDPI, maskLayerIDs);
+    if (svgMask.isEmpty()) return 0;
+
+	QSizeF svgSize = TextUtils::parseForWidthAndHeight(svgMask);
+
+	svgMask = clipToBoard(svgMask, board, maskName, SVG2gerber::ForCopper, "");
+	if (svgMask.isEmpty()) {
+		displayMessage(QObject::tr("mask export failure"), displayMessageBoxes);
+		return 0;
+	}
+
+	return doEnd(svgMask, sketchWidget->boardLayers(), maskName, SVG2gerber::ForCopper, svgSize * GraphicsUtils::StandardFritzingDPI, exportDir, filename, gerberSuffix, displayMessageBoxes);
 }
 
 int GerberGenerator::doEnd(const QString & svg, int boardLayers, const QString & layerName, SVG2gerber::ForWhy forWhy, QSizeF svgSize, 
-							const QString & exportDir, const QString & prefix, const QString & suffix, bool displayMessageBoxes, bool chopPrefix)
+							const QString & exportDir, const QString & prefix, const QString & suffix, bool displayMessageBoxes)
 {
     // create mask gerber from svg
     SVG2gerber gerber;
 	int invalidCount = gerber.convert(svg, boardLayers == 2, layerName, forWhy, svgSize);
 
-	saveEnd(layerName, exportDir, prefix, suffix, displayMessageBoxes, chopPrefix, gerber);
+	saveEnd(layerName, exportDir, prefix, suffix, displayMessageBoxes, gerber);
 
 	return invalidCount;
 }
 
-bool GerberGenerator::saveEnd(const QString & layerName, const QString & exportDir, const QString & prefix, const QString & suffix, bool displayMessageBoxes, bool chopPrefix, SVG2gerber & gerber)
+bool GerberGenerator::saveEnd(const QString & layerName, const QString & exportDir, const QString & prefix, const QString & suffix, bool displayMessageBoxes, SVG2gerber & gerber)
 {
-	QString usePrefix = (chopPrefix) ? QFileInfo(prefix).completeBaseName() : prefix;
 
-    QString outname = exportDir + "/" +  usePrefix + suffix;
+    QString outname = exportDir + "/" +  prefix + suffix;
     QFile out(outname);
 	if (!out.open(QIODevice::WriteOnly | QIODevice::Text)) {
-		displayMessage(QObject::tr("%1 file export failure (2)").arg(layerName), displayMessageBoxes);
+		displayMessage(QObject::tr("%1 file export failure (2): %2").arg(layerName).arg(outname), displayMessageBoxes);
 		return false;
 	}
 
@@ -342,14 +385,39 @@ QString GerberGenerator::clipToBoard(QString svgString, QRectF & boardRect, cons
 		return "";
 	}
 
-	QDomElement root = domDocument1.documentElement();
-	if (root.firstChildElement().isNull()) {
+	QDomElement root1 = domDocument1.documentElement();
+	if (root1.firstChildElement().isNull()) {
 		return "";
 	}
 
+    bool multipleContours = false;
+    if (forWhy == SVG2gerber::ForOutline) { 
+        // split path into multiple contours
+        QDomNodeList paths = root1.elementsByTagName("path");
+        // should only be one
+        for (int p = 0; p < paths.count(); p++) {
+            QDomElement path = paths.at(p).toElement();
+            QString originalPath = path.attribute("d", "").trimmed();
+            if (MultipleZs.indexIn(originalPath) >= 0) {
+                multipleContours = true;
+                QStringList ds = path.attribute("d").split("z", QString::SkipEmptyParts);
+                for (int i = 1; i < ds.count(); i++) {
+                    QDomElement newPath = path.cloneNode(true).toElement();
+                    QString z = ((i < ds.count() - 1) || originalPath.endsWith("z", Qt::CaseInsensitive)) ? "z" : "";
+                    QString d = ds.at(i).trimmed() + z;
+                    if (!d.startsWith("M")) {
+                        DebugDialog::debug("subpath doesn't start with M: " + originalPath);
+                    }
+                    newPath.setAttribute("d",  d);
+                    path.parentNode().appendChild(newPath);
+                }
+                path.setAttribute("d", ds.at(0) + "z");
+            }
+        }
+    }
+
 	// document 2 will contain svg that must be rasterized for gerber conversion
-	QDomDocument domDocument2;
-	domDocument2.setContent(svgString, &errorStr, &errorLine, &errorColumn);
+	QDomDocument domDocument2 = domDocument1.cloneNode(true).toDocument();
 
 	bool anyConverted = false;
     if (TextUtils::squashElement(domDocument1, "text", "", QRegExp())) {
@@ -374,6 +442,33 @@ QString GerberGenerator::clipToBoard(QString svgString, QRectF & boardRect, cons
 		anyConverted = true;
     }
 
+	// gerber can't handle multiple subpaths if there are intersections
+    if (TextUtils::squashElement(domDocument1, "path", "d", MultipleZs)) {
+		anyConverted = true;
+    }
+
+    // can't handle scaled paths very well. There is probably a deeper bug that needs to be chased down.
+    // is this only necessary for contour view?
+    QDomNodeList nodeList = root1.elementsByTagName("path");
+    for (int i = 0; i < nodeList.count(); i++) {
+        QDomNode parent = nodeList.at(i);
+        while (!parent.isNull()) {
+            QString transformString = parent.toElement().attribute("transform");
+            if (!transformString.isNull()) {
+                QMatrix matrix = TextUtils::transformStringToMatrix(transformString);
+                QTransform transform(matrix);
+                if (transform.isScaling()) {
+                    nodeList.at(i).toElement().setTagName("g");
+                    anyConverted = true;
+                    break;
+                }
+
+            }
+
+            parent = parent.parentNode();
+        }
+    }
+
 	QVector <QDomElement> leaves1;
 	int transformCount1 = 0;
     QDomElement e1 = domDocument1.documentElement();
@@ -386,11 +481,12 @@ QString GerberGenerator::clipToBoard(QString svgString, QRectF & boardRect, cons
 
 	double res = GraphicsUtils::StandardFritzingDPI;
 	// convert from pixel dpi to StandardFritzingDPI
-	QRectF sourceRes(boardRect.left() * res / FSvgRenderer::printerScale(), boardRect.top() * res / FSvgRenderer::printerScale(), 
-					 boardRect.width() * res / FSvgRenderer::printerScale(), boardRect.height() * res / FSvgRenderer::printerScale());
+	QRectF sourceRes(boardRect.left() * res / GraphicsUtils::SVGDPI, boardRect.top() * res / GraphicsUtils::SVGDPI, 
+					 boardRect.width() * res / GraphicsUtils::SVGDPI, boardRect.height() * res / GraphicsUtils::SVGDPI);
 	int twidth = sourceRes.width();
 	int theight = sourceRes.height();
-	QSize imgSize(twidth, theight);
+	QSize imgSize(twidth + 2, theight + 2);
+	QRectF target(0, 0, twidth, theight);
 
 	QImage * clipImage = NULL;
 	if (!clipString.isEmpty()) {
@@ -398,7 +494,6 @@ QString GerberGenerator::clipToBoard(QString svgString, QRectF & boardRect, cons
 		clipImage->fill(0xffffffff);
 		clipImage->setDotsPerMeterX(res * GraphicsUtils::InchesPerMeter);
 		clipImage->setDotsPerMeterY(res * GraphicsUtils::InchesPerMeter);
-		QRectF target(0, 0, twidth, theight);
 
 		QXmlStreamReader reader(clipString);
 		QSvgRenderer renderer(&reader);		
@@ -406,6 +501,11 @@ QString GerberGenerator::clipToBoard(QString svgString, QRectF & boardRect, cons
 		painter.begin(clipImage);
 		renderer.render(&painter, target);
 		painter.end();
+
+#ifndef QT_NO_DEBUG
+        clipImage->save(FolderUtils::getUserDataStorePath("") + "/clip.png");
+#endif
+
 	}
 
 	svgString = TextUtils::removeXMLEntities(domDocument1.toString());
@@ -413,39 +513,29 @@ QString GerberGenerator::clipToBoard(QString svgString, QRectF & boardRect, cons
 	QXmlStreamReader reader(svgString);
 	QSvgRenderer renderer(&reader);
 	bool anyClipped = false;
-	for (int i = 0; i < transformCount1; i++) {
-		QString n = QString::number(i);
-		QRectF bounds = renderer.boundsOnElement(n);
-		QMatrix m = renderer.matrixForElement(n);
-		QDomElement element = leaves1.at(i);
-		QRectF mBounds = m.mapRect(bounds);
-		if (mBounds.left() < sourceRes.left() - 0.1|| mBounds.top() < sourceRes.top() - 0.1 || mBounds.right() > sourceRes.right() + 0.1 || mBounds.bottom() > sourceRes.bottom() + 0.1) {
-			// element is outside of bounds--squash it so it will be clipped
-			// we don't care if the board shape is irregular
-			// since anything printed between the shape and the bounding rectangle 
-			// will be physically clipped when the board is cut out
-			element.setTagName("g");
-			anyClipped = anyConverted = true;
-		}	
-	}
-
-	if (forWhy == SVG2gerber::ForOutline) {
-		// make one big polygon.  Assume there are no holes in the board
-
-		if (anyConverted || leaves1.count() > 1) {
-			anyClipped = true;
-			foreach (QDomElement l, leaves1) {
-				l.setTagName("g");
-			}
-		}
-	}
+    if (forWhy != SVG2gerber::ForOutline) { 
+	    for (int i = 0; i < transformCount1; i++) {
+		    QString n = QString::number(i);
+		    QRectF bounds = renderer.boundsOnElement(n);
+		    QMatrix m = renderer.matrixForElement(n);
+		    QDomElement element = leaves1.at(i);
+		    QRectF mBounds = m.mapRect(bounds);
+		    if (mBounds.left() < sourceRes.left() - 0.1|| mBounds.top() < sourceRes.top() - 0.1 || mBounds.right() > sourceRes.right() + 0.1 || mBounds.bottom() > sourceRes.bottom() + 0.1) {
+			    // element is outside of bounds--squash it so it will be clipped
+			    // we don't care if the board shape is irregular
+			    // since anything printed between the shape and the bounding rectangle 
+			    // will be physically clipped when the board is cut out
+			    element.setTagName("g");
+			    anyClipped = anyConverted = true;
+		    }	
+	    }
+    }
 
 	if (clipImage) {
 		QImage another(imgSize, QImage::Format_Mono);
 		another.fill(0xffffffff);
 		another.setDotsPerMeterX(res * GraphicsUtils::InchesPerMeter);
 		another.setDotsPerMeterY(res * GraphicsUtils::InchesPerMeter);
-		QRectF target(0, 0, twidth, theight);
 
 		svgString = TextUtils::removeXMLEntities(domDocument1.toString());
 		QXmlStreamReader reader(svgString);
@@ -467,10 +557,9 @@ QString GerberGenerator::clipToBoard(QString svgString, QRectF & boardRect, cons
 			QMatrix m = renderer.matrixForElement(n);
 			QRectF mBounds = m.mapRect(bounds);
 
-
-			int x1 = qFloor(qMax(0.0, mBounds.left() - sourceRes.left()));
+			int x1 = qFloor(qMax((qreal) 0.0, mBounds.left() - sourceRes.left()));          // atmel compiler fails without cast
 			int x2 = qCeil(qMin(sourceRes.width(), mBounds.right() - sourceRes.left()));
-			int y1 = qFloor(qMax(0.0, mBounds.top() - sourceRes.top()));
+			int y1 = qFloor(qMax((qreal) 0.0, mBounds.top() - sourceRes.top()));            // atmel compiler fails without cast
 			int y2 = qCeil(qMin(sourceRes.height(), mBounds.bottom() - sourceRes.top()));
 			
 			if (pixelsCollide(&another, clipImage, x1, y1, x2, y2)) {
@@ -498,80 +587,84 @@ QString GerberGenerator::clipToBoard(QString svgString, QRectF & boardRect, cons
 		
 
 		// expand the svg to fill the space of the image
-		QDomElement root = domDocument2.documentElement();
-		root.setAttribute("width", QString("%1px").arg(twidth));
-		root.setAttribute("height", QString("%1px").arg(theight));
+		QDomElement root2 = domDocument2.documentElement();
+		root2.setAttribute("width", QString("%1px").arg(twidth));
+		root2.setAttribute("height", QString("%1px").arg(theight));
 		if (boardRect.x() != 0 || boardRect.y() != 0) {
-			QString viewBox = root.attribute("viewBox");
+			QString viewBox = root2.attribute("viewBox");
 			QStringList coords = viewBox.split(" ", QString::SkipEmptyParts);
 			coords[0] = QString::number(sourceRes.left());
 			coords[1] = QString::number(sourceRes.top());
-			root.setAttribute("viewBox", coords.join(" "));
+			root2.setAttribute("viewBox", coords.join(" "));
 		}
 
-		QString svg = TextUtils::removeXMLEntities(domDocument2.toString());
-
 		QStringList exceptions;
 		exceptions << "none" << "";
 		QString toColor("#000000");
-		QByteArray svgByteArray;
-		SvgFileSplitter::changeColors(svg, toColor, exceptions, svgByteArray);
+		SvgFileSplitter::changeColors(root2, toColor, exceptions);
 
-		QImage image(imgSize, QImage::Format_Mono);
-		image.fill(0xffffffff);
+        QImage image(imgSize, QImage::Format_Mono);
 		image.setDotsPerMeterX(res * GraphicsUtils::InchesPerMeter);
 		image.setDotsPerMeterY(res * GraphicsUtils::InchesPerMeter);
-		QRectF target(0, 0, twidth, theight);
 
-		QSvgRenderer renderer(svgByteArray);
-		QPainter painter;
-		painter.begin(&image);
-		renderer.render(&painter, target);
-		painter.end();
-		image.invertPixels();				// need white pixels on a black background for GroundPlaneGenerator
-
-		if (clipImage != NULL) {
-			// can this be done with a single blt using composition mode
-			// if not, grab a scanline instead of testing every pixel
-			for (int y = 0; y < theight; y++) {
-				for (int x = 0; x < twidth; x++) {
-					if (clipImage->pixel(x, y) != 0xffffffff) {
-						image.setPixel(x, y, 0);
-					}
-				}
-			}
+        if (forWhy == SVG2gerber::ForOutline) {		
+            QDomNodeList paths = root2.elementsByTagName("path");
+            if (paths.count() == 0) {
+                // some non-path element makes up the outline
+                mergeOutlineElement(image, target, res, domDocument2, svgString, 0, layerName);
+            }
+            else {
+                for (int p = 0; p < paths.count(); p++) {
+                    QDomElement path = paths.at(p).toElement();
+                    path.setTagName("g");
+                }
+                for (int p = 0; p < paths.count(); p++) {
+                    QDomElement path = paths.at(p).toElement();
+                    path.setTagName("path");
+                    if (p > 0) {
+                        paths.at(p - 1).toElement().setTagName("g");
+                    }
+                    mergeOutlineElement(image, target, res, domDocument2, svgString, p, layerName);
+                }
+            }
 		}
+        else {
+		    image.fill(0xffffffff);
+		    QByteArray svg = TextUtils::removeXMLEntities(domDocument2.toString()).toUtf8();
+		    QSvgRenderer renderer(svg);
+		    QPainter painter;
+		    painter.begin(&image);
+		    renderer.render(&painter, target);
+		    painter.end();
+		    image.invertPixels();				// need white pixels on a black background for GroundPlaneGenerator
 
-#ifndef QT_NO_DEBUG
-		image.save("output.png");
-#endif
+    #ifndef QT_NO_DEBUG
+		    image.save(FolderUtils::getUserDataStorePath("") + "/preclip_output.png");
+    #endif
 
-		GroundPlaneGenerator gpg;
-		gpg.setLayerName(layerName);
-		gpg.setMinRunSize(1, 1);
-		if (forWhy == SVG2gerber::ForOutline) {
-		//	int tinyWidth = boardRect.width();
-		//	int tinyHeight = boardRect.height();
-		//	QRectF tinyTarget(0, 0, tinyWidth, tinyHeight);
-		//	QImage tinyImage(tinyWidth, tinyHeight, QImage::Format_Mono);
-		//	QPainter painter;
-		//	painter.begin(&tinyImage);
-		//	renderer.render(&painter, tinyTarget);
-		//	painter.end();
-		//	tinyImage.invertPixels();				// need white pixels on a black background for GroundPlaneGenerator
-			gpg.scanOutline(image, image.width(), image.height(), GraphicsUtils::StandardFritzingDPI / res, GraphicsUtils::StandardFritzingDPI, "#000000", false, false, QSizeF(0, 0), 0);
-		}
-		else {
+		    if (clipImage != NULL) {
+			    // can this be done with a single blt using composition mode
+			    // if not, grab a scanline instead of testing every pixel
+			    for (int y = 0; y < theight; y++) {
+				    for (int x = 0; x < twidth; x++) {
+					    if (clipImage->pixel(x, y) != 0xffffffff) {
+						    image.setPixel(x, y, 0);
+					    }
+				    }
+			    }
+		    }
+
+    #ifndef QT_NO_DEBUG
+		    image.save(FolderUtils::getUserDataStorePath("") + "/output.png");
+    #endif
+
+		    GroundPlaneGenerator gpg;
+		    gpg.setLayerName(layerName);
+		    gpg.setMinRunSize(1, 1);
 			gpg.scanImage(image, image.width(), image.height(), GraphicsUtils::StandardFritzingDPI / res, GraphicsUtils::StandardFritzingDPI, "#000000", false, false, QSizeF(0, 0), 0, sourceRes.topLeft());
-		}
-
-		if (gpg.newSVGs().count() > 0) {
-			QDomDocument doc;
-			TextUtils::mergeSvg(doc, svgString, "");
-			foreach (QString gsvg, gpg.newSVGs()) {
-				TextUtils::mergeSvg(doc, gsvg, "");
-			}
-			svgString = TextUtils::mergeSvgFinish(doc);
+		    if (gpg.newSVGs().count() > 0) {
+                svgString = gpg.mergeSVGs(svgString, "");
+		    }
 		}
 	}
 
@@ -587,6 +680,10 @@ QString GerberGenerator::cleanOutline(const QString & outlineSvg)
 	QList<QDomElement> leaves;
     QDomElement root = doc.documentElement();
     TextUtils::collectLeaves(root, leaves);
+	QDomNodeList textNodes = root.elementsByTagName("text");
+	for (int t = 0; t < textNodes.count(); t++) {
+		leaves << textNodes.at(t).toElement();
+	}
 
 	if (leaves.count() == 0) return "";
 	if (leaves.count() == 1) return outlineSvg;
@@ -597,7 +694,8 @@ QString GerberGenerator::cleanOutline(const QString & outlineSvg)
 			if (leaf.attribute("id", "").compare(MagicBoardOutlineID) == 0) {
 				for (int j = 0; j < leaves.count(); j++) {
 					if (i != j) {
-						leaves.at(j).parentNode().removeChild(leaves.at(j));
+						QDomElement jleaf = leaves.at(j);
+						jleaf.parentNode().removeChild(jleaf);
 					}
 				}
 
@@ -610,3 +708,30 @@ QString GerberGenerator::cleanOutline(const QString & outlineSvg)
 
 	return outlineSvg;
 }
+
+void GerberGenerator::mergeOutlineElement(QImage & image, QRectF & target, double res, QDomDocument & document, QString & svgString, int ix, const QString & layerName) {
+    
+    image.fill(0xffffffff);
+	QByteArray svg = TextUtils::removeXMLEntities(document.toString()).toUtf8();
+
+	QSvgRenderer renderer(svg);
+	QPainter painter;
+	painter.begin(&image);
+	renderer.render(&painter, target);
+	painter.end();
+	image.invertPixels();				// need white pixels on a black background for GroundPlaneGenerator
+
+    #ifndef QT_NO_DEBUG
+		image.save(QString("%2/output%1.png").arg(ix).arg(FolderUtils::getUserDataStorePath("")));
+    #else
+        Q_UNUSED(ix);
+    #endif
+
+	GroundPlaneGenerator gpg;
+	gpg.setLayerName(layerName);
+	gpg.setMinRunSize(1, 1);
+    gpg.scanOutline(image, image.width(), image.height(), GraphicsUtils::StandardFritzingDPI / res, GraphicsUtils::StandardFritzingDPI, "#000000", false, false, QSizeF(0, 0), 0);
+	if (gpg.newSVGs().count() > 0) {
+        svgString = gpg.mergeSVGs(svgString, "");
+	}
+}
