@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5892 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-03-05 04:23:26 +0100 (Mon, 05 Mar 2012) $
+$Revision: 6483 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-26 15:45:37 +0200 (Wed, 26 Sep 2012) $
 
 ********************************************************************/
 
@@ -64,19 +64,12 @@ GroundPlaneGenerator::GroundPlaneGenerator()
 GroundPlaneGenerator::~GroundPlaneGenerator() {
 }
 
-bool GroundPlaneGenerator::getBoardRects(const QString & boardSvg, QGraphicsItem * board, double res, double keepoutSpace, QList<QRect> & rects)
+bool GroundPlaneGenerator::getBoardRects(const QByteArray & boardByteArray, QGraphicsItem * board, double res, double keepoutSpace, QList<QRect> & rects)
 {
-	QByteArray boardByteArray;
-    QString tempColor("#000000");
-	QStringList exceptions;
-	exceptions << "none" << "";
-    if (!SvgFileSplitter::changeColors(boardSvg, tempColor, exceptions, boardByteArray)) {
-		return false;
-	}
 
 	QRectF br = board->sceneBoundingRect();
-	double bWidth = res * br.width() / FSvgRenderer::printerScale();
-	double bHeight = res * br.height() / FSvgRenderer::printerScale();
+	double bWidth = res * br.width() / GraphicsUtils::SVGDPI;
+	double bHeight = res * br.height() / GraphicsUtils::SVGDPI;
 	QImage image(bWidth, bHeight, QImage::Format_Mono);  
 	image.setDotsPerMeterX(res * GraphicsUtils::InchesPerMeter);
 	image.setDotsPerMeterY(res * GraphicsUtils::InchesPerMeter);
@@ -90,7 +83,7 @@ bool GroundPlaneGenerator::getBoardRects(const QString & boardSvg, QGraphicsItem
 	painter.end();
 
 #ifndef QT_NO_DEBUG
-	image.save("getBoardRects.png");
+	image.save(FolderUtils::getUserDataStorePath("") + "/getBoardRects.png");
 #endif
 
 	QColor keepaway(255,255,255);
@@ -117,7 +110,7 @@ bool GroundPlaneGenerator::getBoardRects(const QString & boardSvg, QGraphicsItem
 	painter.end();
 
 #ifndef QT_NO_DEBUG
-	image2.save("getBoardRects2.png");
+	image2.save(FolderUtils::getUserDataStorePath("") + "/getBoardRects2.png");
 #endif
 
 	scanLines(image2, bWidth, bHeight, rects);
@@ -162,8 +155,8 @@ bool GroundPlaneGenerator::generateGroundPlaneUnit(const QString & boardSvg, QSi
 
 	QRectF bsbr = board->sceneBoundingRect();
 
-	QPoint s(qRound(res * (whereToStart.x() - bsbr.topLeft().x()) / FSvgRenderer::printerScale()),
-			qRound(res * (whereToStart.y() - bsbr.topLeft().y()) / FSvgRenderer::printerScale()));
+	QPoint s(qRound(res * (whereToStart.x() - bsbr.topLeft().x()) / GraphicsUtils::SVGDPI),
+			qRound(res * (whereToStart.y() - bsbr.topLeft().y()) / GraphicsUtils::SVGDPI));
 
 	QBitArray redMarker(image->height() * image->width(), false);
 
@@ -222,10 +215,10 @@ bool GroundPlaneGenerator::generateGroundPlaneUnit(const QString & boardSvg, QSi
 	}
 
 #ifndef QT_NO_DEBUG
-	image->save("testGroundPlaneUnit3.png");
+	image->save(FolderUtils::getUserDataStorePath("") + "/testGroundPlaneUnit3.png");
 #endif
 
-	scanImage(*image, bWidth, bHeight, GraphicsUtils::StandardFritzingDPI / res, res, color, true, true, QSizeF(.05, .05), 1 / FSvgRenderer::printerScale(), QPointF(0,0));
+	scanImage(*image, bWidth, bHeight, GraphicsUtils::StandardFritzingDPI / res, res, color, true, true, QSizeF(.05, .05), 1 / GraphicsUtils::SVGDPI, QPointF(0,0));
 	delete image;
 	return true;
 }
@@ -239,7 +232,7 @@ bool GroundPlaneGenerator::generateGroundPlane(const QString & boardSvg, QSizeF
 	QImage * image = generateGroundPlaneAux(boardSvg, boardImageSize, svg, copperImageSize, exceptions, board, res, bWidth, bHeight);
 	if (image == NULL) return false;
 
-	scanImage(*image, bWidth, bHeight, GraphicsUtils::StandardFritzingDPI / res, res, color, true, true, QSizeF(.05, .05), 1 / FSvgRenderer::printerScale(), QPointF(0,0));
+	scanImage(*image, bWidth, bHeight, GraphicsUtils::StandardFritzingDPI / res, res, color, true, true, QSizeF(.05, .05), 1 / GraphicsUtils::SVGDPI, QPointF(0,0));
 	delete image;
 	return true;
 }
@@ -261,7 +254,7 @@ QImage * GroundPlaneGenerator::generateGroundPlaneAux(const QString & boardSvg,
 	//file0.close();
 	
 	QByteArray copperByteArray;
-	if (!SvgFileSplitter::changeStrokeWidth(svg, m_strokeWidthIncrement, false, copperByteArray)) {
+	if (!SvgFileSplitter::changeStrokeWidth(svg, m_strokeWidthIncrement, false, true, copperByteArray)) {
 		return NULL;
 	}
 	
@@ -272,12 +265,12 @@ QImage * GroundPlaneGenerator::generateGroundPlaneAux(const QString & boardSvg,
 	//file1.close();
 	
 
-	double svgWidth = res * qMax(boardImageSize.width(), copperImageSize.width()) / FSvgRenderer::printerScale();
-	double svgHeight = res * qMax(boardImageSize.height(), copperImageSize.height()) / FSvgRenderer::printerScale();
+	double svgWidth = res * qMax(boardImageSize.width(), copperImageSize.width()) / GraphicsUtils::SVGDPI;
+	double svgHeight = res * qMax(boardImageSize.height(), copperImageSize.height()) / GraphicsUtils::SVGDPI;
 
 	QRectF br =  board->sceneBoundingRect();
-	bWidth = res * br.width() / FSvgRenderer::printerScale();
-	bHeight = res * br.height() / FSvgRenderer::printerScale();
+	bWidth = res * br.width() / GraphicsUtils::SVGDPI;
+	bHeight = res * br.height() / GraphicsUtils::SVGDPI;
 	QImage * image = new QImage(qMax(svgWidth, bWidth), qMax(svgHeight, bHeight), QImage::Format_Mono); //
 	image->setDotsPerMeterX(res * GraphicsUtils::InchesPerMeter);
 	image->setDotsPerMeterY(res * GraphicsUtils::InchesPerMeter);
@@ -287,13 +280,13 @@ QImage * GroundPlaneGenerator::generateGroundPlaneAux(const QString & boardSvg,
 	QPainter painter;
 	painter.begin(image);
 	painter.setRenderHint(QPainter::Antialiasing, false);
-	QRectF boardBounds(0, 0, res * boardImageSize.width() / FSvgRenderer::printerScale(), res * boardImageSize.height() / FSvgRenderer::printerScale()); 
+	QRectF boardBounds(0, 0, res * boardImageSize.width() / GraphicsUtils::SVGDPI, res * boardImageSize.height() / GraphicsUtils::SVGDPI); 
 	DebugDialog::debug("boardbounds", boardBounds);
 	renderer.render(&painter, boardBounds);
 	painter.end();
 
 #ifndef QT_NO_DEBUG
-	image->save("testGroundFillBoard.png");
+	image->save(FolderUtils::getUserDataStorePath("") + "/testGroundFillBoard.png");
 #endif
 
 	for (double m = 0; m < BORDERINCHES; m += (1.0 / res)) {   // 1 mm
@@ -321,7 +314,7 @@ QImage * GroundPlaneGenerator::generateGroundPlaneAux(const QString & boardSvg,
 	}
 
 #ifndef QT_NO_DEBUG
-	image->save("testGroundFillBoardBorder.png");
+	image->save(FolderUtils::getUserDataStorePath("") + "/testGroundFillBoardBorder.png");
 #endif
 	
 	// "blur" the image a little
@@ -329,7 +322,7 @@ QImage * GroundPlaneGenerator::generateGroundPlaneAux(const QString & boardSvg,
 	QSvgRenderer renderer2(copperByteArray);
 	painter.begin(image);
 	painter.setRenderHint(QPainter::Antialiasing, false);
-	QRectF bounds(0, 0, res * copperImageSize.width() / FSvgRenderer::printerScale(), res * copperImageSize.height() / FSvgRenderer::printerScale());
+	QRectF bounds(0, 0, res * copperImageSize.width() / GraphicsUtils::SVGDPI, res * copperImageSize.height() / GraphicsUtils::SVGDPI);
 	DebugDialog::debug("copperbounds", bounds);
 	renderer2.render(&painter, bounds);
 	if (m_blurBy != 0) {
@@ -353,7 +346,7 @@ QImage * GroundPlaneGenerator::generateGroundPlaneAux(const QString & boardSvg,
 	painter.end();
 
 #ifndef QT_NO_DEBUG
-	image->save("testGroundFillCopper.png");
+	image->save(FolderUtils::getUserDataStorePath("") + "/testGroundFillCopper.png");
 #endif
 
 	emit postImageSignal(this, image, board);	
@@ -385,7 +378,7 @@ void GroundPlaneGenerator::scanImage(QImage & image, double bWidth, double bHeig
 
 		m_newSVGs.append(pSvg);
 		if (makeOffset) {
-			offset *= FSvgRenderer::printerScale();
+			offset *= GraphicsUtils::SVGDPI;
 			m_newOffsets.append(offset);			// offset now in pixels
 		}
 
@@ -984,7 +977,7 @@ void GroundPlaneGenerator::collectBorderPoints(QImage & image, QList<QPoint> & p
 
 			currentX = x;
 			currentY = y;
-			DebugDialog::debug(QString("first point %1 %2").arg(currentX).arg(currentY));
+			//DebugDialog::debug(QString("first point %1 %2").arg(currentX).arg(currentY));
 			points.append(QPoint(currentX, currentY));
 			gotSomething = true;
 			break;
@@ -997,20 +990,35 @@ void GroundPlaneGenerator::collectBorderPoints(QImage & image, QList<QPoint> & p
 		return;
 	}
 
+    //int inc = 0;
 	while (true) {
-		if (tryNextPoint(currentX, currentY + 1, image, points));
-		else if (tryNextPoint(currentX + 1, currentY, image, points));
-		else if (tryNextPoint(currentX, currentY - 1, image, points));
-		else if (tryNextPoint(currentX - 1, currentY, image, points));
-		else if (tryNextPoint(currentX + 1, currentY + 1, image, points));
-		else if (tryNextPoint(currentX - 1, currentY + 1, image, points));
-		else if (tryNextPoint(currentX + 1, currentY - 1, image, points));
-		else if (tryNextPoint(currentX - 1, currentY - 1, image, points));
-		else break;
+        if (try8(currentX, currentY, image, points)) ;
+		else {            
+            QPoint p = points.first();
+            if (qAbs(p.x() - currentX) < 4 && qAbs(p.y() - currentY) < 4) {
+                // we're near the beginning again
+                break;
+            }
+
+            bool keepGoing = false;
+            for (int ix = points.count() - 2; ix >= 0; ix--) {
+                QPoint p = points.at(ix);
+                if (try8(p.x(), p.y(), image, points)) {
+                    keepGoing = true; 
+                    break;
+                }
+            }
+
+            if (!keepGoing) break;
+        }
 
 		QPoint p = points.last();
 		currentX = p.x();
 		currentY = p.y();
+        //DebugDialog::debug(QString("next point %1 %2").arg(currentX).arg(currentY));
+        //if (++inc % 100 == 0) {
+        //    DebugDialog::debug("\n");
+        //}
 	}
 }
 
@@ -1040,7 +1048,7 @@ void GroundPlaneGenerator::scanOutline(QImage & image, double bWidth, double bHe
 	if (!pSvg.isEmpty()) {
 		m_newSVGs.append(pSvg);
 		if (makeOffset) {
-			offset *= FSvgRenderer::printerScale();
+			offset *= GraphicsUtils::SVGDPI;
 			m_newOffsets.append(offset);			// offset now in pixels
 		}
 	}
@@ -1054,6 +1062,19 @@ void GroundPlaneGenerator::scanOutline(QImage & image, double bWidth, double bHe
 	*/
 }
 
+
+bool GroundPlaneGenerator::try8(int x, int y, QImage & image, QList<QPoint> & points) {
+    if (tryNextPoint(x, y + 1, image, points)) return true;
+	else if (tryNextPoint(x + 1, y, image, points)) return true;
+	else if (tryNextPoint(x, y - 1, image, points)) return true;
+	else if (tryNextPoint(x - 1, y, image, points)) return true;
+	else if (tryNextPoint(x + 1, y + 1, image, points)) return true;
+	else if (tryNextPoint(x - 1, y + 1, image, points)) return true;
+	else if (tryNextPoint(x + 1, y - 1, image, points)) return true;
+	else if (tryNextPoint(x - 1, y - 1, image, points)) return true;
+    return false;
+}
+
 bool GroundPlaneGenerator::tryNextPoint(int x, int y, QImage & image, QList<QPoint> & points)
 {
 	if (x < 0) return false;
@@ -1088,6 +1109,7 @@ bool GroundPlaneGenerator::tryNextPoint(int x, int y, QImage & image, QList<QPoi
 	}
 
 	QRgb pixel = image.pixel(x, y);
+    //DebugDialog::debug(QString("pixel %1,%2 %3").arg(x).arg(y).arg(pixel, 0, 16));
 	if (pixel != 0xffffffff) {						
 		// empty pixel, not on the border
 		return false;
@@ -1160,3 +1182,15 @@ void GroundPlaneGenerator::setMinRunSize(int mrus, int mris) {
 	m_minRunSize = mrus;
 	m_minRiseSize = mris;
 }
+
+QString GroundPlaneGenerator::mergeSVGs(const QString & initialSVG, const QString & layerName) {
+    QDomDocument doc;
+    if (!initialSVG.isEmpty()) {
+		TextUtils::mergeSvg(doc, initialSVG, layerName);        
+    }
+	foreach (QString newSvg, m_newSVGs) {
+		TextUtils::mergeSvg(doc, newSvg, layerName);
+	}
+	return TextUtils::mergeSvgFinish(doc);
+}
+
