@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5892 $:
+$Revision: 6244 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-03-05 04:23:26 +0100 (Mon, 05 Mar 2012) $
+$Date: 2012-08-04 01:13:27 +0200 (Sat, 04 Aug 2012) $
 
 ********************************************************************/
 
@@ -52,7 +52,7 @@ public:
 	void scanOutline(QImage & image, double bWidth, double bHeight, double pixelFactor, double res, 
 					const QString & colorString, bool makeConnector, bool makeOffset, QSizeF minAreaInches, double minDimensionInches);  
 	void scanLines(QImage & image, int bWidth, int bHeight, QList<QRect> & rects);
-	bool getBoardRects(const QString & boardSvg, QGraphicsItem * board, double res, double keepoutSpace, QList<QRect> & rects);
+	bool getBoardRects(const QByteArray & boardByteArray, QGraphicsItem * board, double res, double keepoutSpace, QList<QRect> & rects);
 	const QStringList & newSVGs();
 	const QList<QPointF> & newOffsets();
 	void setBlurBy(double);
@@ -60,6 +60,7 @@ public:
 	void setLayerName(const QString &);
 	const QString & layerName();
 	void setMinRunSize(int minRunSize, int minRiseSize);
+    QString mergeSVGs(const QString & initialSVG, const QString & layerName);
 
 public:
 	static QString ConnectorName;
@@ -79,6 +80,7 @@ protected:
 	void makeConnector(QList<QPolygon> & polygons, double res, double pixelFactor, const QString & colorString, int minX, int minY, QString & svg);
 	bool tryNextPoint(int x, int y, QImage & image, QList<QPoint> & points);
 	void collectBorderPoints(QImage & image, QList<QPoint> & points);
+    bool try8(int x, int y, QImage & image, QList<QPoint> & points);
 
 
 protected:
