@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5450 $:
+$Revision: 6218 $:
 $Author: cohen@irascible.com $:
-$Date: 2011-09-02 12:04:00 +0200 (Fri, 02 Sep 2011) $
+$Date: 2012-07-26 10:32:57 +0200 (Thu, 26 Jul 2012) $
 
 ********************************************************************/
 
@@ -291,8 +291,8 @@ QString KicadSchematic2Svg::convertField(const QString & xString, const QString
 
 	// convert back to 1000 dpi
 	QRectF brf(0, 0,
-			   bri.width() * GraphicsUtils::StandardFritzingDPI / FSvgRenderer::printerScale(), 
-			   bri.height() * GraphicsUtils::StandardFritzingDPI / FSvgRenderer::printerScale());
+			   bri.width() * GraphicsUtils::StandardFritzingDPI / GraphicsUtils::SVGDPI, 
+			   bri.height() * GraphicsUtils::StandardFritzingDPI / GraphicsUtils::SVGDPI);
 
 	if (anchor == "start") {
 		brf.translate(x, y - (brf.height() / 2));
