@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5614 $:
+$Revision: 6118 $:
 $Author: cohen@irascible.com $:
-$Date: 2011-11-12 13:32:21 +0100 (Sat, 12 Nov 2011) $
+$Date: 2012-06-29 08:00:43 +0200 (Fri, 29 Jun 2012) $
 
 ********************************************************************/
 
@@ -144,7 +144,13 @@ int SVG2gerber::renderGerber(bool doubleSided, const QString & mainLayerName, Fo
 				continue;
 			}
 
-			apertures.insert(current, string);
+            QStringList values = apertures.values(current);
+            if (values.contains(string)) {
+                //DebugDialog::debug("already have this value");
+            }
+            else {
+			    apertures.insert(current, string);
+            }
 		}
 
 		foreach (QString T, apertures.uniqueKeys()) {
