@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5450 $:
+$Revision: 6218 $:
 $Author: cohen@irascible.com $:
-$Date: 2011-09-02 12:04:00 +0200 (Fri, 02 Sep 2011) $
+$Date: 2012-07-26 10:32:57 +0200 (Thu, 26 Jul 2012) $
 
 ********************************************************************/
 
@@ -45,7 +45,8 @@ public:
 		ForSilk,
 		ForOutline,
 		ForMask,
-		ForDrill
+		ForDrill,
+        ForPasteMask
 	};
 
 	int convert(const QString & svgStr, bool doubleSided, const QString & mainLayerName, ForWhy, QSizeF boardSize);
