@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5922 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-03-19 20:11:41 +0100 (Mon, 19 Mar 2012) $
+$Revision: 6563 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-13 10:32:03 +0200 (Sat, 13 Oct 2012) $
 
 ********************************************************************/
 
@@ -38,8 +38,6 @@ $Date: 2012-03-19 20:11:41 +0100 (Mon, 19 Mar 2012) $
 #include <QtDebug>
 #include <QXmlStreamReader>
 
-static QString findStyle("%1[\\s]*:[\\s]*([^;]*)[;]?");
-
 struct HVConvertData {
 	double x;
 	double y;
@@ -81,18 +79,19 @@ bool SvgFileSplitter::splitString(QString & contents, const QString & elementID)
 	m_byteArray.clear();
 
 	// gets rid of some crap inserted by illustrator which can screw up polygons and paths
-	contents.remove(QChar('\t'));
-	contents.remove(QChar('\n'));
-	contents.remove(QChar('\r'));
+	contents.replace('\t', ' ');
+	contents.replace('\n', ' ');
+	contents.replace('\r', ' ');
 
 	// get rid of inkscape stuff too
-	contents.remove(TextUtils::SodipodiDetector);
+	TextUtils::cleanSodipodi(contents);
 
 	QString errorStr;
 	int errorLine;
 	int errorColumn;
 
 	if (!m_domDocument.setContent(contents, true, &errorStr, &errorLine, &errorColumn)) {
+        //DebugDialog::debug(QString("parse error: %1 l:%2 c:%3\n\n%4").arg(errorStr).arg(errorLine).arg(errorColumn).arg(contents));
 		return false;
 	}
 
@@ -355,13 +354,13 @@ void SvgFileSplitter::normalizeChild(QDomElement & element,
 	bool doChildren = false;
 	QString nodeName = element.nodeName();
 	if (nodeName.compare("g") == 0) {
-		fixStyleAttribute(element);
+		TextUtils::fixStyleAttribute(element);
 		normalizeAttribute(element, "stroke-width", sNewWidth, vbWidth);
 		setStrokeOrFill(element, blackOnly, "black", false);
 		doChildren = true;
 	}
 	else if (nodeName.compare("circle") == 0) {
-		fixStyleAttribute(element);
+		TextUtils::fixStyleAttribute(element);
 		normalizeAttribute(element, "cx", sNewWidth, vbWidth);
 		normalizeAttribute(element, "cy", sNewHeight, vbHeight);
 		normalizeAttribute(element, "r", sNewWidth, vbWidth);
@@ -369,7 +368,7 @@ void SvgFileSplitter::normalizeChild(QDomElement & element,
 		setStrokeOrFill(element, blackOnly, "black", false);
 	}
 	else if (nodeName.compare("line") == 0) {
-		fixStyleAttribute(element);
+		TextUtils::fixStyleAttribute(element);
 		normalizeAttribute(element, "x1", sNewWidth, vbWidth);
 		normalizeAttribute(element, "y1", sNewHeight, vbHeight);
 		normalizeAttribute(element, "x2", sNewWidth, vbWidth);
@@ -378,7 +377,7 @@ void SvgFileSplitter::normalizeChild(QDomElement & element,
 		setStrokeOrFill(element, blackOnly, "black", false);
 	}
 	else if (nodeName.compare("rect") == 0) {
-		fixStyleAttribute(element);
+		TextUtils::fixStyleAttribute(element);
 		normalizeAttribute(element, "width", sNewWidth, vbWidth);
 		normalizeAttribute(element, "height", sNewHeight, vbHeight);
 		normalizeAttribute(element, "x", sNewWidth, vbWidth);
@@ -395,7 +394,7 @@ void SvgFileSplitter::normalizeChild(QDomElement & element,
 		setStrokeOrFill(element, blackOnly, "black", false);
 	}
 	else if (nodeName.compare("ellipse") == 0) {
-		fixStyleAttribute(element);
+		TextUtils::fixStyleAttribute(element);
 		normalizeAttribute(element, "cx", sNewWidth, vbWidth);
 		normalizeAttribute(element, "cy", sNewHeight, vbHeight);
 		normalizeAttribute(element, "rx", sNewWidth, vbWidth);
@@ -404,7 +403,7 @@ void SvgFileSplitter::normalizeChild(QDomElement & element,
 		setStrokeOrFill(element, blackOnly, "black", false);
 	}
 	else if (nodeName.compare("polygon") == 0 || nodeName.compare("polyline") == 0) {
-		fixStyleAttribute(element);
+		TextUtils::fixStyleAttribute(element);
 		normalizeAttribute(element, "stroke-width", sNewWidth, vbWidth);
 		QString data = element.attribute("points");
 		if (!data.isEmpty()) {
@@ -423,7 +422,7 @@ void SvgFileSplitter::normalizeChild(QDomElement & element,
 		setStrokeOrFill(element, blackOnly, "black", false);
 	}
 	else if (nodeName.compare("path") == 0) {
-		fixStyleAttribute(element);
+		TextUtils::fixStyleAttribute(element);
 		normalizeAttribute(element, "stroke-width", sNewWidth, vbWidth);
 		setStrokeOrFill(element, blackOnly, "black", false);
 		QString data = element.attribute("d").trimmed();
@@ -441,7 +440,7 @@ void SvgFileSplitter::normalizeChild(QDomElement & element,
 		}
 	}
 	else if (nodeName.compare("text") == 0) {
-		fixStyleAttribute(element);
+		TextUtils::fixStyleAttribute(element);
 		normalizeAttribute(element, "x", sNewWidth, vbWidth);
 		normalizeAttribute(element, "y", sNewHeight, vbHeight);
 		normalizeAttribute(element, "stroke-width", sNewWidth, vbWidth);
@@ -486,9 +485,20 @@ void SvgFileSplitter::normalizeChild(QDomElement & element,
 
 bool SvgFileSplitter::normalizeAttribute(QDomElement & element, const char * attributeName, double num, double denom)
 {
-	double n = element.attribute(attributeName).toDouble() * num / denom;
+    QString attributeValue = element.attribute(attributeName);
+    if (attributeValue.isEmpty()) return true;
+
+    bool ok;
+	double n = attributeValue.toDouble(&ok) * num / denom;
+    if (!ok) {
+        QString string;
+        QTextStream stream(&string);
+        element.save(stream, 0);
+        DebugDialog::debug("bad attribute " + string);
+    }
+
 	element.setAttribute(attributeName, QString::number(n));
-	return true;
+	return ok;
 }
 
 QString SvgFileSplitter::shift(double x, double y, const QString & elementID, bool shiftTransforms)
@@ -496,7 +506,7 @@ QString SvgFileSplitter::shift(double x, double y, const QString & elementID, bo
 	QDomElement root = m_domDocument.documentElement();
 
 	QDomElement mainElement = TextUtils::findElementWithAttribute(root, "id", elementID);
-	if (mainElement.isNull()) return false;
+	if (mainElement.isNull()) return "";
 
 	QDomElement childElement = mainElement.firstChildElement();
 	while (!childElement.isNull()) {
@@ -1052,7 +1062,7 @@ void SvgFileSplitter::setStrokeOrFill(QDomElement & element, bool blackOnly, con
 }
 
 void SvgFileSplitter::fixStyleAttributeRecurse(QDomElement & element) {
-	fixStyleAttribute(element);
+	TextUtils::fixStyleAttribute(element);
 	QDomElement childElement = element.firstChildElement();
 	while (!childElement.isNull()) {
 		fixStyleAttributeRecurse(childElement);
@@ -1061,7 +1071,7 @@ void SvgFileSplitter::fixStyleAttributeRecurse(QDomElement & element) {
 }
 
 void SvgFileSplitter::fixColorRecurse(QDomElement & element, const QString & newColor, const QStringList & exceptions) {
-	fixStyleAttribute(element);
+	TextUtils::fixStyleAttribute(element);
 	bool gotException = false;
 	QString s = element.attribute("stroke");
 	QString f = element.attribute("fill");
@@ -1103,42 +1113,6 @@ void SvgFileSplitter::fixColorRecurse(QDomElement & element, const QString & new
 	}
 }
 
-void SvgFileSplitter::fixStyleAttribute(QDomElement & element)
-{
-	QString style = element.attribute("style");
-	if (style.isEmpty()) return;
-
-	fixStyleAttribute(element, style, "stroke-width");
-	fixStyleAttribute(element, style, "stroke");
-	fixStyleAttribute(element, style, "fill");
-	fixStyleAttribute(element, style, "fill-opacity");
-	fixStyleAttribute(element, style, "stroke-opacity");
-	fixStyleAttribute(element, style, "font-size");
-
-	if (style.trimmed().isEmpty()) {
-		element.removeAttribute("style");
-	}
-	else {
-		element.setAttribute("style", style);
-	}
-
-	//QString deleteMe;
-	//QTextStream stream(&deleteMe);
-	//stream << element;
-	//DebugDialog::debug(deleteMe);
-}
-
-void SvgFileSplitter::fixStyleAttribute(QDomElement & element, QString & style, const QString & attributeName)
-{
-	QString str = findStyle.arg(attributeName);
-	QRegExp sw(str);
-	if (sw.indexIn(style) >= 0) {
-		QString value = sw.cap(1);
-		style.remove(sw);
-		element.setAttribute(attributeName, value);
-	}
-}
-
 bool SvgFileSplitter::getSvgSizeAttributes(const QString & svg, QString & width, QString & height, QString & viewBox)
 {
 	QXmlStreamReader xml(svg);
@@ -1161,7 +1135,7 @@ bool SvgFileSplitter::getSvgSizeAttributes(const QString & svg, QString & width,
 	return false;
 }
 
-bool SvgFileSplitter::changeStrokeWidth(const QString & svg, double delta, bool absolute, QByteArray & byteArray) {
+bool SvgFileSplitter::changeStrokeWidth(const QString & svg, double delta, bool absolute, bool changeOpacity, QByteArray & byteArray) {
 	QString errorStr;
 	int errorLine;
 	int errorColumn;
@@ -1181,24 +1155,54 @@ bool SvgFileSplitter::changeStrokeWidth(const QString & svg, double delta, bool
 		return false;
 	}
 
-	changeStrokeWidth(root, delta, absolute);
+	changeStrokeWidth(root, delta, absolute, changeOpacity);
 	byteArray = domDocument.toByteArray();
 	return true;
 }
 
-void SvgFileSplitter::changeStrokeWidth(QDomElement & element, double delta, bool absolute) {
+void SvgFileSplitter::changeStrokeWidth(QDomElement & element, double delta, bool absolute, bool changeOpacity) {
 	bool ok;
 	double sw = element.attribute("stroke-width").toDouble(&ok);
 	if (ok) {
 		element.setAttribute("stroke-width", QString::number((absolute) ? delta : sw + delta));
 	}
+
+    if (changeOpacity) {
+	    QString fillo = element.attribute("fill-opacity");
+	    if (!fillo.isEmpty()) {
+		    element.setAttribute("fill-opacity", "1.0");
+	    }
+
+	    QString sillo = element.attribute("stroke-opacity");
+	    if (!sillo.isEmpty()) {
+		    element.setAttribute("stroke-opacity", "1.0");
+	    }
+    }
+
 	QDomElement child = element.firstChildElement();
 	while (!child.isNull()) {
-		changeStrokeWidth(child, delta, absolute);
+		changeStrokeWidth(child, delta, absolute, changeOpacity);
 		child = child.nextSiblingElement();
 	}
 }
 
+void SvgFileSplitter::forceStrokeWidth(QDomElement & element, double delta, const QString & stroke, bool recurse) {
+	bool ok;
+	double sw = element.attribute("stroke-width").toDouble(&ok);
+    if (!ok) sw = 0;
+
+	element.setAttribute("stroke-width", QString::number(sw + delta));
+	element.setAttribute("stroke", stroke);
+
+    if (recurse) {
+	    QDomElement child = element.firstChildElement();
+	    while (!child.isNull()) {
+		    forceStrokeWidth(child, delta, stroke, recurse);
+		    child = child.nextSiblingElement();
+	    }
+    }
+}
+
 bool SvgFileSplitter::changeColors(const QString & svg, QString & toColor, QStringList & exceptions, QByteArray & byteArray) {
 	QString errorStr;
 	int errorLine;
