@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5771 $:
+$Revision: 6435 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-01-23 18:45:50 +0100 (Mon, 23 Jan 2012) $
+$Date: 2012-09-16 23:31:00 +0200 (Sun, 16 Sep 2012) $
 
 ********************************************************************/
 
@@ -82,15 +82,14 @@ void SvgFlattener::unRotateChild(QDomElement & element, QMatrix transform) {
 
     if(!element.hasChildNodes()) {
 
-		double scale = qMin(qAbs(transform.m11()), qAbs(transform.m22()));
-		if (scale != 1 && transform.m21() == 0 && transform.m12() == 0) {
-			QString sw = element.attribute("stroke-width");
-			if (!sw.isEmpty()) {
-				bool ok;
-				double strokeWidth = sw.toDouble(&ok);
-				if (ok) {
-					element.setAttribute("stroke-width", QString::number(strokeWidth * scale));
-				}
+		QString sw = element.attribute("stroke-width");
+		if (!sw.isEmpty()) {
+			bool ok;
+			double strokeWidth = sw.toDouble(&ok);
+			if (ok) {
+                QLineF line(0, 0, strokeWidth, 0);
+                QLineF newLine = transform.map(line);
+				element.setAttribute("stroke-width", newLine.length());
 			}
 		}
 
@@ -147,9 +146,13 @@ void SvgFlattener::unRotateChild(QDomElement & element, QMatrix transform) {
         else if(tag == "circle"){
             float cx = element.attribute("cx").toFloat();
             float cy = element.attribute("cy").toFloat();
+            float r = element.attribute("r").toFloat();
             QPointF point = transform.map(QPointF(cx,cy));
             element.setAttribute("cx", point.x());
             element.setAttribute("cy", point.y());
+            QLineF line(0, 0, r, 0);
+            QLineF newLine = transform.map(line);
+            element.setAttribute("r", newLine.length());
         }
         else if(tag == "line") {
             float x1 = element.attribute("x1").toFloat();
