@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5929 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-03-28 12:13:01 +0200 (Wed, 28 Mar 2012) $
+$Revision: 6482 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-25 17:05:02 +0200 (Tue, 25 Sep 2012) $
 
 ********************************************************************/
 
@@ -154,9 +154,20 @@ const QString FolderUtils::applicationDirPath() {
 #ifdef Q_WS_WIN
 		return QCoreApplication::applicationDirPath();
 #else
-		// look in standard Fritzing location (applicationDirPath) then in standard linux locations
+		// look in standard Fritzing location (applicationDirPath and parent folders) then in standard linux locations
 		QStringList candidates;
 		candidates.append(QCoreApplication::applicationDirPath());
+		QDir dir(QCoreApplication::applicationDirPath());
+		if (dir.cdUp()) {
+			candidates.append(dir.absolutePath());
+			if (dir.cdUp()) {
+				candidates.append(dir.absolutePath());
+				if (dir.cdUp()) {
+					candidates.append(dir.absolutePath());
+				}
+			}
+		}
+		
 #ifdef PKGDATADIR
 		candidates.append(QLatin1String(PKGDATADIR));
 #else
@@ -165,11 +176,11 @@ const QString FolderUtils::applicationDirPath() {
 #endif
 		candidates.append(QDir::homePath() + "/.local/share/fritzing");
 		foreach (QString candidate, candidates) {
-                        //DebugDialog::debug(QString("candidate:%1").arg(candidate));
+            //DebugDialog::debug(QString("candidate:%1").arg(candidate));
 			QDir dir(candidate);
-                        if (!dir.exists("parts")) continue;
+            if (!dir.exists("parts")) continue;
 
-                        if (dir.exists("bins")) {
+            if (dir.exists("bins")) {
 				m_appPath = candidate;
 				return m_appPath;
 			}
@@ -177,7 +188,7 @@ const QString FolderUtils::applicationDirPath() {
 		}
 
 		m_appPath = QCoreApplication::applicationDirPath();
-                DebugDialog::debug("data folders not found");
+        DebugDialog::debug("data folders not found");
 
 #endif
 	}
@@ -216,7 +227,7 @@ void FolderUtils::setOpenSaveFolderAux(const QString& path)
 
 
 const QString FolderUtils::openSaveFolder() {
-	if(m_openSaveFolder == ___emptyString___) {
+	if(m_openSaveFolder.isEmpty()) {
 		QSettings settings;
 		QString tempFolder = settings.value("openSaveFolder").toString();
 		if (!tempFolder.isEmpty()) {
@@ -326,7 +337,7 @@ void FolderUtils::rmdir(QDir & dir) {
 	dir.rmdir(dir.path());
 }
 
-bool FolderUtils::createZipAndSaveTo(const QDir &dirToCompress, const QString &filepath) {
+bool FolderUtils::createZipAndSaveTo(const QDir &dirToCompress, const QString &filepath, const QStringList & skipSuffixes) {
 	DebugDialog::debug("zipping "+dirToCompress.path()+" into "+filepath);
 
 	QString tempZipFile = QDir::temp().path()+"/"+getRandText()+".zip";
@@ -348,6 +359,15 @@ bool FolderUtils::createZipAndSaveTo(const QDir &dirToCompress, const QString &f
 		if(!file.isFile()||file.fileName()==filepath) continue;
 		if (file.fileName().contains(LockManager::LockedFileName)) continue;
 
+        bool skip = false;
+        foreach (QString suffix, skipSuffixes) {
+            if (file.fileName().endsWith(suffix)) {
+                skip = true;
+                break;
+            }
+        }
+        if (skip) continue;
+
 //#pragma message("remove fzz check")
 //if (file.fileName().endsWith(".fzz")) continue;
 
@@ -503,3 +523,33 @@ void FolderUtils::makePartFolderHierarchy(const QString & prefixFolder, const QS
 	dir.mkdir("schematic");
 	dir.mkdir("pcb");
 }
+
+void FolderUtils::copyBin(const QString & dest, const QString & source) {
+    if(QFileInfo(dest).exists()) return;
+
+    // this copy action, is not working on windows, because is a resources file
+    if(!QFile(source).copy(dest)) {
+#ifdef Q_WS_WIN // may not be needed from qt 4.5.2 on
+        DebugDialog::debug("Failed to copy a file from the resources");
+        QDir binsFolder = QFileInfo(dest).dir().absolutePath();
+        QStringList binFiles = binsFolder.entryList(QDir::AllEntries | QDir::NoDotAndDotDot);
+        foreach(QString binName, binFiles) {
+            if(binName.startsWith("qt_temp.")) {
+                QString filePath = binsFolder.absoluteFilePath(binName);
+                bool success = QFile(filePath).rename(dest);
+                Q_UNUSED(success);
+                break;
+            }
+        }
+#endif
+    }
+    QFlags<QFile::Permission> ps = QFile::permissions(dest);
+    QFile::setPermissions(
+        dest,
+        QFile::WriteOwner | QFile::WriteUser | ps
+#ifdef Q_WS_WIN
+        | QFile::WriteOther | QFile::WriteGroup
+#endif
+
+    );
+}
\ No newline at end of file
