@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5801 $:
+$Revision: 6158 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-02-01 10:30:37 +0100 (Wed, 01 Feb 2012) $
+$Date: 2012-07-10 16:19:33 +0200 (Tue, 10 Jul 2012) $
 
 ********************************************************************/
 
@@ -54,13 +54,14 @@ public:
 	static bool isEmptyFileName(const QString &filename, const QString &unsavedFilename);
 	static void rmdir(const QString &dirPath);
 	static void rmdir(QDir & dir);
-	static bool createZipAndSaveTo(const QDir &dirToCompress, const QString &filename);
+	static bool createZipAndSaveTo(const QDir &dirToCompress, const QString &filename, const QStringList & skipSuffixes);
 	static bool unzipTo(const QString &filepath, const QString &dirToDecompress);
 	static void replicateDir(QDir srcDir, QDir targDir);
 	static QString getRandText();
 	static void cleanup();
 	static void collectFiles(const QDir & parent, QStringList & filters, QStringList & files);
 	static void makePartFolderHierarchy(const QString & prefixFolder, const QString & destFolder);
+    static void copyBin(const QString & source, const QString & dest);
 
 protected:
 	FolderUtils();
