@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5859 $:
+$Revision: 6218 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-02-13 13:29:26 +0100 (Mon, 13 Feb 2012) $
+$Date: 2012-07-26 10:32:57 +0200 (Thu, 26 Jul 2012) $
 
 ********************************************************************/
 
@@ -32,6 +32,9 @@ $Date: 2012-02-13 13:29:26 +0100 (Mon, 13 Feb 2012) $
 #include <qmath.h>
 
 
+const double GraphicsUtils::IllustratorDPI = 72;
+const double GraphicsUtils::StandardFritzingDPI = 1000;
+const double GraphicsUtils::SVGDPI = 90;
 const double GraphicsUtils::InchesPerMeter = 39.370078;
 const double GraphicsUtils::StandardSchematicSeparationMils = 295.275591;   // 7.5mm
 
