@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5857 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-02-12 18:16:07 +0100 (Sun, 12 Feb 2012) $
+$Revision: 6469 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-09-23 00:54:30 +0200 (Sun, 23 Sep 2012) $
 
 ********************************************************************/
 
@@ -29,12 +29,13 @@ $Date: 2012-02-12 18:16:07 +0100 (Sun, 12 Feb 2012) $
 #include "../items/wire.h"
 #include "../items/jumperitem.h"
 #include "../sketch/sketchwidget.h"
+#include "../debugdialog.h"
 
 #ifdef _MSC_VER 
 #pragma warning(push) 
+#pragma warning(disable:4503)
 #pragma warning(disable:4100)			// disable scary-looking compiler warnings in Boost library
 #pragma warning(disable:4181)	
-#pragma warning(disable:4503)
 #endif
 
 #include <boost/config.hpp>
@@ -293,7 +294,8 @@ void GraphUtils::minCut(QList<ConnectorItem *> & connectorItems, QList<SketchWid
 
 	// if color_map parameter not specified, colors are not set
     long flow = edmonds_karp_max_flow(g, s, t, color_map(color)); 
-	DebugDialog::debug(QString("flow %1, s%2, t%3").arg(flow).arg(index(s)).arg(index(t)));
+	Q_UNUSED(flow);
+	//DebugDialog::debug(QString("flow %1, s%2, t%3").arg(flow).arg(index(s)).arg(index(t)));
 	//for (int i = 0; i < verts.count(); ++i) {
 	//	DebugDialog::debug(QString("index %1 %2").arg(index(verts[i])).arg(color(verts[i])));
 	//}
@@ -426,6 +428,11 @@ bool GraphUtils::chooseRatsnestGraph(const QList<ConnectorItem *> * partConnecto
 	return true;
 }
 
+#define add_edge_d(i, j, g) \
+	add_edge(verts[i], verts[j], g); \
+    //partConnectorItems[i]->debugInfo(QString("edge from %1").arg(i));
+	//partConnectorItems[j]->debugInfo(QString("\tto %1").arg(j));
+
 bool GraphUtils::scoreOneNet(QList<ConnectorItem *> & partConnectorItems, ViewGeometry::WireFlags myTrace, RoutingStatus & routingStatus) {
 	using namespace boost;
 
@@ -445,14 +452,14 @@ bool GraphUtils::scoreOneNet(QList<ConnectorItem *> & partConnectorItems, ViewGe
 	//std::pair<int, int> pair;
 	bool gotUserConnection = false;
 	for (int i = 0; i < num_nodes; i++) {
-		add_edge(verts[i], verts[i], G);
+		add_edge_d(i, i, G);
 		ConnectorItem * from = partConnectorItems[i];
 		for (int j = i + 1; j < num_nodes; j++) {
 			ConnectorItem * to = partConnectorItems[j];
 
 			if (from->isCrossLayerConnectorItem(to)) {
-				add_edge(verts[i], verts[j], G);
-				add_edge(verts[j], verts[i], G);
+				add_edge_d(i, j, G);
+				add_edge_d(j, i, G);
 				continue;
 			}
 
@@ -462,8 +469,8 @@ bool GraphUtils::scoreOneNet(QList<ConnectorItem *> & partConnectorItems, ViewGe
 			}
 
 			if ((to->bus() != NULL) && (to->bus() == from->bus())) {	
-				add_edge(verts[i], verts[j], G);
-				add_edge(verts[j], verts[i], G);
+				add_edge_d(i, j, G);
+				add_edge_d(j, i, G);
 				continue;
 			}
 
@@ -483,9 +490,27 @@ bool GraphUtils::scoreOneNet(QList<ConnectorItem *> & partConnectorItems, ViewGe
 			routingStatus.m_jumperItemCount++;				
 		}
 		foreach (ConnectorItem * toConnectorItem, fromConnectorItem->connectedToItems()) {
-			if (toConnectorItem->attachedToItemType() != ModelPart::Wire) {
-				continue;
-			}
+            switch (toConnectorItem->attachedToItemType()) {
+                case ModelPart::Wire:
+                    break;
+                case ModelPart::Breadboard:
+                    if (toConnectorItem->attachedTo()->isEverVisible()) {
+                        QList<ConnectorItem *> ends;
+                        collectBreadboard(toConnectorItem, partConnectorItems, ends);
+                        foreach (ConnectorItem * end, ends) {
+				            if (end == fromConnectorItem) continue;
+
+				            int j = partConnectorItems.indexOf(end);
+				            if (j >= 0) {
+					            add_edge_d(i, j, G);
+					            add_edge_d(j, i, G);
+				            }
+			            }
+                    }
+                    continue;
+                default:
+                    continue;
+            }
 
 			Wire * wire = qobject_cast<Wire *>(toConnectorItem->attachedTo());
 			if (wire == NULL) continue;
@@ -503,8 +528,8 @@ bool GraphUtils::scoreOneNet(QList<ConnectorItem *> & partConnectorItems, ViewGe
 
 				int j = partConnectorItems.indexOf(end);
 				if (j >= 0) {
-					add_edge(verts[i], verts[j], G);
-					add_edge(verts[j], verts[i], G);
+					add_edge_d(i, j, G);
+					add_edge_d(j, i, G);
 				}
 			}
 		}
@@ -532,7 +557,7 @@ bool GraphUtils::scoreOneNet(QList<ConnectorItem *> & partConnectorItems, ViewGe
 				
 				//ConnectorItem * ci = partConnectorItems.at(i);
 				//ConnectorItem * cj = partConnectorItems.at(j);
-				//ci->debugInfo("score one ci");
+				//ci->debugInfo("missing one ci");
 				//cj->debugInfo("\t\tcj");
 				
 			}
@@ -549,4 +574,34 @@ bool GraphUtils::scoreOneNet(QList<ConnectorItem *> & partConnectorItems, ViewGe
 	return true;
 }
 
+void GraphUtils::collectBreadboard(ConnectorItem * connectorItem, QList<ConnectorItem *> & partConnectorItems, QList<ConnectorItem *> & ends)
+{
+    QList<ConnectorItem *> itemsToGo;
+    itemsToGo.append(connectorItem);
+    for (int i = 0; i < itemsToGo.count(); i++) {
+        ConnectorItem * candidate = itemsToGo.at(i);
+        if (partConnectorItems.contains(candidate)) {
+            if (!ends.contains(candidate)) {
+                ends.append(candidate);
+            }
+            continue;
+        }
 
+        Bus * bus = candidate->bus();
+        if (bus) {
+            QList<ConnectorItem *> busConnectorItems;
+            candidate->attachedTo()->busConnectorItems(bus, busConnectorItems);
+            foreach (ConnectorItem * bci, busConnectorItems) {
+                if (!itemsToGo.contains(bci)) {
+                    itemsToGo.append(bci);
+                }
+            }
+        }
+        
+        foreach (ConnectorItem * to, candidate->connectedToItems()) {
+            if (!itemsToGo.contains(to)) {
+                itemsToGo.append(to);
+            }
+        }
+    }
+}
