@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5847 $:
+$Revision: 6444 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-02-07 00:20:48 +0100 (Tue, 07 Feb 2012) $
+$Date: 2012-09-17 14:27:26 +0200 (Mon, 17 Sep 2012) $
 
 ********************************************************************/
 
@@ -63,7 +63,6 @@ $Date: 2012-02-07 00:20:48 +0100 (Tue, 07 Feb 2012) $
 #define ALLMOUSEBUTTONS (Qt::LeftButton | Qt::MidButton | Qt::RightButton | Qt::XButton1 | Qt::XButton2)
 
 typedef QPair<double, double> RealPair;
-typedef QPair<QString, QString> StringPair;
 
 static QString ___emptyString___;
 static QDomElement ___emptyElement___;
@@ -72,6 +71,8 @@ static QHash<QString, QString> ___emptyStringHash___;
 static QDir ___emptyDir___;
 static QByteArray ___emptyByteArray___;
 
+static const QString ResourcePath(":/resources/");
+
 bool isParent(QObject * candidateParent, QObject * candidateChild);
 
 static const QString FritzingSketchExtension(".fz");
@@ -88,4 +89,11 @@ static const QString MaleSymbolString = QString("%1").arg(QChar(0x2642));
 
 Qt::KeyboardModifier altOrMetaModifier();
 
+static QRegExp IntegerFinder("\\d+");
+
+static const int PartsBinHeightDefault = 240;
+static const int InfoViewHeightDefault = 220;
+static const int DockWidthDefault = 300;
+static const int DockHeightDefault = 50;
+
 #endif
