@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5917 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-03-17 10:19:17 +0100 (Sat, 17 Mar 2012) $
+$Revision: 6561 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-12 22:39:11 +0200 (Fri, 12 Oct 2012) $
 
 ********************************************************************/
 
@@ -29,23 +29,29 @@ $Date: 2012-03-17 10:19:17 +0100 (Sat, 17 Mar 2012) $
 
 #include "textutils.h"
 #include "misc.h"
+#include "../installedfonts.h"
 //#include "../debugdialog.h"
 
 #include <QRegExp>
 #include <QBuffer>
 #include <QFile>
 
+#include <qmath.h>
+#include <qnumeric.h>
+
 const QString TextUtils::CreatedWithFritzingString("Created with Fritzing (http://www.fritzing.org/)");
 const QString TextUtils::CreatedWithFritzingXmlComment("<!-- " + CreatedWithFritzingString + " -->\n");
 
 const QRegExp TextUtils::FindWhitespace("[\\s]+");
-const QRegExp TextUtils::SodipodiDetector("((inkscape)|(sodipodi)):[^=\\s]+=\"([^\"\\\\]*(\\\\.[^\"\\\\]*)*)\"");
+static const QRegExp SodipodiAttributeDetector("(inkscape|sodipodi):[^=\\s]+=\"([^\"\\\\]*(\\\\.[^\"\\\\]*)*)\"");
+static const QRegExp SodipodiElementDetector("</{0,1}(inkscape|sodipodi):[^>]+>");
 const QString TextUtils::SMDFlipSuffix("___");
 
 const QString TextUtils::RegexFloatDetector = "[-+]?[0-9]*\\.?[0-9]+([eE][-+]?[0-9]+)?";
 const QRegExp TextUtils::floatingPointMatcher(RegexFloatDetector);		
 
-const QRegExp HexExpr("&#x[0-9a-fA-F];");   // &#x9; &#xa; &#xd;
+static const QRegExp HexExpr("&#x[0-9a-fA-F];");   // &#x9; &#xa; &#xd;
+static const QRegExp Xmlns("xmlns=([\"|'])[^\"']*\\1");
 
 static const ushort MicroSymbolCode = 181;
 const QString TextUtils::MicroSymbol = QString::fromUtf16(&MicroSymbolCode, 1);
@@ -56,6 +62,87 @@ QList<QString> PowerPrefixes;
 QList<double> PowerPrefixValues;
 const QString TextUtils::PowerPrefixesString = QString("pnmkMGTu\\x%1").arg(MicroSymbolCode, 4, 16, QChar('0'));
 
+typedef QHash<QString /*brokenFont*/, QString /*replacementFont*/> FixedFontsHash;
+
+//////////////////////////////////////////////
+
+QSet<QString> getAttrFontFamilies(const QString &fileContent) {
+	/*
+	 * font-family defined as attr example:
+
+<text xmlns="http://www.w3.org/2000/svg" font-family="DroidSans"
+id="text2732" transform="matrix(1 0 0 1 32.2012 236.969)"
+font-size="9.9771" >A0</text>
+
+	 */
+
+	static QString pattern = "font-family\\s*=\\s*\"([^\"]*)\"";
+	return TextUtils::getRegexpCaptures(pattern,fileContent);
+}
+
+QSet<QString> getFontFamiliesInsideStyleTag(const QString &fileContent) {
+	/*
+	 * regexp: font-family\s*:\s*(.|[^;"]*).*"
+	 * font-family defined in a style attr example:
+
+style="font-size:9;-inkscape-font-specification:Droid Sans;font-family:Droid Sans;font-weight:normal;font-style:normal;font-stretch:normal;font-variant:normal"
+
+style="font-size:144px;font-style:normal;font-weight:normal;line-height:100%;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:Bitstream Vera Sans" x="18.000002"
+
+	 */
+
+	static QString pattern = "font-family\\s*:\\s*([^;\"]*)";
+	return TextUtils::getRegexpCaptures(pattern,fileContent);
+}
+
+
+FixedFontsHash fixFontsMapping(const QSet<QString> fontsTofix, const QString & destFont) {
+	FixedFontsHash retval;
+
+	QSet<QString> tempFontsToFix;
+	tempFontsToFix = fontsTofix - InstalledFonts::InstalledFontsList;
+	foreach (QString fontFileName, InstalledFonts::InstalledFontsNameMapper.values()) {
+		// SVG uses filename which may not match family name (e.g. "DroidSans" and "Droid Sans")
+		tempFontsToFix.remove(fontFileName);
+	}
+
+	foreach (QString broken, tempFontsToFix) {
+		retval.insert(broken, destFont);
+	}
+
+	return retval;
+}
+
+bool removeFontFamilySingleQuotes(QString &fileContent) {
+	static QString pattern = "font-family=\"('[^']*')\"";
+	QSet<QString> wrongFontFamilies = TextUtils::getRegexpCaptures(pattern, fileContent);
+
+	foreach(QString ff, wrongFontFamilies) {
+		QString wrongFF = ff;
+		QString fixedFF = ff.remove('\'');
+		fileContent.replace(wrongFF,fixedFF);
+	}
+
+	return wrongFontFamilies.size() > 0;
+}
+
+bool fixUnavailableFontFamilies(QString &fileContent, const QString & destFont) {
+	QSet<QString> definedFFs;
+	definedFFs.unite(getAttrFontFamilies(fileContent));
+	definedFFs.unite(getFontFamiliesInsideStyleTag(fileContent));
+
+	FixedFontsHash fixedFonts = fixFontsMapping(definedFFs, destFont);
+	foreach(QString oldF, fixedFonts.keys()) {
+		QString newF = fixedFonts[oldF];
+		fileContent.replace(oldF,newF);
+	}
+
+	return fixedFonts.size() > 0;
+}
+
+///////////////////////////////////////
+
+
 void TextUtils::findElementsWithAttribute(QDomElement & element, const QString & att, QList<QDomElement> & elements) {
 	if (!element.attribute(att).isEmpty()) {
 		elements.append(element);
@@ -99,30 +186,41 @@ QSet<QString> TextUtils::getRegexpCaptures(const QString &pattern, const QString
 double TextUtils::convertToInches(const QString & s, bool * ok, bool isIllustrator) {
 	QString string = s;
 	double divisor = 1.0;
+	int chop = 2;
 	if (string.endsWith("cm", Qt::CaseInsensitive)) {
 		divisor = 2.54;
-		string.chop(2);
 	}
 	else if (string.endsWith("mm", Qt::CaseInsensitive)) {
 		divisor = 25.4;
-		string.chop(2);
 	}
 	else if (string.endsWith("in", Qt::CaseInsensitive)) {
 		divisor = 1.0;
-		string.chop(2);
 	}
 	else if (string.endsWith("px", Qt::CaseInsensitive)) {
 		divisor = isIllustrator? 72.0: 90.0;
-		string.chop(2);
 	}
 	else if (string.endsWith("mil", Qt::CaseInsensitive)) {
 		divisor = 1000.0;
-		string.chop(3);
+		chop = 3;
+	}
+	else if (string.endsWith("pt", Qt::CaseInsensitive)) {
+		divisor = 72.0;
+	}
+	else if (string.endsWith("pc", Qt::CaseInsensitive)) {
+		divisor = 6.0;
 	}
 	else {
+		for (int ix = string.count() - 1; ix >= 0; ix--) {
+			if (string.at(ix).isDigit()) break;
+			
+			string.chop(1);
+		}
 		divisor = 90.0;			// default to Qt's standard internal units if all else fails
+		chop = 0;
 	}
 
+	if (chop) string.chop(chop);
+
 	bool fine;
 	double result = string.toDouble(&fine);
 	if (!fine) {
@@ -180,6 +278,28 @@ QString TextUtils::replaceTextElement(const QString & svg, const QString & id, c
 	return svg;
 }
 
+QByteArray TextUtils::replaceTextElement(const QByteArray & svg, const QString & id, const QString & newValue) {
+	QString errorStr;
+	int errorLine;
+	int errorColumn;
+	QDomDocument doc;
+	if (!doc.setContent(svg, &errorStr, &errorLine, &errorColumn)) return svg;
+
+	QDomElement root = doc.documentElement();
+	QDomNodeList domNodeList = root.elementsByTagName("text");
+	for (int i = 0; i < domNodeList.count(); i++) {
+		QDomElement node = domNodeList.item(i).toElement();
+		if (node.isNull()) continue;
+
+		if (node.attribute("id").compare(id) != 0) continue;
+
+		replaceChildText(doc, node, newValue);
+		return doc.toByteArray();
+	}
+		
+	return svg;
+}
+
 QString TextUtils::replaceTextElements(const QString & svg, const QHash<QString, QString> & hash) {
 	QString errorStr;
 	int errorLine;
@@ -280,7 +400,9 @@ QString TextUtils::mergeSvgFinish(QDomDocument & doc) {
 QString TextUtils::mergeSvg(const QString & svg1, const QString & svg2, const QString & id, bool flip) {
 
 	QDomDocument doc1;
-	if (!TextUtils::mergeSvg(doc1, svg1, id)) return ___emptyString___;
+    if (!svg1.isEmpty()) {
+	    if (!TextUtils::mergeSvg(doc1, svg1, id)) return ___emptyString___;
+    }
 
 	if (!TextUtils::mergeSvg(doc1, svg2, id)) return ___emptyString___;
 
@@ -343,18 +465,23 @@ bool TextUtils::isIllustratorDoc(const QDomDocument & doc) {
 }
 
 QString TextUtils::removeXMLEntities(QString svgContent) {
-	return removeXMLNS(svgContent.remove(HexExpr));
+	return svgNSOnly(svgContent.remove(HexExpr));
 }
 
-QString TextUtils::removeXMLNS(QString svgContent) {
+QString TextUtils::killXMLNS(QString svgContent) {
 	// TODO: this is a bug in Qt, it would be nice to fix it there
-	// but as a stopgap, it would be nice if this function removed all repetitious xmlns attributes, not just the svg one
-	QString svgNS = "xmlns=\"http://www.w3.org/2000/svg\"";
-	QStringList strings = svgContent.split(svgNS);
-	if (strings.count() < 3) return svgContent;
 
-	QString first = strings.takeFirst();
-	return first + svgNS + strings.join("");
+    svgContent.remove(Xmlns);
+    return svgContent;
+}
+
+QString TextUtils::svgNSOnly(QString svgContent) {
+    svgContent.remove(Xmlns);
+    int ix = svgContent.indexOf("<svg");
+    if (ix >= 0) {
+        svgContent.insert(ix + 5, "xmlns=\"http://www.w3.org/2000/svg\" ");
+    }
+    return svgContent;
 }
 
 bool TextUtils::cleanSodipodi(QString &content)
@@ -362,22 +489,9 @@ bool TextUtils::cleanSodipodi(QString &content)
 	// clean out sodipodi stuff
 	// TODO: don't bother with the core parts
 	int l1 = content.length();
-	content.remove(SodipodiDetector);
+	content.remove(SodipodiAttributeDetector);          // remove attributes first
+	content.remove(SodipodiElementDetector);
 	if (content.length() != l1) {
-		/*
-		QFileInfo f(filename);
-		QString p = f.absoluteFilePath();
-		p.remove(':');
-		p.remove('/');
-		p.remove('\\');
-		QFile fi(QCoreApplication::applicationDirPath() + p);
-		bool ok = fi.open(QFile::WriteOnly);
-		if (ok) {
-			QTextStream out(&fi);
-   			out << str;
-			fi.close();
-		}
-		*/
 		return true;
 	}
 	return false;
@@ -402,41 +516,6 @@ bool TextUtils::cleanSodipodi(QString &content)
 	*/
 }
 
-bool TextUtils::fixViewboxOrigin(QString &fileContent) {
-	QDomDocument svgDom;
-
-	bool fileHasChanged = false;
-	if(isIllustratorFile(fileContent)) {
-		QString errorMsg;
-		int errorLine;
-		int errorCol;
-		if(!svgDom.setContent(fileContent, true, &errorMsg, &errorLine, &errorCol)) {
-			return false;
-		}
-
-		QDomElement elem = svgDom.firstChildElement("svg");
-
-		fileHasChanged = moveViewboxToTopLeftCorner(elem);
-
-		if(fileHasChanged) {
-			fileContent = svgDom.toString();
-		}
-	}
-
-	return fileHasChanged;
-}
-
-bool TextUtils::moveViewboxToTopLeftCorner(QDomElement &elem) {
-	QString attrName = elem.hasAttribute("viewbox")? "viewbox": "viewBox";
-	QStringList vals = elem.attribute(attrName).split(" ");
-	if(vals.length() == 4 && (vals[0] != "0" || vals[1] != "0")) {
-		QString newValue = QString("0 0 %1 %2").arg(vals[2]).arg(vals[3]);
-		elem.setAttribute(attrName,newValue);
-		return true;
-	}
-	return false;
-}
-
 bool TextUtils::fixPixelDimensionsIn(QString &fileContent) {
 	bool isIllustrator = isIllustratorFile(fileContent);
 	if (!isIllustrator) return false;
@@ -849,20 +928,194 @@ void TextUtils::gWrap(QDomDocument & domDocument, const QHash<QString, QString>
 	}
 }
 
-bool TextUtils::tspanRemove(QString &svg) {
-	if (!svg.contains("<tspan")) return false;
+bool TextUtils::fixInternalUnits(QString & svg) 
+{
+	// float detector is a little weak
+	static QRegExp findInternalUnits("[\"']([\\d,\\.]+)(px|mm|cm|in|pt|pc)[\"']");
+	static QRegExp findStrokeWidth("stroke-width:([\\d,\\.]+)(px|mm|cm|in|pt|pc)");
 
-	// TODO: if the <text> element has its own text node, this will be ordered first, even if the text node occurs after one or more <tspan> elements
-	// this is a very unlikely occurrence, so fixing it is very low priority.
+	int sw = 0;
+	int iu = 0;
+	int jx = svg.indexOf("<svg");
+	if (jx >= 0) {
+		sw = iu = svg.indexOf(">", jx + 4);
+	}
+
+	bool firstTime = true;
+	QSizeF size;
+	QRectF viewBox;
+	bool result = false;
+	while (true) {
+		iu = findInternalUnits.indexIn(svg, iu);
+		if (iu < 0) break;
+
+		result = true;
+		if (firstTime) {
+			// assumes width dpi = height dpi
+			size = parseForWidthAndHeight(svg, viewBox);
+			if (size.width() == 0) {
+				// svg is messed up
+				return false;
+			}
+		}
+
+		QString old = findInternalUnits.cap(1) + findInternalUnits.cap(2); 
+		double in = convertToInches(old);
+		double replacement = in * viewBox.width() / size.width();
+		svg.replace(iu + 1, old.length(), QString::number(replacement));
+	}
+
+	while (true) {
+		sw = findStrokeWidth.indexIn(svg, sw);
+		if (sw < 0) break;
+
+		result = true;
+		if (firstTime) {
+			// assumes width dpi = height dpi
+			size = parseForWidthAndHeight(svg, viewBox);
+			if (size.width() == 0) {
+				// svg is messed up
+				return false;
+			}
+		}
+
+		QString old = findStrokeWidth.cap(1) + findStrokeWidth.cap(2); 
+		double in = convertToInches(old);
+		double replacement = in * viewBox.width() / size.width();
+		svg.replace(sw + 13, old.length(), QString::number(replacement));
+	}
+
+	return result;
+}
+
+bool TextUtils::fixMuch(QString &svg, bool fixStrokeWidthFlag)
+{
+    bool result = cleanSodipodi(svg);
+	result |= fixInternalUnits(svg);
 
 	QDomDocument svgDom;
 	QString errorMsg;
 	int errorLine;
 	int errorCol;
 	if(!svgDom.setContent(svg, true, &errorMsg, &errorLine, &errorCol)) {
-		return false;
+		return result;
 	}
 
+    QDomElement root = svgDom.documentElement();
+    result |= fixViewBox(root);
+
+    QStringList strings;
+    strings << "pattern" << "marker" << "clipPath";
+    foreach (QString string, strings) {
+        if (svg.contains("<" + string)) {
+            result |= noPatternAux(svgDom, string);
+        }
+    }
+
+    if (svg.contains("<use")) {
+        result |= noUseAux(svgDom);
+    }
+
+    if (svg.contains("<tspan")) {
+        result |= tspanRemoveAux(svgDom);
+    }
+
+    if (fixStrokeWidthFlag) {
+        result |= fixStrokeWidth(svgDom);
+    }
+
+    result |= elevateTransform(root);
+
+    if (result) {
+        svg = removeXMLEntities(svgDom.toString());
+    }
+
+    return result;
+}
+
+bool TextUtils::fixViewBox(QDomElement & root) {
+	QString viewBox = root.attribute("viewBox");
+    if (viewBox.isEmpty()) return false;
+
+	QStringList coords = viewBox.split(QRegExp(" |,"));
+	if (coords.length() != 4) return false;
+    
+    if (coords[0] == "0" && coords[1] == "0") return false;
+
+    bool ok;
+    double x = coords.at(0).toDouble(&ok);
+    if (!ok) return false;
+
+    double y = coords.at(1).toDouble(&ok);
+    if (!ok) return false;
+
+	QString newValue = QString("0 0 %1 %2").arg(coords[2]).arg(coords[3]);
+	root.setAttribute("viewBox", newValue);
+
+    QDomElement transformElement = root.ownerDocument().createElement("g");
+    transformElement.setAttribute("transform", QString("translate(%1,%2)").arg(-x).arg(-y));
+    transformElement = root.insertBefore(transformElement, QDomElement()).toElement();
+    QDomElement nextElement = transformElement.nextSiblingElement();
+    while (!nextElement.isNull()) {
+        transformElement.appendChild(nextElement);
+        nextElement = transformElement.nextSiblingElement();
+    }
+
+	return true;
+}
+
+bool TextUtils::fixStrokeWidth(QDomDocument & svgDoc) {
+    bool result = false;
+
+    QList<QDomElement> todo;
+    todo << svgDoc.documentElement();
+    while (todo.count() > 0) {
+        QDomElement element = todo.takeFirst();
+        QDomElement child = element.firstChildElement();
+        while (!child.isNull()) {
+            todo.append(child);
+            child = child.nextSiblingElement();
+        }
+
+        QString stroke, strokeWidth;
+        stroke = element.attribute("stroke");
+        strokeWidth = element.attribute("stroke-width");
+        if (stroke.isEmpty()) {
+            QString style = element.attribute("style");
+            if (style.contains("stroke")) {
+                fixStyleAttribute(element);
+                stroke = element.attribute("stroke");
+                strokeWidth = element.attribute("stroke-width");
+            }
+        }
+
+        if (stroke.isEmpty()) continue;
+        if (stroke == "none") continue;
+        if (!strokeWidth.isEmpty()) continue;
+
+        element.setAttribute("stroke-width", 1);
+        result = true;
+    }
+
+    return result;
+}
+
+
+bool TextUtils::noPatternAux(QDomDocument & svgDom, const QString & tag) 
+{
+    bool result = false;
+	QDomNodeList nodeList = svgDom.elementsByTagName(tag);
+    for (int i = 0; i < nodeList.count(); i++) {
+        QDomNode pattern = nodeList.at(i);
+        pattern.parentNode().removeChild(pattern);
+        result = true;
+	}
+    return result;
+}
+
+
+bool TextUtils::tspanRemoveAux(QDomDocument & svgDom)
+{
 	QList<QDomElement> texts;
 	QDomNodeList textNodeList = svgDom.elementsByTagName("text");
     for (int i = 0; i < textNodeList.count(); i++) {
@@ -873,6 +1126,8 @@ bool TextUtils::tspanRemove(QString &svg) {
 		texts.append(text);
 	}
 
+    if (texts.count() == 0) return false;
+
 	foreach (QDomElement text, texts) {
 		QDomElement g = svgDom.createElement("g");
 		text.parentNode().replaceChild(g, text);
@@ -895,10 +1150,56 @@ bool TextUtils::tspanRemove(QString &svg) {
 		}
 	}
 
-	svg = removeXMLEntities(svgDom.toString());
 	return true;
 }
 
+bool TextUtils::noUseAux(QDomDocument & svgDom)
+{
+
+    QDomElement root = svgDom.documentElement();
+    if (root.isNull()) return false;
+
+	QList<QDomElement> uses;
+	QDomNodeList useNodeList = svgDom.elementsByTagName("use");
+    for (int i = 0; i < useNodeList.count(); i++) {
+        QDomElement use = useNodeList.item(i).toElement();
+        QString refid = use.attribute("href");
+        if (refid.isEmpty()) continue;
+
+        QString id = use.attribute("id");
+        if (id.isEmpty()) continue;
+
+		uses.append(use);
+	}
+
+    if (uses.count() == 0) return false;
+
+	foreach (QDomElement use, uses) {
+		QString transform = use.attribute("transform");
+        QString refid = use.attribute("href");
+        QString id = use.attribute("id");
+
+        QDomElement g = svgDom.createElement("g");
+		use.parentNode().replaceChild(g, use);
+        g.setAttribute("transform", transform);
+
+        if (refid.startsWith("#")) {
+            refid.remove(0, 1);
+            if (refid.isEmpty()) continue;
+        }
+
+        QDomElement toCopy = findElementWithAttribute(root, "id", refid);
+        if (toCopy.isNull()) continue;
+
+        QDomElement copy = toCopy.cloneNode(true).toElement();
+        g.appendChild(copy);
+        copy.setAttribute("id", id);
+	}
+
+	return true;
+}
+
+
 QDomElement TextUtils::copyText(QDomDocument & svgDom, QDomElement & parent, QDomElement & text, const QString & defaultX, const QString & defaultY, bool copyAttributes)
 {
 	QDomNode cnode = text.firstChild();
@@ -929,6 +1230,18 @@ QDomElement TextUtils::copyText(QDomDocument & svgDom, QDomElement & parent, QDo
 	return ___emptyElement___;
 }
 
+QString TextUtils::slamStrokeAndFill(const QString & svg, const QString & stroke, const QString & strokeWidth, const QString & fill)
+{
+	QDomDocument doc;
+    if (doc.setContent(svg)) {
+        QDomElement root = doc.documentElement();
+        slamStrokeAndFill(root, stroke, strokeWidth, fill);
+        return doc.toString();
+    }
+
+    return svg;
+}
+
 void TextUtils::slamStrokeAndFill(QDomElement & element, const QString & stroke, const QString & strokeWidth, const QString & fill)
 {
 	// assumes style elements have been normalized already
@@ -1207,3 +1520,203 @@ void TextUtils::expandAndFillAux(QDomElement & element, const QString & color, d
 	element.setAttribute("stroke-width", QString::number(sw));
 
 }
+
+bool TextUtils::writeUtf8(const QString & fileName, const QString & text)
+{
+	QFile file(fileName);
+	if (file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
+		QTextStream out(&file);
+		out.setCodec("UTF-8");
+		out << text;
+		file.close();
+        return true;
+    }
+
+    return false;
+}
+
+int TextUtils::getPinsAndSpacing(const QString & expectedFileName, QString & spacingString) 
+{
+    QStringList pieces = expectedFileName.split("_");
+    int pix = 0;
+    foreach (QString piece, pieces) {
+        bool ok;
+        piece.toInt(&ok);
+        if (ok) break;
+
+        pix++;
+    }
+    if (pix >= pieces.count()) return 0;
+
+	int pins = pieces.at(pix).toInt();
+
+	spacingString = "100mil";
+    for (++pix; pix < pieces.count(); pix++) {
+        if (QRegExp("\\d").indexIn(pieces.at(pix)) == 0) {
+            spacingString = pieces.at(pix);
+            return pins;
+        }
+    }
+
+    return pins;
+}
+
+QSizeF TextUtils::parseForWidthAndHeight(const QString & svg)
+{
+	QRectF viewBox;
+    return parseForWidthAndHeight(svg, viewBox);
+}
+
+QSizeF TextUtils::parseForWidthAndHeight(const QString & svg, QRectF & viewBox)
+{
+	QXmlStreamReader streamReader(svg);
+    return parseForWidthAndHeight(streamReader, viewBox);
+}
+
+QSizeF TextUtils::parseForWidthAndHeight(QXmlStreamReader & svg, QRectF & viewBox)
+{
+    svg.setNamespaceProcessing(false);
+
+	QSizeF size(0, 0);
+	viewBox.setRect(0, 0, 0, 0);
+
+	bool isIllustrator = false;
+	bool bad = false;
+
+	while (!svg.atEnd() && !bad) {
+        switch (svg.readNext()) {
+		case QXmlStreamReader::Comment:
+			if (!isIllustrator) {
+				isIllustrator = TextUtils::isIllustratorFile(svg.text().toString());
+			}
+			break;
+        case QXmlStreamReader::StartElement:
+			if (svg.name().toString().compare("svg") == 0) {
+				QString ws = svg.attributes().value("width").toString();
+				QString hs = svg.attributes().value("height").toString();
+				bool okw, okh;
+				double w = TextUtils::convertToInches(ws, &okw, isIllustrator);
+				double h = TextUtils::convertToInches(hs, &okh, isIllustrator);
+				if (!okw || qIsNaN(w) || qIsInf(w) || !okh || qIsNaN(h) || qIsInf(h)) {
+					bad = true;
+					break;
+				}
+
+				size.setWidth(w);
+				size.setHeight(h);
+				viewBox.setRect(0, 0, w, h);
+
+				QString vb = svg.attributes().value("viewBox").toString();
+				QStringList vbs = vb.split(QRegExp(",| "));
+				if (vbs.count() == 4) {
+					bool ok = false;
+					double d[4];
+					for (int i = 0; i < 4; i++) {
+						d[i] = vbs.at(i).toDouble(&ok);
+						if (!ok) break;
+					}
+					if (ok) {
+						viewBox.setRect(d[0], d[1], d[2], d[3]);
+					}
+				}
+
+				return size;
+			}
+			break;		
+		default:
+			break;		
+		}
+	}
+
+    return size;
+}
+
+void TextUtils::gornTree(QDomDocument & doc)
+{
+    QDomElement root = doc.documentElement();
+    root.setAttribute("id", "0");
+    gornTreeAux(root);
+}
+
+void TextUtils::gornTreeAux(QDomElement & root) {
+    QString prefix = root.attribute("id");
+    QDomElement child = root.firstChildElement();
+    int index = 0;
+    while (!child.isNull()) {
+        QString oldid = child.attribute("id");
+        QString newid = QString("%1.%2").arg(prefix).arg(index++);
+        child.setAttribute("id", newid);
+        child.setAttribute("gorn", newid);
+        if (!oldid.isEmpty()) child.setAttribute("oldid", oldid);
+        gornTreeAux(child);
+        child = child.nextSiblingElement();
+    }
+}
+
+bool TextUtils::elevateTransform(QDomElement & root) {
+    bool result = false;
+    if (root.hasChildNodes()) {
+        QDomElement child = root.firstChildElement();
+        while (!child.isNull()) {
+            QDomElement next = child.nextSiblingElement();
+            result |= elevateTransform(child);
+            child = next;
+        }
+        return result;
+    }
+
+    QString transform = root.attribute("transform");
+    if (transform.isEmpty()) return result;
+
+    root.removeAttribute("transform");
+    QDomElement g = root.ownerDocument().createElement("g");
+    g.setAttribute("transform", transform);
+    root.parentNode().insertBefore(g, root);
+    g.appendChild(root);
+    return true;
+}
+
+bool TextUtils::fixFonts(QString & svg, const QString & destFont) {
+	bool changed = removeFontFamilySingleQuotes(svg);
+	changed |= fixUnavailableFontFamilies(svg, destFont);
+
+	return changed;
+}
+
+void TextUtils::fixStyleAttribute(QDomElement & element)
+{
+	QString style = element.attribute("style");
+	if (style.isEmpty()) return;
+
+	fixStyleAttribute(element, style, "stroke-width");
+	fixStyleAttribute(element, style, "stroke");
+	fixStyleAttribute(element, style, "fill");
+	fixStyleAttribute(element, style, "fill-opacity");
+	fixStyleAttribute(element, style, "stroke-opacity");
+	fixStyleAttribute(element, style, "font-size");
+
+	if (style.trimmed().isEmpty()) {
+		element.removeAttribute("style");
+	}
+	else {
+		element.setAttribute("style", style);
+	}
+
+	//QString deleteMe;
+	//QTextStream stream(&deleteMe);
+	//stream << element;
+	//DebugDialog::debug(deleteMe);
+}
+
+void TextUtils::fixStyleAttribute(QDomElement & element, QString & style, const QString & attributeName)
+{
+    static const QString findStyle("%1[\\s]*:[\\s]*([^;]*)[;]?");
+
+	QString str = findStyle.arg(attributeName);
+	QRegExp sw(str);
+	if (sw.indexIn(style) >= 0) {
+		QString value = sw.cap(1);
+		style.remove(sw);
+		element.setAttribute(attributeName, value);
+	}
+}
\ No newline at end of file
