@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5917 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-03-17 10:19:17 +0100 (Sat, 17 Mar 2012) $
+$Revision: 6561 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-12 22:39:11 +0200 (Fri, 12 Oct 2012) $
 
 ********************************************************************/
 
@@ -32,11 +32,11 @@ $Date: 2012-03-17 10:19:17 +0100 (Sat, 17 Mar 2012) $
 #include <QSet>
 #include <QMatrix>
 #include <QTransform>
+#include <QXmlStreamReader>
 
 typedef QString (*CopyPinFunction)(int pin, const QString & argString, void * userData);
 typedef QString (*MultiplyPinFunction)(int pin, double increment, double value);
 
-
 class TextUtils
 {
 
@@ -51,6 +51,7 @@ public:
 	static double convertFromPowerPrefixU(QString & val, const QString & symbol);
 
 	static QString replaceTextElement(const QString & svg, const QString & id, const QString &  newValue);
+	static QByteArray replaceTextElement(const QByteArray & svg, const QString & id, const QString &  newValue);
 	static QString replaceTextElements(const QString & svg, const QHash<QString, QString> &);
     static bool squashElement(QDomDocument &, const QString & elementName, const QString & attName, const QRegExp & matchContent);
     static QString mergeSvg(const QString & svg1, const QString & svg2, const QString & id, bool flip);
@@ -62,7 +63,6 @@ public:
 	static bool isIllustratorDoc(const QDomDocument & doc);
 	static QString removeXMLEntities(QString svgContent);
 	static bool cleanSodipodi(QString &bytes);
-	static bool fixViewboxOrigin(QString &fileContent);
 	static bool fixPixelDimensionsIn(QString &fileContent);
 	static bool addCopper1(const QString & filename, QDomDocument & doc, const QString & srcAtt, const QString & destAtt);
 	static void setSVGTransform(QDomElement &, QMatrix &);
@@ -77,10 +77,11 @@ public:
 	static QMatrix transformStringToMatrix(const QString & transform);
     static QList<double> getTransformFloats(QDomElement & element);
 	static QList<double> getTransformFloats(const QString & transform);
-	static QString removeXMLNS(QString svgContent);
+	static QString svgNSOnly(QString svgContent);
+	static QString killXMLNS(QString svgContent);
 	static void gWrap(QDomDocument & domDocument, const QHash<QString, QString> & attributes);
-	static bool tspanRemove(QString &svg);
 	static void slamStrokeAndFill(QDomElement &, const QString & stroke, const QString & strokeWidth, const QString & fill);
+	static QString slamStrokeAndFill(const QString & svg, const QString & stroke, const QString & strokeWidth, const QString & fill);
 	static QString incrementTemplate(const QString & filename, int pins, double unitIncrement, MultiplyPinFunction, CopyPinFunction, void * userData);
 	static QString incrementTemplateString(const QString & templateString, int pins, double increment, MultiplyPinFunction, CopyPinFunction, void * userData);
 	static QString standardCopyPinFunction(int pin, const QString & argString, void * userData);
@@ -102,10 +103,20 @@ public:
 	static QString getMacAddress();
 	static QString expandAndFill(const QString & svg, const QString & color, double expandBy);
 	static void expandAndFillAux(QDomElement &, const QString & color, double expandBy);
-	
+    static bool writeUtf8(const QString & fileName, const QString & text);
+    static int getPinsAndSpacing(const QString & expectedFileName, QString & spacingString);
+	static QSizeF parseForWidthAndHeight(QXmlStreamReader &, QRectF & viewBox);
+	static QSizeF parseForWidthAndHeight(const QString & svg, QRectF & viewBox);
+	static QSizeF parseForWidthAndHeight(const QString & svg);
+    static void gornTree(QDomDocument &);
+    static bool elevateTransform(QDomElement &);
+    static bool fixMuch(QString &svg, bool fixStrokeWidth);
+	static bool fixInternalUnits(QString & svg);
+	static bool fixFonts(QString & svg, const QString & destFont);
+	static void fixStyleAttribute(QDomElement & element);
+
 public:
 	static const QRegExp FindWhitespace;
-	static const QRegExp SodipodiDetector;
 	static const QString SMDFlipSuffix;
 	static const QString MicroSymbol;
 	static const QString PowerPrefixesString;
@@ -118,11 +129,17 @@ public:
 	static const QString AdobeIllustratorIdentifier;
 
 protected:
-	static bool moveViewboxToTopLeftCorner(QDomElement &elem);
 	static bool pxToInches(QDomElement &elem, const QString &attrName, bool isIllustrator);
     static void squashNotElement(QDomElement & element, const QString & elementName, const QString & attName, const QRegExp & matchContent, bool & result);
 	static void initPowerPrefixes();
 	static QDomElement copyText(QDomDocument & svgDom, QDomElement & parent, QDomElement & text, const QString & defaultX, const QString & defaultY, bool copyAttributes);
+    static void gornTreeAux(QDomElement &);
+    static bool noPatternAux(QDomDocument & svgDom, const QString & tag);
+    static bool noUseAux(QDomDocument & svgDom);
+    static bool tspanRemoveAux(QDomDocument & svgDom);
+    static void fixStyleAttribute(QDomElement & element, QString & style, const QString & attributeName);
+    static bool fixStrokeWidth(QDomDocument & svgDoc);
+    static bool fixViewBox(QDomElement & root);
 };
 
 #endif
