@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -13,30 +13,31 @@ but WITHOUT ANY WARRANTY; without even the implied warranty ofswap
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.		
 
-You should have received a copy of the GNU General Public License
+You should have received a copy of the GNU General Public License           
 along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.	
 	 			
 *********************************************************************
-												
-$Revision: 5970 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-04-10 19:16:12 +0200 (Tue, 10 Apr 2012) $
+							                    					
+$Revision: 6551 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-10-12 11:08:21 +0200 (Fri, 12 Oct 2012) $
 
 ********************************************************************/
-										
-#include "version.h"											
+					   					
+#include "version.h"            										
 											
 #include <QString>
 #include <QStringList>			
 			
-#include "../debugdialog.h"					
+#include "../debugdialog.h"		                	                
+
 	
 QString Version::m_majorVersion("0");				
 QString Version::m_minorVersion("7");
-QString Version::m_minorSubVersion("4");
+QString Version::m_minorSubVersion("10");
 QString Version::m_modifier("b");
-QString Version::m_svnRevision("$Revision: 5970 $:");
-QString Version::m_svnDate("$Date: 2012-04-10 19:16:12 +0200 (Tue, 10 Apr 2012) $");
+QString Version::m_svnRevision("$Revision: 6551 $:");
+QString Version::m_svnDate("$Date: 2012-10-12 11:08:21 +0200 (Fri, 12 Oct 2012) $");
 QString Version::m_revision;
 QString Version::m_date;
 QString Version::m_shortDate;
