@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5762 $:
+$Revision: 6409 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-01-19 23:04:44 +0100 (Thu, 19 Jan 2012) $
+$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 ********************************************************************/
 
@@ -32,7 +32,12 @@ $Date: 2012-01-19 23:04:44 +0100 (Thu, 19 Jan 2012) $
 #include <QHash>
 #include <QMultiHash>
 
-#include "utils/misc.h"
+struct NamePair {
+    QString xmlName;
+    QString displayName;
+
+    NamePair(QString xml, QString display);
+};
 
 class ViewLayer : public QObject
 {
@@ -92,16 +97,27 @@ public:
 		UnknownSpec
 	};
 
+   enum ViewIdentifier {
+    	IconView,
+    	BreadboardView,
+    	SchematicView,
+    	PCBView,
+    	AllViews,
+		UnknownView,
+    	ViewCount
+   	};
+
 public:
 	static const QString HolesColor;
 	static const QString Copper0Color;
 	static const QString Copper1Color;
 	static const QString Silkscreen1Color;
 	static const QString Silkscreen0Color;
+	static const QString BoardColor;
 
 protected:
 	static double zIncrement;
-	static QHash<ViewLayerID, StringPair *> names;
+	static QHash<ViewLayerID, NamePair *> names;
 	static QMultiHash<ViewLayerID, ViewLayerID> alternatives;
 	static QMultiHash<ViewLayerID, ViewLayerID> unconnectables;
 	static QHash<QString, ViewLayerID> xmlHash;
@@ -146,6 +162,13 @@ public:
 	static bool isCopperLayer(ViewLayer::ViewLayerID);
 	static bool isNonCopperLayer(ViewLayer::ViewLayerID viewLayerID);  // for pcb view layers only
 
+    static QString & viewIdentifierName(ViewLayer::ViewIdentifier);
+	static QString & viewIdentifierXmlName(ViewLayer::ViewIdentifier);
+	static QString & viewIdentifierNaturalName(ViewLayer::ViewIdentifier);
+	static ViewIdentifier idFromXmlName(const QString & name);
+	static const QList<ViewLayer::ViewLayerID> & layersForView(ViewLayer::ViewIdentifier);
+	static bool viewHasLayer(ViewIdentifier, ViewLayer::ViewLayerID);
+
 
 protected:
 	bool m_visible;
@@ -158,6 +181,8 @@ protected:
 	bool m_active;
 	bool m_includeChildLayers;
 
+    static QHash <ViewIdentifier, class NameTriple * > ViewIdentifierNames;
+
 };
 
 typedef QHash<ViewLayer::ViewLayerID, ViewLayer *> LayerHash;
