@@ -11,7 +11,7 @@ fi
 compile_folder="build-$arch_aux"
 svn export http://fritzing.googlecode.com/svn/trunk/fritzing $compile_folder
 
-# get rid of user folder contents
+# get rid of user folder contents and bins
 current_dir=$(pwd)
 cd $compile_folder/parts/user
 rm -rf *
@@ -23,6 +23,10 @@ cd ../pcb
 rm -rf *
 cd ../icon
 rm -rf *
+cd $current_dir
+cd $compile_folder/bins/more
+rm -rf sparkfun-*.fzb
+
 cd $current_dir
 
 #let's define some variables that we'll need to in the future
@@ -33,6 +37,15 @@ if [ "$arch_aux" == 'x86_64' ] ; then
 	# only creates the source tarball, when running on the 64 platform
 	tarball_folder="fritzing-$relname.source"
 	cp -rf $compile_folder $tarball_folder
+	cp -rf $compile_folder/pdb/contrib $tarball_folder/parts
+	cp -rf $compile_folder/pdb/core $tarball_folder/parts
+	cp -rf $compile_folder/pdb/obsolete $tarball_folder/parts
+	#cp -rf $compile_folder/pdb/user $tarball_folder/parts
+	rm -rf $tarball_folder/SetupAPI.Lib
+	rm -rf $tarball_folder/deploy_fritzing.bat
+	rm -rf $tarball_folder/FritzingInfo.plist
+	rm -rf $tarball_folder/parts/parts.db
+	rm -rf $tarball_folder/pdb
 	rm -rf $tarball_folder/datasheets
 	rm -rf $tarball_folder/not_quite_ready
 	rm -rf $tarball_folder/part-gen-scripts
@@ -43,6 +56,7 @@ if [ "$arch_aux" == 'x86_64' ] ; then
 	echo "making source tarball: $tarball_folder"
 	tar -cjf ./$tarball_folder.tar.bz2 $tarball_folder
 	rm -rf $tarball_folder
+	echo "done with source tarball: $tarball_folder"
 
 	else arch='i386'
 fi
@@ -51,7 +65,7 @@ cd $compile_folder
 #QT_HOME="/home/jonathan/qtsdk-2010.05/qt"
 #QT_HOME="/usr"
 #QT_HOME="/home/jonathan/QtSDK/Desktop/Qt/473/gcc"
-QT_HOME="/usr/local/Trolltech/Qt-4.8.0"
+QT_HOME="/usr/local/Trolltech/Qt-4.8.3"
 
 
 $QT_HOME/bin/qmake CONFIG+=release -unix
@@ -63,7 +77,7 @@ echo "making release folder: $release_folder"
 mkdir ../$release_folder
 
 echo "copying release files"
-cp -rf bins/ parts/ sketches/ Fritzing Fritzing.sh README.txt LICENSE.GPL2 LICENSE.GPL3 ../$release_folder/
+cp -rf bins/ parts/ sketches/ help/ pdb/ Fritzing Fritzing.sh README.txt LICENSE.GPL2 LICENSE.GPL3 ../$release_folder/
 cd ../$release_folder
 
 echo "making library folders"
